Class: Aws::Deadline::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Deadline::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-deadline/client.rb,
sig/client.rbs
Overview
An API client for Deadline. To construct a client, you need to configure a :region and :credentials.
client = Aws::Deadline::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociateMemberToFarmResponseSuccess, _AssociateMemberToFleetResponseSuccess, _AssociateMemberToJobResponseSuccess, _AssociateMemberToQueueResponseSuccess, _AssumeFleetRoleForReadResponseSuccess, _AssumeFleetRoleForWorkerResponseSuccess, _AssumeQueueRoleForReadResponseSuccess, _AssumeQueueRoleForUserResponseSuccess, _AssumeQueueRoleForWorkerResponseSuccess, _BatchGetJobEntityResponseSuccess, _BatchGetJobResponseSuccess, _BatchGetSessionActionResponseSuccess, _BatchGetSessionResponseSuccess, _BatchGetStepResponseSuccess, _BatchGetTaskResponseSuccess, _BatchGetWorkerResponseSuccess, _BatchUpdateJobResponseSuccess, _BatchUpdateTaskResponseSuccess, _CopyJobTemplateResponseSuccess, _CreateBudgetResponseSuccess, _CreateFarmResponseSuccess, _CreateFleetResponseSuccess, _CreateJobResponseSuccess, _CreateLicenseEndpointResponseSuccess, _CreateLimitResponseSuccess, _CreateMonitorResponseSuccess, _CreateQueueEnvironmentResponseSuccess, _CreateQueueFleetAssociationResponseSuccess, _CreateQueueLimitAssociationResponseSuccess, _CreateQueueResponseSuccess, _CreateStorageProfileResponseSuccess, _CreateWorkerResponseSuccess, _DeleteBudgetResponseSuccess, _DeleteFarmResponseSuccess, _DeleteFleetResponseSuccess, _DeleteLicenseEndpointResponseSuccess, _DeleteLimitResponseSuccess, _DeleteMeteredProductResponseSuccess, _DeleteMonitorResponseSuccess, _DeleteQueueEnvironmentResponseSuccess, _DeleteQueueFleetAssociationResponseSuccess, _DeleteQueueLimitAssociationResponseSuccess, _DeleteQueueResponseSuccess, _DeleteStorageProfileResponseSuccess, _DeleteVolumeResponseSuccess, _DeleteWorkerResponseSuccess, _DisassociateMemberFromFarmResponseSuccess, _DisassociateMemberFromFleetResponseSuccess, _DisassociateMemberFromJobResponseSuccess, _DisassociateMemberFromQueueResponseSuccess, _GetBudgetResponseSuccess, _GetFarmResponseSuccess, _GetFleetResponseSuccess, _GetJobResponseSuccess, _GetLicenseEndpointResponseSuccess, _GetLimitResponseSuccess, _GetMonitorResponseSuccess, _GetMonitorSettingsResponseSuccess, _GetQueueEnvironmentResponseSuccess, _GetQueueFleetAssociationResponseSuccess, _GetQueueLimitAssociationResponseSuccess, _GetQueueResponseSuccess, _GetSessionActionResponseSuccess, _GetSessionResponseSuccess, _GetSessionsStatisticsAggregationResponseSuccess, _GetStepResponseSuccess, _GetStorageProfileForQueueResponseSuccess, _GetStorageProfileResponseSuccess, _GetTaskResponseSuccess, _GetVolumeResponseSuccess, _GetWorkerResponseSuccess, _ListAvailableMeteredProductsResponseSuccess, _ListBudgetsResponseSuccess, _ListFarmMembersResponseSuccess, _ListFarmsResponseSuccess, _ListFleetMembersResponseSuccess, _ListFleetsResponseSuccess, _ListJobMembersResponseSuccess, _ListJobParameterDefinitionsResponseSuccess, _ListJobsResponseSuccess, _ListLicenseEndpointsResponseSuccess, _ListLimitsResponseSuccess, _ListMeteredProductsResponseSuccess, _ListMonitorsResponseSuccess, _ListQueueEnvironmentsResponseSuccess, _ListQueueFleetAssociationsResponseSuccess, _ListQueueLimitAssociationsResponseSuccess, _ListQueueMembersResponseSuccess, _ListQueuesResponseSuccess, _ListSessionActionsResponseSuccess, _ListSessionsForWorkerResponseSuccess, _ListSessionsResponseSuccess, _ListStepConsumersResponseSuccess, _ListStepDependenciesResponseSuccess, _ListStepsResponseSuccess, _ListStorageProfilesForQueueResponseSuccess, _ListStorageProfilesResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTasksResponseSuccess, _ListVolumesResponseSuccess, _ListWorkersResponseSuccess, _PutMeteredProductResponseSuccess, _SearchJobsResponseSuccess, _SearchStepsResponseSuccess, _SearchTasksResponseSuccess, _SearchWorkersResponseSuccess, _StartSessionsStatisticsAggregationResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateBudgetResponseSuccess, _UpdateFarmResponseSuccess, _UpdateFleetResponseSuccess, _UpdateJobResponseSuccess, _UpdateLimitResponseSuccess, _UpdateMonitorResponseSuccess, _UpdateMonitorSettingsResponseSuccess, _UpdateQueueEnvironmentResponseSuccess, _UpdateQueueFleetAssociationResponseSuccess, _UpdateQueueLimitAssociationResponseSuccess, _UpdateQueueResponseSuccess, _UpdateSessionResponseSuccess, _UpdateStepResponseSuccess, _UpdateStorageProfileResponseSuccess, _UpdateTaskResponseSuccess, _UpdateWorkerResponseSuccess, _UpdateWorkerScheduleResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_member_to_farm(params = {}) ⇒ Struct
Assigns a farm membership level to a member.
-
#associate_member_to_fleet(params = {}) ⇒ Struct
Assigns a fleet membership level to a member.
-
#associate_member_to_job(params = {}) ⇒ Struct
Assigns a job membership level to a member.
-
#associate_member_to_queue(params = {}) ⇒ Struct
Assigns a queue membership level to a member.
-
#assume_fleet_role_for_read(params = {}) ⇒ Types::AssumeFleetRoleForReadResponse
Get Amazon Web Services credentials from the fleet role.
-
#assume_fleet_role_for_worker(params = {}) ⇒ Types::AssumeFleetRoleForWorkerResponse
Get credentials from the fleet role for a worker.
-
#assume_queue_role_for_read(params = {}) ⇒ Types::AssumeQueueRoleForReadResponse
Gets Amazon Web Services credentials from the queue role.
-
#assume_queue_role_for_user(params = {}) ⇒ Types::AssumeQueueRoleForUserResponse
Allows a user to assume a role for a queue.
-
#assume_queue_role_for_worker(params = {}) ⇒ Types::AssumeQueueRoleForWorkerResponse
Allows a worker to assume a queue role.
-
#batch_get_job(params = {}) ⇒ Types::BatchGetJobResponse
Retrieves multiple jobs in a single request.
-
#batch_get_job_entity(params = {}) ⇒ Types::BatchGetJobEntityResponse
Get batched job details for a worker.
-
#batch_get_session(params = {}) ⇒ Types::BatchGetSessionResponse
Retrieves multiple sessions in a single request.
-
#batch_get_session_action(params = {}) ⇒ Types::BatchGetSessionActionResponse
Retrieves multiple session actions in a single request.
-
#batch_get_step(params = {}) ⇒ Types::BatchGetStepResponse
Retrieves multiple steps in a single request.
-
#batch_get_task(params = {}) ⇒ Types::BatchGetTaskResponse
Retrieves multiple tasks in a single request.
-
#batch_get_worker(params = {}) ⇒ Types::BatchGetWorkerResponse
Retrieves multiple workers in a single request.
-
#batch_update_job(params = {}) ⇒ Types::BatchUpdateJobResponse
Updates multiple jobs in a single request.
-
#batch_update_task(params = {}) ⇒ Types::BatchUpdateTaskResponse
Updates multiple tasks in a single request.
-
#copy_job_template(params = {}) ⇒ Types::CopyJobTemplateResponse
Copies a job template to an Amazon S3 bucket.
-
#create_budget(params = {}) ⇒ Types::CreateBudgetResponse
Creates a budget to set spending thresholds for your rendering activity.
-
#create_farm(params = {}) ⇒ Types::CreateFarmResponse
Creates a farm to allow space for queues and fleets.
-
#create_fleet(params = {}) ⇒ Types::CreateFleetResponse
Creates a fleet.
-
#create_job(params = {}) ⇒ Types::CreateJobResponse
Creates a job.
-
#create_license_endpoint(params = {}) ⇒ Types::CreateLicenseEndpointResponse
Creates a license endpoint to integrate your various licensed software used for rendering on Deadline Cloud.
-
#create_limit(params = {}) ⇒ Types::CreateLimitResponse
Creates a limit that manages the distribution of shared resources, such as floating licenses.
-
#create_monitor(params = {}) ⇒ Types::CreateMonitorResponse
Creates an Amazon Web Services Deadline Cloud monitor that you can use to view your farms, queues, and fleets.
-
#create_queue(params = {}) ⇒ Types::CreateQueueResponse
Creates a queue to coordinate the order in which jobs run on a farm.
-
#create_queue_environment(params = {}) ⇒ Types::CreateQueueEnvironmentResponse
Creates an environment for a queue that defines how jobs in the queue run.
-
#create_queue_fleet_association(params = {}) ⇒ Struct
Creates an association between a queue and a fleet.
-
#create_queue_limit_association(params = {}) ⇒ Struct
Associates a limit with a particular queue.
-
#create_storage_profile(params = {}) ⇒ Types::CreateStorageProfileResponse
Creates a storage profile that specifies the operating system, file type, and file location of resources used on a farm.
-
#create_worker(params = {}) ⇒ Types::CreateWorkerResponse
Creates a worker.
-
#delete_budget(params = {}) ⇒ Struct
Deletes a budget.
-
#delete_farm(params = {}) ⇒ Struct
Deletes a farm.
-
#delete_fleet(params = {}) ⇒ Struct
Deletes a fleet.
-
#delete_license_endpoint(params = {}) ⇒ Struct
Deletes a license endpoint.
-
#delete_limit(params = {}) ⇒ Struct
Removes a limit from the specified farm.
-
#delete_metered_product(params = {}) ⇒ Struct
Deletes a metered product.
-
#delete_monitor(params = {}) ⇒ Struct
Removes a Deadline Cloud monitor.
-
#delete_queue(params = {}) ⇒ Struct
Deletes a queue.
-
#delete_queue_environment(params = {}) ⇒ Struct
Deletes a queue environment.
-
#delete_queue_fleet_association(params = {}) ⇒ Struct
Deletes a queue-fleet association.
-
#delete_queue_limit_association(params = {}) ⇒ Struct
Removes the association between a queue and a limit.
-
#delete_storage_profile(params = {}) ⇒ Struct
Deletes a storage profile.
-
#delete_volume(params = {}) ⇒ Struct
Deletes a persistent volume.
-
#delete_worker(params = {}) ⇒ Struct
Deletes a worker.
-
#disassociate_member_from_farm(params = {}) ⇒ Struct
Disassociates a member from a farm.
-
#disassociate_member_from_fleet(params = {}) ⇒ Struct
Disassociates a member from a fleet.
-
#disassociate_member_from_job(params = {}) ⇒ Struct
Disassociates a member from a job.
-
#disassociate_member_from_queue(params = {}) ⇒ Struct
Disassociates a member from a queue.
-
#get_budget(params = {}) ⇒ Types::GetBudgetResponse
Get a budget.
-
#get_farm(params = {}) ⇒ Types::GetFarmResponse
Get a farm.
-
#get_fleet(params = {}) ⇒ Types::GetFleetResponse
Get a fleet.
-
#get_job(params = {}) ⇒ Types::GetJobResponse
Gets a Deadline Cloud job.
-
#get_license_endpoint(params = {}) ⇒ Types::GetLicenseEndpointResponse
Gets a licence endpoint.
-
#get_limit(params = {}) ⇒ Types::GetLimitResponse
Gets information about a specific limit.
-
#get_monitor(params = {}) ⇒ Types::GetMonitorResponse
Gets information about the specified monitor.
-
#get_monitor_settings(params = {}) ⇒ Types::GetMonitorSettingsResponse
Gets the settings for a Deadline Cloud monitor.
-
#get_queue(params = {}) ⇒ Types::GetQueueResponse
Gets a queue.
-
#get_queue_environment(params = {}) ⇒ Types::GetQueueEnvironmentResponse
Gets a queue environment.
-
#get_queue_fleet_association(params = {}) ⇒ Types::GetQueueFleetAssociationResponse
Gets a queue-fleet association.
-
#get_queue_limit_association(params = {}) ⇒ Types::GetQueueLimitAssociationResponse
Gets information about a specific association between a queue and a limit.
-
#get_session(params = {}) ⇒ Types::GetSessionResponse
Gets a session.
-
#get_session_action(params = {}) ⇒ Types::GetSessionActionResponse
Gets a session action for the job.
-
#get_sessions_statistics_aggregation(params = {}) ⇒ Types::GetSessionsStatisticsAggregationResponse
Gets a set of statistics for queues or farms.
-
#get_step(params = {}) ⇒ Types::GetStepResponse
Gets a step.
-
#get_storage_profile(params = {}) ⇒ Types::GetStorageProfileResponse
Gets a storage profile.
-
#get_storage_profile_for_queue(params = {}) ⇒ Types::GetStorageProfileForQueueResponse
Gets a storage profile for a queue.
-
#get_task(params = {}) ⇒ Types::GetTaskResponse
Gets a task.
-
#get_volume(params = {}) ⇒ Types::GetVolumeResponse
Gets a persistent volume.
-
#get_worker(params = {}) ⇒ Types::GetWorkerResponse
Gets a worker.
-
#list_available_metered_products(params = {}) ⇒ Types::ListAvailableMeteredProductsResponse
A list of the available metered products.
-
#list_budgets(params = {}) ⇒ Types::ListBudgetsResponse
A list of budgets in a farm.
-
#list_farm_members(params = {}) ⇒ Types::ListFarmMembersResponse
Lists the members of a farm.
-
#list_farms(params = {}) ⇒ Types::ListFarmsResponse
Lists farms.
-
#list_fleet_members(params = {}) ⇒ Types::ListFleetMembersResponse
Lists fleet members.
-
#list_fleets(params = {}) ⇒ Types::ListFleetsResponse
Lists fleets.
-
#list_job_members(params = {}) ⇒ Types::ListJobMembersResponse
Lists members on a job.
-
#list_job_parameter_definitions(params = {}) ⇒ Types::ListJobParameterDefinitionsResponse
Lists parameter definitions of a job.
-
#list_jobs(params = {}) ⇒ Types::ListJobsResponse
Lists jobs.
-
#list_license_endpoints(params = {}) ⇒ Types::ListLicenseEndpointsResponse
Lists license endpoints.
-
#list_limits(params = {}) ⇒ Types::ListLimitsResponse
Gets a list of limits defined in the specified farm.
-
#list_metered_products(params = {}) ⇒ Types::ListMeteredProductsResponse
Lists metered products.
-
#list_monitors(params = {}) ⇒ Types::ListMonitorsResponse
Gets a list of your monitors in Deadline Cloud.
-
#list_queue_environments(params = {}) ⇒ Types::ListQueueEnvironmentsResponse
Lists queue environments.
-
#list_queue_fleet_associations(params = {}) ⇒ Types::ListQueueFleetAssociationsResponse
Lists queue-fleet associations.
-
#list_queue_limit_associations(params = {}) ⇒ Types::ListQueueLimitAssociationsResponse
Gets a list of the associations between queues and limits defined in a farm.
-
#list_queue_members(params = {}) ⇒ Types::ListQueueMembersResponse
Lists the members in a queue.
-
#list_queues(params = {}) ⇒ Types::ListQueuesResponse
Lists queues.
-
#list_session_actions(params = {}) ⇒ Types::ListSessionActionsResponse
Lists session actions.
-
#list_sessions(params = {}) ⇒ Types::ListSessionsResponse
Lists sessions.
-
#list_sessions_for_worker(params = {}) ⇒ Types::ListSessionsForWorkerResponse
Lists sessions for a worker.
-
#list_step_consumers(params = {}) ⇒ Types::ListStepConsumersResponse
Lists step consumers.
-
#list_step_dependencies(params = {}) ⇒ Types::ListStepDependenciesResponse
Lists the dependencies for a step.
-
#list_steps(params = {}) ⇒ Types::ListStepsResponse
Lists steps for a job.
-
#list_storage_profiles(params = {}) ⇒ Types::ListStorageProfilesResponse
Lists storage profiles.
-
#list_storage_profiles_for_queue(params = {}) ⇒ Types::ListStorageProfilesForQueueResponse
Lists storage profiles for a queue.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags for a resource.
-
#list_tasks(params = {}) ⇒ Types::ListTasksResponse
Lists tasks for a job.
-
#list_volumes(params = {}) ⇒ Types::ListVolumesResponse
Lists the persistent volumes in a fleet.
-
#list_workers(params = {}) ⇒ Types::ListWorkersResponse
Lists workers.
-
#put_metered_product(params = {}) ⇒ Struct
Adds a metered product.
-
#search_jobs(params = {}) ⇒ Types::SearchJobsResponse
Searches for jobs.
-
#search_steps(params = {}) ⇒ Types::SearchStepsResponse
Searches for steps.
-
#search_tasks(params = {}) ⇒ Types::SearchTasksResponse
Searches for tasks.
-
#search_workers(params = {}) ⇒ Types::SearchWorkersResponse
Searches for workers.
-
#start_sessions_statistics_aggregation(params = {}) ⇒ Types::StartSessionsStatisticsAggregationResponse
Starts an asynchronous request for getting aggregated statistics about queues and farms.
-
#tag_resource(params = {}) ⇒ Struct
Tags a resource using the resource's ARN and desired tags.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag from a resource using the resource's ARN and tag to remove.
-
#update_budget(params = {}) ⇒ Struct
Updates a budget that sets spending thresholds for rendering activity.
-
#update_farm(params = {}) ⇒ Struct
Updates a farm.
-
#update_fleet(params = {}) ⇒ Struct
Updates a fleet.
-
#update_job(params = {}) ⇒ Struct
Updates a job.
-
#update_limit(params = {}) ⇒ Struct
Updates the properties of the specified limit.
-
#update_monitor(params = {}) ⇒ Struct
Modifies the settings for a Deadline Cloud monitor.
-
#update_monitor_settings(params = {}) ⇒ Struct
Updates the settings for a Deadline Cloud monitor.
-
#update_queue(params = {}) ⇒ Struct
Updates a queue.
-
#update_queue_environment(params = {}) ⇒ Struct
Updates the queue environment.
-
#update_queue_fleet_association(params = {}) ⇒ Struct
Updates a queue-fleet association.
-
#update_queue_limit_association(params = {}) ⇒ Struct
Updates the status of the queue.
-
#update_session(params = {}) ⇒ Struct
Updates a session.
-
#update_step(params = {}) ⇒ Struct
Updates a step.
-
#update_storage_profile(params = {}) ⇒ Struct
Updates a storage profile.
-
#update_task(params = {}) ⇒ Struct
Updates a task.
-
#update_worker(params = {}) ⇒ Types::UpdateWorkerResponse
Updates a worker.
-
#update_worker_schedule(params = {}) ⇒ Types::UpdateWorkerScheduleResponse
Updates the schedule for a worker.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
-
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-deadline/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
8509 8510 8511 |
# File 'lib/aws-sdk-deadline/client.rb', line 8509 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
8512 8513 8514 |
# File 'lib/aws-sdk-deadline/client.rb', line 8512 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_member_to_farm(params = {}) ⇒ Struct
Assigns a farm membership level to a member.
85 |
# File 'sig/client.rbs', line 85
def associate_member_to_farm: (
|
#associate_member_to_fleet(params = {}) ⇒ Struct
Assigns a fleet membership level to a member.
99 |
# File 'sig/client.rbs', line 99
def associate_member_to_fleet: (
|
#associate_member_to_job(params = {}) ⇒ Struct
Assigns a job membership level to a member
114 |
# File 'sig/client.rbs', line 114
def associate_member_to_job: (
|
#associate_member_to_queue(params = {}) ⇒ Struct
Assigns a queue membership level to a member
130 |
# File 'sig/client.rbs', line 130
def associate_member_to_queue: (
|
#assume_fleet_role_for_read(params = {}) ⇒ Types::AssumeFleetRoleForReadResponse
Get Amazon Web Services credentials from the fleet role. The IAM permissions of the credentials are scoped down to have read-only access.
146 |
# File 'sig/client.rbs', line 146
def assume_fleet_role_for_read: (
|
#assume_fleet_role_for_worker(params = {}) ⇒ Types::AssumeFleetRoleForWorkerResponse
Get credentials from the fleet role for a worker.
157 |
# File 'sig/client.rbs', line 157
def assume_fleet_role_for_worker: (
|
#assume_queue_role_for_read(params = {}) ⇒ Types::AssumeQueueRoleForReadResponse
Gets Amazon Web Services credentials from the queue role. The IAM permissions of the credentials are scoped down to have read-only access.
169 |
# File 'sig/client.rbs', line 169
def assume_queue_role_for_read: (
|
#assume_queue_role_for_user(params = {}) ⇒ Types::AssumeQueueRoleForUserResponse
Allows a user to assume a role for a queue.
180 |
# File 'sig/client.rbs', line 180
def assume_queue_role_for_user: (
|
#assume_queue_role_for_worker(params = {}) ⇒ Types::AssumeQueueRoleForWorkerResponse
Allows a worker to assume a queue role.
191 |
# File 'sig/client.rbs', line 191
def assume_queue_role_for_worker: (
|
#batch_get_job(params = {}) ⇒ Types::BatchGetJobResponse
Retrieves multiple jobs in a single request. This is a batch version
of the GetJob API.
The result of getting each job is reported individually in the response. Because the batch request can result in a combination of successful and unsuccessful actions, you should check for batch errors even when the call returns an HTTP status code of 200.
205 |
# File 'sig/client.rbs', line 205
def batch_get_job: (
|
#batch_get_job_entity(params = {}) ⇒ Types::BatchGetJobEntityResponse
Get batched job details for a worker.
222 |
# File 'sig/client.rbs', line 222
def batch_get_job_entity: (
|
#batch_get_session(params = {}) ⇒ Types::BatchGetSessionResponse
Retrieves multiple sessions in a single request. This is a batch
version of the GetSession API.
The result of getting each session is reported individually in the response. Because the batch request can result in a combination of successful and unsuccessful actions, you should check for batch errors even when the call returns an HTTP status code of 200.
253 |
# File 'sig/client.rbs', line 253
def batch_get_session: (
|
#batch_get_session_action(params = {}) ⇒ Types::BatchGetSessionActionResponse
Retrieves multiple session actions in a single request. This is a
batch version of the GetSessionAction API.
The result of getting each session action is reported individually in the response. Because the batch request can result in a combination of successful and unsuccessful actions, you should check for batch errors even when the call returns an HTTP status code of 200.
271 |
# File 'sig/client.rbs', line 271
def batch_get_session_action: (
|
#batch_get_step(params = {}) ⇒ Types::BatchGetStepResponse
Retrieves multiple steps in a single request. This is a batch version
of the GetStep API.
The result of getting each step is reported individually in the response. Because the batch request can result in a combination of successful and unsuccessful actions, you should check for batch errors even when the call returns an HTTP status code of 200.
289 |
# File 'sig/client.rbs', line 289
def batch_get_step: (
|
#batch_get_task(params = {}) ⇒ Types::BatchGetTaskResponse
Retrieves multiple tasks in a single request. This is a batch version
of the GetTask API.
The result of getting each task is reported individually in the response. Because the batch request can result in a combination of successful and unsuccessful actions, you should check for batch errors even when the call returns an HTTP status code of 200.
307 |
# File 'sig/client.rbs', line 307
def batch_get_task: (
|
#batch_get_worker(params = {}) ⇒ Types::BatchGetWorkerResponse
Retrieves multiple workers in a single request. This is a batch
version of the GetWorker API.
The result of getting each worker is reported individually in the response. Because the batch request can result in a combination of successful and unsuccessful actions, you should check for batch errors even when the call returns an HTTP status code of 200.
326 |
# File 'sig/client.rbs', line 326
def batch_get_worker: (
|
#batch_update_job(params = {}) ⇒ Types::BatchUpdateJobResponse
Updates multiple jobs in a single request. This is a batch version of
the UpdateJob API.
The result of updating each job is reported individually in the response. Because the batch request can result in a combination of successful and unsuccessful actions, you should check for batch errors even when the call returns an HTTP status code of 200.
When you change the status of a job to ARCHIVED, the job can't be
scheduled or archived.
An archived job and its steps and tasks are deleted after 120 days. The job can't be recovered.
342 |
# File 'sig/client.rbs', line 342
def batch_update_job: (
|
#batch_update_task(params = {}) ⇒ Types::BatchUpdateTaskResponse
Updates multiple tasks in a single request. This is a batch version of
the UpdateTask API.
The result of updating each task is reported individually in the response. Because the batch request can result in a combination of successful and unsuccessful actions, you should check for batch errors even when the call returns an HTTP status code of 200.
367 |
# File 'sig/client.rbs', line 367
def batch_update_task: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
8351 8352 8353 8354 8355 8356 8357 8358 8359 8360 8361 8362 8363 8364 8365 8366 8367 |
# File 'lib/aws-sdk-deadline/client.rb', line 8351 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Deadline') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-deadline' context[:gem_version] = '1.59.0' Seahorse::Client::Request.new(handlers, context) end |
#copy_job_template(params = {}) ⇒ Types::CopyJobTemplateResponse
Copies a job template to an Amazon S3 bucket.
387 |
# File 'sig/client.rbs', line 387
def copy_job_template: (
|
#create_budget(params = {}) ⇒ Types::CreateBudgetResponse
Creates a budget to set spending thresholds for your rendering activity.
403 |
# File 'sig/client.rbs', line 403
def create_budget: (
|
#create_farm(params = {}) ⇒ Types::CreateFarmResponse
Creates a farm to allow space for queues and fleets. Farms are the space where the components of your renders gather and are pieced together in the cloud. Farms contain budgets and allow you to enforce permissions. Deadline Cloud farms are a useful container for large projects.
434 |
# File 'sig/client.rbs', line 434
def create_farm: (
|
#create_fleet(params = {}) ⇒ Types::CreateFleetResponse
Creates a fleet. Fleets gather information relating to compute, or capacity, for renders within your farms. You can choose to manage your own capacity or opt to have fleets fully managed by Deadline Cloud.
449 |
# File 'sig/client.rbs', line 449
def create_fleet: (
|
#create_job(params = {}) ⇒ Types::CreateJobResponse
Creates a job. A job is a set of instructions that Deadline Cloud uses to schedule and run work on available workers. For more information, see Deadline Cloud jobs.
471 |
# File 'sig/client.rbs', line 471
def create_job: (
|
#create_license_endpoint(params = {}) ⇒ Types::CreateLicenseEndpointResponse
Creates a license endpoint to integrate your various licensed software used for rendering on Deadline Cloud.
514 |
# File 'sig/client.rbs', line 514
def create_license_endpoint: (
|
#create_limit(params = {}) ⇒ Types::CreateLimitResponse
Creates a limit that manages the distribution of shared resources, such as floating licenses. A limit can throttle work assignments, help manage workloads, and track current usage. Before you use a limit, you must associate the limit with one or more queues.
You must add the amountRequirementName to a step in a job template
to declare the limit requirement.
528 |
# File 'sig/client.rbs', line 528
def create_limit: (
|
#create_monitor(params = {}) ⇒ Types::CreateMonitorResponse
Creates an Amazon Web Services Deadline Cloud monitor that you can use to view your farms, queues, and fleets. After you submit a job, you can track the progress of the tasks and steps that make up the job, and then download the job's results.
544 |
# File 'sig/client.rbs', line 544
def create_monitor: (
|
#create_queue(params = {}) ⇒ Types::CreateQueueResponse
Creates a queue to coordinate the order in which jobs run on a farm. A queue can also specify where to pull resources and indicate where to output completed jobs.
560 |
# File 'sig/client.rbs', line 560
def create_queue: (
|
#create_queue_environment(params = {}) ⇒ Types::CreateQueueEnvironmentResponse
Creates an environment for a queue that defines how jobs in the queue run.
584 |
# File 'sig/client.rbs', line 584
def create_queue_environment: (
|
#create_queue_fleet_association(params = {}) ⇒ Struct
Creates an association between a queue and a fleet.
598 |
# File 'sig/client.rbs', line 598
def create_queue_fleet_association: (
|
#create_queue_limit_association(params = {}) ⇒ Struct
Associates a limit with a particular queue. After the limit is
associated, all workers for jobs that specify the limit associated
with the queue are subject to the limit. You can't associate two
limits with the same amountRequirementName to the same queue.
609 |
# File 'sig/client.rbs', line 609
def create_queue_limit_association: (
|
#create_storage_profile(params = {}) ⇒ Types::CreateStorageProfileResponse
Creates a storage profile that specifies the operating system, file type, and file location of resources used on a farm.
621 |
# File 'sig/client.rbs', line 621
def create_storage_profile: (
|
#create_worker(params = {}) ⇒ Types::CreateWorkerResponse
Creates a worker. A worker tells your instance how much processing power (vCPU), and memory (GiB) you’ll need to assemble the digital assets held within a particular instance. You can specify certain instance types to use, or let the worker know which instances types to exclude.
Deadline Cloud limits the number of workers to less than or equal to
the fleet's maximum worker count. The service maintains eventual
consistency for the worker count. If you make multiple rapid calls to
CreateWorker before the field updates, you might exceed your
fleet's maximum worker count. For example, if your maxWorkerCount
is 10 and you currently have 9 workers, making two quick
CreateWorker calls might successfully create 2 workers instead of 1,
resulting in 11 total workers.
641 |
# File 'sig/client.rbs', line 641
def create_worker: (
|
#delete_budget(params = {}) ⇒ Struct
Deletes a budget.
660 |
# File 'sig/client.rbs', line 660
def delete_budget: (
|
#delete_farm(params = {}) ⇒ Struct
Deletes a farm.
670 |
# File 'sig/client.rbs', line 670
def delete_farm: (
|
#delete_fleet(params = {}) ⇒ Struct
Deletes a fleet.
679 |
# File 'sig/client.rbs', line 679
def delete_fleet: (
|
#delete_license_endpoint(params = {}) ⇒ Struct
Deletes a license endpoint.
690 |
# File 'sig/client.rbs', line 690
def delete_license_endpoint: (
|
#delete_limit(params = {}) ⇒ Struct
Removes a limit from the specified farm. Before you delete a limit you
must use the DeleteQueueLimitAssociation operation to remove the
association with any queues.
699 |
# File 'sig/client.rbs', line 699
def delete_limit: (
|
#delete_metered_product(params = {}) ⇒ Struct
Deletes a metered product.
709 |
# File 'sig/client.rbs', line 709
def delete_metered_product: (
|
#delete_monitor(params = {}) ⇒ Struct
Removes a Deadline Cloud monitor. After you delete a monitor, you can create a new one and attach farms to the monitor.
719 |
# File 'sig/client.rbs', line 719
def delete_monitor: (
|
#delete_queue(params = {}) ⇒ Struct
Deletes a queue.
You can't recover the jobs in a queue if you delete the queue. Deleting the queue also deletes the jobs in that queue.
728 |
# File 'sig/client.rbs', line 728
def delete_queue: (
|
#delete_queue_environment(params = {}) ⇒ Struct
Deletes a queue environment.
738 |
# File 'sig/client.rbs', line 738
def delete_queue_environment: (
|
#delete_queue_fleet_association(params = {}) ⇒ Struct
Deletes a queue-fleet association.
749 |
# File 'sig/client.rbs', line 749
def delete_queue_fleet_association: (
|
#delete_queue_limit_association(params = {}) ⇒ Struct
Removes the association between a queue and a limit. You must use the
UpdateQueueLimitAssociation operation to set the status to
STOP_LIMIT_USAGE_AND_COMPLETE_TASKS or
STOP_LIMIT_USAGE_AND_CANCEL_TASKS. The status does not change
immediately. Use the GetQueueLimitAssociation operation to see if
the status changed to STOPPED before deleting the association.
760 |
# File 'sig/client.rbs', line 760
def delete_queue_limit_association: (
|
#delete_storage_profile(params = {}) ⇒ Struct
Deletes a storage profile.
771 |
# File 'sig/client.rbs', line 771
def delete_storage_profile: (
|
#delete_volume(params = {}) ⇒ Struct
Deletes a persistent volume.
781 |
# File 'sig/client.rbs', line 781
def delete_volume: (
|
#delete_worker(params = {}) ⇒ Struct
Deletes a worker.
792 |
# File 'sig/client.rbs', line 792
def delete_worker: (
|
#disassociate_member_from_farm(params = {}) ⇒ Struct
Disassociates a member from a farm.
803 |
# File 'sig/client.rbs', line 803
def disassociate_member_from_farm: (
|
#disassociate_member_from_fleet(params = {}) ⇒ Struct
Disassociates a member from a fleet.
813 |
# File 'sig/client.rbs', line 813
def disassociate_member_from_fleet: (
|
#disassociate_member_from_job(params = {}) ⇒ Struct
Disassociates a member from a job.
824 |
# File 'sig/client.rbs', line 824
def disassociate_member_from_job: (
|
#disassociate_member_from_queue(params = {}) ⇒ Struct
Disassociates a member from a queue.
836 |
# File 'sig/client.rbs', line 836
def disassociate_member_from_queue: (
|
#get_budget(params = {}) ⇒ Types::GetBudgetResponse
Get a budget.
861 |
# File 'sig/client.rbs', line 861
def get_budget: (
|
#get_farm(params = {}) ⇒ Types::GetFarmResponse
Get a farm.
880 |
# File 'sig/client.rbs', line 880
def get_farm: (
|
#get_fleet(params = {}) ⇒ Types::GetFleetResponse
Get a fleet.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* fleet_active
908 |
# File 'sig/client.rbs', line 908
def get_fleet: (
|
#get_job(params = {}) ⇒ Types::GetJobResponse
Gets a Deadline Cloud job.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* job_complete
* job_create_complete
* job_succeeded
941 |
# File 'sig/client.rbs', line 941
def get_job: (
|
#get_license_endpoint(params = {}) ⇒ Types::GetLicenseEndpointResponse
Gets a licence endpoint.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* license_endpoint_deleted
* license_endpoint_valid
959 |
# File 'sig/client.rbs', line 959
def get_license_endpoint: (
|
#get_limit(params = {}) ⇒ Types::GetLimitResponse
Gets information about a specific limit.
979 |
# File 'sig/client.rbs', line 979
def get_limit: (
|
#get_monitor(params = {}) ⇒ Types::GetMonitorResponse
Gets information about the specified monitor.
1001 |
# File 'sig/client.rbs', line 1001
def get_monitor: (
|
#get_monitor_settings(params = {}) ⇒ Types::GetMonitorSettingsResponse
Gets the settings for a Deadline Cloud monitor.
1011 |
# File 'sig/client.rbs', line 1011
def get_monitor_settings: (
|
#get_queue(params = {}) ⇒ Types::GetQueueResponse
Gets a queue.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* queue_scheduling
* queue_scheduling_blocked
1037 |
# File 'sig/client.rbs', line 1037
def get_queue: (
|
#get_queue_environment(params = {}) ⇒ Types::GetQueueEnvironmentResponse
Gets a queue environment.
1056 |
# File 'sig/client.rbs', line 1056
def get_queue_environment: (
|
#get_queue_fleet_association(params = {}) ⇒ Types::GetQueueFleetAssociationResponse
Gets a queue-fleet association.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* queue_fleet_association_stopped
1074 |
# File 'sig/client.rbs', line 1074
def get_queue_fleet_association: (
|
#get_queue_limit_association(params = {}) ⇒ Types::GetQueueLimitAssociationResponse
Gets information about a specific association between a queue and a limit.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* queue_limit_association_stopped
1092 |
# File 'sig/client.rbs', line 1092
def get_queue_limit_association: (
|
#get_session(params = {}) ⇒ Types::GetSessionResponse
Gets a session.
1115 |
# File 'sig/client.rbs', line 1115
def get_session: (
|
#get_session_action(params = {}) ⇒ Types::GetSessionActionResponse
Gets a session action for the job.
1139 |
# File 'sig/client.rbs', line 1139
def get_session_action: (
|
#get_sessions_statistics_aggregation(params = {}) ⇒ Types::GetSessionsStatisticsAggregationResponse
Gets a set of statistics for queues or farms. Before you can call the
GetSessionStatisticsAggregation operation, you must first call the
StartSessionsStatisticsAggregation operation. Statistics are
available for 1 hour after you call the
StartSessionsStatisticsAggregation operation.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1155 |
# File 'sig/client.rbs', line 1155
def get_sessions_statistics_aggregation: (
|
#get_step(params = {}) ⇒ Types::GetStepResponse
Gets a step.
1185 |
# File 'sig/client.rbs', line 1185
def get_step: (
|
#get_storage_profile(params = {}) ⇒ Types::GetStorageProfileResponse
Gets a storage profile.
1205 |
# File 'sig/client.rbs', line 1205
def get_storage_profile: (
|
#get_storage_profile_for_queue(params = {}) ⇒ Types::GetStorageProfileForQueueResponse
Gets a storage profile for a queue.
1219 |
# File 'sig/client.rbs', line 1219
def get_storage_profile_for_queue: (
|
#get_task(params = {}) ⇒ Types::GetTaskResponse
Gets a task.
1242 |
# File 'sig/client.rbs', line 1242
def get_task: (
|
#get_volume(params = {}) ⇒ Types::GetVolumeResponse
Gets a persistent volume.
1269 |
# File 'sig/client.rbs', line 1269
def get_volume: (
|
#get_worker(params = {}) ⇒ Types::GetWorkerResponse
Gets a worker.
1290 |
# File 'sig/client.rbs', line 1290
def get_worker: (
|
#list_available_metered_products(params = {}) ⇒ Types::ListAvailableMeteredProductsResponse
A list of the available metered products.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1303 |
# File 'sig/client.rbs', line 1303
def list_available_metered_products: (
|
#list_budgets(params = {}) ⇒ Types::ListBudgetsResponse
A list of budgets in a farm.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1315 |
# File 'sig/client.rbs', line 1315
def list_budgets: (
|
#list_farm_members(params = {}) ⇒ Types::ListFarmMembersResponse
Lists the members of a farm.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1329 |
# File 'sig/client.rbs', line 1329
def list_farm_members: (
|
#list_farms(params = {}) ⇒ Types::ListFarmsResponse
Lists farms.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1342 |
# File 'sig/client.rbs', line 1342
def list_farms: (
|
#list_fleet_members(params = {}) ⇒ Types::ListFleetMembersResponse
Lists fleet members.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1355 |
# File 'sig/client.rbs', line 1355
def list_fleet_members: (
|
#list_fleets(params = {}) ⇒ Types::ListFleetsResponse
Lists fleets.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1369 |
# File 'sig/client.rbs', line 1369
def list_fleets: (
|
#list_job_members(params = {}) ⇒ Types::ListJobMembersResponse
Lists members on a job.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1385 |
# File 'sig/client.rbs', line 1385
def list_job_members: (
|
#list_job_parameter_definitions(params = {}) ⇒ Types::ListJobParameterDefinitionsResponse
Lists parameter definitions of a job.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1400 |
# File 'sig/client.rbs', line 1400
def list_job_parameter_definitions: (
|
#list_jobs(params = {}) ⇒ Types::ListJobsResponse
Lists jobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1415 |
# File 'sig/client.rbs', line 1415
def list_jobs: (
|
#list_license_endpoints(params = {}) ⇒ Types::ListLicenseEndpointsResponse
Lists license endpoints.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1430 |
# File 'sig/client.rbs', line 1430
def list_license_endpoints: (
|
#list_limits(params = {}) ⇒ Types::ListLimitsResponse
Gets a list of limits defined in the specified farm.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1442 |
# File 'sig/client.rbs', line 1442
def list_limits: (
|
#list_metered_products(params = {}) ⇒ Types::ListMeteredProductsResponse
Lists metered products.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1455 |
# File 'sig/client.rbs', line 1455
def list_metered_products: (
|
#list_monitors(params = {}) ⇒ Types::ListMonitorsResponse
Gets a list of your monitors in Deadline Cloud.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1468 |
# File 'sig/client.rbs', line 1468
def list_monitors: (
|
#list_queue_environments(params = {}) ⇒ Types::ListQueueEnvironmentsResponse
Lists queue environments.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1480 |
# File 'sig/client.rbs', line 1480
def list_queue_environments: (
|
#list_queue_fleet_associations(params = {}) ⇒ Types::ListQueueFleetAssociationsResponse
Lists queue-fleet associations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1494 |
# File 'sig/client.rbs', line 1494
def list_queue_fleet_associations: (
|
#list_queue_limit_associations(params = {}) ⇒ Types::ListQueueLimitAssociationsResponse
Gets a list of the associations between queues and limits defined in a farm.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1509 |
# File 'sig/client.rbs', line 1509
def list_queue_limit_associations: (
|
#list_queue_members(params = {}) ⇒ Types::ListQueueMembersResponse
Lists the members in a queue.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1524 |
# File 'sig/client.rbs', line 1524
def list_queue_members: (
|
#list_queues(params = {}) ⇒ Types::ListQueuesResponse
Lists queues.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1538 |
# File 'sig/client.rbs', line 1538
def list_queues: (
|
#list_session_actions(params = {}) ⇒ Types::ListSessionActionsResponse
Lists session actions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1553 |
# File 'sig/client.rbs', line 1553
def list_session_actions: (
|
#list_sessions(params = {}) ⇒ Types::ListSessionsResponse
Lists sessions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1570 |
# File 'sig/client.rbs', line 1570
def list_sessions: (
|
#list_sessions_for_worker(params = {}) ⇒ Types::ListSessionsForWorkerResponse
Lists sessions for a worker.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1585 |
# File 'sig/client.rbs', line 1585
def list_sessions_for_worker: (
|
#list_step_consumers(params = {}) ⇒ Types::ListStepConsumersResponse
Lists step consumers.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1600 |
# File 'sig/client.rbs', line 1600
def list_step_consumers: (
|
#list_step_dependencies(params = {}) ⇒ Types::ListStepDependenciesResponse
Lists the dependencies for a step.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1616 |
# File 'sig/client.rbs', line 1616
def list_step_dependencies: (
|
#list_steps(params = {}) ⇒ Types::ListStepsResponse
Lists steps for a job.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1632 |
# File 'sig/client.rbs', line 1632
def list_steps: (
|
#list_storage_profiles(params = {}) ⇒ Types::ListStorageProfilesResponse
Lists storage profiles.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1647 |
# File 'sig/client.rbs', line 1647
def list_storage_profiles: (
|
#list_storage_profiles_for_queue(params = {}) ⇒ Types::ListStorageProfilesForQueueResponse
Lists storage profiles for a queue.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1660 |
# File 'sig/client.rbs', line 1660
def list_storage_profiles_for_queue: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags for a resource.
1673 |
# File 'sig/client.rbs', line 1673
def list_tags_for_resource: (
|
#list_tasks(params = {}) ⇒ Types::ListTasksResponse
Lists tasks for a job.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1684 |
# File 'sig/client.rbs', line 1684
def list_tasks: (
|
#list_volumes(params = {}) ⇒ Types::ListVolumesResponse
Lists the persistent volumes in a fleet.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1700 |
# File 'sig/client.rbs', line 1700
def list_volumes: (
|
#list_workers(params = {}) ⇒ Types::ListWorkersResponse
Lists workers.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1714 |
# File 'sig/client.rbs', line 1714
def list_workers: (
|
#put_metered_product(params = {}) ⇒ Struct
Adds a metered product.
1726 |
# File 'sig/client.rbs', line 1726
def put_metered_product: (
|
#search_jobs(params = {}) ⇒ Types::SearchJobsResponse
Searches for jobs.
1739 |
# File 'sig/client.rbs', line 1739
def search_jobs: (
|
#search_steps(params = {}) ⇒ Types::SearchStepsResponse
Searches for steps.
1758 |
# File 'sig/client.rbs', line 1758
def search_steps: (
|
#search_tasks(params = {}) ⇒ Types::SearchTasksResponse
Searches for tasks.
1778 |
# File 'sig/client.rbs', line 1778
def search_tasks: (
|
#search_workers(params = {}) ⇒ Types::SearchWorkersResponse
Searches for workers.
1798 |
# File 'sig/client.rbs', line 1798
def search_workers: (
|
#start_sessions_statistics_aggregation(params = {}) ⇒ Types::StartSessionsStatisticsAggregationResponse
Starts an asynchronous request for getting aggregated statistics about
queues and farms. Get the statistics using the
GetSessionsStatisticsAggregation operation. You can only have one
running aggregation for your Deadline Cloud farm. Call the
GetSessionsStatisticsAggregation operation and check the status
field to see if an aggregation is running. Statistics are available
for 1 hour after you call the StartSessionsStatisticsAggregation
operation.
1815 |
# File 'sig/client.rbs', line 1815
def start_sessions_statistics_aggregation: (
|
#tag_resource(params = {}) ⇒ Struct
Tags a resource using the resource's ARN and desired tags.
1834 |
# File 'sig/client.rbs', line 1834
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes a tag from a resource using the resource's ARN and tag to remove.
1844 |
# File 'sig/client.rbs', line 1844
def untag_resource: (
|
#update_budget(params = {}) ⇒ Struct
Updates a budget that sets spending thresholds for rendering activity.
1854 |
# File 'sig/client.rbs', line 1854
def update_budget: (
|
#update_farm(params = {}) ⇒ Struct
Updates a farm.
1888 |
# File 'sig/client.rbs', line 1888
def update_farm: (
|
#update_fleet(params = {}) ⇒ Struct
Updates a fleet.
1900 |
# File 'sig/client.rbs', line 1900
def update_fleet: (
|
#update_job(params = {}) ⇒ Struct
Updates a job.
When you change the status of the job to ARCHIVED, the job can't be
scheduled or archived.
An archived jobs and its steps and tasks are deleted after 120 days. The job can't be recovered.
1921 |
# File 'sig/client.rbs', line 1921
def update_job: (
|
#update_limit(params = {}) ⇒ Struct
Updates the properties of the specified limit.
1941 |
# File 'sig/client.rbs', line 1941
def update_limit: (
|
#update_monitor(params = {}) ⇒ Struct
Modifies the settings for a Deadline Cloud monitor. You can modify one
or all of the settings when you call UpdateMonitor.
1954 |
# File 'sig/client.rbs', line 1954
def update_monitor: (
|
#update_monitor_settings(params = {}) ⇒ Struct
Updates the settings for a Deadline Cloud monitor. Keys present in the request are upserted; keys absent are left unchanged. Send an empty string value to delete a key.
1966 |
# File 'sig/client.rbs', line 1966
def update_monitor_settings: (
|
#update_queue(params = {}) ⇒ Struct
Updates a queue.
1976 |
# File 'sig/client.rbs', line 1976
def update_queue: (
|
#update_queue_environment(params = {}) ⇒ Struct
Updates the queue environment.
2001 |
# File 'sig/client.rbs', line 2001
def update_queue_environment: (
|
#update_queue_fleet_association(params = {}) ⇒ Struct
Updates a queue-fleet association.
2016 |
# File 'sig/client.rbs', line 2016
def update_queue_fleet_association: (
|
#update_queue_limit_association(params = {}) ⇒ Struct
Updates the status of the queue. If you set the status to one of the
STOP_LIMIT_USAGE* values, there will be a delay before the status
transitions to the STOPPED state.
2028 |
# File 'sig/client.rbs', line 2028
def update_queue_limit_association: (
|
#update_session(params = {}) ⇒ Struct
Updates a session.
2040 |
# File 'sig/client.rbs', line 2040
def update_session: (
|
#update_step(params = {}) ⇒ Struct
Updates a step.
2054 |
# File 'sig/client.rbs', line 2054
def update_step: (
|
#update_storage_profile(params = {}) ⇒ Struct
Updates a storage profile.
2068 |
# File 'sig/client.rbs', line 2068
def update_storage_profile: (
|
#update_task(params = {}) ⇒ Struct
Updates a task.
2095 |
# File 'sig/client.rbs', line 2095
def update_task: (
|
#update_worker(params = {}) ⇒ Types::UpdateWorkerResponse
Updates a worker.
2112 |
# File 'sig/client.rbs', line 2112
def update_worker: (
|
#update_worker_schedule(params = {}) ⇒ Types::UpdateWorkerScheduleResponse
Updates the schedule for a worker.
2149 |
# File 'sig/client.rbs', line 2149
def update_worker_schedule: (
|
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
Basic Usage
A waiter will call an API operation until:
- It is successful
- It enters a terminal state
- It makes the maximum number of attempts
In between attempts, the waiter will sleep.
# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.
# poll for ~25 seconds
client.wait_until(waiter_name, params, {
max_attempts: 5,
delay: 5,
})
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
client.wait_until(waiter_name, params, {
# disable max attempts
max_attempts: nil,
# poll for 1 hour, instead of a number of attempts
before_wait: -> (attempts, response) do
throw :failure if Time.now - started_at > 3600
end
})
Handling Errors
When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.
begin
client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
Valid Waiters
The following table lists the valid waiter names, the operations they call,
and the default :delay and :max_attempts values.
| waiter_name | params | :delay | :max_attempts |
|---|---|---|---|
| fleet_active | #get_fleet | 5 | 180 |
| job_complete | #get_job | 15 | 240 |
| job_create_complete | #get_job | 1 | 120 |
| job_succeeded | #get_job | 15 | 240 |
| license_endpoint_deleted | #get_license_endpoint | 10 | 234 |
| license_endpoint_valid | #get_license_endpoint | 10 | 114 |
| queue_fleet_association_stopped | #get_queue_fleet_association | 10 | 60 |
| queue_limit_association_stopped | #get_queue_limit_association | 10 | 60 |
| queue_scheduling | #get_queue | 10 | 70 |
| queue_scheduling_blocked | #get_queue | 10 | 30 |
2172 |
# File 'sig/client.rbs', line 2172
def wait_until: (:fleet_active waiter_name,
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
8474 8475 8476 |
# File 'lib/aws-sdk-deadline/client.rb', line 8474 def waiter_names waiters.keys end |