Module: Aws::Deadline::Types
- Defined in:
- lib/aws-sdk-deadline/types.rb
Defined Under Namespace
Classes: AcceleratorCapabilities, AcceleratorCountRange, AcceleratorSelection, AcceleratorTotalMemoryMiBRange, AccessDeniedException, AcquiredLimit, AssignedEnvironmentEnterSessionActionDefinition, AssignedEnvironmentExitSessionActionDefinition, AssignedSession, AssignedSessionAction, AssignedSessionActionDefinition, AssignedSyncInputJobAttachmentsSessionActionDefinition, AssignedTaskRunSessionActionDefinition, AssociateMemberToFarmRequest, AssociateMemberToFarmResponse, AssociateMemberToFleetRequest, AssociateMemberToFleetResponse, AssociateMemberToJobRequest, AssociateMemberToJobResponse, AssociateMemberToQueueRequest, AssociateMemberToQueueResponse, AssumeFleetRoleForReadRequest, AssumeFleetRoleForReadResponse, AssumeFleetRoleForWorkerRequest, AssumeFleetRoleForWorkerResponse, AssumeQueueRoleForReadRequest, AssumeQueueRoleForReadResponse, AssumeQueueRoleForUserRequest, AssumeQueueRoleForUserResponse, AssumeQueueRoleForWorkerRequest, AssumeQueueRoleForWorkerResponse, Attachments, AwsCredentials, BatchGetJobEntityRequest, BatchGetJobEntityResponse, BatchGetJobError, BatchGetJobIdentifier, BatchGetJobItem, BatchGetJobRequest, BatchGetJobResponse, BatchGetSessionActionError, BatchGetSessionActionIdentifier, BatchGetSessionActionItem, BatchGetSessionActionRequest, BatchGetSessionActionResponse, BatchGetSessionError, BatchGetSessionIdentifier, BatchGetSessionItem, BatchGetSessionRequest, BatchGetSessionResponse, BatchGetStepError, BatchGetStepIdentifier, BatchGetStepItem, BatchGetStepRequest, BatchGetStepResponse, BatchGetTaskError, BatchGetTaskIdentifier, BatchGetTaskItem, BatchGetTaskRequest, BatchGetTaskResponse, BatchGetWorkerError, BatchGetWorkerIdentifier, BatchGetWorkerItem, BatchGetWorkerRequest, BatchGetWorkerResponse, BatchUpdateJobError, BatchUpdateJobItem, BatchUpdateJobRequest, BatchUpdateJobResponse, BatchUpdateTaskError, BatchUpdateTaskItem, BatchUpdateTaskRequest, BatchUpdateTaskResponse, BudgetActionToAdd, BudgetActionToRemove, BudgetSchedule, BudgetSummary, ConflictException, ConsumedUsages, CopyJobTemplateRequest, CopyJobTemplateResponse, CreateBudgetRequest, CreateBudgetResponse, CreateFarmRequest, CreateFarmResponse, CreateFleetRequest, CreateFleetResponse, CreateJobRequest, CreateJobResponse, CreateLicenseEndpointRequest, CreateLicenseEndpointResponse, CreateLimitRequest, CreateLimitResponse, CreateMonitorRequest, CreateMonitorResponse, CreateQueueEnvironmentRequest, CreateQueueEnvironmentResponse, CreateQueueFleetAssociationRequest, CreateQueueFleetAssociationResponse, CreateQueueLimitAssociationRequest, CreateQueueLimitAssociationResponse, CreateQueueRequest, CreateQueueResponse, CreateStorageProfileRequest, CreateStorageProfileResponse, CreateWorkerRequest, CreateWorkerResponse, CustomerManagedAutoScalingConfiguration, CustomerManagedFleetConfiguration, CustomerManagedWorkerCapabilities, DateTimeFilterExpression, DeleteBudgetRequest, DeleteBudgetResponse, DeleteFarmRequest, DeleteFarmResponse, DeleteFleetRequest, DeleteFleetResponse, DeleteLicenseEndpointRequest, DeleteLicenseEndpointResponse, DeleteLimitRequest, DeleteLimitResponse, DeleteMeteredProductRequest, DeleteMeteredProductResponse, DeleteMonitorRequest, DeleteMonitorResponse, DeleteQueueEnvironmentRequest, DeleteQueueEnvironmentResponse, DeleteQueueFleetAssociationRequest, DeleteQueueFleetAssociationResponse, DeleteQueueLimitAssociationRequest, DeleteQueueLimitAssociationResponse, DeleteQueueRequest, DeleteQueueResponse, DeleteStorageProfileRequest, DeleteStorageProfileResponse, DeleteVolumeRequest, DeleteVolumeResponse, DeleteWorkerRequest, DeleteWorkerResponse, DependencyCounts, DisassociateMemberFromFarmRequest, DisassociateMemberFromFarmResponse, DisassociateMemberFromFleetRequest, DisassociateMemberFromFleetResponse, DisassociateMemberFromJobRequest, DisassociateMemberFromJobResponse, DisassociateMemberFromQueueRequest, DisassociateMemberFromQueueResponse, Ec2EbsVolume, EnvironmentDetailsEntity, EnvironmentDetailsError, EnvironmentDetailsIdentifiers, EnvironmentEnterSessionActionDefinition, EnvironmentEnterSessionActionDefinitionSummary, EnvironmentExitSessionActionDefinition, EnvironmentExitSessionActionDefinitionSummary, FarmMember, FarmSummary, FieldSortExpression, FileSystemLocation, FixedBudgetSchedule, FleetAmountCapability, FleetAttributeCapability, FleetCapabilities, FleetConfiguration, FleetMember, FleetSummary, GetBudgetRequest, GetBudgetResponse, GetFarmRequest, GetFarmResponse, GetFleetRequest, GetFleetResponse, GetJobEntityError, GetJobRequest, GetJobResponse, GetLicenseEndpointRequest, GetLicenseEndpointResponse, GetLimitRequest, GetLimitResponse, GetMonitorRequest, GetMonitorResponse, GetMonitorSettingsRequest, GetMonitorSettingsResponse, GetQueueEnvironmentRequest, GetQueueEnvironmentResponse, GetQueueFleetAssociationRequest, GetQueueFleetAssociationResponse, GetQueueLimitAssociationRequest, GetQueueLimitAssociationResponse, GetQueueRequest, GetQueueResponse, GetSessionActionRequest, GetSessionActionResponse, GetSessionRequest, GetSessionResponse, GetSessionsStatisticsAggregationRequest, GetSessionsStatisticsAggregationResponse, GetStepRequest, GetStepResponse, GetStorageProfileForQueueRequest, GetStorageProfileForQueueResponse, GetStorageProfileRequest, GetStorageProfileResponse, GetTaskRequest, GetTaskResponse, GetVolumeRequest, GetVolumeResponse, GetWorkerRequest, GetWorkerResponse, HostConfiguration, HostPropertiesRequest, HostPropertiesResponse, InternalServerErrorException, IpAddresses, JobAttachmentDetailsEntity, JobAttachmentDetailsError, JobAttachmentDetailsIdentifiers, JobAttachmentSettings, JobDetailsEntity, JobDetailsError, JobDetailsIdentifiers, JobEntity, JobEntityIdentifiersUnion, JobMember, JobParameter, JobRunAsUser, JobSearchSummary, JobSummary, LicenseEndpointSummary, LimitSummary, ListAvailableMeteredProductsRequest, ListAvailableMeteredProductsResponse, ListBudgetsRequest, ListBudgetsResponse, ListFarmMembersRequest, ListFarmMembersResponse, ListFarmsRequest, ListFarmsResponse, ListFleetMembersRequest, ListFleetMembersResponse, ListFleetsRequest, ListFleetsResponse, ListJobMembersRequest, ListJobMembersResponse, ListJobParameterDefinitionsRequest, ListJobParameterDefinitionsResponse, ListJobsRequest, ListJobsResponse, ListLicenseEndpointsRequest, ListLicenseEndpointsResponse, ListLimitsRequest, ListLimitsResponse, ListMeteredProductsRequest, ListMeteredProductsResponse, ListMonitorsRequest, ListMonitorsResponse, ListQueueEnvironmentsRequest, ListQueueEnvironmentsResponse, ListQueueFleetAssociationsRequest, ListQueueFleetAssociationsResponse, ListQueueLimitAssociationsRequest, ListQueueLimitAssociationsResponse, ListQueueMembersRequest, ListQueueMembersResponse, ListQueuesRequest, ListQueuesResponse, ListSessionActionsRequest, ListSessionActionsResponse, ListSessionsForWorkerRequest, ListSessionsForWorkerResponse, ListSessionsRequest, ListSessionsResponse, ListStepConsumersRequest, ListStepConsumersResponse, ListStepDependenciesRequest, ListStepDependenciesResponse, ListStepsRequest, ListStepsResponse, ListStorageProfilesForQueueRequest, ListStorageProfilesForQueueResponse, ListStorageProfilesRequest, ListStorageProfilesResponse, ListTagsForResourceRequest, ListTagsForResourceResponse, ListTasksRequest, ListTasksResponse, ListVolumesRequest, ListVolumesResponse, ListWorkersRequest, ListWorkersResponse, LogConfiguration, ManifestProperties, MemoryMiBRange, MeteredProductSummary, MonitorSummary, ParameterFilterExpression, ParameterSortExpression, ParameterSpace, PathMappingRule, PersistentVolumeConfiguration, PosixUser, PriorityBalancedSchedulingConfiguration, PriorityFifoSchedulingConfiguration, PutMeteredProductRequest, PutMeteredProductResponse, QueueEnvironmentSummary, QueueFleetAssociationSummary, QueueLimitAssociationSummary, QueueMember, QueueSummary, ResourceNotFoundException, ResponseBudgetAction, S3Location, SchedulingConfiguration, SchedulingMaxPriorityOverride, SchedulingMaxPriorityOverrideAlwaysScheduleFirst, SchedulingMinPriorityOverride, SchedulingMinPriorityOverrideAlwaysScheduleLast, SearchFilterExpression, SearchGroupedFilterExpressions, SearchJobsRequest, SearchJobsResponse, SearchSortExpression, SearchStepsRequest, SearchStepsResponse, SearchTasksRequest, SearchTasksResponse, SearchTermFilterExpression, SearchWorkersRequest, SearchWorkersResponse, ServiceManagedEc2AutoScalingConfiguration, ServiceManagedEc2FleetConfiguration, ServiceManagedEc2InstanceCapabilities, ServiceManagedEc2InstanceMarketOptions, ServiceQuotaExceededException, SessionActionDefinition, SessionActionDefinitionSummary, SessionActionSummary, SessionSummary, SessionsStatisticsResources, StartSessionsStatisticsAggregationRequest, StartSessionsStatisticsAggregationResponse, Statistics, Stats, StepAmountCapability, StepAttributeCapability, StepConsumer, StepDependency, StepDetailsEntity, StepDetailsError, StepDetailsIdentifiers, StepParameter, StepParameterChunks, StepRequiredCapabilities, StepSearchSummary, StepSummary, StorageProfileSummary, StringFilterExpression, StringListFilterExpression, SyncInputJobAttachmentsSessionActionDefinition, SyncInputJobAttachmentsSessionActionDefinitionSummary, TagResourceRequest, TagResourceResponse, TaskParameterValue, TaskRunManifestPropertiesRequest, TaskRunManifestPropertiesResponse, TaskRunSessionActionDefinition, TaskRunSessionActionDefinitionSummary, TaskSearchSummary, TaskSummary, ThrottlingException, UntagResourceRequest, UntagResourceResponse, UpdateBudgetRequest, UpdateBudgetResponse, UpdateFarmRequest, UpdateFarmResponse, UpdateFleetRequest, UpdateFleetResponse, UpdateJobRequest, UpdateJobResponse, UpdateLimitRequest, UpdateLimitResponse, UpdateMonitorRequest, UpdateMonitorResponse, UpdateMonitorSettingsRequest, UpdateMonitorSettingsResponse, UpdateQueueEnvironmentRequest, UpdateQueueEnvironmentResponse, UpdateQueueFleetAssociationRequest, UpdateQueueFleetAssociationResponse, UpdateQueueLimitAssociationRequest, UpdateQueueLimitAssociationResponse, UpdateQueueRequest, UpdateQueueResponse, UpdateSessionRequest, UpdateSessionResponse, UpdateStepRequest, UpdateStepResponse, UpdateStorageProfileRequest, UpdateStorageProfileResponse, UpdateTaskRequest, UpdateTaskResponse, UpdateWorkerRequest, UpdateWorkerResponse, UpdateWorkerScheduleRequest, UpdateWorkerScheduleResponse, UpdatedSessionActionInfo, UsageTrackingResource, UserJobsFirst, VCpuCountRange, ValidationException, ValidationExceptionField, VolumeSummary, VpcConfiguration, WeightedBalancedSchedulingConfiguration, WindowsUser, WorkerAmountCapability, WorkerAttributeCapability, WorkerCapabilities, WorkerSearchSummary, WorkerSessionSummary, WorkerSummary
Instance Attribute Summary collapse
-
#always_schedule_first ⇒ Types::SchedulingMaxPriorityOverrideAlwaysScheduleFirst
Jobs at the maximum priority (100) are always scheduled before other jobs, regardless of the weighted scheduling formula.
-
#always_schedule_last ⇒ Types::SchedulingMinPriorityOverrideAlwaysScheduleLast
Jobs at the minimum priority (0) are always scheduled after all other jobs, regardless of the weighted scheduling formula.
-
#chunk_int ⇒ String
A range (for example 1-10) or selection of specific (for example 1,3,7,8,10) integers represented as a string.
-
#customer_managed ⇒ Types::CustomerManagedFleetConfiguration
The customer managed fleets within a fleet configuration.
-
#date_time_filter ⇒ Types::DateTimeFilterExpression
Filters based on date and time.
-
#env_enter ⇒ Types::EnvironmentEnterSessionActionDefinitionSummary
The environment to enter into.
-
#env_exit ⇒ Types::EnvironmentExitSessionActionDefinitionSummary
The environment to exit from.
-
#environment_details ⇒ Types::EnvironmentDetailsIdentifiers
The environment details.
-
#field_sort ⇒ Types::FieldSortExpression
Options for sorting by a field.
-
#fixed ⇒ Types::FixedBudgetSchedule
The fixed start and end time of the budget’s schedule.
-
#fleet_ids ⇒ Array<String>
One to 10 fleet IDs that specify the fleets to return statistics for.
-
#float ⇒ String
A double precision IEEE-754 floating point number represented as a string.
-
#group_filter ⇒ Types::SearchGroupedFilterExpressions
Filters by group.
-
#int ⇒ String
A signed integer represented as a string.
-
#job_attachment_details ⇒ Types::JobAttachmentDetailsIdentifiers
The job attachment details.
-
#job_details ⇒ Types::JobDetailsIdentifiers
The job details.
-
#parameter_filter ⇒ Types::ParameterFilterExpression
Filters by parameter.
-
#parameter_sort ⇒ Types::ParameterSortExpression
Options for sorting by a parameter.
-
#path ⇒ String
A file system path represented as a string.
-
#priority_balanced ⇒ Types::PriorityBalancedSchedulingConfiguration
Workers are distributed evenly across all jobs at the highest priority level.
-
#priority_fifo ⇒ Types::PriorityFifoSchedulingConfiguration
Workers are assigned to the highest-priority job first.
-
#queue_id ⇒ String
The queue ID.
-
#queue_ids ⇒ Array<String>
One to 10 queue IDs that specify the queues to return statistics for.
-
#search_term_filter ⇒ Types::SearchTermFilterExpression
Filters by a specified search term.
-
#service_managed_ec2 ⇒ Types::ServiceManagedEc2FleetConfiguration
The service managed Amazon EC2 instances for a fleet configuration.
-
#step_details ⇒ Types::StepDetailsIdentifiers
The step details.
-
#string ⇒ String
A UTF-8 string.
-
#string_filter ⇒ Types::StringFilterExpression
Filters by a string.
-
#string_list_filter ⇒ Types::StringListFilterExpression
Filters by a list of strings.
-
#sync_input_job_attachments ⇒ Types::SyncInputJobAttachmentsSessionActionDefinitionSummary
The session action definition summary for syncing input job attachments.
-
#task_run ⇒ Types::TaskRunSessionActionDefinitionSummary
The task run.
-
#user_jobs_first ⇒ Types::UserJobsFirst
Options for sorting a particular user’s jobs first.
-
#weighted_balanced ⇒ Types::WeightedBalancedSchedulingConfiguration
Workers are assigned to jobs based on a weighted formula that considers job priority, error count, submission time, and the number of tasks currently rendering.
Instance Attribute Details
#always_schedule_first ⇒ Types::SchedulingMaxPriorityOverrideAlwaysScheduleFirst
Jobs at the maximum priority (100) are always scheduled before other jobs, regardless of the weighted scheduling formula. If multiple jobs have priority 100, ties are broken using the standard weighted formula.
9866 9867 9868 9869 9870 9871 9872 9873 9874 9875 |
# File 'lib/aws-sdk-deadline/types.rb', line 9866 class SchedulingMaxPriorityOverride < Struct.new( :always_schedule_first, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AlwaysScheduleFirst < SchedulingMaxPriorityOverride; end class Unknown < SchedulingMaxPriorityOverride; end end |
#always_schedule_last ⇒ Types::SchedulingMinPriorityOverrideAlwaysScheduleLast
Jobs at the minimum priority (0) are always scheduled after all other jobs, regardless of the weighted scheduling formula. If multiple jobs have priority 0, ties are broken using the standard weighted formula.
9902 9903 9904 9905 9906 9907 9908 9909 9910 9911 |
# File 'lib/aws-sdk-deadline/types.rb', line 9902 class SchedulingMinPriorityOverride < Struct.new( :always_schedule_last, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AlwaysScheduleLast < SchedulingMinPriorityOverride; end class Unknown < SchedulingMinPriorityOverride; end end |
#chunk_int ⇒ String
A range (for example 1-10) or selection of specific (for example 1,3,7,8,10) integers represented as a string.
11514 11515 11516 11517 11518 11519 11520 11521 11522 11523 11524 11525 11526 11527 11528 11529 11530 11531 |
# File 'lib/aws-sdk-deadline/types.rb', line 11514 class TaskParameterValue < Struct.new( :int, :float, :string, :path, :chunk_int, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Int < TaskParameterValue; end class Float < TaskParameterValue; end class String < TaskParameterValue; end class Path < TaskParameterValue; end class ChunkInt < TaskParameterValue; end class Unknown < TaskParameterValue; end end |
#customer_managed ⇒ Types::CustomerManagedFleetConfiguration
The customer managed fleets within a fleet configuration.
4398 4399 4400 4401 4402 4403 4404 4405 4406 4407 4408 4409 |
# File 'lib/aws-sdk-deadline/types.rb', line 4398 class FleetConfiguration < Struct.new( :customer_managed, :service_managed_ec2, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CustomerManaged < FleetConfiguration; end class ServiceManagedEc2 < FleetConfiguration; end class Unknown < FleetConfiguration; end end |
#date_time_filter ⇒ Types::DateTimeFilterExpression
Filters based on date and time.
9952 9953 9954 9955 9956 9957 9958 9959 9960 9961 9962 9963 9964 9965 9966 9967 9968 9969 9970 9971 |
# File 'lib/aws-sdk-deadline/types.rb', line 9952 class SearchFilterExpression < Struct.new( :date_time_filter, :parameter_filter, :search_term_filter, :string_filter, :string_list_filter, :group_filter, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DateTimeFilter < SearchFilterExpression; end class ParameterFilter < SearchFilterExpression; end class SearchTermFilter < SearchFilterExpression; end class StringFilter < SearchFilterExpression; end class StringListFilter < SearchFilterExpression; end class GroupFilter < SearchFilterExpression; end class Unknown < SearchFilterExpression; end end |
#env_enter ⇒ Types::EnvironmentEnterSessionActionDefinitionSummary
The environment to enter into.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/aws-sdk-deadline/types.rb', line 324 class AssignedSessionActionDefinition < Struct.new( :env_enter, :env_exit, :task_run, :sync_input_job_attachments, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EnvEnter < AssignedSessionActionDefinition; end class EnvExit < AssignedSessionActionDefinition; end class TaskRun < AssignedSessionActionDefinition; end class SyncInputJobAttachments < AssignedSessionActionDefinition; end class Unknown < AssignedSessionActionDefinition; end end |
#env_exit ⇒ Types::EnvironmentExitSessionActionDefinitionSummary
The environment to exit from.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/aws-sdk-deadline/types.rb', line 324 class AssignedSessionActionDefinition < Struct.new( :env_enter, :env_exit, :task_run, :sync_input_job_attachments, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EnvEnter < AssignedSessionActionDefinition; end class EnvExit < AssignedSessionActionDefinition; end class TaskRun < AssignedSessionActionDefinition; end class SyncInputJobAttachments < AssignedSessionActionDefinition; end class Unknown < AssignedSessionActionDefinition; end end |
#environment_details ⇒ Types::EnvironmentDetailsIdentifiers
The environment details.
4884 4885 4886 4887 4888 4889 4890 4891 4892 4893 4894 4895 4896 4897 4898 4899 |
# File 'lib/aws-sdk-deadline/types.rb', line 4884 class GetJobEntityError < Struct.new( :job_details, :job_attachment_details, :step_details, :environment_details, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class JobDetails < GetJobEntityError; end class JobAttachmentDetails < GetJobEntityError; end class StepDetails < GetJobEntityError; end class EnvironmentDetails < GetJobEntityError; end class Unknown < GetJobEntityError; end end |
#field_sort ⇒ Types::FieldSortExpression
Options for sorting by a field.
10075 10076 10077 10078 10079 10080 10081 10082 10083 10084 10085 10086 10087 10088 |
# File 'lib/aws-sdk-deadline/types.rb', line 10075 class SearchSortExpression < Struct.new( :user_jobs_first, :field_sort, :parameter_sort, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class UserJobsFirst < SearchSortExpression; end class FieldSort < SearchSortExpression; end class ParameterSort < SearchSortExpression; end class Unknown < SearchSortExpression; end end |
#fixed ⇒ Types::FixedBudgetSchedule
The fixed start and end time of the budget’s schedule.
2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 |
# File 'lib/aws-sdk-deadline/types.rb', line 2327 class BudgetSchedule < Struct.new( :fixed, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Fixed < BudgetSchedule; end class Unknown < BudgetSchedule; end end |
#fleet_ids ⇒ Array<String>
One to 10 fleet IDs that specify the fleets to return statistics for. If you specify the ‘fleetIds` field, you can’t specify the ‘queueIds` field.
10717 10718 10719 10720 10721 10722 10723 10724 10725 10726 10727 10728 |
# File 'lib/aws-sdk-deadline/types.rb', line 10717 class SessionsStatisticsResources < Struct.new( :queue_ids, :fleet_ids, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class QueueIds < SessionsStatisticsResources; end class FleetIds < SessionsStatisticsResources; end class Unknown < SessionsStatisticsResources; end end |
#float ⇒ String
A double precision IEEE-754 floating point number represented as a string.
6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 |
# File 'lib/aws-sdk-deadline/types.rb', line 6945 class JobParameter < Struct.new( :int, :float, :string, :path, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Int < JobParameter; end class Float < JobParameter; end class String < JobParameter; end class Path < JobParameter; end class Unknown < JobParameter; end end |
#group_filter ⇒ Types::SearchGroupedFilterExpressions
Filters by group.
9952 9953 9954 9955 9956 9957 9958 9959 9960 9961 9962 9963 9964 9965 9966 9967 9968 9969 9970 9971 |
# File 'lib/aws-sdk-deadline/types.rb', line 9952 class SearchFilterExpression < Struct.new( :date_time_filter, :parameter_filter, :search_term_filter, :string_filter, :string_list_filter, :group_filter, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DateTimeFilter < SearchFilterExpression; end class ParameterFilter < SearchFilterExpression; end class SearchTermFilter < SearchFilterExpression; end class StringFilter < SearchFilterExpression; end class StringListFilter < SearchFilterExpression; end class GroupFilter < SearchFilterExpression; end class Unknown < SearchFilterExpression; end end |
#int ⇒ String
A signed integer represented as a string.
6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 |
# File 'lib/aws-sdk-deadline/types.rb', line 6945 class JobParameter < Struct.new( :int, :float, :string, :path, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Int < JobParameter; end class Float < JobParameter; end class String < JobParameter; end class Path < JobParameter; end class Unknown < JobParameter; end end |
#job_attachment_details ⇒ Types::JobAttachmentDetailsIdentifiers
The job attachment details.
4884 4885 4886 4887 4888 4889 4890 4891 4892 4893 4894 4895 4896 4897 4898 4899 |
# File 'lib/aws-sdk-deadline/types.rb', line 4884 class GetJobEntityError < Struct.new( :job_details, :job_attachment_details, :step_details, :environment_details, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class JobDetails < GetJobEntityError; end class JobAttachmentDetails < GetJobEntityError; end class StepDetails < GetJobEntityError; end class EnvironmentDetails < GetJobEntityError; end class Unknown < GetJobEntityError; end end |
#job_details ⇒ Types::JobDetailsIdentifiers
The job details.
4884 4885 4886 4887 4888 4889 4890 4891 4892 4893 4894 4895 4896 4897 4898 4899 |
# File 'lib/aws-sdk-deadline/types.rb', line 4884 class GetJobEntityError < Struct.new( :job_details, :job_attachment_details, :step_details, :environment_details, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class JobDetails < GetJobEntityError; end class JobAttachmentDetails < GetJobEntityError; end class StepDetails < GetJobEntityError; end class EnvironmentDetails < GetJobEntityError; end class Unknown < GetJobEntityError; end end |
#parameter_filter ⇒ Types::ParameterFilterExpression
Filters by parameter.
9952 9953 9954 9955 9956 9957 9958 9959 9960 9961 9962 9963 9964 9965 9966 9967 9968 9969 9970 9971 |
# File 'lib/aws-sdk-deadline/types.rb', line 9952 class SearchFilterExpression < Struct.new( :date_time_filter, :parameter_filter, :search_term_filter, :string_filter, :string_list_filter, :group_filter, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DateTimeFilter < SearchFilterExpression; end class ParameterFilter < SearchFilterExpression; end class SearchTermFilter < SearchFilterExpression; end class StringFilter < SearchFilterExpression; end class StringListFilter < SearchFilterExpression; end class GroupFilter < SearchFilterExpression; end class Unknown < SearchFilterExpression; end end |
#parameter_sort ⇒ Types::ParameterSortExpression
Options for sorting by a parameter.
10075 10076 10077 10078 10079 10080 10081 10082 10083 10084 10085 10086 10087 10088 |
# File 'lib/aws-sdk-deadline/types.rb', line 10075 class SearchSortExpression < Struct.new( :user_jobs_first, :field_sort, :parameter_sort, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class UserJobsFirst < SearchSortExpression; end class FieldSort < SearchSortExpression; end class ParameterSort < SearchSortExpression; end class Unknown < SearchSortExpression; end end |
#path ⇒ String
A file system path represented as a string.
6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 |
# File 'lib/aws-sdk-deadline/types.rb', line 6945 class JobParameter < Struct.new( :int, :float, :string, :path, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Int < JobParameter; end class Float < JobParameter; end class String < JobParameter; end class Path < JobParameter; end class Unknown < JobParameter; end end |
#priority_balanced ⇒ Types::PriorityBalancedSchedulingConfiguration
Workers are distributed evenly across all jobs at the highest priority level. When workers cannot be evenly divided, the extra workers are assigned to the jobs submitted earliest. If a job has fewer remaining tasks than its share of workers, the surplus workers are redistributed to other jobs at the same priority level.
9835 9836 9837 9838 9839 9840 9841 9842 9843 9844 9845 9846 9847 9848 |
# File 'lib/aws-sdk-deadline/types.rb', line 9835 class SchedulingConfiguration < Struct.new( :priority_fifo, :priority_balanced, :weighted_balanced, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class PriorityFifo < SchedulingConfiguration; end class PriorityBalanced < SchedulingConfiguration; end class WeightedBalanced < SchedulingConfiguration; end class Unknown < SchedulingConfiguration; end end |
#priority_fifo ⇒ Types::PriorityFifoSchedulingConfiguration
Workers are assigned to the highest-priority job first. When multiple jobs share the same priority, the job submitted earliest receives workers first. This is the default scheduling configuration for new queues.
9835 9836 9837 9838 9839 9840 9841 9842 9843 9844 9845 9846 9847 9848 |
# File 'lib/aws-sdk-deadline/types.rb', line 9835 class SchedulingConfiguration < Struct.new( :priority_fifo, :priority_balanced, :weighted_balanced, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class PriorityFifo < SchedulingConfiguration; end class PriorityBalanced < SchedulingConfiguration; end class WeightedBalanced < SchedulingConfiguration; end class Unknown < SchedulingConfiguration; end end |
#queue_id ⇒ String
The queue ID.
12813 12814 12815 12816 12817 12818 12819 12820 12821 12822 |
# File 'lib/aws-sdk-deadline/types.rb', line 12813 class UsageTrackingResource < Struct.new( :queue_id, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class QueueId < UsageTrackingResource; end class Unknown < UsageTrackingResource; end end |
#queue_ids ⇒ Array<String>
One to 10 queue IDs that specify the queues to return statistics for. If you specify the ‘queueIds` field, you can’t specify the ‘fleetIds` field.
10717 10718 10719 10720 10721 10722 10723 10724 10725 10726 10727 10728 |
# File 'lib/aws-sdk-deadline/types.rb', line 10717 class SessionsStatisticsResources < Struct.new( :queue_ids, :fleet_ids, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class QueueIds < SessionsStatisticsResources; end class FleetIds < SessionsStatisticsResources; end class Unknown < SessionsStatisticsResources; end end |
#search_term_filter ⇒ Types::SearchTermFilterExpression
Filters by a specified search term.
9952 9953 9954 9955 9956 9957 9958 9959 9960 9961 9962 9963 9964 9965 9966 9967 9968 9969 9970 9971 |
# File 'lib/aws-sdk-deadline/types.rb', line 9952 class SearchFilterExpression < Struct.new( :date_time_filter, :parameter_filter, :search_term_filter, :string_filter, :string_list_filter, :group_filter, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DateTimeFilter < SearchFilterExpression; end class ParameterFilter < SearchFilterExpression; end class SearchTermFilter < SearchFilterExpression; end class StringFilter < SearchFilterExpression; end class StringListFilter < SearchFilterExpression; end class GroupFilter < SearchFilterExpression; end class Unknown < SearchFilterExpression; end end |
#service_managed_ec2 ⇒ Types::ServiceManagedEc2FleetConfiguration
The service managed Amazon EC2 instances for a fleet configuration.
4398 4399 4400 4401 4402 4403 4404 4405 4406 4407 4408 4409 |
# File 'lib/aws-sdk-deadline/types.rb', line 4398 class FleetConfiguration < Struct.new( :customer_managed, :service_managed_ec2, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CustomerManaged < FleetConfiguration; end class ServiceManagedEc2 < FleetConfiguration; end class Unknown < FleetConfiguration; end end |
#step_details ⇒ Types::StepDetailsIdentifiers
The step details.
4884 4885 4886 4887 4888 4889 4890 4891 4892 4893 4894 4895 4896 4897 4898 4899 |
# File 'lib/aws-sdk-deadline/types.rb', line 4884 class GetJobEntityError < Struct.new( :job_details, :job_attachment_details, :step_details, :environment_details, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class JobDetails < GetJobEntityError; end class JobAttachmentDetails < GetJobEntityError; end class StepDetails < GetJobEntityError; end class EnvironmentDetails < GetJobEntityError; end class Unknown < GetJobEntityError; end end |
#string ⇒ String
A UTF-8 string.
6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 |
# File 'lib/aws-sdk-deadline/types.rb', line 6945 class JobParameter < Struct.new( :int, :float, :string, :path, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Int < JobParameter; end class Float < JobParameter; end class String < JobParameter; end class Path < JobParameter; end class Unknown < JobParameter; end end |
#string_filter ⇒ Types::StringFilterExpression
Filters by a string.
9952 9953 9954 9955 9956 9957 9958 9959 9960 9961 9962 9963 9964 9965 9966 9967 9968 9969 9970 9971 |
# File 'lib/aws-sdk-deadline/types.rb', line 9952 class SearchFilterExpression < Struct.new( :date_time_filter, :parameter_filter, :search_term_filter, :string_filter, :string_list_filter, :group_filter, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DateTimeFilter < SearchFilterExpression; end class ParameterFilter < SearchFilterExpression; end class SearchTermFilter < SearchFilterExpression; end class StringFilter < SearchFilterExpression; end class StringListFilter < SearchFilterExpression; end class GroupFilter < SearchFilterExpression; end class Unknown < SearchFilterExpression; end end |
#string_list_filter ⇒ Types::StringListFilterExpression
Filters by a list of strings.
9952 9953 9954 9955 9956 9957 9958 9959 9960 9961 9962 9963 9964 9965 9966 9967 9968 9969 9970 9971 |
# File 'lib/aws-sdk-deadline/types.rb', line 9952 class SearchFilterExpression < Struct.new( :date_time_filter, :parameter_filter, :search_term_filter, :string_filter, :string_list_filter, :group_filter, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DateTimeFilter < SearchFilterExpression; end class ParameterFilter < SearchFilterExpression; end class SearchTermFilter < SearchFilterExpression; end class StringFilter < SearchFilterExpression; end class StringListFilter < SearchFilterExpression; end class GroupFilter < SearchFilterExpression; end class Unknown < SearchFilterExpression; end end |
#sync_input_job_attachments ⇒ Types::SyncInputJobAttachmentsSessionActionDefinitionSummary
The session action definition summary for syncing input job attachments.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/aws-sdk-deadline/types.rb', line 324 class AssignedSessionActionDefinition < Struct.new( :env_enter, :env_exit, :task_run, :sync_input_job_attachments, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EnvEnter < AssignedSessionActionDefinition; end class EnvExit < AssignedSessionActionDefinition; end class TaskRun < AssignedSessionActionDefinition; end class SyncInputJobAttachments < AssignedSessionActionDefinition; end class Unknown < AssignedSessionActionDefinition; end end |
#task_run ⇒ Types::TaskRunSessionActionDefinitionSummary
The task run.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/aws-sdk-deadline/types.rb', line 324 class AssignedSessionActionDefinition < Struct.new( :env_enter, :env_exit, :task_run, :sync_input_job_attachments, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EnvEnter < AssignedSessionActionDefinition; end class EnvExit < AssignedSessionActionDefinition; end class TaskRun < AssignedSessionActionDefinition; end class SyncInputJobAttachments < AssignedSessionActionDefinition; end class Unknown < AssignedSessionActionDefinition; end end |
#user_jobs_first ⇒ Types::UserJobsFirst
Options for sorting a particular user’s jobs first.
10075 10076 10077 10078 10079 10080 10081 10082 10083 10084 10085 10086 10087 10088 |
# File 'lib/aws-sdk-deadline/types.rb', line 10075 class SearchSortExpression < Struct.new( :user_jobs_first, :field_sort, :parameter_sort, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class UserJobsFirst < SearchSortExpression; end class FieldSort < SearchSortExpression; end class ParameterSort < SearchSortExpression; end class Unknown < SearchSortExpression; end end |
#weighted_balanced ⇒ Types::WeightedBalancedSchedulingConfiguration
Workers are assigned to jobs based on a weighted formula that considers job priority, error count, submission time, and the number of tasks currently rendering. Each factor has a configurable weight that determines its influence on scheduling decisions.
9835 9836 9837 9838 9839 9840 9841 9842 9843 9844 9845 9846 9847 9848 |
# File 'lib/aws-sdk-deadline/types.rb', line 9835 class SchedulingConfiguration < Struct.new( :priority_fifo, :priority_balanced, :weighted_balanced, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class PriorityFifo < SchedulingConfiguration; end class PriorityBalanced < SchedulingConfiguration; end class WeightedBalanced < SchedulingConfiguration; end class Unknown < SchedulingConfiguration; end end |