Class: Aws::Deadline::Types::AcceleratorTotalMemoryMiBRange

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Defines the maximum and minimum amount of memory, in MiB, to use for the accelerator.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#maxInteger

The maximum amount of memory to use for the accelerator, measured in MiB.

Returns:



179
180
181
182
183
184
# File 'lib/aws-sdk-deadline/types.rb', line 179

class AcceleratorTotalMemoryMiBRange < Struct.new(
  :min,
  :max)
  SENSITIVE = []
  include Aws::Structure
end

#minInteger

The minimum amount of memory to use for the accelerator, measured in MiB.

Returns:



179
180
181
182
183
184
# File 'lib/aws-sdk-deadline/types.rb', line 179

class AcceleratorTotalMemoryMiBRange < Struct.new(
  :min,
  :max)
  SENSITIVE = []
  include Aws::Structure
end