Class: Aws::Deadline::Types::AssignedSyncInputJobAttachmentsSessionActionDefinition

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

The assigned session action definition for syncing input job attachments.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#step_idString

The step ID for the assigned sync input job attachments session action.

Returns:

  • (String)


351
352
353
354
355
# File 'lib/aws-sdk-deadline/types.rb', line 351

class AssignedSyncInputJobAttachmentsSessionActionDefinition < Struct.new(
  :step_id)
  SENSITIVE = []
  include Aws::Structure
end