Class: Aws::Deadline::Types::AssociateMemberToFarmRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Shared member fields for Associate inputs and ResourceMember response structures. principalId is excluded because it has @httpLabel on inputs but not on responses.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#farm_idString

The ID of the farm to associate with the member.

Returns:

  • (String)


412
413
414
415
416
417
418
419
420
421
# File 'lib/aws-sdk-deadline/types.rb', line 412

class AssociateMemberToFarmRequest < Struct.new(
  :farm_id,
  :principal_type,
  :identity_store_id,
  :membership_level,
  :principal_id,
  :identity_center_region)
  SENSITIVE = []
  include Aws::Structure
end

#identity_center_regionString

The Region of the IAM Identity Center instance. If not provided, the service defaults to the Region of the farm.

Returns:

  • (String)


412
413
414
415
416
417
418
419
420
421
# File 'lib/aws-sdk-deadline/types.rb', line 412

class AssociateMemberToFarmRequest < Struct.new(
  :farm_id,
  :principal_type,
  :identity_store_id,
  :membership_level,
  :principal_id,
  :identity_center_region)
  SENSITIVE = []
  include Aws::Structure
end

#identity_store_idString

The identity store ID of the member to associate with the farm.

Returns:

  • (String)


412
413
414
415
416
417
418
419
420
421
# File 'lib/aws-sdk-deadline/types.rb', line 412

class AssociateMemberToFarmRequest < Struct.new(
  :farm_id,
  :principal_type,
  :identity_store_id,
  :membership_level,
  :principal_id,
  :identity_center_region)
  SENSITIVE = []
  include Aws::Structure
end

#membership_levelString

The principal’s membership level for the associated farm.

Returns:

  • (String)


412
413
414
415
416
417
418
419
420
421
# File 'lib/aws-sdk-deadline/types.rb', line 412

class AssociateMemberToFarmRequest < Struct.new(
  :farm_id,
  :principal_type,
  :identity_store_id,
  :membership_level,
  :principal_id,
  :identity_center_region)
  SENSITIVE = []
  include Aws::Structure
end

#principal_idString

The member’s principal ID to associate with the farm.

Returns:

  • (String)


412
413
414
415
416
417
418
419
420
421
# File 'lib/aws-sdk-deadline/types.rb', line 412

class AssociateMemberToFarmRequest < Struct.new(
  :farm_id,
  :principal_type,
  :identity_store_id,
  :membership_level,
  :principal_id,
  :identity_center_region)
  SENSITIVE = []
  include Aws::Structure
end

#principal_typeString

The principal type of the member to associate with the farm.

Returns:

  • (String)


412
413
414
415
416
417
418
419
420
421
# File 'lib/aws-sdk-deadline/types.rb', line 412

class AssociateMemberToFarmRequest < Struct.new(
  :farm_id,
  :principal_type,
  :identity_store_id,
  :membership_level,
  :principal_id,
  :identity_center_region)
  SENSITIVE = []
  include Aws::Structure
end