Class: Aws::Deadline::Types::AssociateMemberToFleetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::AssociateMemberToFleetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Shared member fields for Associate inputs and ResourceMember response structures. principalId is excluded because it has @httpLabel on inputs but not on responses.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#farm_id ⇒ String
The farm ID of the fleet to associate with the member.
-
#fleet_id ⇒ String
The ID of the fleet to associate with a member.
-
#identity_center_region ⇒ String
The Region of the IAM Identity Center instance.
-
#identity_store_id ⇒ String
The member’s identity store ID to associate with the fleet.
-
#membership_level ⇒ String
The principal’s membership level for the associated fleet.
-
#principal_id ⇒ String
The member’s principal ID to associate with a fleet.
-
#principal_type ⇒ String
The member’s principal type to associate with the fleet.
Instance Attribute Details
#farm_id ⇒ String
The farm ID of the fleet to associate with the member.
462 463 464 465 466 467 468 469 470 471 472 |
# File 'lib/aws-sdk-deadline/types.rb', line 462 class AssociateMemberToFleetRequest < Struct.new( :farm_id, :fleet_id, :principal_type, :identity_store_id, :membership_level, :principal_id, :identity_center_region) SENSITIVE = [] include Aws::Structure end |
#fleet_id ⇒ String
The ID of the fleet to associate with a member.
462 463 464 465 466 467 468 469 470 471 472 |
# File 'lib/aws-sdk-deadline/types.rb', line 462 class AssociateMemberToFleetRequest < Struct.new( :farm_id, :fleet_id, :principal_type, :identity_store_id, :membership_level, :principal_id, :identity_center_region) SENSITIVE = [] include Aws::Structure end |
#identity_center_region ⇒ String
The Region of the IAM Identity Center instance. If not provided, the service defaults to the Region of the farm.
462 463 464 465 466 467 468 469 470 471 472 |
# File 'lib/aws-sdk-deadline/types.rb', line 462 class AssociateMemberToFleetRequest < Struct.new( :farm_id, :fleet_id, :principal_type, :identity_store_id, :membership_level, :principal_id, :identity_center_region) SENSITIVE = [] include Aws::Structure end |
#identity_store_id ⇒ String
The member’s identity store ID to associate with the fleet.
462 463 464 465 466 467 468 469 470 471 472 |
# File 'lib/aws-sdk-deadline/types.rb', line 462 class AssociateMemberToFleetRequest < Struct.new( :farm_id, :fleet_id, :principal_type, :identity_store_id, :membership_level, :principal_id, :identity_center_region) SENSITIVE = [] include Aws::Structure end |
#membership_level ⇒ String
The principal’s membership level for the associated fleet.
462 463 464 465 466 467 468 469 470 471 472 |
# File 'lib/aws-sdk-deadline/types.rb', line 462 class AssociateMemberToFleetRequest < Struct.new( :farm_id, :fleet_id, :principal_type, :identity_store_id, :membership_level, :principal_id, :identity_center_region) SENSITIVE = [] include Aws::Structure end |
#principal_id ⇒ String
The member’s principal ID to associate with a fleet.
462 463 464 465 466 467 468 469 470 471 472 |
# File 'lib/aws-sdk-deadline/types.rb', line 462 class AssociateMemberToFleetRequest < Struct.new( :farm_id, :fleet_id, :principal_type, :identity_store_id, :membership_level, :principal_id, :identity_center_region) SENSITIVE = [] include Aws::Structure end |
#principal_type ⇒ String
The member’s principal type to associate with the fleet.
462 463 464 465 466 467 468 469 470 471 472 |
# File 'lib/aws-sdk-deadline/types.rb', line 462 class AssociateMemberToFleetRequest < Struct.new( :farm_id, :fleet_id, :principal_type, :identity_store_id, :membership_level, :principal_id, :identity_center_region) SENSITIVE = [] include Aws::Structure end |