Class: Aws::Deadline::Types::AssociateMemberToJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::AssociateMemberToJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Shared member fields for Associate inputs and ResourceMember response structures. principalId is excluded because it has @httpLabel on inputs but not on responses.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#farm_id ⇒ String
The farm ID of the job to associate with the member.
-
#identity_center_region ⇒ String
The Region of the IAM Identity Center instance.
-
#identity_store_id ⇒ String
The member’s identity store ID to associate with the job.
-
#job_id ⇒ String
The job ID to associate with the member.
-
#membership_level ⇒ String
The principal’s membership level for the associated job.
-
#principal_id ⇒ String
The member’s principal ID to associate with the job.
-
#principal_type ⇒ String
The member’s principal type to associate with the job.
-
#queue_id ⇒ String
The queue ID to associate to the member.
Instance Attribute Details
#farm_id ⇒ String
The farm ID of the job to associate with the member.
517 518 519 520 521 522 523 524 525 526 527 528 |
# File 'lib/aws-sdk-deadline/types.rb', line 517 class AssociateMemberToJobRequest < Struct.new( :farm_id, :queue_id, :job_id, :principal_type, :identity_store_id, :membership_level, :principal_id, :identity_center_region) SENSITIVE = [] include Aws::Structure end |
#identity_center_region ⇒ String
The Region of the IAM Identity Center instance. If not provided, the service defaults to the Region of the farm.
517 518 519 520 521 522 523 524 525 526 527 528 |
# File 'lib/aws-sdk-deadline/types.rb', line 517 class AssociateMemberToJobRequest < Struct.new( :farm_id, :queue_id, :job_id, :principal_type, :identity_store_id, :membership_level, :principal_id, :identity_center_region) SENSITIVE = [] include Aws::Structure end |
#identity_store_id ⇒ String
The member’s identity store ID to associate with the job.
517 518 519 520 521 522 523 524 525 526 527 528 |
# File 'lib/aws-sdk-deadline/types.rb', line 517 class AssociateMemberToJobRequest < Struct.new( :farm_id, :queue_id, :job_id, :principal_type, :identity_store_id, :membership_level, :principal_id, :identity_center_region) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The job ID to associate with the member.
517 518 519 520 521 522 523 524 525 526 527 528 |
# File 'lib/aws-sdk-deadline/types.rb', line 517 class AssociateMemberToJobRequest < Struct.new( :farm_id, :queue_id, :job_id, :principal_type, :identity_store_id, :membership_level, :principal_id, :identity_center_region) SENSITIVE = [] include Aws::Structure end |
#membership_level ⇒ String
The principal’s membership level for the associated job.
517 518 519 520 521 522 523 524 525 526 527 528 |
# File 'lib/aws-sdk-deadline/types.rb', line 517 class AssociateMemberToJobRequest < Struct.new( :farm_id, :queue_id, :job_id, :principal_type, :identity_store_id, :membership_level, :principal_id, :identity_center_region) SENSITIVE = [] include Aws::Structure end |
#principal_id ⇒ String
The member’s principal ID to associate with the job.
517 518 519 520 521 522 523 524 525 526 527 528 |
# File 'lib/aws-sdk-deadline/types.rb', line 517 class AssociateMemberToJobRequest < Struct.new( :farm_id, :queue_id, :job_id, :principal_type, :identity_store_id, :membership_level, :principal_id, :identity_center_region) SENSITIVE = [] include Aws::Structure end |
#principal_type ⇒ String
The member’s principal type to associate with the job.
517 518 519 520 521 522 523 524 525 526 527 528 |
# File 'lib/aws-sdk-deadline/types.rb', line 517 class AssociateMemberToJobRequest < Struct.new( :farm_id, :queue_id, :job_id, :principal_type, :identity_store_id, :membership_level, :principal_id, :identity_center_region) SENSITIVE = [] include Aws::Structure end |
#queue_id ⇒ String
The queue ID to associate to the member.
517 518 519 520 521 522 523 524 525 526 527 528 |
# File 'lib/aws-sdk-deadline/types.rb', line 517 class AssociateMemberToJobRequest < Struct.new( :farm_id, :queue_id, :job_id, :principal_type, :identity_store_id, :membership_level, :principal_id, :identity_center_region) SENSITIVE = [] include Aws::Structure end |