Class: Aws::Deadline::Types::AssociateMemberToQueueRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::AssociateMemberToQueueRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Shared member fields for Associate inputs and ResourceMember response structures. principalId is excluded because it has @httpLabel on inputs but not on responses.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#farm_id ⇒ String
The farm ID of the queue to associate with the member.
-
#identity_center_region ⇒ String
The Region of the IAM Identity Center instance.
-
#identity_store_id ⇒ String
The member’s identity store ID to associate with the queue.
-
#membership_level ⇒ String
The principal’s membership level for the associated queue.
-
#principal_id ⇒ String
The member’s principal ID to associate with the queue.
-
#principal_type ⇒ String
The member’s principal type to associate with the queue.
-
#queue_id ⇒ String
The ID of the queue to associate to the member.
Instance Attribute Details
#farm_id ⇒ String
The farm ID of the queue to associate with the member.
569 570 571 572 573 574 575 576 577 578 579 |
# File 'lib/aws-sdk-deadline/types.rb', line 569 class AssociateMemberToQueueRequest < Struct.new( :farm_id, :queue_id, :principal_type, :identity_store_id, :membership_level, :principal_id, :identity_center_region) SENSITIVE = [] include Aws::Structure end |
#identity_center_region ⇒ String
The Region of the IAM Identity Center instance. If not provided, the service defaults to the Region of the farm.
569 570 571 572 573 574 575 576 577 578 579 |
# File 'lib/aws-sdk-deadline/types.rb', line 569 class AssociateMemberToQueueRequest < Struct.new( :farm_id, :queue_id, :principal_type, :identity_store_id, :membership_level, :principal_id, :identity_center_region) SENSITIVE = [] include Aws::Structure end |
#identity_store_id ⇒ String
The member’s identity store ID to associate with the queue.
569 570 571 572 573 574 575 576 577 578 579 |
# File 'lib/aws-sdk-deadline/types.rb', line 569 class AssociateMemberToQueueRequest < Struct.new( :farm_id, :queue_id, :principal_type, :identity_store_id, :membership_level, :principal_id, :identity_center_region) SENSITIVE = [] include Aws::Structure end |
#membership_level ⇒ String
The principal’s membership level for the associated queue.
569 570 571 572 573 574 575 576 577 578 579 |
# File 'lib/aws-sdk-deadline/types.rb', line 569 class AssociateMemberToQueueRequest < Struct.new( :farm_id, :queue_id, :principal_type, :identity_store_id, :membership_level, :principal_id, :identity_center_region) SENSITIVE = [] include Aws::Structure end |
#principal_id ⇒ String
The member’s principal ID to associate with the queue.
569 570 571 572 573 574 575 576 577 578 579 |
# File 'lib/aws-sdk-deadline/types.rb', line 569 class AssociateMemberToQueueRequest < Struct.new( :farm_id, :queue_id, :principal_type, :identity_store_id, :membership_level, :principal_id, :identity_center_region) SENSITIVE = [] include Aws::Structure end |
#principal_type ⇒ String
The member’s principal type to associate with the queue.
569 570 571 572 573 574 575 576 577 578 579 |
# File 'lib/aws-sdk-deadline/types.rb', line 569 class AssociateMemberToQueueRequest < Struct.new( :farm_id, :queue_id, :principal_type, :identity_store_id, :membership_level, :principal_id, :identity_center_region) SENSITIVE = [] include Aws::Structure end |
#queue_id ⇒ String
The ID of the queue to associate to the member.
569 570 571 572 573 574 575 576 577 578 579 |
# File 'lib/aws-sdk-deadline/types.rb', line 569 class AssociateMemberToQueueRequest < Struct.new( :farm_id, :queue_id, :principal_type, :identity_store_id, :membership_level, :principal_id, :identity_center_region) SENSITIVE = [] include Aws::Structure end |