Class: Aws::Deadline::Types::BatchGetJobError

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

The error details for a job that could not be retrieved in a batch get operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeString

The error code.

Returns:

  • (String)


850
851
852
853
854
855
856
857
858
# File 'lib/aws-sdk-deadline/types.rb', line 850

class BatchGetJobError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#farm_idString

The farm ID of the job that could not be retrieved.

Returns:

  • (String)


850
851
852
853
854
855
856
857
858
# File 'lib/aws-sdk-deadline/types.rb', line 850

class BatchGetJobError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The job ID of the job that could not be retrieved.

Returns:

  • (String)


850
851
852
853
854
855
856
857
858
# File 'lib/aws-sdk-deadline/types.rb', line 850

class BatchGetJobError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

The error message.

Returns:

  • (String)


850
851
852
853
854
855
856
857
858
# File 'lib/aws-sdk-deadline/types.rb', line 850

class BatchGetJobError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#queue_idString

The queue ID of the job that could not be retrieved.

Returns:

  • (String)


850
851
852
853
854
855
856
857
858
# File 'lib/aws-sdk-deadline/types.rb', line 850

class BatchGetJobError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end