Class: Aws::Deadline::Types::BatchGetJobItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::BatchGetJobItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
The details of a job returned in a batch get operation.
Constant Summary collapse
- SENSITIVE =
[:parameters, :description]
Instance Attribute Summary collapse
-
#attachments ⇒ Types::Attachments
The attachments for the job.
-
#created_at ⇒ Time
The date and time the resource was created.
-
#created_by ⇒ String
The user or system that created this resource.
-
#description ⇒ String
The description of the job.
-
#ended_at ⇒ Time
The date and time the resource ended running.
-
#farm_id ⇒ String
The farm ID of the job.
-
#job_id ⇒ String
The job ID.
-
#lifecycle_status ⇒ String
The life cycle status of the job.
-
#lifecycle_status_message ⇒ String
A message that communicates the status of the life cycle.
-
#max_failed_tasks_count ⇒ Integer
The number of task failures before the job stops running and is marked as ‘FAILED`.
-
#max_retries_per_task ⇒ Integer
The maximum number of retries per failed tasks.
-
#max_worker_count ⇒ Integer
The maximum number of worker hosts that can concurrently process a job.
-
#name ⇒ String
The name of the job.
-
#parameters ⇒ Hash<String,Types::JobParameter>
The parameters for the job.
-
#priority ⇒ Integer
The job priority.
-
#queue_id ⇒ String
The queue ID of the job.
-
#source_job_id ⇒ String
The job ID for the source job.
-
#started_at ⇒ Time
The date and time the resource started running.
-
#storage_profile_id ⇒ String
The storage profile ID associated with the job.
-
#target_task_run_status ⇒ String
The task status to start with on the job.
-
#task_failure_retry_count ⇒ Integer
The number of times that tasks failed and were retried.
-
#task_run_status ⇒ String
The task run status for the job.
-
#task_run_status_counts ⇒ Hash<String,Integer>
The number of tasks for each run status for the job.
-
#updated_at ⇒ Time
The date and time the resource was updated.
-
#updated_by ⇒ String
The user or system that updated this resource.
Instance Attribute Details
#attachments ⇒ Types::Attachments
The attachments for the job.
1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-deadline/types.rb', line 1025 class BatchGetJobItem < Struct.new( :farm_id, :queue_id, :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#created_at ⇒ Time
The date and time the resource was created.
1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-deadline/types.rb', line 1025 class BatchGetJobItem < Struct.new( :farm_id, :queue_id, :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#created_by ⇒ String
The user or system that created this resource.
1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-deadline/types.rb', line 1025 class BatchGetJobItem < Struct.new( :farm_id, :queue_id, :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#description ⇒ String
The description of the job.
1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-deadline/types.rb', line 1025 class BatchGetJobItem < Struct.new( :farm_id, :queue_id, :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#ended_at ⇒ Time
The date and time the resource ended running.
1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-deadline/types.rb', line 1025 class BatchGetJobItem < Struct.new( :farm_id, :queue_id, :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#farm_id ⇒ String
The farm ID of the job.
1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-deadline/types.rb', line 1025 class BatchGetJobItem < Struct.new( :farm_id, :queue_id, :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#job_id ⇒ String
The job ID.
1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-deadline/types.rb', line 1025 class BatchGetJobItem < Struct.new( :farm_id, :queue_id, :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#lifecycle_status ⇒ String
The life cycle status of the job.
1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-deadline/types.rb', line 1025 class BatchGetJobItem < Struct.new( :farm_id, :queue_id, :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#lifecycle_status_message ⇒ String
A message that communicates the status of the life cycle.
1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-deadline/types.rb', line 1025 class BatchGetJobItem < Struct.new( :farm_id, :queue_id, :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#max_failed_tasks_count ⇒ Integer
The number of task failures before the job stops running and is marked as ‘FAILED`.
1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-deadline/types.rb', line 1025 class BatchGetJobItem < Struct.new( :farm_id, :queue_id, :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#max_retries_per_task ⇒ Integer
The maximum number of retries per failed tasks.
1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-deadline/types.rb', line 1025 class BatchGetJobItem < Struct.new( :farm_id, :queue_id, :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#max_worker_count ⇒ Integer
The maximum number of worker hosts that can concurrently process a job.
1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-deadline/types.rb', line 1025 class BatchGetJobItem < Struct.new( :farm_id, :queue_id, :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#name ⇒ String
The name of the job.
1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-deadline/types.rb', line 1025 class BatchGetJobItem < Struct.new( :farm_id, :queue_id, :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#parameters ⇒ Hash<String,Types::JobParameter>
The parameters for the job.
1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-deadline/types.rb', line 1025 class BatchGetJobItem < Struct.new( :farm_id, :queue_id, :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#priority ⇒ Integer
The job priority.
1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-deadline/types.rb', line 1025 class BatchGetJobItem < Struct.new( :farm_id, :queue_id, :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#queue_id ⇒ String
The queue ID of the job.
1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-deadline/types.rb', line 1025 class BatchGetJobItem < Struct.new( :farm_id, :queue_id, :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#source_job_id ⇒ String
The job ID for the source job.
1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-deadline/types.rb', line 1025 class BatchGetJobItem < Struct.new( :farm_id, :queue_id, :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#started_at ⇒ Time
The date and time the resource started running.
1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-deadline/types.rb', line 1025 class BatchGetJobItem < Struct.new( :farm_id, :queue_id, :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#storage_profile_id ⇒ String
The storage profile ID associated with the job.
1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-deadline/types.rb', line 1025 class BatchGetJobItem < Struct.new( :farm_id, :queue_id, :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#target_task_run_status ⇒ String
The task status to start with on the job.
1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-deadline/types.rb', line 1025 class BatchGetJobItem < Struct.new( :farm_id, :queue_id, :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#task_failure_retry_count ⇒ Integer
The number of times that tasks failed and were retried.
1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-deadline/types.rb', line 1025 class BatchGetJobItem < Struct.new( :farm_id, :queue_id, :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#task_run_status ⇒ String
The task run status for the job.
1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-deadline/types.rb', line 1025 class BatchGetJobItem < Struct.new( :farm_id, :queue_id, :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#task_run_status_counts ⇒ Hash<String,Integer>
The number of tasks for each run status for the job.
1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-deadline/types.rb', line 1025 class BatchGetJobItem < Struct.new( :farm_id, :queue_id, :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the resource was updated.
1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-deadline/types.rb', line 1025 class BatchGetJobItem < Struct.new( :farm_id, :queue_id, :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#updated_by ⇒ String
The user or system that updated this resource.
1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/aws-sdk-deadline/types.rb', line 1025 class BatchGetJobItem < Struct.new( :farm_id, :queue_id, :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |