Class: Aws::Deadline::Types::BatchGetSessionActionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#errorsArray<Types::BatchGetSessionActionError>

A list of errors for session actions that could not be retrieved.



1262
1263
1264
1265
1266
1267
# File 'lib/aws-sdk-deadline/types.rb', line 1262

class BatchGetSessionActionResponse < Struct.new(
  :session_actions,
  :errors)
  SENSITIVE = []
  include Aws::Structure
end

#session_actionsArray<Types::BatchGetSessionActionItem>

A list of session actions that were successfully retrieved.



1262
1263
1264
1265
1266
1267
# File 'lib/aws-sdk-deadline/types.rb', line 1262

class BatchGetSessionActionResponse < Struct.new(
  :session_actions,
  :errors)
  SENSITIVE = []
  include Aws::Structure
end