Class: Aws::Deadline::Types::BatchGetSessionError
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::BatchGetSessionError
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
The error details for a session that could not be retrieved in a batch get operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
The error code.
-
#farm_id ⇒ String
The farm ID of the session that could not be retrieved.
-
#job_id ⇒ String
The job ID of the session that could not be retrieved.
-
#message ⇒ String
The error message.
-
#queue_id ⇒ String
The queue ID of the session that could not be retrieved.
-
#session_id ⇒ String
The session ID of the session that could not be retrieved.
Instance Attribute Details
#code ⇒ String
The error code.
1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 |
# File 'lib/aws-sdk-deadline/types.rb', line 1263 class BatchGetSessionError < Struct.new( :farm_id, :queue_id, :job_id, :session_id, :code, :message) SENSITIVE = [] include Aws::Structure end |
#farm_id ⇒ String
The farm ID of the session that could not be retrieved.
1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 |
# File 'lib/aws-sdk-deadline/types.rb', line 1263 class BatchGetSessionError < Struct.new( :farm_id, :queue_id, :job_id, :session_id, :code, :message) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The job ID of the session that could not be retrieved.
1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 |
# File 'lib/aws-sdk-deadline/types.rb', line 1263 class BatchGetSessionError < Struct.new( :farm_id, :queue_id, :job_id, :session_id, :code, :message) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
The error message.
1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 |
# File 'lib/aws-sdk-deadline/types.rb', line 1263 class BatchGetSessionError < Struct.new( :farm_id, :queue_id, :job_id, :session_id, :code, :message) SENSITIVE = [] include Aws::Structure end |
#queue_id ⇒ String
The queue ID of the session that could not be retrieved.
1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 |
# File 'lib/aws-sdk-deadline/types.rb', line 1263 class BatchGetSessionError < Struct.new( :farm_id, :queue_id, :job_id, :session_id, :code, :message) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The session ID of the session that could not be retrieved.
1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 |
# File 'lib/aws-sdk-deadline/types.rb', line 1263 class BatchGetSessionError < Struct.new( :farm_id, :queue_id, :job_id, :session_id, :code, :message) SENSITIVE = [] include Aws::Structure end |