Class: Aws::Deadline::Types::BatchGetStepError

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

The error details for a step that could not be retrieved in a batch get operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeString

The error code.

Returns:

  • (String)


1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
# File 'lib/aws-sdk-deadline/types.rb', line 1446

class BatchGetStepError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#farm_idString

The farm ID of the step that could not be retrieved.

Returns:

  • (String)


1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
# File 'lib/aws-sdk-deadline/types.rb', line 1446

class BatchGetStepError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The job ID of the step that could not be retrieved.

Returns:

  • (String)


1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
# File 'lib/aws-sdk-deadline/types.rb', line 1446

class BatchGetStepError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

The error message.

Returns:

  • (String)


1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
# File 'lib/aws-sdk-deadline/types.rb', line 1446

class BatchGetStepError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#queue_idString

The queue ID of the step that could not be retrieved.

Returns:

  • (String)


1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
# File 'lib/aws-sdk-deadline/types.rb', line 1446

class BatchGetStepError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#step_idString

The step ID of the step that could not be retrieved.

Returns:

  • (String)


1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
# File 'lib/aws-sdk-deadline/types.rb', line 1446

class BatchGetStepError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end