Class: Aws::Deadline::Types::BatchGetStepItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

The details of a step returned in a batch get operation.

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The date and time the resource was created.

Returns:

  • (Time)


1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-deadline/types.rb', line 1609

class BatchGetStepItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :target_task_run_status,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :dependency_counts,
  :required_capabilities,
  :parameter_space,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#created_byString

The user or system that created this resource.

Returns:

  • (String)


1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-deadline/types.rb', line 1609

class BatchGetStepItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :target_task_run_status,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :dependency_counts,
  :required_capabilities,
  :parameter_space,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#dependency_countsTypes::DependencyCounts

The number of dependencies for the step.



1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-deadline/types.rb', line 1609

class BatchGetStepItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :target_task_run_status,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :dependency_counts,
  :required_capabilities,
  :parameter_space,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

The description of the step.

Returns:

  • (String)


1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-deadline/types.rb', line 1609

class BatchGetStepItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :target_task_run_status,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :dependency_counts,
  :required_capabilities,
  :parameter_space,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#ended_atTime

The date and time the resource ended running.

Returns:

  • (Time)


1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-deadline/types.rb', line 1609

class BatchGetStepItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :target_task_run_status,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :dependency_counts,
  :required_capabilities,
  :parameter_space,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#farm_idString

The farm ID of the step.

Returns:

  • (String)


1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-deadline/types.rb', line 1609

class BatchGetStepItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :target_task_run_status,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :dependency_counts,
  :required_capabilities,
  :parameter_space,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#job_idString

The job ID of the step.

Returns:

  • (String)


1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-deadline/types.rb', line 1609

class BatchGetStepItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :target_task_run_status,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :dependency_counts,
  :required_capabilities,
  :parameter_space,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#lifecycle_statusString

The life cycle status of the step.

Returns:

  • (String)


1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-deadline/types.rb', line 1609

class BatchGetStepItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :target_task_run_status,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :dependency_counts,
  :required_capabilities,
  :parameter_space,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#lifecycle_status_messageString

A message that communicates the status of the life cycle.

Returns:

  • (String)


1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-deadline/types.rb', line 1609

class BatchGetStepItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :target_task_run_status,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :dependency_counts,
  :required_capabilities,
  :parameter_space,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#nameString

The name of the step.

Returns:

  • (String)


1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-deadline/types.rb', line 1609

class BatchGetStepItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :target_task_run_status,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :dependency_counts,
  :required_capabilities,
  :parameter_space,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#parameter_spaceTypes::ParameterSpace

The parameter space for the step.



1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-deadline/types.rb', line 1609

class BatchGetStepItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :target_task_run_status,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :dependency_counts,
  :required_capabilities,
  :parameter_space,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#queue_idString

The queue ID of the step.

Returns:

  • (String)


1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-deadline/types.rb', line 1609

class BatchGetStepItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :target_task_run_status,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :dependency_counts,
  :required_capabilities,
  :parameter_space,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#required_capabilitiesTypes::StepRequiredCapabilities

The required capabilities for the step.



1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-deadline/types.rb', line 1609

class BatchGetStepItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :target_task_run_status,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :dependency_counts,
  :required_capabilities,
  :parameter_space,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#started_atTime

The date and time the resource started running.

Returns:

  • (Time)


1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-deadline/types.rb', line 1609

class BatchGetStepItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :target_task_run_status,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :dependency_counts,
  :required_capabilities,
  :parameter_space,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#step_idString

The step ID.

Returns:

  • (String)


1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-deadline/types.rb', line 1609

class BatchGetStepItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :target_task_run_status,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :dependency_counts,
  :required_capabilities,
  :parameter_space,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#target_task_run_statusString

The task status to start with on the step.

Returns:

  • (String)


1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-deadline/types.rb', line 1609

class BatchGetStepItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :target_task_run_status,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :dependency_counts,
  :required_capabilities,
  :parameter_space,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#task_failure_retry_countInteger

The number of times that tasks failed and were retried.

Returns:

  • (Integer)


1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-deadline/types.rb', line 1609

class BatchGetStepItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :target_task_run_status,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :dependency_counts,
  :required_capabilities,
  :parameter_space,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#task_run_statusString

The task run status for the step.

Returns:

  • (String)


1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-deadline/types.rb', line 1609

class BatchGetStepItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :target_task_run_status,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :dependency_counts,
  :required_capabilities,
  :parameter_space,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#task_run_status_countsHash<String,Integer>

The number of tasks for each run status for the step.

Returns:

  • (Hash<String,Integer>)


1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-deadline/types.rb', line 1609

class BatchGetStepItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :target_task_run_status,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :dependency_counts,
  :required_capabilities,
  :parameter_space,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#updated_atTime

The date and time the resource was updated.

Returns:

  • (Time)


1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-deadline/types.rb', line 1609

class BatchGetStepItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :target_task_run_status,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :dependency_counts,
  :required_capabilities,
  :parameter_space,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#updated_byString

The user or system that updated this resource.

Returns:

  • (String)


1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-deadline/types.rb', line 1609

class BatchGetStepItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :target_task_run_status,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :dependency_counts,
  :required_capabilities,
  :parameter_space,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end