Class: Aws::Deadline::Types::BatchGetTaskItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

The details of a task returned in a batch get operation.

Constant Summary collapse

SENSITIVE =
[:parameters]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The date and time the resource was created.



1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
# File 'lib/aws-sdk-deadline/types.rb', line 1812

class BatchGetTaskItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :task_id,
  :created_at,
  :created_by,
  :run_status,
  :target_run_status,
  :failure_retry_count,
  :started_at,
  :ended_at,
  :updated_at,
  :updated_by,
  :latest_session_action_id,
  :parameters)
  SENSITIVE = [:parameters]
  include Aws::Structure
end

#created_byString

The user or system that created this resource.



1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
# File 'lib/aws-sdk-deadline/types.rb', line 1812

class BatchGetTaskItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :task_id,
  :created_at,
  :created_by,
  :run_status,
  :target_run_status,
  :failure_retry_count,
  :started_at,
  :ended_at,
  :updated_at,
  :updated_by,
  :latest_session_action_id,
  :parameters)
  SENSITIVE = [:parameters]
  include Aws::Structure
end

#ended_atTime

The date and time the resource ended running.



1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
# File 'lib/aws-sdk-deadline/types.rb', line 1812

class BatchGetTaskItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :task_id,
  :created_at,
  :created_by,
  :run_status,
  :target_run_status,
  :failure_retry_count,
  :started_at,
  :ended_at,
  :updated_at,
  :updated_by,
  :latest_session_action_id,
  :parameters)
  SENSITIVE = [:parameters]
  include Aws::Structure
end

#failure_retry_countInteger

The number of times the task failed and was retried.



1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
# File 'lib/aws-sdk-deadline/types.rb', line 1812

class BatchGetTaskItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :task_id,
  :created_at,
  :created_by,
  :run_status,
  :target_run_status,
  :failure_retry_count,
  :started_at,
  :ended_at,
  :updated_at,
  :updated_by,
  :latest_session_action_id,
  :parameters)
  SENSITIVE = [:parameters]
  include Aws::Structure
end

#farm_idString

The farm ID of the task.



1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
# File 'lib/aws-sdk-deadline/types.rb', line 1812

class BatchGetTaskItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :task_id,
  :created_at,
  :created_by,
  :run_status,
  :target_run_status,
  :failure_retry_count,
  :started_at,
  :ended_at,
  :updated_at,
  :updated_by,
  :latest_session_action_id,
  :parameters)
  SENSITIVE = [:parameters]
  include Aws::Structure
end

#job_idString

The job ID of the task.



1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
# File 'lib/aws-sdk-deadline/types.rb', line 1812

class BatchGetTaskItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :task_id,
  :created_at,
  :created_by,
  :run_status,
  :target_run_status,
  :failure_retry_count,
  :started_at,
  :ended_at,
  :updated_at,
  :updated_by,
  :latest_session_action_id,
  :parameters)
  SENSITIVE = [:parameters]
  include Aws::Structure
end

#latest_session_action_idString

The latest session action for the task.



1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
# File 'lib/aws-sdk-deadline/types.rb', line 1812

class BatchGetTaskItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :task_id,
  :created_at,
  :created_by,
  :run_status,
  :target_run_status,
  :failure_retry_count,
  :started_at,
  :ended_at,
  :updated_at,
  :updated_by,
  :latest_session_action_id,
  :parameters)
  SENSITIVE = [:parameters]
  include Aws::Structure
end

#parametersHash<String,Types::TaskParameterValue>

The parameters for the task.



1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
# File 'lib/aws-sdk-deadline/types.rb', line 1812

class BatchGetTaskItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :task_id,
  :created_at,
  :created_by,
  :run_status,
  :target_run_status,
  :failure_retry_count,
  :started_at,
  :ended_at,
  :updated_at,
  :updated_by,
  :latest_session_action_id,
  :parameters)
  SENSITIVE = [:parameters]
  include Aws::Structure
end

#queue_idString

The queue ID of the task.



1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
# File 'lib/aws-sdk-deadline/types.rb', line 1812

class BatchGetTaskItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :task_id,
  :created_at,
  :created_by,
  :run_status,
  :target_run_status,
  :failure_retry_count,
  :started_at,
  :ended_at,
  :updated_at,
  :updated_by,
  :latest_session_action_id,
  :parameters)
  SENSITIVE = [:parameters]
  include Aws::Structure
end

#run_statusString

The run status of the task.



1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
# File 'lib/aws-sdk-deadline/types.rb', line 1812

class BatchGetTaskItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :task_id,
  :created_at,
  :created_by,
  :run_status,
  :target_run_status,
  :failure_retry_count,
  :started_at,
  :ended_at,
  :updated_at,
  :updated_by,
  :latest_session_action_id,
  :parameters)
  SENSITIVE = [:parameters]
  include Aws::Structure
end

#started_atTime

The date and time the resource started running.



1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
# File 'lib/aws-sdk-deadline/types.rb', line 1812

class BatchGetTaskItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :task_id,
  :created_at,
  :created_by,
  :run_status,
  :target_run_status,
  :failure_retry_count,
  :started_at,
  :ended_at,
  :updated_at,
  :updated_by,
  :latest_session_action_id,
  :parameters)
  SENSITIVE = [:parameters]
  include Aws::Structure
end

#step_idString

The step ID of the task.



1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
# File 'lib/aws-sdk-deadline/types.rb', line 1812

class BatchGetTaskItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :task_id,
  :created_at,
  :created_by,
  :run_status,
  :target_run_status,
  :failure_retry_count,
  :started_at,
  :ended_at,
  :updated_at,
  :updated_by,
  :latest_session_action_id,
  :parameters)
  SENSITIVE = [:parameters]
  include Aws::Structure
end

#target_run_statusString

The run status with which to start the task.



1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
# File 'lib/aws-sdk-deadline/types.rb', line 1812

class BatchGetTaskItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :task_id,
  :created_at,
  :created_by,
  :run_status,
  :target_run_status,
  :failure_retry_count,
  :started_at,
  :ended_at,
  :updated_at,
  :updated_by,
  :latest_session_action_id,
  :parameters)
  SENSITIVE = [:parameters]
  include Aws::Structure
end

#task_idString

The task ID.



1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
# File 'lib/aws-sdk-deadline/types.rb', line 1812

class BatchGetTaskItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :task_id,
  :created_at,
  :created_by,
  :run_status,
  :target_run_status,
  :failure_retry_count,
  :started_at,
  :ended_at,
  :updated_at,
  :updated_by,
  :latest_session_action_id,
  :parameters)
  SENSITIVE = [:parameters]
  include Aws::Structure
end

#updated_atTime

The date and time the resource was updated.



1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
# File 'lib/aws-sdk-deadline/types.rb', line 1812

class BatchGetTaskItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :task_id,
  :created_at,
  :created_by,
  :run_status,
  :target_run_status,
  :failure_retry_count,
  :started_at,
  :ended_at,
  :updated_at,
  :updated_by,
  :latest_session_action_id,
  :parameters)
  SENSITIVE = [:parameters]
  include Aws::Structure
end

#updated_byString

The user or system that updated this resource.



1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
# File 'lib/aws-sdk-deadline/types.rb', line 1812

class BatchGetTaskItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :task_id,
  :created_at,
  :created_by,
  :run_status,
  :target_run_status,
  :failure_retry_count,
  :started_at,
  :ended_at,
  :updated_at,
  :updated_by,
  :latest_session_action_id,
  :parameters)
  SENSITIVE = [:parameters]
  include Aws::Structure
end