Class: Aws::Deadline::Types::BatchGetWorkerError

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

The error details for a worker that could not be retrieved in a batch get operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeString

The error code.

Returns:



1888
1889
1890
1891
1892
1893
1894
1895
1896
# File 'lib/aws-sdk-deadline/types.rb', line 1888

class BatchGetWorkerError < Struct.new(
  :farm_id,
  :fleet_id,
  :worker_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#farm_idString

The farm ID of the worker that could not be retrieved.

Returns:



1888
1889
1890
1891
1892
1893
1894
1895
1896
# File 'lib/aws-sdk-deadline/types.rb', line 1888

class BatchGetWorkerError < Struct.new(
  :farm_id,
  :fleet_id,
  :worker_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#fleet_idString

The fleet ID of the worker that could not be retrieved.

Returns:



1888
1889
1890
1891
1892
1893
1894
1895
1896
# File 'lib/aws-sdk-deadline/types.rb', line 1888

class BatchGetWorkerError < Struct.new(
  :farm_id,
  :fleet_id,
  :worker_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

The error message.

Returns:



1888
1889
1890
1891
1892
1893
1894
1895
1896
# File 'lib/aws-sdk-deadline/types.rb', line 1888

class BatchGetWorkerError < Struct.new(
  :farm_id,
  :fleet_id,
  :worker_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#worker_idString

The worker ID of the worker that could not be retrieved.

Returns:



1888
1889
1890
1891
1892
1893
1894
1895
1896
# File 'lib/aws-sdk-deadline/types.rb', line 1888

class BatchGetWorkerError < Struct.new(
  :farm_id,
  :fleet_id,
  :worker_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end