Class: Aws::Deadline::Types::BatchGetWorkerResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::BatchGetWorkerResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#errors ⇒ Array<Types::BatchGetWorkerError>
A list of errors for workers that could not be retrieved.
-
#workers ⇒ Array<Types::BatchGetWorkerItem>
A list of workers that were successfully retrieved.
Instance Attribute Details
#errors ⇒ Array<Types::BatchGetWorkerError>
A list of errors for workers that could not be retrieved.
1969 1970 1971 1972 1973 1974 |
# File 'lib/aws-sdk-deadline/types.rb', line 1969 class BatchGetWorkerResponse < Struct.new( :workers, :errors) SENSITIVE = [] include Aws::Structure end |
#workers ⇒ Array<Types::BatchGetWorkerItem>
A list of workers that were successfully retrieved.
1969 1970 1971 1972 1973 1974 |
# File 'lib/aws-sdk-deadline/types.rb', line 1969 class BatchGetWorkerResponse < Struct.new( :workers, :errors) SENSITIVE = [] include Aws::Structure end |