Class: Aws::Deadline::Types::BatchUpdateJobError

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

The error details for a job that could not be updated in a batch update operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeString

The error code.

Returns:

  • (String)


2012
2013
2014
2015
2016
2017
2018
2019
2020
# File 'lib/aws-sdk-deadline/types.rb', line 2012

class BatchUpdateJobError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#farm_idString

The farm ID of the job that could not be updated.

Returns:

  • (String)


2012
2013
2014
2015
2016
2017
2018
2019
2020
# File 'lib/aws-sdk-deadline/types.rb', line 2012

class BatchUpdateJobError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The job ID of the job that could not be updated.

Returns:

  • (String)


2012
2013
2014
2015
2016
2017
2018
2019
2020
# File 'lib/aws-sdk-deadline/types.rb', line 2012

class BatchUpdateJobError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

The error message.

Returns:

  • (String)


2012
2013
2014
2015
2016
2017
2018
2019
2020
# File 'lib/aws-sdk-deadline/types.rb', line 2012

class BatchUpdateJobError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#queue_idString

The queue ID of the job that could not be updated.

Returns:

  • (String)


2012
2013
2014
2015
2016
2017
2018
2019
2020
# File 'lib/aws-sdk-deadline/types.rb', line 2012

class BatchUpdateJobError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end