Class: Aws::Deadline::Types::BatchUpdateJobItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::BatchUpdateJobItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
The details of a job to update in a batch update operation.
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the job to update.
-
#farm_id ⇒ String
The farm ID of the job to update.
-
#job_id ⇒ String
The job ID of the job to update.
-
#lifecycle_status ⇒ String
The status of a job in its lifecycle.
-
#max_failed_tasks_count ⇒ Integer
The number of task failures before the job stops running and is marked as ‘FAILED`.
-
#max_retries_per_task ⇒ Integer
The maximum number of retries per failed tasks.
-
#max_worker_count ⇒ Integer
The maximum number of worker hosts that can concurrently process a job.
-
#name ⇒ String
The name of the job to update.
-
#priority ⇒ Integer
The job priority to update.
-
#queue_id ⇒ String
The queue ID of the job to update.
-
#target_task_run_status ⇒ String
The task status to update the job’s tasks to.
Instance Attribute Details
#description ⇒ String
The description of the job to update.
2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 |
# File 'lib/aws-sdk-deadline/types.rb', line 2100 class BatchUpdateJobItem < Struct.new( :farm_id, :queue_id, :job_id, :target_task_run_status, :priority, :max_failed_tasks_count, :max_retries_per_task, :lifecycle_status, :max_worker_count, :name, :description) SENSITIVE = [:description] include Aws::Structure end |
#farm_id ⇒ String
The farm ID of the job to update.
2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 |
# File 'lib/aws-sdk-deadline/types.rb', line 2100 class BatchUpdateJobItem < Struct.new( :farm_id, :queue_id, :job_id, :target_task_run_status, :priority, :max_failed_tasks_count, :max_retries_per_task, :lifecycle_status, :max_worker_count, :name, :description) SENSITIVE = [:description] include Aws::Structure end |
#job_id ⇒ String
The job ID of the job to update.
2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 |
# File 'lib/aws-sdk-deadline/types.rb', line 2100 class BatchUpdateJobItem < Struct.new( :farm_id, :queue_id, :job_id, :target_task_run_status, :priority, :max_failed_tasks_count, :max_retries_per_task, :lifecycle_status, :max_worker_count, :name, :description) SENSITIVE = [:description] include Aws::Structure end |
#lifecycle_status ⇒ String
The status of a job in its lifecycle. When you change the status of the job to ‘ARCHIVED`, the job can’t be scheduled or archived.
An archived job and its steps and tasks are deleted after 120 days. The job can’t be recovered.
2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 |
# File 'lib/aws-sdk-deadline/types.rb', line 2100 class BatchUpdateJobItem < Struct.new( :farm_id, :queue_id, :job_id, :target_task_run_status, :priority, :max_failed_tasks_count, :max_retries_per_task, :lifecycle_status, :max_worker_count, :name, :description) SENSITIVE = [:description] include Aws::Structure end |
#max_failed_tasks_count ⇒ Integer
The number of task failures before the job stops running and is marked as ‘FAILED`.
2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 |
# File 'lib/aws-sdk-deadline/types.rb', line 2100 class BatchUpdateJobItem < Struct.new( :farm_id, :queue_id, :job_id, :target_task_run_status, :priority, :max_failed_tasks_count, :max_retries_per_task, :lifecycle_status, :max_worker_count, :name, :description) SENSITIVE = [:description] include Aws::Structure end |
#max_retries_per_task ⇒ Integer
The maximum number of retries per failed tasks.
2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 |
# File 'lib/aws-sdk-deadline/types.rb', line 2100 class BatchUpdateJobItem < Struct.new( :farm_id, :queue_id, :job_id, :target_task_run_status, :priority, :max_failed_tasks_count, :max_retries_per_task, :lifecycle_status, :max_worker_count, :name, :description) SENSITIVE = [:description] include Aws::Structure end |
#max_worker_count ⇒ Integer
The maximum number of worker hosts that can concurrently process a job.
2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 |
# File 'lib/aws-sdk-deadline/types.rb', line 2100 class BatchUpdateJobItem < Struct.new( :farm_id, :queue_id, :job_id, :target_task_run_status, :priority, :max_failed_tasks_count, :max_retries_per_task, :lifecycle_status, :max_worker_count, :name, :description) SENSITIVE = [:description] include Aws::Structure end |
#name ⇒ String
The name of the job to update.
2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 |
# File 'lib/aws-sdk-deadline/types.rb', line 2100 class BatchUpdateJobItem < Struct.new( :farm_id, :queue_id, :job_id, :target_task_run_status, :priority, :max_failed_tasks_count, :max_retries_per_task, :lifecycle_status, :max_worker_count, :name, :description) SENSITIVE = [:description] include Aws::Structure end |
#priority ⇒ Integer
The job priority to update.
2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 |
# File 'lib/aws-sdk-deadline/types.rb', line 2100 class BatchUpdateJobItem < Struct.new( :farm_id, :queue_id, :job_id, :target_task_run_status, :priority, :max_failed_tasks_count, :max_retries_per_task, :lifecycle_status, :max_worker_count, :name, :description) SENSITIVE = [:description] include Aws::Structure end |
#queue_id ⇒ String
The queue ID of the job to update.
2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 |
# File 'lib/aws-sdk-deadline/types.rb', line 2100 class BatchUpdateJobItem < Struct.new( :farm_id, :queue_id, :job_id, :target_task_run_status, :priority, :max_failed_tasks_count, :max_retries_per_task, :lifecycle_status, :max_worker_count, :name, :description) SENSITIVE = [:description] include Aws::Structure end |
#target_task_run_status ⇒ String
The task status to update the job’s tasks to.
2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 |
# File 'lib/aws-sdk-deadline/types.rb', line 2100 class BatchUpdateJobItem < Struct.new( :farm_id, :queue_id, :job_id, :target_task_run_status, :priority, :max_failed_tasks_count, :max_retries_per_task, :lifecycle_status, :max_worker_count, :name, :description) SENSITIVE = [:description] include Aws::Structure end |