Class: Aws::Deadline::Types::BatchUpdateTaskRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::BatchUpdateTaskRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
The unique token which the server uses to recognize retries of the same request.
-
#tasks ⇒ Array<Types::BatchUpdateTaskItem>
The list of tasks to update.
Instance Attribute Details
#client_token ⇒ String
The unique token which the server uses to recognize retries of the same request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
2225 2226 2227 2228 2229 2230 |
# File 'lib/aws-sdk-deadline/types.rb', line 2225 class BatchUpdateTaskRequest < Struct.new( :client_token, :tasks) SENSITIVE = [] include Aws::Structure end |
#tasks ⇒ Array<Types::BatchUpdateTaskItem>
The list of tasks to update. You can specify up to 100 tasks per request.
2225 2226 2227 2228 2229 2230 |
# File 'lib/aws-sdk-deadline/types.rb', line 2225 class BatchUpdateTaskRequest < Struct.new( :client_token, :tasks) SENSITIVE = [] include Aws::Structure end |