Class: Aws::Deadline::Types::BudgetSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

The budget summary.

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#approximate_dollar_limitFloat

The approximate dollar limit of the budget.

Returns:

  • (Float)


2375
2376
2377
2378
2379
2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
# File 'lib/aws-sdk-deadline/types.rb', line 2375

class BudgetSummary < Struct.new(
  :budget_id,
  :usage_tracking_resource,
  :status,
  :display_name,
  :approximate_dollar_limit,
  :usages,
  :created_by,
  :created_at,
  :updated_by,
  :updated_at,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#budget_idString

The budget ID.

Returns:

  • (String)


2375
2376
2377
2378
2379
2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
# File 'lib/aws-sdk-deadline/types.rb', line 2375

class BudgetSummary < Struct.new(
  :budget_id,
  :usage_tracking_resource,
  :status,
  :display_name,
  :approximate_dollar_limit,
  :usages,
  :created_by,
  :created_at,
  :updated_by,
  :updated_at,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#created_atTime

The date and time the resource was created.

Returns:

  • (Time)


2375
2376
2377
2378
2379
2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
# File 'lib/aws-sdk-deadline/types.rb', line 2375

class BudgetSummary < Struct.new(
  :budget_id,
  :usage_tracking_resource,
  :status,
  :display_name,
  :approximate_dollar_limit,
  :usages,
  :created_by,
  :created_at,
  :updated_by,
  :updated_at,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#created_byString

The user or system that created this resource.

Returns:

  • (String)


2375
2376
2377
2378
2379
2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
# File 'lib/aws-sdk-deadline/types.rb', line 2375

class BudgetSummary < Struct.new(
  :budget_id,
  :usage_tracking_resource,
  :status,
  :display_name,
  :approximate_dollar_limit,
  :usages,
  :created_by,
  :created_at,
  :updated_by,
  :updated_at,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

The description of the budget summary.

This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.

Returns:

  • (String)


2375
2376
2377
2378
2379
2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
# File 'lib/aws-sdk-deadline/types.rb', line 2375

class BudgetSummary < Struct.new(
  :budget_id,
  :usage_tracking_resource,
  :status,
  :display_name,
  :approximate_dollar_limit,
  :usages,
  :created_by,
  :created_at,
  :updated_by,
  :updated_at,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#display_nameString

The display name of the budget summary to update.

This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.

Returns:

  • (String)


2375
2376
2377
2378
2379
2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
# File 'lib/aws-sdk-deadline/types.rb', line 2375

class BudgetSummary < Struct.new(
  :budget_id,
  :usage_tracking_resource,
  :status,
  :display_name,
  :approximate_dollar_limit,
  :usages,
  :created_by,
  :created_at,
  :updated_by,
  :updated_at,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#statusString

The status of the budget.

  • ‘ACTIVE`–The budget is being evaluated.

  • ‘INACTIVE`–The budget is inactive. This can include Expired, Canceled, or deleted Deleted statuses.

Returns:

  • (String)


2375
2376
2377
2378
2379
2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
# File 'lib/aws-sdk-deadline/types.rb', line 2375

class BudgetSummary < Struct.new(
  :budget_id,
  :usage_tracking_resource,
  :status,
  :display_name,
  :approximate_dollar_limit,
  :usages,
  :created_by,
  :created_at,
  :updated_by,
  :updated_at,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#updated_atTime

The date and time the resource was updated.

Returns:

  • (Time)


2375
2376
2377
2378
2379
2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
# File 'lib/aws-sdk-deadline/types.rb', line 2375

class BudgetSummary < Struct.new(
  :budget_id,
  :usage_tracking_resource,
  :status,
  :display_name,
  :approximate_dollar_limit,
  :usages,
  :created_by,
  :created_at,
  :updated_by,
  :updated_at,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#updated_byString

The user or system that updated this resource.

Returns:

  • (String)


2375
2376
2377
2378
2379
2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
# File 'lib/aws-sdk-deadline/types.rb', line 2375

class BudgetSummary < Struct.new(
  :budget_id,
  :usage_tracking_resource,
  :status,
  :display_name,
  :approximate_dollar_limit,
  :usages,
  :created_by,
  :created_at,
  :updated_by,
  :updated_at,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#usage_tracking_resourceTypes::UsageTrackingResource

The resource used to track expenditure in the budget.



2375
2376
2377
2378
2379
2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
# File 'lib/aws-sdk-deadline/types.rb', line 2375

class BudgetSummary < Struct.new(
  :budget_id,
  :usage_tracking_resource,
  :status,
  :display_name,
  :approximate_dollar_limit,
  :usages,
  :created_by,
  :created_at,
  :updated_by,
  :updated_at,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#usagesTypes::ConsumedUsages

The consumed usage for the budget.



2375
2376
2377
2378
2379
2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
# File 'lib/aws-sdk-deadline/types.rb', line 2375

class BudgetSummary < Struct.new(
  :budget_id,
  :usage_tracking_resource,
  :status,
  :display_name,
  :approximate_dollar_limit,
  :usages,
  :created_by,
  :created_at,
  :updated_by,
  :updated_at,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end