Class: Aws::Deadline::Types::CreateFarmRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Shared displayName + description for Create operations where both are present. displayName is @required here - this mixin is Create-only by design (Update has optional displayName).

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

The unique token which the server uses to recognize retries of the same request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
# File 'lib/aws-sdk-deadline/types.rb', line 2602

class CreateFarmRequest < Struct.new(
  :client_token,
  :display_name,
  :description,
  :kms_key_arn,
  :cost_scale_factor,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#cost_scale_factorFloat

A multiplier applied to the farm’s calculated costs for usage data and budget tracking. A value less than 1 represents a discount, a value greater than 1 represents a premium, and a value of 1 represents no adjustment. The default value is 1.

Returns:

  • (Float)


2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
# File 'lib/aws-sdk-deadline/types.rb', line 2602

class CreateFarmRequest < Struct.new(
  :client_token,
  :display_name,
  :description,
  :kms_key_arn,
  :cost_scale_factor,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

The description of the farm.

This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.

Returns:

  • (String)


2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
# File 'lib/aws-sdk-deadline/types.rb', line 2602

class CreateFarmRequest < Struct.new(
  :client_token,
  :display_name,
  :description,
  :kms_key_arn,
  :cost_scale_factor,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#display_nameString

The display name of the farm.

This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.

Returns:

  • (String)


2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
# File 'lib/aws-sdk-deadline/types.rb', line 2602

class CreateFarmRequest < Struct.new(
  :client_token,
  :display_name,
  :description,
  :kms_key_arn,
  :cost_scale_factor,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#kms_key_arnString

The ARN of the KMS key to use on the farm.

Returns:

  • (String)


2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
# File 'lib/aws-sdk-deadline/types.rb', line 2602

class CreateFarmRequest < Struct.new(
  :client_token,
  :display_name,
  :description,
  :kms_key_arn,
  :cost_scale_factor,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end

#tagsHash<String,String>

The tags to add to your farm. Each tag consists of a tag key and a tag value. Tag keys and values are both required, but tag values can be empty strings.

Returns:

  • (Hash<String,String>)


2602
2603
2604
2605
2606
2607
2608
2609
2610
2611
# File 'lib/aws-sdk-deadline/types.rb', line 2602

class CreateFarmRequest < Struct.new(
  :client_token,
  :display_name,
  :description,
  :kms_key_arn,
  :cost_scale_factor,
  :tags)
  SENSITIVE = [:description]
  include Aws::Structure
end