Class: Aws::Deadline::Types::CreateJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::CreateJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:template, :parameters, :description_override]
Instance Attribute Summary collapse
-
#attachments ⇒ Types::Attachments
The attachments for the job.
-
#client_token ⇒ String
The unique token which the server uses to recognize retries of the same request.
-
#description_override ⇒ String
A custom description to override the job description derived from the job template.
-
#farm_id ⇒ String
The farm ID of the farm to connect to the job.
-
#max_failed_tasks_count ⇒ Integer
The number of task failures before the job stops running and is marked as ‘FAILED`.
-
#max_retries_per_task ⇒ Integer
The maximum number of retries for each task.
-
#max_worker_count ⇒ Integer
The maximum number of worker hosts that can concurrently process a job.
-
#name_override ⇒ String
A custom name to override the job name derived from the job template.
-
#parameters ⇒ Hash<String,Types::JobParameter>
The parameters for the job.
-
#priority ⇒ Integer
The priority of the job.
-
#queue_id ⇒ String
The ID of the queue that the job is submitted to.
-
#source_job_id ⇒ String
The job ID for the source job.
-
#storage_profile_id ⇒ String
The storage profile ID for the storage profile to connect to the job.
-
#tags ⇒ Hash<String,String>
The tags to add to your job.
-
#target_task_run_status ⇒ String
The initial job status when it is created.
-
#template ⇒ String
The job template to use for this job.
-
#template_type ⇒ String
The file type for the job template.
Instance Attribute Details
#attachments ⇒ Types::Attachments
The attachments for the job. Attach files required for the job to run to a render job.
2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 |
# File 'lib/aws-sdk-deadline/types.rb', line 2859 class CreateJobRequest < Struct.new( :farm_id, :queue_id, :client_token, :template, :template_type, :priority, :parameters, :attachments, :storage_profile_id, :target_task_run_status, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id, :name_override, :description_override, :tags) SENSITIVE = [:template, :parameters, :description_override] include Aws::Structure end |
#client_token ⇒ String
The unique token which the server uses to recognize retries of the same request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 |
# File 'lib/aws-sdk-deadline/types.rb', line 2859 class CreateJobRequest < Struct.new( :farm_id, :queue_id, :client_token, :template, :template_type, :priority, :parameters, :attachments, :storage_profile_id, :target_task_run_status, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id, :name_override, :description_override, :tags) SENSITIVE = [:template, :parameters, :description_override] include Aws::Structure end |
#description_override ⇒ String
A custom description to override the job description derived from the job template.
2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 |
# File 'lib/aws-sdk-deadline/types.rb', line 2859 class CreateJobRequest < Struct.new( :farm_id, :queue_id, :client_token, :template, :template_type, :priority, :parameters, :attachments, :storage_profile_id, :target_task_run_status, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id, :name_override, :description_override, :tags) SENSITIVE = [:template, :parameters, :description_override] include Aws::Structure end |
#farm_id ⇒ String
The farm ID of the farm to connect to the job.
2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 |
# File 'lib/aws-sdk-deadline/types.rb', line 2859 class CreateJobRequest < Struct.new( :farm_id, :queue_id, :client_token, :template, :template_type, :priority, :parameters, :attachments, :storage_profile_id, :target_task_run_status, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id, :name_override, :description_override, :tags) SENSITIVE = [:template, :parameters, :description_override] include Aws::Structure end |
#max_failed_tasks_count ⇒ Integer
The number of task failures before the job stops running and is marked as ‘FAILED`.
2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 |
# File 'lib/aws-sdk-deadline/types.rb', line 2859 class CreateJobRequest < Struct.new( :farm_id, :queue_id, :client_token, :template, :template_type, :priority, :parameters, :attachments, :storage_profile_id, :target_task_run_status, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id, :name_override, :description_override, :tags) SENSITIVE = [:template, :parameters, :description_override] include Aws::Structure end |
#max_retries_per_task ⇒ Integer
The maximum number of retries for each task.
2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 |
# File 'lib/aws-sdk-deadline/types.rb', line 2859 class CreateJobRequest < Struct.new( :farm_id, :queue_id, :client_token, :template, :template_type, :priority, :parameters, :attachments, :storage_profile_id, :target_task_run_status, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id, :name_override, :description_override, :tags) SENSITIVE = [:template, :parameters, :description_override] include Aws::Structure end |
#max_worker_count ⇒ Integer
The maximum number of worker hosts that can concurrently process a job. When the ‘maxWorkerCount` is reached, no more workers will be assigned to process the job, even if the fleets assigned to the job’s queue has available workers.
You can’t set the ‘maxWorkerCount` to 0. If you set it to -1, there is no maximum number of workers.
If you don’t specify the ‘maxWorkerCount`, Deadline Cloud won’t throttle the number of workers used to process the job.
2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 |
# File 'lib/aws-sdk-deadline/types.rb', line 2859 class CreateJobRequest < Struct.new( :farm_id, :queue_id, :client_token, :template, :template_type, :priority, :parameters, :attachments, :storage_profile_id, :target_task_run_status, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id, :name_override, :description_override, :tags) SENSITIVE = [:template, :parameters, :description_override] include Aws::Structure end |
#name_override ⇒ String
A custom name to override the job name derived from the job template.
2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 |
# File 'lib/aws-sdk-deadline/types.rb', line 2859 class CreateJobRequest < Struct.new( :farm_id, :queue_id, :client_token, :template, :template_type, :priority, :parameters, :attachments, :storage_profile_id, :target_task_run_status, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id, :name_override, :description_override, :tags) SENSITIVE = [:template, :parameters, :description_override] include Aws::Structure end |
#parameters ⇒ Hash<String,Types::JobParameter>
The parameters for the job.
2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 |
# File 'lib/aws-sdk-deadline/types.rb', line 2859 class CreateJobRequest < Struct.new( :farm_id, :queue_id, :client_token, :template, :template_type, :priority, :parameters, :attachments, :storage_profile_id, :target_task_run_status, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id, :name_override, :description_override, :tags) SENSITIVE = [:template, :parameters, :description_override] include Aws::Structure end |
#priority ⇒ Integer
The priority of the job. The highest priority (first scheduled) is
-
When two jobs have the same priority, the oldest job is
scheduled first.
2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 |
# File 'lib/aws-sdk-deadline/types.rb', line 2859 class CreateJobRequest < Struct.new( :farm_id, :queue_id, :client_token, :template, :template_type, :priority, :parameters, :attachments, :storage_profile_id, :target_task_run_status, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id, :name_override, :description_override, :tags) SENSITIVE = [:template, :parameters, :description_override] include Aws::Structure end |
#queue_id ⇒ String
The ID of the queue that the job is submitted to.
2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 |
# File 'lib/aws-sdk-deadline/types.rb', line 2859 class CreateJobRequest < Struct.new( :farm_id, :queue_id, :client_token, :template, :template_type, :priority, :parameters, :attachments, :storage_profile_id, :target_task_run_status, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id, :name_override, :description_override, :tags) SENSITIVE = [:template, :parameters, :description_override] include Aws::Structure end |
#source_job_id ⇒ String
The job ID for the source job.
2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 |
# File 'lib/aws-sdk-deadline/types.rb', line 2859 class CreateJobRequest < Struct.new( :farm_id, :queue_id, :client_token, :template, :template_type, :priority, :parameters, :attachments, :storage_profile_id, :target_task_run_status, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id, :name_override, :description_override, :tags) SENSITIVE = [:template, :parameters, :description_override] include Aws::Structure end |
#storage_profile_id ⇒ String
The storage profile ID for the storage profile to connect to the job.
2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 |
# File 'lib/aws-sdk-deadline/types.rb', line 2859 class CreateJobRequest < Struct.new( :farm_id, :queue_id, :client_token, :template, :template_type, :priority, :parameters, :attachments, :storage_profile_id, :target_task_run_status, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id, :name_override, :description_override, :tags) SENSITIVE = [:template, :parameters, :description_override] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to add to your job. Each tag consists of a tag key and a tag value. Tag keys and values are both required, but tag values can be empty strings.
2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 |
# File 'lib/aws-sdk-deadline/types.rb', line 2859 class CreateJobRequest < Struct.new( :farm_id, :queue_id, :client_token, :template, :template_type, :priority, :parameters, :attachments, :storage_profile_id, :target_task_run_status, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id, :name_override, :description_override, :tags) SENSITIVE = [:template, :parameters, :description_override] include Aws::Structure end |
#target_task_run_status ⇒ String
The initial job status when it is created. Jobs that are created with a ‘SUSPENDED` status will not run until manually requeued.
2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 |
# File 'lib/aws-sdk-deadline/types.rb', line 2859 class CreateJobRequest < Struct.new( :farm_id, :queue_id, :client_token, :template, :template_type, :priority, :parameters, :attachments, :storage_profile_id, :target_task_run_status, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id, :name_override, :description_override, :tags) SENSITIVE = [:template, :parameters, :description_override] include Aws::Structure end |
#template ⇒ String
The job template to use for this job.
2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 |
# File 'lib/aws-sdk-deadline/types.rb', line 2859 class CreateJobRequest < Struct.new( :farm_id, :queue_id, :client_token, :template, :template_type, :priority, :parameters, :attachments, :storage_profile_id, :target_task_run_status, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id, :name_override, :description_override, :tags) SENSITIVE = [:template, :parameters, :description_override] include Aws::Structure end |
#template_type ⇒ String
The file type for the job template.
2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 |
# File 'lib/aws-sdk-deadline/types.rb', line 2859 class CreateJobRequest < Struct.new( :farm_id, :queue_id, :client_token, :template, :template_type, :priority, :parameters, :attachments, :storage_profile_id, :target_task_run_status, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id, :name_override, :description_override, :tags) SENSITIVE = [:template, :parameters, :description_override] include Aws::Structure end |