Class: Aws::Deadline::Types::CreateMonitorRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

The unique token which the server uses to recognize retries of the same request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


3044
3045
3046
3047
3048
3049
3050
3051
3052
3053
3054
# File 'lib/aws-sdk-deadline/types.rb', line 3044

class CreateMonitorRequest < Struct.new(
  :client_token,
  :display_name,
  :identity_center_instance_arn,
  :identity_center_region,
  :subdomain,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The name that you give the monitor that is displayed in the Deadline Cloud console.

This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.

Returns:

  • (String)


3044
3045
3046
3047
3048
3049
3050
3051
3052
3053
3054
# File 'lib/aws-sdk-deadline/types.rb', line 3044

class CreateMonitorRequest < Struct.new(
  :client_token,
  :display_name,
  :identity_center_instance_arn,
  :identity_center_region,
  :subdomain,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#identity_center_instance_arnString

The Amazon Resource Name of the IAM Identity Center instance that authenticates monitor users.

Returns:

  • (String)


3044
3045
3046
3047
3048
3049
3050
3051
3052
3053
3054
# File 'lib/aws-sdk-deadline/types.rb', line 3044

class CreateMonitorRequest < Struct.new(
  :client_token,
  :display_name,
  :identity_center_instance_arn,
  :identity_center_region,
  :subdomain,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#identity_center_regionString

The AWS Region where IAM Identity Center is enabled. Required when IAM Identity Center is in a different Region than the monitor.

Returns:

  • (String)


3044
3045
3046
3047
3048
3049
3050
3051
3052
3053
3054
# File 'lib/aws-sdk-deadline/types.rb', line 3044

class CreateMonitorRequest < Struct.new(
  :client_token,
  :display_name,
  :identity_center_instance_arn,
  :identity_center_region,
  :subdomain,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name of the IAM role that the monitor uses to connect to Deadline Cloud. Every user that signs in to the monitor using IAM Identity Center uses this role to access Deadline Cloud resources.

Returns:

  • (String)


3044
3045
3046
3047
3048
3049
3050
3051
3052
3053
3054
# File 'lib/aws-sdk-deadline/types.rb', line 3044

class CreateMonitorRequest < Struct.new(
  :client_token,
  :display_name,
  :identity_center_instance_arn,
  :identity_center_region,
  :subdomain,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#subdomainString

The subdomain to use when creating the monitor URL. The full URL of the monitor is subdomain.Region.deadlinecloud.amazonaws.com.

Returns:

  • (String)


3044
3045
3046
3047
3048
3049
3050
3051
3052
3053
3054
# File 'lib/aws-sdk-deadline/types.rb', line 3044

class CreateMonitorRequest < Struct.new(
  :client_token,
  :display_name,
  :identity_center_instance_arn,
  :identity_center_region,
  :subdomain,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags to add to your monitor. Each tag consists of a tag key and a tag value. Tag keys and values are both required, but tag values can be empty strings.

Returns:

  • (Hash<String,String>)


3044
3045
3046
3047
3048
3049
3050
3051
3052
3053
3054
# File 'lib/aws-sdk-deadline/types.rb', line 3044

class CreateMonitorRequest < Struct.new(
  :client_token,
  :display_name,
  :identity_center_instance_arn,
  :identity_center_region,
  :subdomain,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end