Class: Aws::Deadline::Types::CreateQueueEnvironmentRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:template]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

The unique token which the server uses to recognize retries of the same request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.



1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
# File 'lib/aws-sdk-deadline/types.rb', line 1606

class CreateQueueEnvironmentRequest < Struct.new(
  :client_token,
  :farm_id,
  :queue_id,
  :priority,
  :template_type,
  :template)
  SENSITIVE = [:template]
  include Aws::Structure
end

#farm_idString

The farm ID of the farm to connect to the environment.



1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
# File 'lib/aws-sdk-deadline/types.rb', line 1606

class CreateQueueEnvironmentRequest < Struct.new(
  :client_token,
  :farm_id,
  :queue_id,
  :priority,
  :template_type,
  :template)
  SENSITIVE = [:template]
  include Aws::Structure
end

#priorityInteger

Sets the priority of the environments in the queue from 0 to 10,000, where 0 is the highest priority (activated first and deactivated last). If two environments share the same priority value, the environment created first takes higher priority.



1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
# File 'lib/aws-sdk-deadline/types.rb', line 1606

class CreateQueueEnvironmentRequest < Struct.new(
  :client_token,
  :farm_id,
  :queue_id,
  :priority,
  :template_type,
  :template)
  SENSITIVE = [:template]
  include Aws::Structure
end

#queue_idString

The queue ID to connect the queue and environment.



1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
# File 'lib/aws-sdk-deadline/types.rb', line 1606

class CreateQueueEnvironmentRequest < Struct.new(
  :client_token,
  :farm_id,
  :queue_id,
  :priority,
  :template_type,
  :template)
  SENSITIVE = [:template]
  include Aws::Structure
end

#templateString

The environment template to use in the queue.



1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
# File 'lib/aws-sdk-deadline/types.rb', line 1606

class CreateQueueEnvironmentRequest < Struct.new(
  :client_token,
  :farm_id,
  :queue_id,
  :priority,
  :template_type,
  :template)
  SENSITIVE = [:template]
  include Aws::Structure
end

#template_typeString

The template’s file type, JSON or YAML.



1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
# File 'lib/aws-sdk-deadline/types.rb', line 1606

class CreateQueueEnvironmentRequest < Struct.new(
  :client_token,
  :farm_id,
  :queue_id,
  :priority,
  :template_type,
  :template)
  SENSITIVE = [:template]
  include Aws::Structure
end