Class: Aws::Deadline::Types::CreateQueueRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Shared displayName + description for Create operations where both are present. displayName is @required here - this mixin is Create-only by design (Update has optional displayName).

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_storage_profile_idsArray<String>

The storage profile IDs to include in the queue.

Returns:

  • (Array<String>)


3260
3261
3262
3263
3264
3265
3266
3267
3268
3269
3270
3271
3272
3273
3274
3275
# File 'lib/aws-sdk-deadline/types.rb', line 3260

class CreateQueueRequest < Struct.new(
  :farm_id,
  :client_token,
  :display_name,
  :description,
  :default_budget_action,
  :job_attachment_settings,
  :role_arn,
  :job_run_as_user,
  :required_file_system_location_names,
  :allowed_storage_profile_ids,
  :tags,
  :scheduling_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#client_tokenString

The unique token which the server uses to recognize retries of the same request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


3260
3261
3262
3263
3264
3265
3266
3267
3268
3269
3270
3271
3272
3273
3274
3275
# File 'lib/aws-sdk-deadline/types.rb', line 3260

class CreateQueueRequest < Struct.new(
  :farm_id,
  :client_token,
  :display_name,
  :description,
  :default_budget_action,
  :job_attachment_settings,
  :role_arn,
  :job_run_as_user,
  :required_file_system_location_names,
  :allowed_storage_profile_ids,
  :tags,
  :scheduling_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#default_budget_actionString

The default action to take on a queue if a budget isn’t configured.

Returns:

  • (String)


3260
3261
3262
3263
3264
3265
3266
3267
3268
3269
3270
3271
3272
3273
3274
3275
# File 'lib/aws-sdk-deadline/types.rb', line 3260

class CreateQueueRequest < Struct.new(
  :farm_id,
  :client_token,
  :display_name,
  :description,
  :default_budget_action,
  :job_attachment_settings,
  :role_arn,
  :job_run_as_user,
  :required_file_system_location_names,
  :allowed_storage_profile_ids,
  :tags,
  :scheduling_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

The description of the queue.

This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.

Returns:

  • (String)


3260
3261
3262
3263
3264
3265
3266
3267
3268
3269
3270
3271
3272
3273
3274
3275
# File 'lib/aws-sdk-deadline/types.rb', line 3260

class CreateQueueRequest < Struct.new(
  :farm_id,
  :client_token,
  :display_name,
  :description,
  :default_budget_action,
  :job_attachment_settings,
  :role_arn,
  :job_run_as_user,
  :required_file_system_location_names,
  :allowed_storage_profile_ids,
  :tags,
  :scheduling_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#display_nameString

The display name of the queue.

This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.

Returns:

  • (String)


3260
3261
3262
3263
3264
3265
3266
3267
3268
3269
3270
3271
3272
3273
3274
3275
# File 'lib/aws-sdk-deadline/types.rb', line 3260

class CreateQueueRequest < Struct.new(
  :farm_id,
  :client_token,
  :display_name,
  :description,
  :default_budget_action,
  :job_attachment_settings,
  :role_arn,
  :job_run_as_user,
  :required_file_system_location_names,
  :allowed_storage_profile_ids,
  :tags,
  :scheduling_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#farm_idString

The farm ID of the farm to connect to the queue.

Returns:

  • (String)


3260
3261
3262
3263
3264
3265
3266
3267
3268
3269
3270
3271
3272
3273
3274
3275
# File 'lib/aws-sdk-deadline/types.rb', line 3260

class CreateQueueRequest < Struct.new(
  :farm_id,
  :client_token,
  :display_name,
  :description,
  :default_budget_action,
  :job_attachment_settings,
  :role_arn,
  :job_run_as_user,
  :required_file_system_location_names,
  :allowed_storage_profile_ids,
  :tags,
  :scheduling_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#job_attachment_settingsTypes::JobAttachmentSettings

The job attachment settings for the queue. These are the Amazon S3 bucket name and the Amazon S3 prefix.



3260
3261
3262
3263
3264
3265
3266
3267
3268
3269
3270
3271
3272
3273
3274
3275
# File 'lib/aws-sdk-deadline/types.rb', line 3260

class CreateQueueRequest < Struct.new(
  :farm_id,
  :client_token,
  :display_name,
  :description,
  :default_budget_action,
  :job_attachment_settings,
  :role_arn,
  :job_run_as_user,
  :required_file_system_location_names,
  :allowed_storage_profile_ids,
  :tags,
  :scheduling_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#job_run_as_userTypes::JobRunAsUser

The jobs in the queue run as the specified POSIX user.

Returns:



3260
3261
3262
3263
3264
3265
3266
3267
3268
3269
3270
3271
3272
3273
3274
3275
# File 'lib/aws-sdk-deadline/types.rb', line 3260

class CreateQueueRequest < Struct.new(
  :farm_id,
  :client_token,
  :display_name,
  :description,
  :default_budget_action,
  :job_attachment_settings,
  :role_arn,
  :job_run_as_user,
  :required_file_system_location_names,
  :allowed_storage_profile_ids,
  :tags,
  :scheduling_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#required_file_system_location_namesArray<String>

The file system location name to include in the queue.

Returns:

  • (Array<String>)


3260
3261
3262
3263
3264
3265
3266
3267
3268
3269
3270
3271
3272
3273
3274
3275
# File 'lib/aws-sdk-deadline/types.rb', line 3260

class CreateQueueRequest < Struct.new(
  :farm_id,
  :client_token,
  :display_name,
  :description,
  :default_budget_action,
  :job_attachment_settings,
  :role_arn,
  :job_run_as_user,
  :required_file_system_location_names,
  :allowed_storage_profile_ids,
  :tags,
  :scheduling_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#role_arnString

The IAM role ARN that workers will use while running jobs for this queue.

Returns:

  • (String)


3260
3261
3262
3263
3264
3265
3266
3267
3268
3269
3270
3271
3272
3273
3274
3275
# File 'lib/aws-sdk-deadline/types.rb', line 3260

class CreateQueueRequest < Struct.new(
  :farm_id,
  :client_token,
  :display_name,
  :description,
  :default_budget_action,
  :job_attachment_settings,
  :role_arn,
  :job_run_as_user,
  :required_file_system_location_names,
  :allowed_storage_profile_ids,
  :tags,
  :scheduling_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#scheduling_configurationTypes::SchedulingConfiguration

The scheduling configuration for the queue. This configuration determines how workers are assigned to jobs in the queue.

If not specified, the queue defaults to the ‘priorityFifo` scheduling configuration.



3260
3261
3262
3263
3264
3265
3266
3267
3268
3269
3270
3271
3272
3273
3274
3275
# File 'lib/aws-sdk-deadline/types.rb', line 3260

class CreateQueueRequest < Struct.new(
  :farm_id,
  :client_token,
  :display_name,
  :description,
  :default_budget_action,
  :job_attachment_settings,
  :role_arn,
  :job_run_as_user,
  :required_file_system_location_names,
  :allowed_storage_profile_ids,
  :tags,
  :scheduling_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#tagsHash<String,String>

Each tag consists of a tag key and a tag value. Tag keys and values are both required, but tag values can be empty strings.

Returns:

  • (Hash<String,String>)


3260
3261
3262
3263
3264
3265
3266
3267
3268
3269
3270
3271
3272
3273
3274
3275
# File 'lib/aws-sdk-deadline/types.rb', line 3260

class CreateQueueRequest < Struct.new(
  :farm_id,
  :client_token,
  :display_name,
  :description,
  :default_budget_action,
  :job_attachment_settings,
  :role_arn,
  :job_run_as_user,
  :required_file_system_location_names,
  :allowed_storage_profile_ids,
  :tags,
  :scheduling_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end