Class: Aws::Deadline::Types::CreateWorkerRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

The unique token which the server uses to recognize retries of the same request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


1850
1851
1852
1853
1854
1855
1856
1857
1858
# File 'lib/aws-sdk-deadline/types.rb', line 1850

class CreateWorkerRequest < Struct.new(
  :farm_id,
  :fleet_id,
  :host_properties,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#farm_idString

The farm ID of the farm to connect to the worker.

Returns:

  • (String)


1850
1851
1852
1853
1854
1855
1856
1857
1858
# File 'lib/aws-sdk-deadline/types.rb', line 1850

class CreateWorkerRequest < Struct.new(
  :farm_id,
  :fleet_id,
  :host_properties,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#fleet_idString

The fleet ID to connect to the worker.

Returns:

  • (String)


1850
1851
1852
1853
1854
1855
1856
1857
1858
# File 'lib/aws-sdk-deadline/types.rb', line 1850

class CreateWorkerRequest < Struct.new(
  :farm_id,
  :fleet_id,
  :host_properties,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#host_propertiesTypes::HostPropertiesRequest

The IP address and host name of the worker.



1850
1851
1852
1853
1854
1855
1856
1857
1858
# File 'lib/aws-sdk-deadline/types.rb', line 1850

class CreateWorkerRequest < Struct.new(
  :farm_id,
  :fleet_id,
  :host_properties,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Each tag consists of a tag key and a tag value. Tag keys and values are both required, but tag values can be empty strings.

Returns:

  • (Hash<String,String>)


1850
1851
1852
1853
1854
1855
1856
1857
1858
# File 'lib/aws-sdk-deadline/types.rb', line 1850

class CreateWorkerRequest < Struct.new(
  :farm_id,
  :fleet_id,
  :host_properties,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end