Class: Aws::Deadline::Types::CustomerManagedFleetConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::CustomerManagedFleetConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
The configuration details for a customer managed fleet.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#mode ⇒ String
The Auto Scaling mode for the customer managed fleet.
-
#storage_profile_id ⇒ String
The storage profile ID for the customer managed fleet.
-
#tag_propagation_mode ⇒ String
The tag propagation mode for the customer managed fleet.
-
#worker_capabilities ⇒ Types::CustomerManagedWorkerCapabilities
The worker capabilities for the customer managed fleet.
Instance Attribute Details
#mode ⇒ String
The Auto Scaling mode for the customer managed fleet.
1897 1898 1899 1900 1901 1902 1903 1904 |
# File 'lib/aws-sdk-deadline/types.rb', line 1897 class CustomerManagedFleetConfiguration < Struct.new( :mode, :worker_capabilities, :storage_profile_id, :tag_propagation_mode) SENSITIVE = [] include Aws::Structure end |
#storage_profile_id ⇒ String
The storage profile ID for the customer managed fleet.
1897 1898 1899 1900 1901 1902 1903 1904 |
# File 'lib/aws-sdk-deadline/types.rb', line 1897 class CustomerManagedFleetConfiguration < Struct.new( :mode, :worker_capabilities, :storage_profile_id, :tag_propagation_mode) SENSITIVE = [] include Aws::Structure end |
#tag_propagation_mode ⇒ String
The tag propagation mode for the customer managed fleet.
1897 1898 1899 1900 1901 1902 1903 1904 |
# File 'lib/aws-sdk-deadline/types.rb', line 1897 class CustomerManagedFleetConfiguration < Struct.new( :mode, :worker_capabilities, :storage_profile_id, :tag_propagation_mode) SENSITIVE = [] include Aws::Structure end |
#worker_capabilities ⇒ Types::CustomerManagedWorkerCapabilities
The worker capabilities for the customer managed fleet.
1897 1898 1899 1900 1901 1902 1903 1904 |
# File 'lib/aws-sdk-deadline/types.rb', line 1897 class CustomerManagedFleetConfiguration < Struct.new( :mode, :worker_capabilities, :storage_profile_id, :tag_propagation_mode) SENSITIVE = [] include Aws::Structure end |