Class: Aws::Deadline::Types::DeleteQueueRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::DeleteQueueRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#farm_id ⇒ String
The ID of the farm from which to remove the queue.
-
#queue_id ⇒ String
The queue ID of the queue to delete.
Instance Attribute Details
#farm_id ⇒ String
The ID of the farm from which to remove the queue.
3775 3776 3777 3778 3779 3780 |
# File 'lib/aws-sdk-deadline/types.rb', line 3775 class DeleteQueueRequest < Struct.new( :farm_id, :queue_id) SENSITIVE = [] include Aws::Structure end |
#queue_id ⇒ String
The queue ID of the queue to delete.
3775 3776 3777 3778 3779 3780 |
# File 'lib/aws-sdk-deadline/types.rb', line 3775 class DeleteQueueRequest < Struct.new( :farm_id, :queue_id) SENSITIVE = [] include Aws::Structure end |