Class: Aws::Deadline::Types::GetBudgetResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::GetBudgetResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Mixin that adds an optional ARN field to response structures. Apply to SummaryMixins (flows into Get, Summary, and BatchGet) and Create outputs.
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#actions ⇒ Array<Types::ResponseBudgetAction>
The budget actions for the budget.
-
#approximate_dollar_limit ⇒ Float
The consumed usage limit for the budget.
-
#budget_id ⇒ String
The budget ID.
-
#created_at ⇒ Time
The date and time the resource was created.
-
#created_by ⇒ String
The user or system that created this resource.
-
#description ⇒ String
The description of the budget.
-
#display_name ⇒ String
The display name of the budget.
-
#queue_stopped_at ⇒ Time
The date and time the queue stopped.
-
#schedule ⇒ Types::BudgetSchedule
The budget schedule.
-
#status ⇒ String
The status of the budget.
-
#updated_at ⇒ Time
The date and time the resource was updated.
-
#updated_by ⇒ String
The user or system that updated this resource.
-
#usage_tracking_resource ⇒ Types::UsageTrackingResource
The resource that the budget is tracking usage for.
-
#usages ⇒ Types::ConsumedUsages
The usages of the budget.
Instance Attribute Details
#actions ⇒ Array<Types::ResponseBudgetAction>
The budget actions for the budget.
4606 4607 4608 4609 4610 4611 4612 4613 4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 |
# File 'lib/aws-sdk-deadline/types.rb', line 4606 class GetBudgetResponse < Struct.new( :budget_id, :usage_tracking_resource, :status, :display_name, :approximate_dollar_limit, :usages, :created_by, :created_at, :updated_by, :updated_at, :description, :actions, :schedule, :queue_stopped_at) SENSITIVE = [:description] include Aws::Structure end |
#approximate_dollar_limit ⇒ Float
The consumed usage limit for the budget.
4606 4607 4608 4609 4610 4611 4612 4613 4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 |
# File 'lib/aws-sdk-deadline/types.rb', line 4606 class GetBudgetResponse < Struct.new( :budget_id, :usage_tracking_resource, :status, :display_name, :approximate_dollar_limit, :usages, :created_by, :created_at, :updated_by, :updated_at, :description, :actions, :schedule, :queue_stopped_at) SENSITIVE = [:description] include Aws::Structure end |
#budget_id ⇒ String
The budget ID.
4606 4607 4608 4609 4610 4611 4612 4613 4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 |
# File 'lib/aws-sdk-deadline/types.rb', line 4606 class GetBudgetResponse < Struct.new( :budget_id, :usage_tracking_resource, :status, :display_name, :approximate_dollar_limit, :usages, :created_by, :created_at, :updated_by, :updated_at, :description, :actions, :schedule, :queue_stopped_at) SENSITIVE = [:description] include Aws::Structure end |
#created_at ⇒ Time
The date and time the resource was created.
4606 4607 4608 4609 4610 4611 4612 4613 4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 |
# File 'lib/aws-sdk-deadline/types.rb', line 4606 class GetBudgetResponse < Struct.new( :budget_id, :usage_tracking_resource, :status, :display_name, :approximate_dollar_limit, :usages, :created_by, :created_at, :updated_by, :updated_at, :description, :actions, :schedule, :queue_stopped_at) SENSITIVE = [:description] include Aws::Structure end |
#created_by ⇒ String
The user or system that created this resource.
4606 4607 4608 4609 4610 4611 4612 4613 4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 |
# File 'lib/aws-sdk-deadline/types.rb', line 4606 class GetBudgetResponse < Struct.new( :budget_id, :usage_tracking_resource, :status, :display_name, :approximate_dollar_limit, :usages, :created_by, :created_at, :updated_by, :updated_at, :description, :actions, :schedule, :queue_stopped_at) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
The description of the budget.
This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.
4606 4607 4608 4609 4610 4611 4612 4613 4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 |
# File 'lib/aws-sdk-deadline/types.rb', line 4606 class GetBudgetResponse < Struct.new( :budget_id, :usage_tracking_resource, :status, :display_name, :approximate_dollar_limit, :usages, :created_by, :created_at, :updated_by, :updated_at, :description, :actions, :schedule, :queue_stopped_at) SENSITIVE = [:description] include Aws::Structure end |
#display_name ⇒ String
The display name of the budget.
This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.
4606 4607 4608 4609 4610 4611 4612 4613 4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 |
# File 'lib/aws-sdk-deadline/types.rb', line 4606 class GetBudgetResponse < Struct.new( :budget_id, :usage_tracking_resource, :status, :display_name, :approximate_dollar_limit, :usages, :created_by, :created_at, :updated_by, :updated_at, :description, :actions, :schedule, :queue_stopped_at) SENSITIVE = [:description] include Aws::Structure end |
#queue_stopped_at ⇒ Time
The date and time the queue stopped.
4606 4607 4608 4609 4610 4611 4612 4613 4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 |
# File 'lib/aws-sdk-deadline/types.rb', line 4606 class GetBudgetResponse < Struct.new( :budget_id, :usage_tracking_resource, :status, :display_name, :approximate_dollar_limit, :usages, :created_by, :created_at, :updated_by, :updated_at, :description, :actions, :schedule, :queue_stopped_at) SENSITIVE = [:description] include Aws::Structure end |
#schedule ⇒ Types::BudgetSchedule
The budget schedule.
4606 4607 4608 4609 4610 4611 4612 4613 4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 |
# File 'lib/aws-sdk-deadline/types.rb', line 4606 class GetBudgetResponse < Struct.new( :budget_id, :usage_tracking_resource, :status, :display_name, :approximate_dollar_limit, :usages, :created_by, :created_at, :updated_by, :updated_at, :description, :actions, :schedule, :queue_stopped_at) SENSITIVE = [:description] include Aws::Structure end |
#status ⇒ String
The status of the budget.
-
‘ACTIVE`–Get a budget being evaluated.
-
‘INACTIVE`–Get an inactive budget. This can include expired, canceled, or deleted statuses.
4606 4607 4608 4609 4610 4611 4612 4613 4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 |
# File 'lib/aws-sdk-deadline/types.rb', line 4606 class GetBudgetResponse < Struct.new( :budget_id, :usage_tracking_resource, :status, :display_name, :approximate_dollar_limit, :usages, :created_by, :created_at, :updated_by, :updated_at, :description, :actions, :schedule, :queue_stopped_at) SENSITIVE = [:description] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the resource was updated.
4606 4607 4608 4609 4610 4611 4612 4613 4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 |
# File 'lib/aws-sdk-deadline/types.rb', line 4606 class GetBudgetResponse < Struct.new( :budget_id, :usage_tracking_resource, :status, :display_name, :approximate_dollar_limit, :usages, :created_by, :created_at, :updated_by, :updated_at, :description, :actions, :schedule, :queue_stopped_at) SENSITIVE = [:description] include Aws::Structure end |
#updated_by ⇒ String
The user or system that updated this resource.
4606 4607 4608 4609 4610 4611 4612 4613 4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 |
# File 'lib/aws-sdk-deadline/types.rb', line 4606 class GetBudgetResponse < Struct.new( :budget_id, :usage_tracking_resource, :status, :display_name, :approximate_dollar_limit, :usages, :created_by, :created_at, :updated_by, :updated_at, :description, :actions, :schedule, :queue_stopped_at) SENSITIVE = [:description] include Aws::Structure end |
#usage_tracking_resource ⇒ Types::UsageTrackingResource
The resource that the budget is tracking usage for.
4606 4607 4608 4609 4610 4611 4612 4613 4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 |
# File 'lib/aws-sdk-deadline/types.rb', line 4606 class GetBudgetResponse < Struct.new( :budget_id, :usage_tracking_resource, :status, :display_name, :approximate_dollar_limit, :usages, :created_by, :created_at, :updated_by, :updated_at, :description, :actions, :schedule, :queue_stopped_at) SENSITIVE = [:description] include Aws::Structure end |
#usages ⇒ Types::ConsumedUsages
The usages of the budget.
4606 4607 4608 4609 4610 4611 4612 4613 4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 |
# File 'lib/aws-sdk-deadline/types.rb', line 4606 class GetBudgetResponse < Struct.new( :budget_id, :usage_tracking_resource, :status, :display_name, :approximate_dollar_limit, :usages, :created_by, :created_at, :updated_by, :updated_at, :description, :actions, :schedule, :queue_stopped_at) SENSITIVE = [:description] include Aws::Structure end |