Class: Aws::Deadline::Types::GetFarmResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::GetFarmResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Mixin that adds an optional ARN field to response structures. Apply to SummaryMixins (flows into Get, Summary, and BatchGet) and Create outputs.
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#cost_scale_factor ⇒ Float
A multiplier applied to the farm’s calculated costs for usage data and budget tracking.
-
#created_at ⇒ Time
The date and time the resource was created.
-
#created_by ⇒ String
The user or system that created this resource.
-
#description ⇒ String
The description of the farm.
-
#display_name ⇒ String
The display name of the farm.
-
#farm_id ⇒ String
The farm ID of the farm to get.
-
#kms_key_arn ⇒ String
The ARN of the KMS key used on the farm.
-
#updated_at ⇒ Time
The date and time the resource was updated.
-
#updated_by ⇒ String
The user or system that updated this resource.
Instance Attribute Details
#cost_scale_factor ⇒ Float
A multiplier applied to the farm’s calculated costs for usage data and budget tracking. A value less than 1 represents a discount, a value greater than 1 represents a premium, and a value of 1 represents no adjustment.
4664 4665 4666 4667 4668 4669 4670 4671 4672 4673 4674 4675 4676 |
# File 'lib/aws-sdk-deadline/types.rb', line 4664 class GetFarmResponse < Struct.new( :farm_id, :display_name, :kms_key_arn, :created_at, :created_by, :updated_at, :updated_by, :description, :cost_scale_factor) SENSITIVE = [:description] include Aws::Structure end |
#created_at ⇒ Time
The date and time the resource was created.
4664 4665 4666 4667 4668 4669 4670 4671 4672 4673 4674 4675 4676 |
# File 'lib/aws-sdk-deadline/types.rb', line 4664 class GetFarmResponse < Struct.new( :farm_id, :display_name, :kms_key_arn, :created_at, :created_by, :updated_at, :updated_by, :description, :cost_scale_factor) SENSITIVE = [:description] include Aws::Structure end |
#created_by ⇒ String
The user or system that created this resource.
4664 4665 4666 4667 4668 4669 4670 4671 4672 4673 4674 4675 4676 |
# File 'lib/aws-sdk-deadline/types.rb', line 4664 class GetFarmResponse < Struct.new( :farm_id, :display_name, :kms_key_arn, :created_at, :created_by, :updated_at, :updated_by, :description, :cost_scale_factor) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
The description of the farm.
This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.
4664 4665 4666 4667 4668 4669 4670 4671 4672 4673 4674 4675 4676 |
# File 'lib/aws-sdk-deadline/types.rb', line 4664 class GetFarmResponse < Struct.new( :farm_id, :display_name, :kms_key_arn, :created_at, :created_by, :updated_at, :updated_by, :description, :cost_scale_factor) SENSITIVE = [:description] include Aws::Structure end |
#display_name ⇒ String
The display name of the farm.
This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.
4664 4665 4666 4667 4668 4669 4670 4671 4672 4673 4674 4675 4676 |
# File 'lib/aws-sdk-deadline/types.rb', line 4664 class GetFarmResponse < Struct.new( :farm_id, :display_name, :kms_key_arn, :created_at, :created_by, :updated_at, :updated_by, :description, :cost_scale_factor) SENSITIVE = [:description] include Aws::Structure end |
#farm_id ⇒ String
The farm ID of the farm to get.
4664 4665 4666 4667 4668 4669 4670 4671 4672 4673 4674 4675 4676 |
# File 'lib/aws-sdk-deadline/types.rb', line 4664 class GetFarmResponse < Struct.new( :farm_id, :display_name, :kms_key_arn, :created_at, :created_by, :updated_at, :updated_by, :description, :cost_scale_factor) SENSITIVE = [:description] include Aws::Structure end |
#kms_key_arn ⇒ String
The ARN of the KMS key used on the farm.
4664 4665 4666 4667 4668 4669 4670 4671 4672 4673 4674 4675 4676 |
# File 'lib/aws-sdk-deadline/types.rb', line 4664 class GetFarmResponse < Struct.new( :farm_id, :display_name, :kms_key_arn, :created_at, :created_by, :updated_at, :updated_by, :description, :cost_scale_factor) SENSITIVE = [:description] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the resource was updated.
4664 4665 4666 4667 4668 4669 4670 4671 4672 4673 4674 4675 4676 |
# File 'lib/aws-sdk-deadline/types.rb', line 4664 class GetFarmResponse < Struct.new( :farm_id, :display_name, :kms_key_arn, :created_at, :created_by, :updated_at, :updated_by, :description, :cost_scale_factor) SENSITIVE = [:description] include Aws::Structure end |
#updated_by ⇒ String
The user or system that updated this resource.
4664 4665 4666 4667 4668 4669 4670 4671 4672 4673 4674 4675 4676 |
# File 'lib/aws-sdk-deadline/types.rb', line 4664 class GetFarmResponse < Struct.new( :farm_id, :display_name, :kms_key_arn, :created_at, :created_by, :updated_at, :updated_by, :description, :cost_scale_factor) SENSITIVE = [:description] include Aws::Structure end |