Class: Aws::Deadline::Types::GetJobResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::GetJobResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Mixin that adds an optional ARN field to response structures. Apply to SummaryMixins (flows into Get, Summary, and BatchGet) and Create outputs.
Constant Summary collapse
- SENSITIVE =
[:parameters, :description]
Instance Attribute Summary collapse
-
#attachments ⇒ Types::Attachments
The attachments for the job.
-
#created_at ⇒ Time
The date and time the resource was created.
-
#created_by ⇒ String
The user or system that created this resource.
-
#description ⇒ String
The description of the job.
-
#ended_at ⇒ Time
The date and time the resource ended running.
-
#job_id ⇒ String
The job ID.
-
#lifecycle_status ⇒ String
The life cycle status for the job.
-
#lifecycle_status_message ⇒ String
A message that communicates the status of the life cycle for the job.
-
#max_failed_tasks_count ⇒ Integer
The number of task failures before the job stops running and is marked as ‘FAILED`.
-
#max_retries_per_task ⇒ Integer
The maximum number of retries per failed tasks.
-
#max_worker_count ⇒ Integer
The maximum number of worker hosts that can concurrently process a job.
-
#name ⇒ String
The name of the job.
-
#parameters ⇒ Hash<String,Types::JobParameter>
The parameters for the job.
-
#priority ⇒ Integer
The job priority.
-
#source_job_id ⇒ String
The job ID for the source job.
-
#started_at ⇒ Time
The date and time the resource started running.
-
#storage_profile_id ⇒ String
The storage profile ID associated with the job.
-
#target_task_run_status ⇒ String
The task status with which the job started.
-
#task_failure_retry_count ⇒ Integer
The total number of times tasks from the job failed and were retried.
-
#task_run_status ⇒ String
The task run status for the job.
-
#task_run_status_counts ⇒ Hash<String,Integer>
The number of tasks running on the job.
-
#updated_at ⇒ Time
The date and time the resource was updated.
-
#updated_by ⇒ String
The user or system that updated this resource.
Instance Attribute Details
#attachments ⇒ Types::Attachments
The attachments for the job.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 5035 5036 |
# File 'lib/aws-sdk-deadline/types.rb', line 5010 class GetJobResponse < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#created_at ⇒ Time
The date and time the resource was created.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 5035 5036 |
# File 'lib/aws-sdk-deadline/types.rb', line 5010 class GetJobResponse < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#created_by ⇒ String
The user or system that created this resource.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 5035 5036 |
# File 'lib/aws-sdk-deadline/types.rb', line 5010 class GetJobResponse < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#description ⇒ String
The description of the job.
This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 5035 5036 |
# File 'lib/aws-sdk-deadline/types.rb', line 5010 class GetJobResponse < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#ended_at ⇒ Time
The date and time the resource ended running.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 5035 5036 |
# File 'lib/aws-sdk-deadline/types.rb', line 5010 class GetJobResponse < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#job_id ⇒ String
The job ID.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 5035 5036 |
# File 'lib/aws-sdk-deadline/types.rb', line 5010 class GetJobResponse < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#lifecycle_status ⇒ String
The life cycle status for the job.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 5035 5036 |
# File 'lib/aws-sdk-deadline/types.rb', line 5010 class GetJobResponse < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#lifecycle_status_message ⇒ String
A message that communicates the status of the life cycle for the job.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 5035 5036 |
# File 'lib/aws-sdk-deadline/types.rb', line 5010 class GetJobResponse < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#max_failed_tasks_count ⇒ Integer
The number of task failures before the job stops running and is marked as ‘FAILED`.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 5035 5036 |
# File 'lib/aws-sdk-deadline/types.rb', line 5010 class GetJobResponse < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#max_retries_per_task ⇒ Integer
The maximum number of retries per failed tasks.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 5035 5036 |
# File 'lib/aws-sdk-deadline/types.rb', line 5010 class GetJobResponse < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#max_worker_count ⇒ Integer
The maximum number of worker hosts that can concurrently process a job. When the ‘maxWorkerCount` is reached, no more workers will be assigned to process the job, even if the fleets assigned to the job’s queue has available workers.
If you don’t set the ‘maxWorkerCount` when you create a job, this value is not returned in the response.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 5035 5036 |
# File 'lib/aws-sdk-deadline/types.rb', line 5010 class GetJobResponse < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#name ⇒ String
The name of the job.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 5035 5036 |
# File 'lib/aws-sdk-deadline/types.rb', line 5010 class GetJobResponse < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#parameters ⇒ Hash<String,Types::JobParameter>
The parameters for the job.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 5035 5036 |
# File 'lib/aws-sdk-deadline/types.rb', line 5010 class GetJobResponse < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#priority ⇒ Integer
The job priority.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 5035 5036 |
# File 'lib/aws-sdk-deadline/types.rb', line 5010 class GetJobResponse < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#source_job_id ⇒ String
The job ID for the source job.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 5035 5036 |
# File 'lib/aws-sdk-deadline/types.rb', line 5010 class GetJobResponse < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#started_at ⇒ Time
The date and time the resource started running.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 5035 5036 |
# File 'lib/aws-sdk-deadline/types.rb', line 5010 class GetJobResponse < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#storage_profile_id ⇒ String
The storage profile ID associated with the job.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 5035 5036 |
# File 'lib/aws-sdk-deadline/types.rb', line 5010 class GetJobResponse < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#target_task_run_status ⇒ String
The task status with which the job started.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 5035 5036 |
# File 'lib/aws-sdk-deadline/types.rb', line 5010 class GetJobResponse < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#task_failure_retry_count ⇒ Integer
The total number of times tasks from the job failed and were retried.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 5035 5036 |
# File 'lib/aws-sdk-deadline/types.rb', line 5010 class GetJobResponse < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#task_run_status ⇒ String
The task run status for the job.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 5035 5036 |
# File 'lib/aws-sdk-deadline/types.rb', line 5010 class GetJobResponse < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#task_run_status_counts ⇒ Hash<String,Integer>
The number of tasks running on the job.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 5035 5036 |
# File 'lib/aws-sdk-deadline/types.rb', line 5010 class GetJobResponse < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the resource was updated.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 5035 5036 |
# File 'lib/aws-sdk-deadline/types.rb', line 5010 class GetJobResponse < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |
#updated_by ⇒ String
The user or system that updated this resource.
5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 5035 5036 |
# File 'lib/aws-sdk-deadline/types.rb', line 5010 class GetJobResponse < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :storage_profile_id, :max_failed_tasks_count, :max_retries_per_task, :parameters, :attachments, :description, :max_worker_count, :source_job_id) SENSITIVE = [:parameters, :description] include Aws::Structure end |