Class: Aws::Deadline::Types::GetSessionsStatisticsAggregationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

If Deadline Cloud returns nextToken, then there are more results available. The value of nextToken is a unique pagination token for each page. To retrieve the next page, call the operation again using the returned token. Keep all other arguments unchanged. If no results remain, then nextToken is set to null. Each pagination token expires after 24 hours. If you provide a token that isn’t valid, then you receive an HTTP 400 ValidationException error.

Returns:

  • (String)


4256
4257
4258
4259
4260
4261
4262
4263
# File 'lib/aws-sdk-deadline/types.rb', line 4256

class GetSessionsStatisticsAggregationResponse < Struct.new(
  :statistics,
  :next_token,
  :status,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#statisticsArray<Types::Statistics>

The statistics for the specified fleets or queues.

Returns:



4256
4257
4258
4259
4260
4261
4262
4263
# File 'lib/aws-sdk-deadline/types.rb', line 4256

class GetSessionsStatisticsAggregationResponse < Struct.new(
  :statistics,
  :next_token,
  :status,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the aggregated results. An aggregation may fail or time out if the results are too large. If this happens, you can call the StartSessionsStatisticsAggregation operation after you reduce the aggregation time frame, reduce the number of queues or fleets in the aggregation, or increase the period length.

If you call the ‘StartSessionsStatisticsAggregation ` operation when the status is IN_PROGRESS, you will receive a ThrottlingException.

Returns:

  • (String)


4256
4257
4258
4259
4260
4261
4262
4263
# File 'lib/aws-sdk-deadline/types.rb', line 4256

class GetSessionsStatisticsAggregationResponse < Struct.new(
  :statistics,
  :next_token,
  :status,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#status_messageString

A message that describes the status.

Returns:

  • (String)


4256
4257
4258
4259
4260
4261
4262
4263
# File 'lib/aws-sdk-deadline/types.rb', line 4256

class GetSessionsStatisticsAggregationResponse < Struct.new(
  :statistics,
  :next_token,
  :status,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end