Class: Aws::Deadline::Types::GetVolumeResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Mixin that adds an optional ARN field to response structures. Apply to SummaryMixins (flows into Get, Summary, and BatchGet) and Create outputs.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attached_worker_idString

The worker ID of the worker the volume is attached to.

Returns:

  • (String)


6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
6382
6383
6384
6385
6386
# File 'lib/aws-sdk-deadline/types.rb', line 6369

class GetVolumeResponse < Struct.new(
  :volume_id,
  :farm_id,
  :fleet_id,
  :state,
  :size_gi_b,
  :availability_zone_id,
  :attached_worker_id,
  :volume_type,
  :iops,
  :throughput_mi_b,
  :created_at,
  :last_assigned_at,
  :last_released_at,
  :expires_at)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zone_idString

The Availability Zone ID of the volume.

Returns:

  • (String)


6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
6382
6383
6384
6385
6386
# File 'lib/aws-sdk-deadline/types.rb', line 6369

class GetVolumeResponse < Struct.new(
  :volume_id,
  :farm_id,
  :fleet_id,
  :state,
  :size_gi_b,
  :availability_zone_id,
  :attached_worker_id,
  :volume_type,
  :iops,
  :throughput_mi_b,
  :created_at,
  :last_assigned_at,
  :last_released_at,
  :expires_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the resource was created.

Returns:

  • (Time)


6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
6382
6383
6384
6385
6386
# File 'lib/aws-sdk-deadline/types.rb', line 6369

class GetVolumeResponse < Struct.new(
  :volume_id,
  :farm_id,
  :fleet_id,
  :state,
  :size_gi_b,
  :availability_zone_id,
  :attached_worker_id,
  :volume_type,
  :iops,
  :throughput_mi_b,
  :created_at,
  :last_assigned_at,
  :last_released_at,
  :expires_at)
  SENSITIVE = []
  include Aws::Structure
end

#expires_atTime

The date and time the volume expires and will be deleted.

Returns:

  • (Time)


6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
6382
6383
6384
6385
6386
# File 'lib/aws-sdk-deadline/types.rb', line 6369

class GetVolumeResponse < Struct.new(
  :volume_id,
  :farm_id,
  :fleet_id,
  :state,
  :size_gi_b,
  :availability_zone_id,
  :attached_worker_id,
  :volume_type,
  :iops,
  :throughput_mi_b,
  :created_at,
  :last_assigned_at,
  :last_released_at,
  :expires_at)
  SENSITIVE = []
  include Aws::Structure
end

#farm_idString

The farm ID of the farm that contains the fleet.

Returns:

  • (String)


6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
6382
6383
6384
6385
6386
# File 'lib/aws-sdk-deadline/types.rb', line 6369

class GetVolumeResponse < Struct.new(
  :volume_id,
  :farm_id,
  :fleet_id,
  :state,
  :size_gi_b,
  :availability_zone_id,
  :attached_worker_id,
  :volume_type,
  :iops,
  :throughput_mi_b,
  :created_at,
  :last_assigned_at,
  :last_released_at,
  :expires_at)
  SENSITIVE = []
  include Aws::Structure
end

#fleet_idString

The fleet ID of the fleet that contains the volume.

Returns:

  • (String)


6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
6382
6383
6384
6385
6386
# File 'lib/aws-sdk-deadline/types.rb', line 6369

class GetVolumeResponse < Struct.new(
  :volume_id,
  :farm_id,
  :fleet_id,
  :state,
  :size_gi_b,
  :availability_zone_id,
  :attached_worker_id,
  :volume_type,
  :iops,
  :throughput_mi_b,
  :created_at,
  :last_assigned_at,
  :last_released_at,
  :expires_at)
  SENSITIVE = []
  include Aws::Structure
end

#iopsInteger

The IOPS of the volume.

Returns:

  • (Integer)


6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
6382
6383
6384
6385
6386
# File 'lib/aws-sdk-deadline/types.rb', line 6369

class GetVolumeResponse < Struct.new(
  :volume_id,
  :farm_id,
  :fleet_id,
  :state,
  :size_gi_b,
  :availability_zone_id,
  :attached_worker_id,
  :volume_type,
  :iops,
  :throughput_mi_b,
  :created_at,
  :last_assigned_at,
  :last_released_at,
  :expires_at)
  SENSITIVE = []
  include Aws::Structure
end

#last_assigned_atTime

The date and time the volume was last assigned to a worker.

Returns:

  • (Time)


6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
6382
6383
6384
6385
6386
# File 'lib/aws-sdk-deadline/types.rb', line 6369

class GetVolumeResponse < Struct.new(
  :volume_id,
  :farm_id,
  :fleet_id,
  :state,
  :size_gi_b,
  :availability_zone_id,
  :attached_worker_id,
  :volume_type,
  :iops,
  :throughput_mi_b,
  :created_at,
  :last_assigned_at,
  :last_released_at,
  :expires_at)
  SENSITIVE = []
  include Aws::Structure
end

#last_released_atTime

The date and time the volume was last released from a worker.

Returns:

  • (Time)


6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
6382
6383
6384
6385
6386
# File 'lib/aws-sdk-deadline/types.rb', line 6369

class GetVolumeResponse < Struct.new(
  :volume_id,
  :farm_id,
  :fleet_id,
  :state,
  :size_gi_b,
  :availability_zone_id,
  :attached_worker_id,
  :volume_type,
  :iops,
  :throughput_mi_b,
  :created_at,
  :last_assigned_at,
  :last_released_at,
  :expires_at)
  SENSITIVE = []
  include Aws::Structure
end

#size_gi_bInteger

The volume size in GiB.

Returns:

  • (Integer)


6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
6382
6383
6384
6385
6386
# File 'lib/aws-sdk-deadline/types.rb', line 6369

class GetVolumeResponse < Struct.new(
  :volume_id,
  :farm_id,
  :fleet_id,
  :state,
  :size_gi_b,
  :availability_zone_id,
  :attached_worker_id,
  :volume_type,
  :iops,
  :throughput_mi_b,
  :created_at,
  :last_assigned_at,
  :last_released_at,
  :expires_at)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the volume.

Returns:

  • (String)


6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
6382
6383
6384
6385
6386
# File 'lib/aws-sdk-deadline/types.rb', line 6369

class GetVolumeResponse < Struct.new(
  :volume_id,
  :farm_id,
  :fleet_id,
  :state,
  :size_gi_b,
  :availability_zone_id,
  :attached_worker_id,
  :volume_type,
  :iops,
  :throughput_mi_b,
  :created_at,
  :last_assigned_at,
  :last_released_at,
  :expires_at)
  SENSITIVE = []
  include Aws::Structure
end

#throughput_mi_bInteger

The throughput of the volume in MiB.

Returns:

  • (Integer)


6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
6382
6383
6384
6385
6386
# File 'lib/aws-sdk-deadline/types.rb', line 6369

class GetVolumeResponse < Struct.new(
  :volume_id,
  :farm_id,
  :fleet_id,
  :state,
  :size_gi_b,
  :availability_zone_id,
  :attached_worker_id,
  :volume_type,
  :iops,
  :throughput_mi_b,
  :created_at,
  :last_assigned_at,
  :last_released_at,
  :expires_at)
  SENSITIVE = []
  include Aws::Structure
end

#volume_idString

The volume ID.

Returns:

  • (String)


6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
6382
6383
6384
6385
6386
# File 'lib/aws-sdk-deadline/types.rb', line 6369

class GetVolumeResponse < Struct.new(
  :volume_id,
  :farm_id,
  :fleet_id,
  :state,
  :size_gi_b,
  :availability_zone_id,
  :attached_worker_id,
  :volume_type,
  :iops,
  :throughput_mi_b,
  :created_at,
  :last_assigned_at,
  :last_released_at,
  :expires_at)
  SENSITIVE = []
  include Aws::Structure
end

#volume_typeString

The EBS volume type.

Returns:

  • (String)


6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
6382
6383
6384
6385
6386
# File 'lib/aws-sdk-deadline/types.rb', line 6369

class GetVolumeResponse < Struct.new(
  :volume_id,
  :farm_id,
  :fleet_id,
  :state,
  :size_gi_b,
  :availability_zone_id,
  :attached_worker_id,
  :volume_type,
  :iops,
  :throughput_mi_b,
  :created_at,
  :last_assigned_at,
  :last_released_at,
  :expires_at)
  SENSITIVE = []
  include Aws::Structure
end