Class: Aws::Deadline::Types::JobEntity

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Note:

JobEntity is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of JobEntity corresponding to the set member.

The details of a job entity.

Defined Under Namespace

Classes: EnvironmentDetails, JobAttachmentDetails, JobDetails, StepDetails, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#environment_detailsTypes::EnvironmentDetailsEntity

The environment details for the job entity.



5019
5020
5021
5022
5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
# File 'lib/aws-sdk-deadline/types.rb', line 5019

class JobEntity < Struct.new(
  :job_details,
  :job_attachment_details,
  :step_details,
  :environment_details,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class JobDetails < JobEntity; end
  class JobAttachmentDetails < JobEntity; end
  class StepDetails < JobEntity; end
  class EnvironmentDetails < JobEntity; end
  class Unknown < JobEntity; end
end

#job_attachment_detailsTypes::JobAttachmentDetailsEntity

The job attachment details.



5019
5020
5021
5022
5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
# File 'lib/aws-sdk-deadline/types.rb', line 5019

class JobEntity < Struct.new(
  :job_details,
  :job_attachment_details,
  :step_details,
  :environment_details,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class JobDetails < JobEntity; end
  class JobAttachmentDetails < JobEntity; end
  class StepDetails < JobEntity; end
  class EnvironmentDetails < JobEntity; end
  class Unknown < JobEntity; end
end

#job_detailsTypes::JobDetailsEntity

The job details.



5019
5020
5021
5022
5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
# File 'lib/aws-sdk-deadline/types.rb', line 5019

class JobEntity < Struct.new(
  :job_details,
  :job_attachment_details,
  :step_details,
  :environment_details,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class JobDetails < JobEntity; end
  class JobAttachmentDetails < JobEntity; end
  class StepDetails < JobEntity; end
  class EnvironmentDetails < JobEntity; end
  class Unknown < JobEntity; end
end

#step_detailsTypes::StepDetailsEntity

The step details.



5019
5020
5021
5022
5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
# File 'lib/aws-sdk-deadline/types.rb', line 5019

class JobEntity < Struct.new(
  :job_details,
  :job_attachment_details,
  :step_details,
  :environment_details,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class JobDetails < JobEntity; end
  class JobAttachmentDetails < JobEntity; end
  class StepDetails < JobEntity; end
  class EnvironmentDetails < JobEntity; end
  class Unknown < JobEntity; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



5019
5020
5021
# File 'lib/aws-sdk-deadline/types.rb', line 5019

def unknown
  @unknown
end