Class: Aws::Deadline::Types::JobParameter

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Note:

JobParameter is a union - when making an API calls you must set exactly one of the members.

Note:

JobParameter is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of JobParameter corresponding to the set member.

The details of job parameters.

Defined Under Namespace

Classes: Float, Int, Path, String, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#floatString

A double precision IEEE-754 floating point number represented as a string.

Returns:



6965
6966
6967
6968
6969
6970
6971
6972
6973
6974
6975
6976
6977
6978
6979
6980
# File 'lib/aws-sdk-deadline/types.rb', line 6965

class JobParameter < Struct.new(
  :int,
  :float,
  :string,
  :path,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Int < JobParameter; end
  class Float < JobParameter; end
  class String < JobParameter; end
  class Path < JobParameter; end
  class Unknown < JobParameter; end
end

#intString

A signed integer represented as a string.

Returns:



6965
6966
6967
6968
6969
6970
6971
6972
6973
6974
6975
6976
6977
6978
6979
6980
# File 'lib/aws-sdk-deadline/types.rb', line 6965

class JobParameter < Struct.new(
  :int,
  :float,
  :string,
  :path,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Int < JobParameter; end
  class Float < JobParameter; end
  class String < JobParameter; end
  class Path < JobParameter; end
  class Unknown < JobParameter; end
end

#pathString

A file system path represented as a string.

Returns:



6965
6966
6967
6968
6969
6970
6971
6972
6973
6974
6975
6976
6977
6978
6979
6980
# File 'lib/aws-sdk-deadline/types.rb', line 6965

class JobParameter < Struct.new(
  :int,
  :float,
  :string,
  :path,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Int < JobParameter; end
  class Float < JobParameter; end
  class String < JobParameter; end
  class Path < JobParameter; end
  class Unknown < JobParameter; end
end

#stringString

A UTF-8 string.

Returns:



6965
6966
6967
6968
6969
6970
6971
6972
6973
6974
6975
6976
6977
6978
6979
6980
# File 'lib/aws-sdk-deadline/types.rb', line 6965

class JobParameter < Struct.new(
  :int,
  :float,
  :string,
  :path,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Int < JobParameter; end
  class Float < JobParameter; end
  class String < JobParameter; end
  class Path < JobParameter; end
  class Unknown < JobParameter; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



6965
6966
6967
# File 'lib/aws-sdk-deadline/types.rb', line 6965

def unknown
  @unknown
end