Class: Aws::Deadline::Types::JobSearchSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

The details of a job search.

Constant Summary collapse

SENSITIVE =
[:job_parameters]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The date and time the resource was created.

Returns:

  • (Time)


7125
7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
# File 'lib/aws-sdk-deadline/types.rb', line 7125

class JobSearchSummary < Struct.new(
  :job_id,
  :queue_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :created_by,
  :created_at,
  :ended_at,
  :started_at,
  :updated_at,
  :updated_by,
  :job_parameters,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = [:job_parameters]
  include Aws::Structure
end

#created_byString

The user or system that created this resource.

Returns:

  • (String)


7125
7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
# File 'lib/aws-sdk-deadline/types.rb', line 7125

class JobSearchSummary < Struct.new(
  :job_id,
  :queue_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :created_by,
  :created_at,
  :ended_at,
  :started_at,
  :updated_at,
  :updated_by,
  :job_parameters,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = [:job_parameters]
  include Aws::Structure
end

#ended_atTime

The date and time the resource ended running.

Returns:

  • (Time)


7125
7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
# File 'lib/aws-sdk-deadline/types.rb', line 7125

class JobSearchSummary < Struct.new(
  :job_id,
  :queue_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :created_by,
  :created_at,
  :ended_at,
  :started_at,
  :updated_at,
  :updated_by,
  :job_parameters,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = [:job_parameters]
  include Aws::Structure
end

#job_idString

The job ID.

Returns:

  • (String)


7125
7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
# File 'lib/aws-sdk-deadline/types.rb', line 7125

class JobSearchSummary < Struct.new(
  :job_id,
  :queue_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :created_by,
  :created_at,
  :ended_at,
  :started_at,
  :updated_at,
  :updated_by,
  :job_parameters,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = [:job_parameters]
  include Aws::Structure
end

#job_parametersHash<String,Types::JobParameter>

The job parameters.

Returns:



7125
7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
# File 'lib/aws-sdk-deadline/types.rb', line 7125

class JobSearchSummary < Struct.new(
  :job_id,
  :queue_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :created_by,
  :created_at,
  :ended_at,
  :started_at,
  :updated_at,
  :updated_by,
  :job_parameters,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = [:job_parameters]
  include Aws::Structure
end

#lifecycle_statusString

The life cycle status.

Returns:

  • (String)


7125
7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
# File 'lib/aws-sdk-deadline/types.rb', line 7125

class JobSearchSummary < Struct.new(
  :job_id,
  :queue_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :created_by,
  :created_at,
  :ended_at,
  :started_at,
  :updated_at,
  :updated_by,
  :job_parameters,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = [:job_parameters]
  include Aws::Structure
end

#lifecycle_status_messageString

The life cycle status message.

Returns:

  • (String)


7125
7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
# File 'lib/aws-sdk-deadline/types.rb', line 7125

class JobSearchSummary < Struct.new(
  :job_id,
  :queue_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :created_by,
  :created_at,
  :ended_at,
  :started_at,
  :updated_at,
  :updated_by,
  :job_parameters,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = [:job_parameters]
  include Aws::Structure
end

#max_failed_tasks_countInteger

The number of task failures before the job stops running and is marked as FAILED.

Returns:

  • (Integer)


7125
7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
# File 'lib/aws-sdk-deadline/types.rb', line 7125

class JobSearchSummary < Struct.new(
  :job_id,
  :queue_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :created_by,
  :created_at,
  :ended_at,
  :started_at,
  :updated_at,
  :updated_by,
  :job_parameters,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = [:job_parameters]
  include Aws::Structure
end

#max_retries_per_taskInteger

The maximum number of retries for a job.

Returns:

  • (Integer)


7125
7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
# File 'lib/aws-sdk-deadline/types.rb', line 7125

class JobSearchSummary < Struct.new(
  :job_id,
  :queue_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :created_by,
  :created_at,
  :ended_at,
  :started_at,
  :updated_at,
  :updated_by,
  :job_parameters,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = [:job_parameters]
  include Aws::Structure
end

#max_worker_countInteger

The maximum number of worker hosts that can concurrently process a job. When the maxWorkerCount is reached, no more workers will be assigned to process the job, even if the fleets assigned to the job's queue has available workers.

You can't set the maxWorkerCount to 0. If you set it to -1, there is no maximum number of workers.

If you don't specify the maxWorkerCount, the default is -1.

Returns:

  • (Integer)


7125
7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
# File 'lib/aws-sdk-deadline/types.rb', line 7125

class JobSearchSummary < Struct.new(
  :job_id,
  :queue_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :created_by,
  :created_at,
  :ended_at,
  :started_at,
  :updated_at,
  :updated_by,
  :job_parameters,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = [:job_parameters]
  include Aws::Structure
end

#nameString

The job name.

Returns:

  • (String)


7125
7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
# File 'lib/aws-sdk-deadline/types.rb', line 7125

class JobSearchSummary < Struct.new(
  :job_id,
  :queue_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :created_by,
  :created_at,
  :ended_at,
  :started_at,
  :updated_at,
  :updated_by,
  :job_parameters,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = [:job_parameters]
  include Aws::Structure
end

#priorityInteger

The job priority.

Returns:

  • (Integer)


7125
7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
# File 'lib/aws-sdk-deadline/types.rb', line 7125

class JobSearchSummary < Struct.new(
  :job_id,
  :queue_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :created_by,
  :created_at,
  :ended_at,
  :started_at,
  :updated_at,
  :updated_by,
  :job_parameters,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = [:job_parameters]
  include Aws::Structure
end

#queue_idString

The queue ID.

Returns:

  • (String)


7125
7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
# File 'lib/aws-sdk-deadline/types.rb', line 7125

class JobSearchSummary < Struct.new(
  :job_id,
  :queue_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :created_by,
  :created_at,
  :ended_at,
  :started_at,
  :updated_at,
  :updated_by,
  :job_parameters,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = [:job_parameters]
  include Aws::Structure
end

#source_job_idString

The job ID for the source job.

Returns:

  • (String)


7125
7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
# File 'lib/aws-sdk-deadline/types.rb', line 7125

class JobSearchSummary < Struct.new(
  :job_id,
  :queue_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :created_by,
  :created_at,
  :ended_at,
  :started_at,
  :updated_at,
  :updated_by,
  :job_parameters,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = [:job_parameters]
  include Aws::Structure
end

#started_atTime

The date and time the resource started running.

Returns:

  • (Time)


7125
7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
# File 'lib/aws-sdk-deadline/types.rb', line 7125

class JobSearchSummary < Struct.new(
  :job_id,
  :queue_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :created_by,
  :created_at,
  :ended_at,
  :started_at,
  :updated_at,
  :updated_by,
  :job_parameters,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = [:job_parameters]
  include Aws::Structure
end

#target_task_run_statusString

The task status to update the job's tasks to.

Returns:

  • (String)


7125
7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
# File 'lib/aws-sdk-deadline/types.rb', line 7125

class JobSearchSummary < Struct.new(
  :job_id,
  :queue_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :created_by,
  :created_at,
  :ended_at,
  :started_at,
  :updated_at,
  :updated_by,
  :job_parameters,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = [:job_parameters]
  include Aws::Structure
end

#task_failure_retry_countInteger

The total number of times tasks from the job failed and were retried.

Returns:

  • (Integer)


7125
7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
# File 'lib/aws-sdk-deadline/types.rb', line 7125

class JobSearchSummary < Struct.new(
  :job_id,
  :queue_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :created_by,
  :created_at,
  :ended_at,
  :started_at,
  :updated_at,
  :updated_by,
  :job_parameters,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = [:job_parameters]
  include Aws::Structure
end

#task_run_statusString

The task run status for the job.

  • PENDING–pending and waiting for resources.

  • READY–ready to be processed.

  • ASSIGNED–assigned and will run next on a worker.

  • SCHEDULED–scheduled to be run on a worker.

  • INTERRUPTING–being interrupted.

  • RUNNING–running on a worker.

  • SUSPENDED–the task is suspended.

  • CANCELED–the task has been canceled.

  • FAILED–the task has failed.

  • SUCCEEDED–the task has succeeded.

Returns:

  • (String)


7125
7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
# File 'lib/aws-sdk-deadline/types.rb', line 7125

class JobSearchSummary < Struct.new(
  :job_id,
  :queue_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :created_by,
  :created_at,
  :ended_at,
  :started_at,
  :updated_at,
  :updated_by,
  :job_parameters,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = [:job_parameters]
  include Aws::Structure
end

#task_run_status_countsHash<String,Integer>

The number of tasks running on the job.

Returns:

  • (Hash<String,Integer>)


7125
7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
# File 'lib/aws-sdk-deadline/types.rb', line 7125

class JobSearchSummary < Struct.new(
  :job_id,
  :queue_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :created_by,
  :created_at,
  :ended_at,
  :started_at,
  :updated_at,
  :updated_by,
  :job_parameters,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = [:job_parameters]
  include Aws::Structure
end

#updated_atTime

The date and time the resource was updated.

Returns:

  • (Time)


7125
7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
# File 'lib/aws-sdk-deadline/types.rb', line 7125

class JobSearchSummary < Struct.new(
  :job_id,
  :queue_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :created_by,
  :created_at,
  :ended_at,
  :started_at,
  :updated_at,
  :updated_by,
  :job_parameters,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = [:job_parameters]
  include Aws::Structure
end

#updated_byString

The user or system that updated this resource.

Returns:

  • (String)


7125
7126
7127
7128
7129
7130
7131
7132
7133
7134
7135
7136
7137
7138
7139
7140
7141
7142
7143
7144
7145
7146
7147
7148
7149
# File 'lib/aws-sdk-deadline/types.rb', line 7125

class JobSearchSummary < Struct.new(
  :job_id,
  :queue_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :created_by,
  :created_at,
  :ended_at,
  :started_at,
  :updated_at,
  :updated_by,
  :job_parameters,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = [:job_parameters]
  include Aws::Structure
end