Class: Aws::Deadline::Types::JobSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

A summary of job details.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The date and time the resource was created.

Returns:

  • (Time)


7261
7262
7263
7264
7265
7266
7267
7268
7269
7270
7271
7272
7273
7274
7275
7276
7277
7278
7279
7280
7281
7282
7283
# File 'lib/aws-sdk-deadline/types.rb', line 7261

class JobSummary < Struct.new(
  :job_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :priority,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = []
  include Aws::Structure
end

#created_byString

The user or system that created this resource.

Returns:

  • (String)


7261
7262
7263
7264
7265
7266
7267
7268
7269
7270
7271
7272
7273
7274
7275
7276
7277
7278
7279
7280
7281
7282
7283
# File 'lib/aws-sdk-deadline/types.rb', line 7261

class JobSummary < Struct.new(
  :job_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :priority,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = []
  include Aws::Structure
end

#ended_atTime

The date and time the resource ended running.

Returns:

  • (Time)


7261
7262
7263
7264
7265
7266
7267
7268
7269
7270
7271
7272
7273
7274
7275
7276
7277
7278
7279
7280
7281
7282
7283
# File 'lib/aws-sdk-deadline/types.rb', line 7261

class JobSummary < Struct.new(
  :job_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :priority,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The job ID.

Returns:

  • (String)


7261
7262
7263
7264
7265
7266
7267
7268
7269
7270
7271
7272
7273
7274
7275
7276
7277
7278
7279
7280
7281
7282
7283
# File 'lib/aws-sdk-deadline/types.rb', line 7261

class JobSummary < Struct.new(
  :job_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :priority,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = []
  include Aws::Structure
end

#lifecycle_statusString

The life cycle status.

Returns:

  • (String)


7261
7262
7263
7264
7265
7266
7267
7268
7269
7270
7271
7272
7273
7274
7275
7276
7277
7278
7279
7280
7281
7282
7283
# File 'lib/aws-sdk-deadline/types.rb', line 7261

class JobSummary < Struct.new(
  :job_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :priority,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = []
  include Aws::Structure
end

#lifecycle_status_messageString

The life cycle status message.

Returns:

  • (String)


7261
7262
7263
7264
7265
7266
7267
7268
7269
7270
7271
7272
7273
7274
7275
7276
7277
7278
7279
7280
7281
7282
7283
# File 'lib/aws-sdk-deadline/types.rb', line 7261

class JobSummary < Struct.new(
  :job_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :priority,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = []
  include Aws::Structure
end

#max_failed_tasks_countInteger

The number of task failures before the job stops running and is marked as FAILED.

Returns:

  • (Integer)


7261
7262
7263
7264
7265
7266
7267
7268
7269
7270
7271
7272
7273
7274
7275
7276
7277
7278
7279
7280
7281
7282
7283
# File 'lib/aws-sdk-deadline/types.rb', line 7261

class JobSummary < Struct.new(
  :job_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :priority,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = []
  include Aws::Structure
end

#max_retries_per_taskInteger

The maximum number of retries for a job.

Returns:

  • (Integer)


7261
7262
7263
7264
7265
7266
7267
7268
7269
7270
7271
7272
7273
7274
7275
7276
7277
7278
7279
7280
7281
7282
7283
# File 'lib/aws-sdk-deadline/types.rb', line 7261

class JobSummary < Struct.new(
  :job_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :priority,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = []
  include Aws::Structure
end

#max_worker_countInteger

The maximum number of worker hosts that can concurrently process a job. When the maxWorkerCount is reached, no more workers will be assigned to process the job, even if the fleets assigned to the job's queue has available workers.

You can't set the maxWorkerCount to 0. If you set it to -1, there is no maximum number of workers.

If you don't specify the maxWorkerCount, the default is -1.

Returns:

  • (Integer)


7261
7262
7263
7264
7265
7266
7267
7268
7269
7270
7271
7272
7273
7274
7275
7276
7277
7278
7279
7280
7281
7282
7283
# File 'lib/aws-sdk-deadline/types.rb', line 7261

class JobSummary < Struct.new(
  :job_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :priority,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The job name.

Returns:

  • (String)


7261
7262
7263
7264
7265
7266
7267
7268
7269
7270
7271
7272
7273
7274
7275
7276
7277
7278
7279
7280
7281
7282
7283
# File 'lib/aws-sdk-deadline/types.rb', line 7261

class JobSummary < Struct.new(
  :job_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :priority,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = []
  include Aws::Structure
end

#priorityInteger

The job priority.

Returns:

  • (Integer)


7261
7262
7263
7264
7265
7266
7267
7268
7269
7270
7271
7272
7273
7274
7275
7276
7277
7278
7279
7280
7281
7282
7283
# File 'lib/aws-sdk-deadline/types.rb', line 7261

class JobSummary < Struct.new(
  :job_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :priority,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = []
  include Aws::Structure
end

#source_job_idString

The job ID for the source job.

Returns:

  • (String)


7261
7262
7263
7264
7265
7266
7267
7268
7269
7270
7271
7272
7273
7274
7275
7276
7277
7278
7279
7280
7281
7282
7283
# File 'lib/aws-sdk-deadline/types.rb', line 7261

class JobSummary < Struct.new(
  :job_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :priority,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = []
  include Aws::Structure
end

#started_atTime

The date and time the resource started running.

Returns:

  • (Time)


7261
7262
7263
7264
7265
7266
7267
7268
7269
7270
7271
7272
7273
7274
7275
7276
7277
7278
7279
7280
7281
7282
7283
# File 'lib/aws-sdk-deadline/types.rb', line 7261

class JobSummary < Struct.new(
  :job_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :priority,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = []
  include Aws::Structure
end

#target_task_run_statusString

The task status to update the job's tasks to.

Returns:

  • (String)


7261
7262
7263
7264
7265
7266
7267
7268
7269
7270
7271
7272
7273
7274
7275
7276
7277
7278
7279
7280
7281
7282
7283
# File 'lib/aws-sdk-deadline/types.rb', line 7261

class JobSummary < Struct.new(
  :job_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :priority,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = []
  include Aws::Structure
end

#task_failure_retry_countInteger

The total number of times tasks from the job failed and were retried.

Returns:

  • (Integer)


7261
7262
7263
7264
7265
7266
7267
7268
7269
7270
7271
7272
7273
7274
7275
7276
7277
7278
7279
7280
7281
7282
7283
# File 'lib/aws-sdk-deadline/types.rb', line 7261

class JobSummary < Struct.new(
  :job_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :priority,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = []
  include Aws::Structure
end

#task_run_statusString

The task run status for the job.

  • PENDING–pending and waiting for resources.

  • READY–ready to be processed.

  • ASSIGNED–assigned and will run next on a worker.

  • SCHEDULED–scheduled to be run on a worker.

  • INTERRUPTING–being interrupted.

  • RUNNING–running on a worker.

  • SUSPENDED–the task is suspended.

  • CANCELED–the task has been canceled.

  • FAILED–the task has failed.

  • SUCCEEDED–the task has succeeded.

Returns:

  • (String)


7261
7262
7263
7264
7265
7266
7267
7268
7269
7270
7271
7272
7273
7274
7275
7276
7277
7278
7279
7280
7281
7282
7283
# File 'lib/aws-sdk-deadline/types.rb', line 7261

class JobSummary < Struct.new(
  :job_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :priority,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = []
  include Aws::Structure
end

#task_run_status_countsHash<String,Integer>

The number of tasks running on the job.

Returns:

  • (Hash<String,Integer>)


7261
7262
7263
7264
7265
7266
7267
7268
7269
7270
7271
7272
7273
7274
7275
7276
7277
7278
7279
7280
7281
7282
7283
# File 'lib/aws-sdk-deadline/types.rb', line 7261

class JobSummary < Struct.new(
  :job_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :priority,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time the resource was updated.

Returns:

  • (Time)


7261
7262
7263
7264
7265
7266
7267
7268
7269
7270
7271
7272
7273
7274
7275
7276
7277
7278
7279
7280
7281
7282
7283
# File 'lib/aws-sdk-deadline/types.rb', line 7261

class JobSummary < Struct.new(
  :job_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :priority,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = []
  include Aws::Structure
end

#updated_byString

The user or system that updated this resource.

Returns:

  • (String)


7261
7262
7263
7264
7265
7266
7267
7268
7269
7270
7271
7272
7273
7274
7275
7276
7277
7278
7279
7280
7281
7282
7283
# File 'lib/aws-sdk-deadline/types.rb', line 7261

class JobSummary < Struct.new(
  :job_id,
  :name,
  :lifecycle_status,
  :lifecycle_status_message,
  :priority,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :started_at,
  :ended_at,
  :task_run_status,
  :target_task_run_status,
  :task_run_status_counts,
  :task_failure_retry_count,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :max_worker_count,
  :source_job_id)
  SENSITIVE = []
  include Aws::Structure
end