Class: Aws::Deadline::Types::ListBudgetsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#farm_idString

The farm ID associated with the budgets.

Returns:

  • (String)


5630
5631
5632
5633
5634
5635
5636
5637
# File 'lib/aws-sdk-deadline/types.rb', line 5630

class ListBudgetsRequest < Struct.new(
  :next_token,
  :farm_id,
  :max_results,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages.

Returns:

  • (Integer)


5630
5631
5632
5633
5634
5635
5636
5637
# File 'lib/aws-sdk-deadline/types.rb', line 5630

class ListBudgetsRequest < Struct.new(
  :next_token,
  :farm_id,
  :max_results,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results, or null to start from the beginning.

Returns:

  • (String)


5630
5631
5632
5633
5634
5635
5636
5637
# File 'lib/aws-sdk-deadline/types.rb', line 5630

class ListBudgetsRequest < Struct.new(
  :next_token,
  :farm_id,
  :max_results,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status to list for the budgets.

Returns:

  • (String)


5630
5631
5632
5633
5634
5635
5636
5637
# File 'lib/aws-sdk-deadline/types.rb', line 5630

class ListBudgetsRequest < Struct.new(
  :next_token,
  :farm_id,
  :max_results,
  :status)
  SENSITIVE = []
  include Aws::Structure
end