Class: Aws::Deadline::Types::ListFarmMembersRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#farm_idString

The farm ID.

Returns:

  • (String)


5668
5669
5670
5671
5672
5673
5674
# File 'lib/aws-sdk-deadline/types.rb', line 5668

class ListFarmMembersRequest < Struct.new(
  :farm_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages.

Returns:

  • (Integer)


5668
5669
5670
5671
5672
5673
5674
# File 'lib/aws-sdk-deadline/types.rb', line 5668

class ListFarmMembersRequest < Struct.new(
  :farm_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results, or null to start from the beginning.

Returns:

  • (String)


5668
5669
5670
5671
5672
5673
5674
# File 'lib/aws-sdk-deadline/types.rb', line 5668

class ListFarmMembersRequest < Struct.new(
  :farm_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end