Class: Aws::Deadline::Types::ListFarmMembersResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::ListFarmMembersResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#members ⇒ Array<Types::FarmMember>
The members on the list.
-
#next_token ⇒ String
If Deadline Cloud returns
nextToken, then there are more results available.
Instance Attribute Details
#members ⇒ Array<Types::FarmMember>
The members on the list.
5692 5693 5694 5695 5696 5697 |
# File 'lib/aws-sdk-deadline/types.rb', line 5692 class ListFarmMembersResponse < Struct.new( :members, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If Deadline Cloud returns nextToken, then there are more results available. The value of nextToken is a unique pagination token for each page. To retrieve the next page, call the operation again using the returned token. Keep all other arguments unchanged. If no results remain, then nextToken is set to null. Each pagination token expires after 24 hours. If you provide a token that isn’t valid, then you receive an HTTP 400 ValidationException error.
5692 5693 5694 5695 5696 5697 |
# File 'lib/aws-sdk-deadline/types.rb', line 5692 class ListFarmMembersResponse < Struct.new( :members, :next_token) SENSITIVE = [] include Aws::Structure end |