Class: Aws::Deadline::Types::ListFleetMembersResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Shared pagination field for List operation outputs (nextToken).

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#membersArray<Types::FleetMember>

The members on the list.

Returns:



7647
7648
7649
7650
7651
7652
# File 'lib/aws-sdk-deadline/types.rb', line 7647

class ListFleetMembersResponse < Struct.new(
  :members,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If Deadline Cloud returns nextToken, then there are more results available. The value of nextToken is a unique pagination token for each page. To retrieve the next page, call the operation again using the returned token. Keep all other arguments unchanged. If no results remain, then nextToken is set to null. Each pagination token expires after 24 hours. If you provide a token that isn't valid, then you receive an HTTP 400 ValidationException error.

Returns:



7647
7648
7649
7650
7651
7652
# File 'lib/aws-sdk-deadline/types.rb', line 7647

class ListFleetMembersResponse < Struct.new(
  :members,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end