Class: Aws::Deadline::Types::ListJobMembersResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::ListJobMembersResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#members ⇒ Array<Types::JobMember>
The members on the list.
-
#next_token ⇒ String
If Deadline Cloud returns
nextToken, then there are more results available.
Instance Attribute Details
#members ⇒ Array<Types::JobMember>
The members on the list.
5924 5925 5926 5927 5928 5929 |
# File 'lib/aws-sdk-deadline/types.rb', line 5924 class ListJobMembersResponse < Struct.new( :members, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If Deadline Cloud returns nextToken, then there are more results available. The value of nextToken is a unique pagination token for each page. To retrieve the next page, call the operation again using the returned token. Keep all other arguments unchanged. If no results remain, then nextToken is set to null. Each pagination token expires after 24 hours. If you provide a token that isn’t valid, then you receive an HTTP 400 ValidationException error.
5924 5925 5926 5927 5928 5929 |
# File 'lib/aws-sdk-deadline/types.rb', line 5924 class ListJobMembersResponse < Struct.new( :members, :next_token) SENSITIVE = [] include Aws::Structure end |