Class: Aws::Deadline::Types::ListJobParameterDefinitionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#farm_idString

The farm ID of the job to list.

Returns:

  • (String)


5945
5946
5947
5948
5949
5950
5951
5952
5953
# File 'lib/aws-sdk-deadline/types.rb', line 5945

class ListJobParameterDefinitionsRequest < Struct.new(
  :farm_id,
  :job_id,
  :queue_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The job ID to include on the list.

Returns:

  • (String)


5945
5946
5947
5948
5949
5950
5951
5952
5953
# File 'lib/aws-sdk-deadline/types.rb', line 5945

class ListJobParameterDefinitionsRequest < Struct.new(
  :farm_id,
  :job_id,
  :queue_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages.

Returns:

  • (Integer)


5945
5946
5947
5948
5949
5950
5951
5952
5953
# File 'lib/aws-sdk-deadline/types.rb', line 5945

class ListJobParameterDefinitionsRequest < Struct.new(
  :farm_id,
  :job_id,
  :queue_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results, or null to start from the beginning.

Returns:

  • (String)


5945
5946
5947
5948
5949
5950
5951
5952
5953
# File 'lib/aws-sdk-deadline/types.rb', line 5945

class ListJobParameterDefinitionsRequest < Struct.new(
  :farm_id,
  :job_id,
  :queue_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#queue_idString

The queue ID to include on the list.

Returns:

  • (String)


5945
5946
5947
5948
5949
5950
5951
5952
5953
# File 'lib/aws-sdk-deadline/types.rb', line 5945

class ListJobParameterDefinitionsRequest < Struct.new(
  :farm_id,
  :job_id,
  :queue_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end