Class: Aws::Deadline::Types::ListJobParameterDefinitionsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#job_parameter_definitionsArray<Hash,Array,String,Numeric,Boolean>

Lists parameter definitions of a job.

Returns:

  • (Array<Hash,Array,String,Numeric,Boolean>)


5971
5972
5973
5974
5975
5976
# File 'lib/aws-sdk-deadline/types.rb', line 5971

class ListJobParameterDefinitionsResponse < Struct.new(
  :job_parameter_definitions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If Deadline Cloud returns nextToken, then there are more results available. The value of nextToken is a unique pagination token for each page. To retrieve the next page, call the operation again using the returned token. Keep all other arguments unchanged. If no results remain, then nextToken is set to null. Each pagination token expires after 24 hours. If you provide a token that isn’t valid, then you receive an HTTP 400 ValidationException error.

Returns:

  • (String)


5971
5972
5973
5974
5975
5976
# File 'lib/aws-sdk-deadline/types.rb', line 5971

class ListJobParameterDefinitionsResponse < Struct.new(
  :job_parameter_definitions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end