Class: Aws::Deadline::Types::ListJobsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Shared pagination fields for List operation inputs (nextToken + maxResults).

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#farm_idString

The farm ID for the jobs.

Returns:

  • (String)


7876
7877
7878
7879
7880
7881
7882
7883
7884
# File 'lib/aws-sdk-deadline/types.rb', line 7876

class ListJobsRequest < Struct.new(
  :farm_id,
  :queue_id,
  :next_token,
  :max_results,
  :principal_id)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages.

Returns:

  • (Integer)


7876
7877
7878
7879
7880
7881
7882
7883
7884
# File 'lib/aws-sdk-deadline/types.rb', line 7876

class ListJobsRequest < Struct.new(
  :farm_id,
  :queue_id,
  :next_token,
  :max_results,
  :principal_id)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results, or null to start from the beginning.

Returns:

  • (String)


7876
7877
7878
7879
7880
7881
7882
7883
7884
# File 'lib/aws-sdk-deadline/types.rb', line 7876

class ListJobsRequest < Struct.new(
  :farm_id,
  :queue_id,
  :next_token,
  :max_results,
  :principal_id)
  SENSITIVE = []
  include Aws::Structure
end

#principal_idString

The principal ID of the members on the jobs.

Returns:

  • (String)


7876
7877
7878
7879
7880
7881
7882
7883
7884
# File 'lib/aws-sdk-deadline/types.rb', line 7876

class ListJobsRequest < Struct.new(
  :farm_id,
  :queue_id,
  :next_token,
  :max_results,
  :principal_id)
  SENSITIVE = []
  include Aws::Structure
end

#queue_idString

The queue ID for the job.

Returns:

  • (String)


7876
7877
7878
7879
7880
7881
7882
7883
7884
# File 'lib/aws-sdk-deadline/types.rb', line 7876

class ListJobsRequest < Struct.new(
  :farm_id,
  :queue_id,
  :next_token,
  :max_results,
  :principal_id)
  SENSITIVE = []
  include Aws::Structure
end