Class: Aws::Deadline::Types::ListLicenseEndpointsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::ListLicenseEndpointsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Shared pagination fields for List operation inputs (nextToken + maxResults).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return.
-
#next_token ⇒ String
The token for the next set of results, or
nullto start from the beginning.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return. Use this parameter with
NextToken to get results as a set of sequential pages.
7926 7927 7928 7929 7930 7931 |
# File 'lib/aws-sdk-deadline/types.rb', line 7926 class ListLicenseEndpointsRequest < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results, or null to start from the
beginning.
7926 7927 7928 7929 7930 7931 |
# File 'lib/aws-sdk-deadline/types.rb', line 7926 class ListLicenseEndpointsRequest < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |