Class: Aws::Deadline::Types::ListLicenseEndpointsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::ListLicenseEndpointsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#license_endpoints ⇒ Array<Types::LicenseEndpointSummary>
The license endpoints.
-
#next_token ⇒ String
If Deadline Cloud returns
nextToken, then there are more results available.
Instance Attribute Details
#license_endpoints ⇒ Array<Types::LicenseEndpointSummary>
The license endpoints.
6080 6081 6082 6083 6084 6085 |
# File 'lib/aws-sdk-deadline/types.rb', line 6080 class ListLicenseEndpointsResponse < Struct.new( :license_endpoints, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If Deadline Cloud returns nextToken, then there are more results available. The value of nextToken is a unique pagination token for each page. To retrieve the next page, call the operation again using the returned token. Keep all other arguments unchanged. If no results remain, then nextToken is set to null. Each pagination token expires after 24 hours. If you provide a token that isn’t valid, then you receive an HTTP 400 ValidationException error.
6080 6081 6082 6083 6084 6085 |
# File 'lib/aws-sdk-deadline/types.rb', line 6080 class ListLicenseEndpointsResponse < Struct.new( :license_endpoints, :next_token) SENSITIVE = [] include Aws::Structure end |