Class: Aws::Deadline::Types::ListLimitsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Shared pagination fields for List operation inputs (nextToken + maxResults).

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#farm_idString

The unique identifier of the farm that contains the limits.

Returns:

  • (String)


7976
7977
7978
7979
7980
7981
7982
# File 'lib/aws-sdk-deadline/types.rb', line 7976

class ListLimitsRequest < Struct.new(
  :farm_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of limits to return in each page of results.

Returns:

  • (Integer)


7976
7977
7978
7979
7980
7981
7982
# File 'lib/aws-sdk-deadline/types.rb', line 7976

class ListLimitsRequest < Struct.new(
  :farm_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results, or null to start from the beginning.

Returns:

  • (String)


7976
7977
7978
7979
7980
7981
7982
# File 'lib/aws-sdk-deadline/types.rb', line 7976

class ListLimitsRequest < Struct.new(
  :farm_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end