Class: Aws::Deadline::Types::ListQueueEnvironmentsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Shared pagination fields for List operation inputs (nextToken + maxResults).

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#farm_idString

The farm ID for the queue environment list.

Returns:



8132
8133
8134
8135
8136
8137
8138
8139
# File 'lib/aws-sdk-deadline/types.rb', line 8132

class ListQueueEnvironmentsRequest < Struct.new(
  :farm_id,
  :queue_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages.

Returns:



8132
8133
8134
8135
8136
8137
8138
8139
# File 'lib/aws-sdk-deadline/types.rb', line 8132

class ListQueueEnvironmentsRequest < Struct.new(
  :farm_id,
  :queue_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results, or null to start from the beginning.

Returns:



8132
8133
8134
8135
8136
8137
8138
8139
# File 'lib/aws-sdk-deadline/types.rb', line 8132

class ListQueueEnvironmentsRequest < Struct.new(
  :farm_id,
  :queue_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#queue_idString

The queue ID for the queue environment list.

Returns:



8132
8133
8134
8135
8136
8137
8138
8139
# File 'lib/aws-sdk-deadline/types.rb', line 8132

class ListQueueEnvironmentsRequest < Struct.new(
  :farm_id,
  :queue_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end