Class: Aws::Deadline::Types::ListQueueFleetAssociationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#farm_idString

The farm ID for the queue-fleet association list.

Returns:

  • (String)


6299
6300
6301
6302
6303
6304
6305
6306
6307
# File 'lib/aws-sdk-deadline/types.rb', line 6299

class ListQueueFleetAssociationsRequest < Struct.new(
  :farm_id,
  :queue_id,
  :fleet_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#fleet_idString

The fleet ID for the queue-fleet association list.

Returns:

  • (String)


6299
6300
6301
6302
6303
6304
6305
6306
6307
# File 'lib/aws-sdk-deadline/types.rb', line 6299

class ListQueueFleetAssociationsRequest < Struct.new(
  :farm_id,
  :queue_id,
  :fleet_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages.

Returns:

  • (Integer)


6299
6300
6301
6302
6303
6304
6305
6306
6307
# File 'lib/aws-sdk-deadline/types.rb', line 6299

class ListQueueFleetAssociationsRequest < Struct.new(
  :farm_id,
  :queue_id,
  :fleet_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results, or null to start from the beginning.

Returns:

  • (String)


6299
6300
6301
6302
6303
6304
6305
6306
6307
# File 'lib/aws-sdk-deadline/types.rb', line 6299

class ListQueueFleetAssociationsRequest < Struct.new(
  :farm_id,
  :queue_id,
  :fleet_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#queue_idString

The queue ID for the queue-fleet association list.

Returns:

  • (String)


6299
6300
6301
6302
6303
6304
6305
6306
6307
# File 'lib/aws-sdk-deadline/types.rb', line 6299

class ListQueueFleetAssociationsRequest < Struct.new(
  :farm_id,
  :queue_id,
  :fleet_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end