Class: Aws::Deadline::Types::ListQueueMembersRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#farm_idString

The farm ID for the queue.



6407
6408
6409
6410
6411
6412
6413
6414
# File 'lib/aws-sdk-deadline/types.rb', line 6407

class ListQueueMembersRequest < Struct.new(
  :farm_id,
  :queue_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages.



6407
6408
6409
6410
6411
6412
6413
6414
# File 'lib/aws-sdk-deadline/types.rb', line 6407

class ListQueueMembersRequest < Struct.new(
  :farm_id,
  :queue_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results, or null to start from the beginning.



6407
6408
6409
6410
6411
6412
6413
6414
# File 'lib/aws-sdk-deadline/types.rb', line 6407

class ListQueueMembersRequest < Struct.new(
  :farm_id,
  :queue_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#queue_idString

The queue ID to include on the list.



6407
6408
6409
6410
6411
6412
6413
6414
# File 'lib/aws-sdk-deadline/types.rb', line 6407

class ListQueueMembersRequest < Struct.new(
  :farm_id,
  :queue_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end