Class: Aws::Deadline::Types::ListSessionActionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::ListSessionActionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Shared pagination fields for List operation inputs (nextToken + maxResults).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#farm_id ⇒ String
The farm ID for the session actions list.
-
#job_id ⇒ String
The job ID for the session actions list.
-
#max_results ⇒ Integer
The maximum number of results to return.
-
#next_token ⇒ String
The token for the next set of results, or
nullto start from the beginning. -
#queue_id ⇒ String
The queue ID for the session actions list.
-
#session_id ⇒ String
The session ID to include on the sessions action list.
-
#task_id ⇒ String
The task ID for the session actions list.
Instance Attribute Details
#farm_id ⇒ String
The farm ID for the session actions list.
8459 8460 8461 8462 8463 8464 8465 8466 8467 8468 8469 |
# File 'lib/aws-sdk-deadline/types.rb', line 8459 class ListSessionActionsRequest < Struct.new( :farm_id, :queue_id, :job_id, :next_token, :max_results, :session_id, :task_id) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The job ID for the session actions list.
8459 8460 8461 8462 8463 8464 8465 8466 8467 8468 8469 |
# File 'lib/aws-sdk-deadline/types.rb', line 8459 class ListSessionActionsRequest < Struct.new( :farm_id, :queue_id, :job_id, :next_token, :max_results, :session_id, :task_id) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return. Use this parameter with
NextToken to get results as a set of sequential pages.
8459 8460 8461 8462 8463 8464 8465 8466 8467 8468 8469 |
# File 'lib/aws-sdk-deadline/types.rb', line 8459 class ListSessionActionsRequest < Struct.new( :farm_id, :queue_id, :job_id, :next_token, :max_results, :session_id, :task_id) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results, or null to start from the
beginning.
8459 8460 8461 8462 8463 8464 8465 8466 8467 8468 8469 |
# File 'lib/aws-sdk-deadline/types.rb', line 8459 class ListSessionActionsRequest < Struct.new( :farm_id, :queue_id, :job_id, :next_token, :max_results, :session_id, :task_id) SENSITIVE = [] include Aws::Structure end |
#queue_id ⇒ String
The queue ID for the session actions list.
8459 8460 8461 8462 8463 8464 8465 8466 8467 8468 8469 |
# File 'lib/aws-sdk-deadline/types.rb', line 8459 class ListSessionActionsRequest < Struct.new( :farm_id, :queue_id, :job_id, :next_token, :max_results, :session_id, :task_id) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The session ID to include on the sessions action list.
8459 8460 8461 8462 8463 8464 8465 8466 8467 8468 8469 |
# File 'lib/aws-sdk-deadline/types.rb', line 8459 class ListSessionActionsRequest < Struct.new( :farm_id, :queue_id, :job_id, :next_token, :max_results, :session_id, :task_id) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
The task ID for the session actions list.
8459 8460 8461 8462 8463 8464 8465 8466 8467 8468 8469 |
# File 'lib/aws-sdk-deadline/types.rb', line 8459 class ListSessionActionsRequest < Struct.new( :farm_id, :queue_id, :job_id, :next_token, :max_results, :session_id, :task_id) SENSITIVE = [] include Aws::Structure end |