Class: Aws::Deadline::Types::ListSessionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Shared pagination fields for List operation inputs (nextToken + maxResults).

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#farm_idString

The farm ID for the list of sessions.

Returns:

  • (String)


8580
8581
8582
8583
8584
8585
8586
8587
8588
# File 'lib/aws-sdk-deadline/types.rb', line 8580

class ListSessionsRequest < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The job ID for the list of sessions.

Returns:

  • (String)


8580
8581
8582
8583
8584
8585
8586
8587
8588
# File 'lib/aws-sdk-deadline/types.rb', line 8580

class ListSessionsRequest < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages.

Returns:

  • (Integer)


8580
8581
8582
8583
8584
8585
8586
8587
8588
# File 'lib/aws-sdk-deadline/types.rb', line 8580

class ListSessionsRequest < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results, or null to start from the beginning.

Returns:

  • (String)


8580
8581
8582
8583
8584
8585
8586
8587
8588
# File 'lib/aws-sdk-deadline/types.rb', line 8580

class ListSessionsRequest < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#queue_idString

The queue ID for the list of sessions

Returns:

  • (String)


8580
8581
8582
8583
8584
8585
8586
8587
8588
# File 'lib/aws-sdk-deadline/types.rb', line 8580

class ListSessionsRequest < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end