Class: Aws::Deadline::Types::ListSessionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::ListSessionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If Deadline Cloud returns
nextToken, then there are more results available. -
#sessions ⇒ Array<Types::SessionSummary>
The sessions on the list.
Instance Attribute Details
#next_token ⇒ String
If Deadline Cloud returns nextToken, then there are more results available. The value of nextToken is a unique pagination token for each page. To retrieve the next page, call the operation again using the returned token. Keep all other arguments unchanged. If no results remain, then nextToken is set to null. Each pagination token expires after 24 hours. If you provide a token that isn’t valid, then you receive an HTTP 400 ValidationException error.
6672 6673 6674 6675 6676 6677 |
# File 'lib/aws-sdk-deadline/types.rb', line 6672 class ListSessionsResponse < Struct.new( :sessions, :next_token) SENSITIVE = [] include Aws::Structure end |
#sessions ⇒ Array<Types::SessionSummary>
The sessions on the list.
6672 6673 6674 6675 6676 6677 |
# File 'lib/aws-sdk-deadline/types.rb', line 6672 class ListSessionsResponse < Struct.new( :sessions, :next_token) SENSITIVE = [] include Aws::Structure end |