Class: Aws::Deadline::Types::ListStepConsumersResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::ListStepConsumersResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#consumers ⇒ Array<Types::StepConsumer>
The consumers on the list.
-
#next_token ⇒ String
If Deadline Cloud returns
nextToken, then there are more results available.
Instance Attribute Details
#consumers ⇒ Array<Types::StepConsumer>
The consumers on the list.
6734 6735 6736 6737 6738 6739 |
# File 'lib/aws-sdk-deadline/types.rb', line 6734 class ListStepConsumersResponse < Struct.new( :consumers, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If Deadline Cloud returns nextToken, then there are more results available. The value of nextToken is a unique pagination token for each page. To retrieve the next page, call the operation again using the returned token. Keep all other arguments unchanged. If no results remain, then nextToken is set to null. Each pagination token expires after 24 hours. If you provide a token that isn’t valid, then you receive an HTTP 400 ValidationException error.
6734 6735 6736 6737 6738 6739 |
# File 'lib/aws-sdk-deadline/types.rb', line 6734 class ListStepConsumersResponse < Struct.new( :consumers, :next_token) SENSITIVE = [] include Aws::Structure end |