Class: Aws::Deadline::Types::ListStepsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

If Deadline Cloud returns nextToken, then there are more results available. The value of nextToken is a unique pagination token for each page. To retrieve the next page, call the operation again using the returned token. Keep all other arguments unchanged. If no results remain, then nextToken is set to null. Each pagination token expires after 24 hours. If you provide a token that isn’t valid, then you receive an HTTP 400 ValidationException error.

Returns:

  • (String)


6853
6854
6855
6856
6857
6858
# File 'lib/aws-sdk-deadline/types.rb', line 6853

class ListStepsResponse < Struct.new(
  :steps,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#stepsArray<Types::StepSummary>

The steps on the list.

Returns:



6853
6854
6855
6856
6857
6858
# File 'lib/aws-sdk-deadline/types.rb', line 6853

class ListStepsResponse < Struct.new(
  :steps,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end