Class: Aws::Deadline::Types::ListTasksResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Shared pagination field for List operation outputs (nextToken).

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

If Deadline Cloud returns nextToken, then there are more results available. The value of nextToken is a unique pagination token for each page. To retrieve the next page, call the operation again using the returned token. Keep all other arguments unchanged. If no results remain, then nextToken is set to null. Each pagination token expires after 24 hours. If you provide a token that isn't valid, then you receive an HTTP 400 ValidationException error.

Returns:

  • (String)


8999
9000
9001
9002
9003
9004
# File 'lib/aws-sdk-deadline/types.rb', line 8999

class ListTasksResponse < Struct.new(
  :tasks,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#tasksArray<Types::TaskSummary>

Tasks for the job.

Returns:



8999
9000
9001
9002
9003
9004
# File 'lib/aws-sdk-deadline/types.rb', line 8999

class ListTasksResponse < Struct.new(
  :tasks,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end