Class: Aws::Deadline::Types::ListVolumesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::ListVolumesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Shared pagination fields for List operation inputs (nextToken + maxResults).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#farm_id ⇒ String
The farm ID of the farm that contains the fleet.
-
#fleet_id ⇒ String
The fleet ID of the fleet that contains the volumes.
-
#max_results ⇒ Integer
The maximum number of results to return.
-
#next_token ⇒ String
The token for the next set of results, or
nullto start from the beginning.
Instance Attribute Details
#farm_id ⇒ String
The farm ID of the farm that contains the fleet.
9029 9030 9031 9032 9033 9034 9035 9036 |
# File 'lib/aws-sdk-deadline/types.rb', line 9029 class ListVolumesRequest < Struct.new( :farm_id, :fleet_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#fleet_id ⇒ String
The fleet ID of the fleet that contains the volumes.
9029 9030 9031 9032 9033 9034 9035 9036 |
# File 'lib/aws-sdk-deadline/types.rb', line 9029 class ListVolumesRequest < Struct.new( :farm_id, :fleet_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return. Use this parameter with
NextToken to get results as a set of sequential pages.
9029 9030 9031 9032 9033 9034 9035 9036 |
# File 'lib/aws-sdk-deadline/types.rb', line 9029 class ListVolumesRequest < Struct.new( :farm_id, :fleet_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results, or null to start from the
beginning.
9029 9030 9031 9032 9033 9034 9035 9036 |
# File 'lib/aws-sdk-deadline/types.rb', line 9029 class ListVolumesRequest < Struct.new( :farm_id, :fleet_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |