Class: Aws::Deadline::Types::ListVolumesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Shared pagination field for List operation outputs (nextToken).

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

If Deadline Cloud returns nextToken, then there are more results available. The value of nextToken is a unique pagination token for each page. To retrieve the next page, call the operation again using the returned token. Keep all other arguments unchanged. If no results remain, then nextToken is set to null. Each pagination token expires after 24 hours. If you provide a token that isn't valid, then you receive an HTTP 400 ValidationException error.

Returns:

  • (String)


9056
9057
9058
9059
9060
9061
# File 'lib/aws-sdk-deadline/types.rb', line 9056

class ListVolumesResponse < Struct.new(
  :volumes,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#volumesArray<Types::VolumeSummary>

The volumes on the list.

Returns:



9056
9057
9058
9059
9060
9061
# File 'lib/aws-sdk-deadline/types.rb', line 9056

class ListVolumesResponse < Struct.new(
  :volumes,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end