Class: Aws::Deadline::Types::MonitorSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Provides information about a monitor in Deadline Cloud.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The UNIX timestamp of the date and time that the monitor was created.



7283
7284
7285
7286
7287
7288
7289
7290
7291
7292
7293
7294
7295
7296
7297
# File 'lib/aws-sdk-deadline/types.rb', line 7283

class MonitorSummary < Struct.new(
  :monitor_id,
  :display_name,
  :subdomain,
  :url,
  :role_arn,
  :identity_center_instance_arn,
  :identity_center_application_arn,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#created_byString

The user name of the person that created the monitor.



7283
7284
7285
7286
7287
7288
7289
7290
7291
7292
7293
7294
7295
7296
7297
# File 'lib/aws-sdk-deadline/types.rb', line 7283

class MonitorSummary < Struct.new(
  :monitor_id,
  :display_name,
  :subdomain,
  :url,
  :role_arn,
  :identity_center_instance_arn,
  :identity_center_application_arn,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The name of the monitor that displays on the Deadline Cloud console.

This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.



7283
7284
7285
7286
7287
7288
7289
7290
7291
7292
7293
7294
7295
7296
7297
# File 'lib/aws-sdk-deadline/types.rb', line 7283

class MonitorSummary < Struct.new(
  :monitor_id,
  :display_name,
  :subdomain,
  :url,
  :role_arn,
  :identity_center_instance_arn,
  :identity_center_application_arn,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#identity_center_application_arnString

The Amazon Resource Name that the IAM Identity Center assigned to the monitor when it was created.



7283
7284
7285
7286
7287
7288
7289
7290
7291
7292
7293
7294
7295
7296
7297
# File 'lib/aws-sdk-deadline/types.rb', line 7283

class MonitorSummary < Struct.new(
  :monitor_id,
  :display_name,
  :subdomain,
  :url,
  :role_arn,
  :identity_center_instance_arn,
  :identity_center_application_arn,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#identity_center_instance_arnString

The Amazon Resource Name of the IAM Identity Center instance responsible for authenticating monitor users.



7283
7284
7285
7286
7287
7288
7289
7290
7291
7292
7293
7294
7295
7296
7297
# File 'lib/aws-sdk-deadline/types.rb', line 7283

class MonitorSummary < Struct.new(
  :monitor_id,
  :display_name,
  :subdomain,
  :url,
  :role_arn,
  :identity_center_instance_arn,
  :identity_center_application_arn,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#monitor_idString

The unique identifier for the monitor.



7283
7284
7285
7286
7287
7288
7289
7290
7291
7292
7293
7294
7295
7296
7297
# File 'lib/aws-sdk-deadline/types.rb', line 7283

class MonitorSummary < Struct.new(
  :monitor_id,
  :display_name,
  :subdomain,
  :url,
  :role_arn,
  :identity_center_instance_arn,
  :identity_center_application_arn,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name of the IAM role for the monitor. Users of the monitor use this role to access Deadline Cloud resources.



7283
7284
7285
7286
7287
7288
7289
7290
7291
7292
7293
7294
7295
7296
7297
# File 'lib/aws-sdk-deadline/types.rb', line 7283

class MonitorSummary < Struct.new(
  :monitor_id,
  :display_name,
  :subdomain,
  :url,
  :role_arn,
  :identity_center_instance_arn,
  :identity_center_application_arn,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#subdomainString

The subdomain used for the monitor URL. The full URL of the monitor is subdomain.Region.deadlinecloud.amazonaws.com.



7283
7284
7285
7286
7287
7288
7289
7290
7291
7292
7293
7294
7295
7296
7297
# File 'lib/aws-sdk-deadline/types.rb', line 7283

class MonitorSummary < Struct.new(
  :monitor_id,
  :display_name,
  :subdomain,
  :url,
  :role_arn,
  :identity_center_instance_arn,
  :identity_center_application_arn,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The UNIX timestamp of the date and time that the monitor was last updated.



7283
7284
7285
7286
7287
7288
7289
7290
7291
7292
7293
7294
7295
7296
7297
# File 'lib/aws-sdk-deadline/types.rb', line 7283

class MonitorSummary < Struct.new(
  :monitor_id,
  :display_name,
  :subdomain,
  :url,
  :role_arn,
  :identity_center_instance_arn,
  :identity_center_application_arn,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#updated_byString

The user name of the person that last updated the monitor.



7283
7284
7285
7286
7287
7288
7289
7290
7291
7292
7293
7294
7295
7296
7297
# File 'lib/aws-sdk-deadline/types.rb', line 7283

class MonitorSummary < Struct.new(
  :monitor_id,
  :display_name,
  :subdomain,
  :url,
  :role_arn,
  :identity_center_instance_arn,
  :identity_center_application_arn,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#urlString

The complete URL of the monitor. The full URL of the monitor is subdomain.Region.deadlinecloud.amazonaws.com.



7283
7284
7285
7286
7287
7288
7289
7290
7291
7292
7293
7294
7295
7296
7297
# File 'lib/aws-sdk-deadline/types.rb', line 7283

class MonitorSummary < Struct.new(
  :monitor_id,
  :display_name,
  :subdomain,
  :url,
  :role_arn,
  :identity_center_instance_arn,
  :identity_center_application_arn,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end