Class: Aws::Deadline::Types::QueueLimitAssociationSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Provides information about the association between a queue and a limit.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The Unix timestamp of the date and time that the association was created.

Returns:

  • (Time)


9355
9356
9357
9358
9359
9360
9361
9362
9363
9364
9365
# File 'lib/aws-sdk-deadline/types.rb', line 9355

class QueueLimitAssociationSummary < Struct.new(
  :queue_id,
  :limit_id,
  :status,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#created_byString

The user identifier of the person that created the association.

Returns:

  • (String)


9355
9356
9357
9358
9359
9360
9361
9362
9363
9364
9365
# File 'lib/aws-sdk-deadline/types.rb', line 9355

class QueueLimitAssociationSummary < Struct.new(
  :queue_id,
  :limit_id,
  :status,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#limit_idString

The unique identifier of the limit in the association.

Returns:

  • (String)


9355
9356
9357
9358
9359
9360
9361
9362
9363
9364
9365
# File 'lib/aws-sdk-deadline/types.rb', line 9355

class QueueLimitAssociationSummary < Struct.new(
  :queue_id,
  :limit_id,
  :status,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#queue_idString

The unique identifier of the queue in the association.

Returns:

  • (String)


9355
9356
9357
9358
9359
9360
9361
9362
9363
9364
9365
# File 'lib/aws-sdk-deadline/types.rb', line 9355

class QueueLimitAssociationSummary < Struct.new(
  :queue_id,
  :limit_id,
  :status,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of task scheduling in the queue-limit association.

  • ‘ACTIVE` - Association is active.

  • ‘STOP_LIMIT_USAGE_AND_COMPLETE_TASKS` - Association has stopped scheduling new tasks and is completing current tasks.

  • ‘STOP_LIMIT_USAGE_AND_CANCEL_TASKS` - Association has stopped scheduling new tasks and is canceling current tasks.

  • ‘STOPPED` - Association has been stopped.

Returns:

  • (String)


9355
9356
9357
9358
9359
9360
9361
9362
9363
9364
9365
# File 'lib/aws-sdk-deadline/types.rb', line 9355

class QueueLimitAssociationSummary < Struct.new(
  :queue_id,
  :limit_id,
  :status,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The Unix timestamp of the date and time that the association was last updated.

Returns:

  • (Time)


9355
9356
9357
9358
9359
9360
9361
9362
9363
9364
9365
# File 'lib/aws-sdk-deadline/types.rb', line 9355

class QueueLimitAssociationSummary < Struct.new(
  :queue_id,
  :limit_id,
  :status,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end

#updated_byString

The user identifier of the person that updated the association.

Returns:

  • (String)


9355
9356
9357
9358
9359
9360
9361
9362
9363
9364
9365
# File 'lib/aws-sdk-deadline/types.rb', line 9355

class QueueLimitAssociationSummary < Struct.new(
  :queue_id,
  :limit_id,
  :status,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by)
  SENSITIVE = []
  include Aws::Structure
end