Class: Aws::Deadline::Types::StartSessionsStatisticsAggregationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::StartSessionsStatisticsAggregationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_time ⇒ Time
The Linux timestamp of the date and time that the statistics end.
-
#farm_id ⇒ String
The identifier of the farm that contains queues or fleets to return statistics for.
-
#group_by ⇒ Array<String>
The field to use to group the statistics.
-
#period ⇒ String
The period to aggregate the statistics.
-
#resource_ids ⇒ Types::SessionsStatisticsResources
A list of fleet IDs or queue IDs to gather statistics for.
-
#start_time ⇒ Time
The Linux timestamp of the date and time that the statistics start.
-
#statistics ⇒ Array<String>
One to four statistics to return.
-
#timezone ⇒ String
The timezone to use for the statistics.
Instance Attribute Details
#end_time ⇒ Time
The Linux timestamp of the date and time that the statistics end.
10504 10505 10506 10507 10508 10509 10510 10511 10512 10513 10514 10515 |
# File 'lib/aws-sdk-deadline/types.rb', line 10504 class StartSessionsStatisticsAggregationRequest < Struct.new( :farm_id, :resource_ids, :start_time, :end_time, :timezone, :period, :group_by, :statistics) SENSITIVE = [] include Aws::Structure end |
#farm_id ⇒ String
The identifier of the farm that contains queues or fleets to return statistics for.
10504 10505 10506 10507 10508 10509 10510 10511 10512 10513 10514 10515 |
# File 'lib/aws-sdk-deadline/types.rb', line 10504 class StartSessionsStatisticsAggregationRequest < Struct.new( :farm_id, :resource_ids, :start_time, :end_time, :timezone, :period, :group_by, :statistics) SENSITIVE = [] include Aws::Structure end |
#group_by ⇒ Array<String>
The field to use to group the statistics.
10504 10505 10506 10507 10508 10509 10510 10511 10512 10513 10514 10515 |
# File 'lib/aws-sdk-deadline/types.rb', line 10504 class StartSessionsStatisticsAggregationRequest < Struct.new( :farm_id, :resource_ids, :start_time, :end_time, :timezone, :period, :group_by, :statistics) SENSITIVE = [] include Aws::Structure end |
#period ⇒ String
The period to aggregate the statistics.
10504 10505 10506 10507 10508 10509 10510 10511 10512 10513 10514 10515 |
# File 'lib/aws-sdk-deadline/types.rb', line 10504 class StartSessionsStatisticsAggregationRequest < Struct.new( :farm_id, :resource_ids, :start_time, :end_time, :timezone, :period, :group_by, :statistics) SENSITIVE = [] include Aws::Structure end |
#resource_ids ⇒ Types::SessionsStatisticsResources
A list of fleet IDs or queue IDs to gather statistics for.
10504 10505 10506 10507 10508 10509 10510 10511 10512 10513 10514 10515 |
# File 'lib/aws-sdk-deadline/types.rb', line 10504 class StartSessionsStatisticsAggregationRequest < Struct.new( :farm_id, :resource_ids, :start_time, :end_time, :timezone, :period, :group_by, :statistics) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The Linux timestamp of the date and time that the statistics start.
10504 10505 10506 10507 10508 10509 10510 10511 10512 10513 10514 10515 |
# File 'lib/aws-sdk-deadline/types.rb', line 10504 class StartSessionsStatisticsAggregationRequest < Struct.new( :farm_id, :resource_ids, :start_time, :end_time, :timezone, :period, :group_by, :statistics) SENSITIVE = [] include Aws::Structure end |
#statistics ⇒ Array<String>
One to four statistics to return.
10504 10505 10506 10507 10508 10509 10510 10511 10512 10513 10514 10515 |
# File 'lib/aws-sdk-deadline/types.rb', line 10504 class StartSessionsStatisticsAggregationRequest < Struct.new( :farm_id, :resource_ids, :start_time, :end_time, :timezone, :period, :group_by, :statistics) SENSITIVE = [] include Aws::Structure end |
#timezone ⇒ String
The timezone to use for the statistics. Use UTC notation such as “UTC+8.”
10504 10505 10506 10507 10508 10509 10510 10511 10512 10513 10514 10515 |
# File 'lib/aws-sdk-deadline/types.rb', line 10504 class StartSessionsStatisticsAggregationRequest < Struct.new( :farm_id, :resource_ids, :start_time, :end_time, :timezone, :period, :group_by, :statistics) SENSITIVE = [] include Aws::Structure end |