Class: Aws::Deadline::Types::StepSearchSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::StepSearchSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
The details of a step search.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The date and time the resource was created.
-
#created_by ⇒ String
The user or system that created this resource.
-
#ended_at ⇒ Time
The date and time the resource ended running.
-
#job_id ⇒ String
The job ID.
-
#lifecycle_status ⇒ String
The life cycle status.
-
#lifecycle_status_message ⇒ String
The life cycle status message.
-
#name ⇒ String
The step name.
-
#parameter_space ⇒ Types::ParameterSpace
The parameters and combination expressions for the search.
-
#queue_id ⇒ String
The queue ID.
-
#started_at ⇒ Time
The date and time the resource started running.
-
#step_id ⇒ String
The step ID.
-
#target_task_run_status ⇒ String
The task status to update the job’s tasks to.
-
#task_failure_retry_count ⇒ Integer
The total number of times tasks from the step failed and were retried.
-
#task_run_status ⇒ String
The task run status for the job.
-
#task_run_status_counts ⇒ Hash<String,Integer>
The number of tasks running on the job.
-
#updated_at ⇒ Time
The date and time the resource was updated.
-
#updated_by ⇒ String
The user or system that updated this resource.
Instance Attribute Details
#created_at ⇒ Time
The date and time the resource was created.
11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 |
# File 'lib/aws-sdk-deadline/types.rb', line 11231 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The user or system that created this resource.
11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 |
# File 'lib/aws-sdk-deadline/types.rb', line 11231 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#ended_at ⇒ Time
The date and time the resource ended running.
11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 |
# File 'lib/aws-sdk-deadline/types.rb', line 11231 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The job ID.
11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 |
# File 'lib/aws-sdk-deadline/types.rb', line 11231 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#lifecycle_status ⇒ String
The life cycle status.
11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 |
# File 'lib/aws-sdk-deadline/types.rb', line 11231 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#lifecycle_status_message ⇒ String
The life cycle status message.
11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 |
# File 'lib/aws-sdk-deadline/types.rb', line 11231 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The step name.
11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 |
# File 'lib/aws-sdk-deadline/types.rb', line 11231 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#parameter_space ⇒ Types::ParameterSpace
The parameters and combination expressions for the search.
11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 |
# File 'lib/aws-sdk-deadline/types.rb', line 11231 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#queue_id ⇒ String
The queue ID.
11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 |
# File 'lib/aws-sdk-deadline/types.rb', line 11231 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The date and time the resource started running.
11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 |
# File 'lib/aws-sdk-deadline/types.rb', line 11231 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#step_id ⇒ String
The step ID.
11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 |
# File 'lib/aws-sdk-deadline/types.rb', line 11231 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#target_task_run_status ⇒ String
The task status to update the job’s tasks to.
11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 |
# File 'lib/aws-sdk-deadline/types.rb', line 11231 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#task_failure_retry_count ⇒ Integer
The total number of times tasks from the step failed and were retried.
11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 |
# File 'lib/aws-sdk-deadline/types.rb', line 11231 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#task_run_status ⇒ String
The task run status for the job.
-
‘PENDING`–pending and waiting for resources.
-
‘READY`–ready to be processed.
-
‘ASSIGNED`–assigned and will run next on a worker.
-
‘SCHEDULED`–scheduled to be run on a worker.
-
‘INTERRUPTING`–being interrupted.
-
‘RUNNING`–running on a worker.
-
‘SUSPENDED`–the task is suspended.
-
‘CANCELED`–the task has been canceled.
-
‘FAILED`–the task has failed.
-
‘SUCCEEDED`–the task has succeeded.
11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 |
# File 'lib/aws-sdk-deadline/types.rb', line 11231 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#task_run_status_counts ⇒ Hash<String,Integer>
The number of tasks running on the job.
11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 |
# File 'lib/aws-sdk-deadline/types.rb', line 11231 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the resource was updated.
11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 |
# File 'lib/aws-sdk-deadline/types.rb', line 11231 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#updated_by ⇒ String
The user or system that updated this resource.
11231 11232 11233 11234 11235 11236 11237 11238 11239 11240 11241 11242 11243 11244 11245 11246 11247 11248 11249 11250 11251 |
# File 'lib/aws-sdk-deadline/types.rb', line 11231 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |