Class: Aws::Deadline::Types::StepSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::StepSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
The details for a step.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The date and time the resource was created.
-
#created_by ⇒ String
The user or system that created this resource.
-
#dependency_counts ⇒ Types::DependencyCounts
The number of dependencies for the step.
-
#ended_at ⇒ Time
The date and time the resource ended running.
-
#lifecycle_status ⇒ String
The life cycle status.
-
#lifecycle_status_message ⇒ String
A message that describes the lifecycle of the step.
-
#name ⇒ String
The name of the step.
-
#started_at ⇒ Time
The date and time the resource started running.
-
#step_id ⇒ String
The step ID.
-
#target_task_run_status ⇒ String
The task status to update the job’s tasks to.
-
#task_failure_retry_count ⇒ Integer
The total number of times tasks from the step failed and were retried.
-
#task_run_status ⇒ String
The task run status for the job.
-
#task_run_status_counts ⇒ Hash<String,Integer>
The number of tasks running on the job.
-
#updated_at ⇒ Time
The date and time the resource was updated.
-
#updated_by ⇒ String
The user or system that updated this resource.
Instance Attribute Details
#created_at ⇒ Time
The date and time the resource was created.
9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 |
# File 'lib/aws-sdk-deadline/types.rb', line 9092 class StepSummary < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The user or system that created this resource.
9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 |
# File 'lib/aws-sdk-deadline/types.rb', line 9092 class StepSummary < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts) SENSITIVE = [] include Aws::Structure end |
#dependency_counts ⇒ Types::DependencyCounts
The number of dependencies for the step.
9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 |
# File 'lib/aws-sdk-deadline/types.rb', line 9092 class StepSummary < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts) SENSITIVE = [] include Aws::Structure end |
#ended_at ⇒ Time
The date and time the resource ended running.
9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 |
# File 'lib/aws-sdk-deadline/types.rb', line 9092 class StepSummary < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts) SENSITIVE = [] include Aws::Structure end |
#lifecycle_status ⇒ String
The life cycle status.
9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 |
# File 'lib/aws-sdk-deadline/types.rb', line 9092 class StepSummary < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts) SENSITIVE = [] include Aws::Structure end |
#lifecycle_status_message ⇒ String
A message that describes the lifecycle of the step.
9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 |
# File 'lib/aws-sdk-deadline/types.rb', line 9092 class StepSummary < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the step.
9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 |
# File 'lib/aws-sdk-deadline/types.rb', line 9092 class StepSummary < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The date and time the resource started running.
9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 |
# File 'lib/aws-sdk-deadline/types.rb', line 9092 class StepSummary < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts) SENSITIVE = [] include Aws::Structure end |
#step_id ⇒ String
The step ID.
9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 |
# File 'lib/aws-sdk-deadline/types.rb', line 9092 class StepSummary < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts) SENSITIVE = [] include Aws::Structure end |
#target_task_run_status ⇒ String
The task status to update the job’s tasks to.
9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 |
# File 'lib/aws-sdk-deadline/types.rb', line 9092 class StepSummary < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts) SENSITIVE = [] include Aws::Structure end |
#task_failure_retry_count ⇒ Integer
The total number of times tasks from the step failed and were retried.
9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 |
# File 'lib/aws-sdk-deadline/types.rb', line 9092 class StepSummary < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts) SENSITIVE = [] include Aws::Structure end |
#task_run_status ⇒ String
The task run status for the job.
-
PENDING–pending and waiting for resources. -
READY–ready to process. -
ASSIGNED–assigned and will run next on a worker. -
SCHEDULED–scheduled to run on a worker. -
INTERRUPTING–being interrupted. -
RUNNING–running on a worker. -
SUSPENDED–the task is suspended. -
CANCELED–the task has been canceled. -
FAILED–the task has failed. -
SUCCEEDED–the task has succeeded.
9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 |
# File 'lib/aws-sdk-deadline/types.rb', line 9092 class StepSummary < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts) SENSITIVE = [] include Aws::Structure end |
#task_run_status_counts ⇒ Hash<String,Integer>
The number of tasks running on the job.
9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 |
# File 'lib/aws-sdk-deadline/types.rb', line 9092 class StepSummary < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the resource was updated.
9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 |
# File 'lib/aws-sdk-deadline/types.rb', line 9092 class StepSummary < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts) SENSITIVE = [] include Aws::Structure end |
#updated_by ⇒ String
The user or system that updated this resource.
9092 9093 9094 9095 9096 9097 9098 9099 9100 9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 |
# File 'lib/aws-sdk-deadline/types.rb', line 9092 class StepSummary < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts) SENSITIVE = [] include Aws::Structure end |