Class: Aws::Deadline::Types::SyncInputJobAttachmentsSessionActionDefinition

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

The session action definition for syncing input job attachments.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#step_idString

The step ID for the sync input job attachments session action.



9186
9187
9188
9189
9190
# File 'lib/aws-sdk-deadline/types.rb', line 9186

class SyncInputJobAttachmentsSessionActionDefinition < Struct.new(
  :step_id)
  SENSITIVE = []
  include Aws::Structure
end