Class: Aws::Deadline::Types::ThrottlingException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::ThrottlingException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Your request exceeded a request rate quota.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#context ⇒ Hash<String,String>
Information about the resources in use when the exception was thrown.
- #message ⇒ String
-
#quota_code ⇒ String
Identifies the quota that is being throttled.
-
#retry_after_seconds ⇒ Integer
The number of seconds a client should wait before retrying the request.
-
#service_code ⇒ String
Identifies the service that is being throttled.
Instance Attribute Details
#context ⇒ Hash<String,String>
Information about the resources in use when the exception was thrown.
11527 11528 11529 11530 11531 11532 11533 11534 11535 |
# File 'lib/aws-sdk-deadline/types.rb', line 11527 class ThrottlingException < Struct.new( :message, :service_code, :quota_code, :retry_after_seconds, :context) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
11527 11528 11529 11530 11531 11532 11533 11534 11535 |
# File 'lib/aws-sdk-deadline/types.rb', line 11527 class ThrottlingException < Struct.new( :message, :service_code, :quota_code, :retry_after_seconds, :context) SENSITIVE = [] include Aws::Structure end |
#quota_code ⇒ String
Identifies the quota that is being throttled.
11527 11528 11529 11530 11531 11532 11533 11534 11535 |
# File 'lib/aws-sdk-deadline/types.rb', line 11527 class ThrottlingException < Struct.new( :message, :service_code, :quota_code, :retry_after_seconds, :context) SENSITIVE = [] include Aws::Structure end |
#retry_after_seconds ⇒ Integer
The number of seconds a client should wait before retrying the request.
11527 11528 11529 11530 11531 11532 11533 11534 11535 |
# File 'lib/aws-sdk-deadline/types.rb', line 11527 class ThrottlingException < Struct.new( :message, :service_code, :quota_code, :retry_after_seconds, :context) SENSITIVE = [] include Aws::Structure end |
#service_code ⇒ String
Identifies the service that is being throttled.
11527 11528 11529 11530 11531 11532 11533 11534 11535 |
# File 'lib/aws-sdk-deadline/types.rb', line 11527 class ThrottlingException < Struct.new( :message, :service_code, :quota_code, :retry_after_seconds, :context) SENSITIVE = [] include Aws::Structure end |