Class: Aws::Deadline::Types::UpdateFarmRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#cost_scale_factorFloat

The cost scale factor of the farm to update.



9679
9680
9681
9682
9683
9684
9685
9686
# File 'lib/aws-sdk-deadline/types.rb', line 9679

class UpdateFarmRequest < Struct.new(
  :farm_id,
  :display_name,
  :description,
  :cost_scale_factor)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

The description of the farm to update.

This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.



9679
9680
9681
9682
9683
9684
9685
9686
# File 'lib/aws-sdk-deadline/types.rb', line 9679

class UpdateFarmRequest < Struct.new(
  :farm_id,
  :display_name,
  :description,
  :cost_scale_factor)
  SENSITIVE = [:description]
  include Aws::Structure
end

#display_nameString

The display name of the farm to update.

This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.



9679
9680
9681
9682
9683
9684
9685
9686
# File 'lib/aws-sdk-deadline/types.rb', line 9679

class UpdateFarmRequest < Struct.new(
  :farm_id,
  :display_name,
  :description,
  :cost_scale_factor)
  SENSITIVE = [:description]
  include Aws::Structure
end

#farm_idString

The farm ID to update.



9679
9680
9681
9682
9683
9684
9685
9686
# File 'lib/aws-sdk-deadline/types.rb', line 9679

class UpdateFarmRequest < Struct.new(
  :farm_id,
  :display_name,
  :description,
  :cost_scale_factor)
  SENSITIVE = [:description]
  include Aws::Structure
end