Class: Aws::Deadline::Types::UpdateFleetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

The unique token which the server uses to recognize retries of the same request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


9757
9758
9759
9760
9761
9762
9763
9764
9765
9766
9767
9768
9769
9770
# File 'lib/aws-sdk-deadline/types.rb', line 9757

class UpdateFleetRequest < Struct.new(
  :client_token,
  :farm_id,
  :fleet_id,
  :display_name,
  :description,
  :role_arn,
  :min_worker_count,
  :max_worker_count,
  :configuration,
  :host_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#configurationTypes::FleetConfiguration

The fleet configuration to update.



9757
9758
9759
9760
9761
9762
9763
9764
9765
9766
9767
9768
9769
9770
# File 'lib/aws-sdk-deadline/types.rb', line 9757

class UpdateFleetRequest < Struct.new(
  :client_token,
  :farm_id,
  :fleet_id,
  :display_name,
  :description,
  :role_arn,
  :min_worker_count,
  :max_worker_count,
  :configuration,
  :host_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

The description of the fleet to update.

This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.

Returns:

  • (String)


9757
9758
9759
9760
9761
9762
9763
9764
9765
9766
9767
9768
9769
9770
# File 'lib/aws-sdk-deadline/types.rb', line 9757

class UpdateFleetRequest < Struct.new(
  :client_token,
  :farm_id,
  :fleet_id,
  :display_name,
  :description,
  :role_arn,
  :min_worker_count,
  :max_worker_count,
  :configuration,
  :host_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#display_nameString

The display name of the fleet to update.

This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.

Returns:

  • (String)


9757
9758
9759
9760
9761
9762
9763
9764
9765
9766
9767
9768
9769
9770
# File 'lib/aws-sdk-deadline/types.rb', line 9757

class UpdateFleetRequest < Struct.new(
  :client_token,
  :farm_id,
  :fleet_id,
  :display_name,
  :description,
  :role_arn,
  :min_worker_count,
  :max_worker_count,
  :configuration,
  :host_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#farm_idString

The farm ID to update.

Returns:

  • (String)


9757
9758
9759
9760
9761
9762
9763
9764
9765
9766
9767
9768
9769
9770
# File 'lib/aws-sdk-deadline/types.rb', line 9757

class UpdateFleetRequest < Struct.new(
  :client_token,
  :farm_id,
  :fleet_id,
  :display_name,
  :description,
  :role_arn,
  :min_worker_count,
  :max_worker_count,
  :configuration,
  :host_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#fleet_idString

The fleet ID to update.

Returns:

  • (String)


9757
9758
9759
9760
9761
9762
9763
9764
9765
9766
9767
9768
9769
9770
# File 'lib/aws-sdk-deadline/types.rb', line 9757

class UpdateFleetRequest < Struct.new(
  :client_token,
  :farm_id,
  :fleet_id,
  :display_name,
  :description,
  :role_arn,
  :min_worker_count,
  :max_worker_count,
  :configuration,
  :host_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#host_configurationTypes::HostConfiguration

Provides a script that runs as a worker is starting up that you can use to provide additional configuration for workers in your fleet.



9757
9758
9759
9760
9761
9762
9763
9764
9765
9766
9767
9768
9769
9770
# File 'lib/aws-sdk-deadline/types.rb', line 9757

class UpdateFleetRequest < Struct.new(
  :client_token,
  :farm_id,
  :fleet_id,
  :display_name,
  :description,
  :role_arn,
  :min_worker_count,
  :max_worker_count,
  :configuration,
  :host_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#max_worker_countInteger

The maximum number of workers in the fleet.

Deadline Cloud limits the number of workers to less than or equal to the fleet’s maximum worker count. The service maintains eventual consistency for the worker count. If you make multiple rapid calls to CreateWorker before the field updates, you might exceed your fleet’s maximum worker count. For example, if your maxWorkerCount is 10 and you currently have 9 workers, making two quick CreateWorker calls might successfully create 2 workers instead of 1, resulting in 11 total workers.

Returns:

  • (Integer)


9757
9758
9759
9760
9761
9762
9763
9764
9765
9766
9767
9768
9769
9770
# File 'lib/aws-sdk-deadline/types.rb', line 9757

class UpdateFleetRequest < Struct.new(
  :client_token,
  :farm_id,
  :fleet_id,
  :display_name,
  :description,
  :role_arn,
  :min_worker_count,
  :max_worker_count,
  :configuration,
  :host_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#min_worker_countInteger

The minimum number of workers in the fleet.

Returns:

  • (Integer)


9757
9758
9759
9760
9761
9762
9763
9764
9765
9766
9767
9768
9769
9770
# File 'lib/aws-sdk-deadline/types.rb', line 9757

class UpdateFleetRequest < Struct.new(
  :client_token,
  :farm_id,
  :fleet_id,
  :display_name,
  :description,
  :role_arn,
  :min_worker_count,
  :max_worker_count,
  :configuration,
  :host_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#role_arnString

The IAM role ARN that the fleet’s workers assume while running jobs.

Returns:

  • (String)


9757
9758
9759
9760
9761
9762
9763
9764
9765
9766
9767
9768
9769
9770
# File 'lib/aws-sdk-deadline/types.rb', line 9757

class UpdateFleetRequest < Struct.new(
  :client_token,
  :farm_id,
  :fleet_id,
  :display_name,
  :description,
  :role_arn,
  :min_worker_count,
  :max_worker_count,
  :configuration,
  :host_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end