Class: Aws::Deadline::Types::UpdateJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

The unique token which the server uses to recognize retries of the same request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:



9845
9846
9847
9848
9849
9850
9851
9852
9853
9854
9855
9856
9857
9858
9859
9860
# File 'lib/aws-sdk-deadline/types.rb', line 9845

class UpdateJobRequest < Struct.new(
  :client_token,
  :target_task_run_status,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :lifecycle_status,
  :max_worker_count,
  :name,
  :description,
  :farm_id,
  :queue_id,
  :job_id)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

The updated job description.

Returns:



9845
9846
9847
9848
9849
9850
9851
9852
9853
9854
9855
9856
9857
9858
9859
9860
# File 'lib/aws-sdk-deadline/types.rb', line 9845

class UpdateJobRequest < Struct.new(
  :client_token,
  :target_task_run_status,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :lifecycle_status,
  :max_worker_count,
  :name,
  :description,
  :farm_id,
  :queue_id,
  :job_id)
  SENSITIVE = [:description]
  include Aws::Structure
end

#farm_idString

The farm ID of the job to update.

Returns:



9845
9846
9847
9848
9849
9850
9851
9852
9853
9854
9855
9856
9857
9858
9859
9860
# File 'lib/aws-sdk-deadline/types.rb', line 9845

class UpdateJobRequest < Struct.new(
  :client_token,
  :target_task_run_status,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :lifecycle_status,
  :max_worker_count,
  :name,
  :description,
  :farm_id,
  :queue_id,
  :job_id)
  SENSITIVE = [:description]
  include Aws::Structure
end

#job_idString

The job ID to update.

Returns:



9845
9846
9847
9848
9849
9850
9851
9852
9853
9854
9855
9856
9857
9858
9859
9860
# File 'lib/aws-sdk-deadline/types.rb', line 9845

class UpdateJobRequest < Struct.new(
  :client_token,
  :target_task_run_status,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :lifecycle_status,
  :max_worker_count,
  :name,
  :description,
  :farm_id,
  :queue_id,
  :job_id)
  SENSITIVE = [:description]
  include Aws::Structure
end

#lifecycle_statusString

The status of a job in its lifecycle. When you change the status of the job to ARCHIVED, the job can’t be scheduled or archived.

An archived jobs and its steps and tasks are deleted after 120 days. The job can’t be recovered.

Returns:



9845
9846
9847
9848
9849
9850
9851
9852
9853
9854
9855
9856
9857
9858
9859
9860
# File 'lib/aws-sdk-deadline/types.rb', line 9845

class UpdateJobRequest < Struct.new(
  :client_token,
  :target_task_run_status,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :lifecycle_status,
  :max_worker_count,
  :name,
  :description,
  :farm_id,
  :queue_id,
  :job_id)
  SENSITIVE = [:description]
  include Aws::Structure
end

#max_failed_tasks_countInteger

The number of task failures before the job stops running and is marked as FAILED.

Returns:



9845
9846
9847
9848
9849
9850
9851
9852
9853
9854
9855
9856
9857
9858
9859
9860
# File 'lib/aws-sdk-deadline/types.rb', line 9845

class UpdateJobRequest < Struct.new(
  :client_token,
  :target_task_run_status,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :lifecycle_status,
  :max_worker_count,
  :name,
  :description,
  :farm_id,
  :queue_id,
  :job_id)
  SENSITIVE = [:description]
  include Aws::Structure
end

#max_retries_per_taskInteger

The maximum number of retries for a job.

Returns:



9845
9846
9847
9848
9849
9850
9851
9852
9853
9854
9855
9856
9857
9858
9859
9860
# File 'lib/aws-sdk-deadline/types.rb', line 9845

class UpdateJobRequest < Struct.new(
  :client_token,
  :target_task_run_status,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :lifecycle_status,
  :max_worker_count,
  :name,
  :description,
  :farm_id,
  :queue_id,
  :job_id)
  SENSITIVE = [:description]
  include Aws::Structure
end

#max_worker_countInteger

The maximum number of worker hosts that can concurrently process a job. When the maxWorkerCount is reached, no more workers will be assigned to process the job, even if the fleets assigned to the job’s queue has available workers.

You can’t set the maxWorkerCount to 0. If you set it to -1, there is no maximum number of workers.

If you don’t specify the maxWorkerCount, the default is -1.

The maximum number of workers that can process tasks in the job.

Returns:



9845
9846
9847
9848
9849
9850
9851
9852
9853
9854
9855
9856
9857
9858
9859
9860
# File 'lib/aws-sdk-deadline/types.rb', line 9845

class UpdateJobRequest < Struct.new(
  :client_token,
  :target_task_run_status,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :lifecycle_status,
  :max_worker_count,
  :name,
  :description,
  :farm_id,
  :queue_id,
  :job_id)
  SENSITIVE = [:description]
  include Aws::Structure
end

#nameString

The updated job name.

Returns:



9845
9846
9847
9848
9849
9850
9851
9852
9853
9854
9855
9856
9857
9858
9859
9860
# File 'lib/aws-sdk-deadline/types.rb', line 9845

class UpdateJobRequest < Struct.new(
  :client_token,
  :target_task_run_status,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :lifecycle_status,
  :max_worker_count,
  :name,
  :description,
  :farm_id,
  :queue_id,
  :job_id)
  SENSITIVE = [:description]
  include Aws::Structure
end

#priorityInteger

The updated job priority.

Returns:



9845
9846
9847
9848
9849
9850
9851
9852
9853
9854
9855
9856
9857
9858
9859
9860
# File 'lib/aws-sdk-deadline/types.rb', line 9845

class UpdateJobRequest < Struct.new(
  :client_token,
  :target_task_run_status,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :lifecycle_status,
  :max_worker_count,
  :name,
  :description,
  :farm_id,
  :queue_id,
  :job_id)
  SENSITIVE = [:description]
  include Aws::Structure
end

#queue_idString

The queue ID of the job to update.

Returns:



9845
9846
9847
9848
9849
9850
9851
9852
9853
9854
9855
9856
9857
9858
9859
9860
# File 'lib/aws-sdk-deadline/types.rb', line 9845

class UpdateJobRequest < Struct.new(
  :client_token,
  :target_task_run_status,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :lifecycle_status,
  :max_worker_count,
  :name,
  :description,
  :farm_id,
  :queue_id,
  :job_id)
  SENSITIVE = [:description]
  include Aws::Structure
end

#target_task_run_statusString

The task status to update the job’s tasks to.

Returns:



9845
9846
9847
9848
9849
9850
9851
9852
9853
9854
9855
9856
9857
9858
9859
9860
# File 'lib/aws-sdk-deadline/types.rb', line 9845

class UpdateJobRequest < Struct.new(
  :client_token,
  :target_task_run_status,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :lifecycle_status,
  :max_worker_count,
  :name,
  :description,
  :farm_id,
  :queue_id,
  :job_id)
  SENSITIVE = [:description]
  include Aws::Structure
end