Class: Aws::Deadline::Types::UpdateMonitorRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#display_nameString

The new value to use for the monitor’s display name.

This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.

Returns:

  • (String)


11930
11931
11932
11933
11934
11935
11936
11937
# File 'lib/aws-sdk-deadline/types.rb', line 11930

class UpdateMonitorRequest < Struct.new(
  :monitor_id,
  :subdomain,
  :display_name,
  :role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#monitor_idString

The unique identifier of the monitor to update.

Returns:

  • (String)


11930
11931
11932
11933
11934
11935
11936
11937
# File 'lib/aws-sdk-deadline/types.rb', line 11930

class UpdateMonitorRequest < Struct.new(
  :monitor_id,
  :subdomain,
  :display_name,
  :role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name of the new IAM role to use with the monitor.

Returns:

  • (String)


11930
11931
11932
11933
11934
11935
11936
11937
# File 'lib/aws-sdk-deadline/types.rb', line 11930

class UpdateMonitorRequest < Struct.new(
  :monitor_id,
  :subdomain,
  :display_name,
  :role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#subdomainString

The new value of the subdomain to use when forming the monitor URL.

Returns:

  • (String)


11930
11931
11932
11933
11934
11935
11936
11937
# File 'lib/aws-sdk-deadline/types.rb', line 11930

class UpdateMonitorRequest < Struct.new(
  :monitor_id,
  :subdomain,
  :display_name,
  :role_arn)
  SENSITIVE = []
  include Aws::Structure
end