Class: Aws::Deadline::Types::UpdateMonitorSettingsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::UpdateMonitorSettingsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#monitor_id ⇒ String
The unique identifier of the monitor to update settings for.
-
#settings ⇒ Hash<String,String>
Monitor settings as key-value pairs.
Instance Attribute Details
#monitor_id ⇒ String
The unique identifier of the monitor to update settings for.
11955 11956 11957 11958 11959 11960 |
# File 'lib/aws-sdk-deadline/types.rb', line 11955 class UpdateMonitorSettingsRequest < Struct.new( :monitor_id, :settings) SENSITIVE = [] include Aws::Structure end |
#settings ⇒ Hash<String,String>
Monitor settings as key-value pairs. Keys present in the request are upserted; keys absent are left unchanged. Send an empty string value to delete a key.
11955 11956 11957 11958 11959 11960 |
# File 'lib/aws-sdk-deadline/types.rb', line 11955 class UpdateMonitorSettingsRequest < Struct.new( :monitor_id, :settings) SENSITIVE = [] include Aws::Structure end |