Class: Aws::Deadline::Types::UpdateQueueRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::UpdateQueueRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#allowed_storage_profile_ids_to_add ⇒ Array<String>
The storage profile IDs to add.
-
#allowed_storage_profile_ids_to_remove ⇒ Array<String>
The storage profile ID to remove.
-
#client_token ⇒ String
The idempotency token to update in the queue.
-
#default_budget_action ⇒ String
The default action to take for a queue update if a budget isn’t configured.
-
#description ⇒ String
The description of the queue to update.
-
#display_name ⇒ String
The display name of the queue to update.
-
#farm_id ⇒ String
The farm ID to update in the queue.
-
#job_attachment_settings ⇒ Types::JobAttachmentSettings
The job attachment settings to update for the queue.
-
#job_run_as_user ⇒ Types::JobRunAsUser
Update the jobs in the queue to run as a specified POSIX user.
-
#queue_id ⇒ String
The queue ID to update.
-
#required_file_system_location_names_to_add ⇒ Array<String>
The required file system location names to add to the queue.
-
#required_file_system_location_names_to_remove ⇒ Array<String>
The required file system location names to remove from the queue.
-
#role_arn ⇒ String
The IAM role ARN that’s used to run jobs from this queue.
-
#scheduling_configuration ⇒ Types::SchedulingConfiguration
The scheduling configuration for the queue.
Instance Attribute Details
#allowed_storage_profile_ids_to_add ⇒ Array<String>
The storage profile IDs to add.
12399 12400 12401 12402 12403 12404 12405 12406 12407 12408 12409 12410 12411 12412 12413 12414 12415 12416 |
# File 'lib/aws-sdk-deadline/types.rb', line 12399 class UpdateQueueRequest < Struct.new( :farm_id, :queue_id, :client_token, :display_name, :description, :default_budget_action, :job_attachment_settings, :role_arn, :job_run_as_user, :required_file_system_location_names_to_add, :required_file_system_location_names_to_remove, :allowed_storage_profile_ids_to_add, :allowed_storage_profile_ids_to_remove, :scheduling_configuration) SENSITIVE = [:description] include Aws::Structure end |
#allowed_storage_profile_ids_to_remove ⇒ Array<String>
The storage profile ID to remove.
12399 12400 12401 12402 12403 12404 12405 12406 12407 12408 12409 12410 12411 12412 12413 12414 12415 12416 |
# File 'lib/aws-sdk-deadline/types.rb', line 12399 class UpdateQueueRequest < Struct.new( :farm_id, :queue_id, :client_token, :display_name, :description, :default_budget_action, :job_attachment_settings, :role_arn, :job_run_as_user, :required_file_system_location_names_to_add, :required_file_system_location_names_to_remove, :allowed_storage_profile_ids_to_add, :allowed_storage_profile_ids_to_remove, :scheduling_configuration) SENSITIVE = [:description] include Aws::Structure end |
#client_token ⇒ String
The idempotency token to update in the queue.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
12399 12400 12401 12402 12403 12404 12405 12406 12407 12408 12409 12410 12411 12412 12413 12414 12415 12416 |
# File 'lib/aws-sdk-deadline/types.rb', line 12399 class UpdateQueueRequest < Struct.new( :farm_id, :queue_id, :client_token, :display_name, :description, :default_budget_action, :job_attachment_settings, :role_arn, :job_run_as_user, :required_file_system_location_names_to_add, :required_file_system_location_names_to_remove, :allowed_storage_profile_ids_to_add, :allowed_storage_profile_ids_to_remove, :scheduling_configuration) SENSITIVE = [:description] include Aws::Structure end |
#default_budget_action ⇒ String
The default action to take for a queue update if a budget isn’t configured.
12399 12400 12401 12402 12403 12404 12405 12406 12407 12408 12409 12410 12411 12412 12413 12414 12415 12416 |
# File 'lib/aws-sdk-deadline/types.rb', line 12399 class UpdateQueueRequest < Struct.new( :farm_id, :queue_id, :client_token, :display_name, :description, :default_budget_action, :job_attachment_settings, :role_arn, :job_run_as_user, :required_file_system_location_names_to_add, :required_file_system_location_names_to_remove, :allowed_storage_profile_ids_to_add, :allowed_storage_profile_ids_to_remove, :scheduling_configuration) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
The description of the queue to update.
This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.
12399 12400 12401 12402 12403 12404 12405 12406 12407 12408 12409 12410 12411 12412 12413 12414 12415 12416 |
# File 'lib/aws-sdk-deadline/types.rb', line 12399 class UpdateQueueRequest < Struct.new( :farm_id, :queue_id, :client_token, :display_name, :description, :default_budget_action, :job_attachment_settings, :role_arn, :job_run_as_user, :required_file_system_location_names_to_add, :required_file_system_location_names_to_remove, :allowed_storage_profile_ids_to_add, :allowed_storage_profile_ids_to_remove, :scheduling_configuration) SENSITIVE = [:description] include Aws::Structure end |
#display_name ⇒ String
The display name of the queue to update.
This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.
12399 12400 12401 12402 12403 12404 12405 12406 12407 12408 12409 12410 12411 12412 12413 12414 12415 12416 |
# File 'lib/aws-sdk-deadline/types.rb', line 12399 class UpdateQueueRequest < Struct.new( :farm_id, :queue_id, :client_token, :display_name, :description, :default_budget_action, :job_attachment_settings, :role_arn, :job_run_as_user, :required_file_system_location_names_to_add, :required_file_system_location_names_to_remove, :allowed_storage_profile_ids_to_add, :allowed_storage_profile_ids_to_remove, :scheduling_configuration) SENSITIVE = [:description] include Aws::Structure end |
#farm_id ⇒ String
The farm ID to update in the queue.
12399 12400 12401 12402 12403 12404 12405 12406 12407 12408 12409 12410 12411 12412 12413 12414 12415 12416 |
# File 'lib/aws-sdk-deadline/types.rb', line 12399 class UpdateQueueRequest < Struct.new( :farm_id, :queue_id, :client_token, :display_name, :description, :default_budget_action, :job_attachment_settings, :role_arn, :job_run_as_user, :required_file_system_location_names_to_add, :required_file_system_location_names_to_remove, :allowed_storage_profile_ids_to_add, :allowed_storage_profile_ids_to_remove, :scheduling_configuration) SENSITIVE = [:description] include Aws::Structure end |
#job_attachment_settings ⇒ Types::JobAttachmentSettings
The job attachment settings to update for the queue.
12399 12400 12401 12402 12403 12404 12405 12406 12407 12408 12409 12410 12411 12412 12413 12414 12415 12416 |
# File 'lib/aws-sdk-deadline/types.rb', line 12399 class UpdateQueueRequest < Struct.new( :farm_id, :queue_id, :client_token, :display_name, :description, :default_budget_action, :job_attachment_settings, :role_arn, :job_run_as_user, :required_file_system_location_names_to_add, :required_file_system_location_names_to_remove, :allowed_storage_profile_ids_to_add, :allowed_storage_profile_ids_to_remove, :scheduling_configuration) SENSITIVE = [:description] include Aws::Structure end |
#job_run_as_user ⇒ Types::JobRunAsUser
Update the jobs in the queue to run as a specified POSIX user.
12399 12400 12401 12402 12403 12404 12405 12406 12407 12408 12409 12410 12411 12412 12413 12414 12415 12416 |
# File 'lib/aws-sdk-deadline/types.rb', line 12399 class UpdateQueueRequest < Struct.new( :farm_id, :queue_id, :client_token, :display_name, :description, :default_budget_action, :job_attachment_settings, :role_arn, :job_run_as_user, :required_file_system_location_names_to_add, :required_file_system_location_names_to_remove, :allowed_storage_profile_ids_to_add, :allowed_storage_profile_ids_to_remove, :scheduling_configuration) SENSITIVE = [:description] include Aws::Structure end |
#queue_id ⇒ String
The queue ID to update.
12399 12400 12401 12402 12403 12404 12405 12406 12407 12408 12409 12410 12411 12412 12413 12414 12415 12416 |
# File 'lib/aws-sdk-deadline/types.rb', line 12399 class UpdateQueueRequest < Struct.new( :farm_id, :queue_id, :client_token, :display_name, :description, :default_budget_action, :job_attachment_settings, :role_arn, :job_run_as_user, :required_file_system_location_names_to_add, :required_file_system_location_names_to_remove, :allowed_storage_profile_ids_to_add, :allowed_storage_profile_ids_to_remove, :scheduling_configuration) SENSITIVE = [:description] include Aws::Structure end |
#required_file_system_location_names_to_add ⇒ Array<String>
The required file system location names to add to the queue.
12399 12400 12401 12402 12403 12404 12405 12406 12407 12408 12409 12410 12411 12412 12413 12414 12415 12416 |
# File 'lib/aws-sdk-deadline/types.rb', line 12399 class UpdateQueueRequest < Struct.new( :farm_id, :queue_id, :client_token, :display_name, :description, :default_budget_action, :job_attachment_settings, :role_arn, :job_run_as_user, :required_file_system_location_names_to_add, :required_file_system_location_names_to_remove, :allowed_storage_profile_ids_to_add, :allowed_storage_profile_ids_to_remove, :scheduling_configuration) SENSITIVE = [:description] include Aws::Structure end |
#required_file_system_location_names_to_remove ⇒ Array<String>
The required file system location names to remove from the queue.
12399 12400 12401 12402 12403 12404 12405 12406 12407 12408 12409 12410 12411 12412 12413 12414 12415 12416 |
# File 'lib/aws-sdk-deadline/types.rb', line 12399 class UpdateQueueRequest < Struct.new( :farm_id, :queue_id, :client_token, :display_name, :description, :default_budget_action, :job_attachment_settings, :role_arn, :job_run_as_user, :required_file_system_location_names_to_add, :required_file_system_location_names_to_remove, :allowed_storage_profile_ids_to_add, :allowed_storage_profile_ids_to_remove, :scheduling_configuration) SENSITIVE = [:description] include Aws::Structure end |
#role_arn ⇒ String
The IAM role ARN that’s used to run jobs from this queue.
12399 12400 12401 12402 12403 12404 12405 12406 12407 12408 12409 12410 12411 12412 12413 12414 12415 12416 |
# File 'lib/aws-sdk-deadline/types.rb', line 12399 class UpdateQueueRequest < Struct.new( :farm_id, :queue_id, :client_token, :display_name, :description, :default_budget_action, :job_attachment_settings, :role_arn, :job_run_as_user, :required_file_system_location_names_to_add, :required_file_system_location_names_to_remove, :allowed_storage_profile_ids_to_add, :allowed_storage_profile_ids_to_remove, :scheduling_configuration) SENSITIVE = [:description] include Aws::Structure end |
#scheduling_configuration ⇒ Types::SchedulingConfiguration
The scheduling configuration for the queue. This configuration determines how workers are assigned to jobs in the queue.
When updating the scheduling configuration, the entire configuration is replaced.
In-progress tasks run to completion before the new scheduling configuration takes effect.
12399 12400 12401 12402 12403 12404 12405 12406 12407 12408 12409 12410 12411 12412 12413 12414 12415 12416 |
# File 'lib/aws-sdk-deadline/types.rb', line 12399 class UpdateQueueRequest < Struct.new( :farm_id, :queue_id, :client_token, :display_name, :description, :default_budget_action, :job_attachment_settings, :role_arn, :job_run_as_user, :required_file_system_location_names_to_add, :required_file_system_location_names_to_remove, :allowed_storage_profile_ids_to_add, :allowed_storage_profile_ids_to_remove, :scheduling_configuration) SENSITIVE = [:description] include Aws::Structure end |