Class: Aws::Deadline::Types::UpdateStepRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

The unique token which the server uses to recognize retries of the same request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.



10219
10220
10221
10222
10223
10224
10225
10226
10227
10228
# File 'lib/aws-sdk-deadline/types.rb', line 10219

class UpdateStepRequest < Struct.new(
  :target_task_run_status,
  :client_token,
  :farm_id,
  :queue_id,
  :job_id,
  :step_id)
  SENSITIVE = []
  include Aws::Structure
end

#farm_idString

The farm ID to update.



10219
10220
10221
10222
10223
10224
10225
10226
10227
10228
# File 'lib/aws-sdk-deadline/types.rb', line 10219

class UpdateStepRequest < Struct.new(
  :target_task_run_status,
  :client_token,
  :farm_id,
  :queue_id,
  :job_id,
  :step_id)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The job ID to update.



10219
10220
10221
10222
10223
10224
10225
10226
10227
10228
# File 'lib/aws-sdk-deadline/types.rb', line 10219

class UpdateStepRequest < Struct.new(
  :target_task_run_status,
  :client_token,
  :farm_id,
  :queue_id,
  :job_id,
  :step_id)
  SENSITIVE = []
  include Aws::Structure
end

#queue_idString

The queue ID to update.



10219
10220
10221
10222
10223
10224
10225
10226
10227
10228
# File 'lib/aws-sdk-deadline/types.rb', line 10219

class UpdateStepRequest < Struct.new(
  :target_task_run_status,
  :client_token,
  :farm_id,
  :queue_id,
  :job_id,
  :step_id)
  SENSITIVE = []
  include Aws::Structure
end

#step_idString

The step ID to update.



10219
10220
10221
10222
10223
10224
10225
10226
10227
10228
# File 'lib/aws-sdk-deadline/types.rb', line 10219

class UpdateStepRequest < Struct.new(
  :target_task_run_status,
  :client_token,
  :farm_id,
  :queue_id,
  :job_id,
  :step_id)
  SENSITIVE = []
  include Aws::Structure
end

#target_task_run_statusString

The task status to update the step’s tasks to.



10219
10220
10221
10222
10223
10224
10225
10226
10227
10228
# File 'lib/aws-sdk-deadline/types.rb', line 10219

class UpdateStepRequest < Struct.new(
  :target_task_run_status,
  :client_token,
  :farm_id,
  :queue_id,
  :job_id,
  :step_id)
  SENSITIVE = []
  include Aws::Structure
end