Class: Aws::Deadline::Types::UpdateStorageProfileRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::UpdateStorageProfileRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:file_system_locations_to_add, :file_system_locations_to_remove]
Instance Attribute Summary collapse
-
#client_token ⇒ String
The unique token which the server uses to recognize retries of the same request.
-
#display_name ⇒ String
The display name of the storage profile to update.
-
#farm_id ⇒ String
The farm ID to update.
-
#file_system_locations_to_add ⇒ Array<Types::FileSystemLocation>
The file system location names to add.
-
#file_system_locations_to_remove ⇒ Array<Types::FileSystemLocation>
The file system location names to remove.
-
#os_family ⇒ String
The OS system to update.
-
#storage_profile_id ⇒ String
The storage profile ID to update.
Instance Attribute Details
#client_token ⇒ String
The unique token which the server uses to recognize retries of the same request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 |
# File 'lib/aws-sdk-deadline/types.rb', line 12312 class UpdateStorageProfileRequest < Struct.new( :farm_id, :storage_profile_id, :client_token, :display_name, :os_family, :file_system_locations_to_add, :file_system_locations_to_remove) SENSITIVE = [:file_system_locations_to_add, :file_system_locations_to_remove] include Aws::Structure end |
#display_name ⇒ String
The display name of the storage profile to update.
This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.
12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 |
# File 'lib/aws-sdk-deadline/types.rb', line 12312 class UpdateStorageProfileRequest < Struct.new( :farm_id, :storage_profile_id, :client_token, :display_name, :os_family, :file_system_locations_to_add, :file_system_locations_to_remove) SENSITIVE = [:file_system_locations_to_add, :file_system_locations_to_remove] include Aws::Structure end |
#farm_id ⇒ String
The farm ID to update.
12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 |
# File 'lib/aws-sdk-deadline/types.rb', line 12312 class UpdateStorageProfileRequest < Struct.new( :farm_id, :storage_profile_id, :client_token, :display_name, :os_family, :file_system_locations_to_add, :file_system_locations_to_remove) SENSITIVE = [:file_system_locations_to_add, :file_system_locations_to_remove] include Aws::Structure end |
#file_system_locations_to_add ⇒ Array<Types::FileSystemLocation>
The file system location names to add.
12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 |
# File 'lib/aws-sdk-deadline/types.rb', line 12312 class UpdateStorageProfileRequest < Struct.new( :farm_id, :storage_profile_id, :client_token, :display_name, :os_family, :file_system_locations_to_add, :file_system_locations_to_remove) SENSITIVE = [:file_system_locations_to_add, :file_system_locations_to_remove] include Aws::Structure end |
#file_system_locations_to_remove ⇒ Array<Types::FileSystemLocation>
The file system location names to remove.
12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 |
# File 'lib/aws-sdk-deadline/types.rb', line 12312 class UpdateStorageProfileRequest < Struct.new( :farm_id, :storage_profile_id, :client_token, :display_name, :os_family, :file_system_locations_to_add, :file_system_locations_to_remove) SENSITIVE = [:file_system_locations_to_add, :file_system_locations_to_remove] include Aws::Structure end |
#os_family ⇒ String
The OS system to update.
12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 |
# File 'lib/aws-sdk-deadline/types.rb', line 12312 class UpdateStorageProfileRequest < Struct.new( :farm_id, :storage_profile_id, :client_token, :display_name, :os_family, :file_system_locations_to_add, :file_system_locations_to_remove) SENSITIVE = [:file_system_locations_to_add, :file_system_locations_to_remove] include Aws::Structure end |
#storage_profile_id ⇒ String
The storage profile ID to update.
12312 12313 12314 12315 12316 12317 12318 12319 12320 12321 12322 |
# File 'lib/aws-sdk-deadline/types.rb', line 12312 class UpdateStorageProfileRequest < Struct.new( :farm_id, :storage_profile_id, :client_token, :display_name, :os_family, :file_system_locations_to_add, :file_system_locations_to_remove) SENSITIVE = [:file_system_locations_to_add, :file_system_locations_to_remove] include Aws::Structure end |