Class: Aws::Deadline::Types::VolumeSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::VolumeSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
The summary of a persistent volume.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attached_worker_id ⇒ String
The worker ID of the worker the volume is attached to.
-
#availability_zone_id ⇒ String
The Availability Zone ID of the volume.
-
#farm_id ⇒ String
The farm ID of the farm that contains the fleet.
-
#fleet_id ⇒ String
The fleet ID of the fleet that contains the volume.
-
#size_gi_b ⇒ Integer
The volume size in GiB.
-
#state ⇒ String
The state of the volume.
-
#volume_id ⇒ String
The volume ID.
Instance Attribute Details
#attached_worker_id ⇒ String
The worker ID of the worker the volume is attached to.
12914 12915 12916 12917 12918 12919 12920 12921 12922 12923 12924 |
# File 'lib/aws-sdk-deadline/types.rb', line 12914 class VolumeSummary < Struct.new( :volume_id, :farm_id, :fleet_id, :state, :size_gi_b, :availability_zone_id, :attached_worker_id) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The Availability Zone ID of the volume.
12914 12915 12916 12917 12918 12919 12920 12921 12922 12923 12924 |
# File 'lib/aws-sdk-deadline/types.rb', line 12914 class VolumeSummary < Struct.new( :volume_id, :farm_id, :fleet_id, :state, :size_gi_b, :availability_zone_id, :attached_worker_id) SENSITIVE = [] include Aws::Structure end |
#farm_id ⇒ String
The farm ID of the farm that contains the fleet.
12914 12915 12916 12917 12918 12919 12920 12921 12922 12923 12924 |
# File 'lib/aws-sdk-deadline/types.rb', line 12914 class VolumeSummary < Struct.new( :volume_id, :farm_id, :fleet_id, :state, :size_gi_b, :availability_zone_id, :attached_worker_id) SENSITIVE = [] include Aws::Structure end |
#fleet_id ⇒ String
The fleet ID of the fleet that contains the volume.
12914 12915 12916 12917 12918 12919 12920 12921 12922 12923 12924 |
# File 'lib/aws-sdk-deadline/types.rb', line 12914 class VolumeSummary < Struct.new( :volume_id, :farm_id, :fleet_id, :state, :size_gi_b, :availability_zone_id, :attached_worker_id) SENSITIVE = [] include Aws::Structure end |
#size_gi_b ⇒ Integer
The volume size in GiB.
12914 12915 12916 12917 12918 12919 12920 12921 12922 12923 12924 |
# File 'lib/aws-sdk-deadline/types.rb', line 12914 class VolumeSummary < Struct.new( :volume_id, :farm_id, :fleet_id, :state, :size_gi_b, :availability_zone_id, :attached_worker_id) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the volume.
12914 12915 12916 12917 12918 12919 12920 12921 12922 12923 12924 |
# File 'lib/aws-sdk-deadline/types.rb', line 12914 class VolumeSummary < Struct.new( :volume_id, :farm_id, :fleet_id, :state, :size_gi_b, :availability_zone_id, :attached_worker_id) SENSITIVE = [] include Aws::Structure end |
#volume_id ⇒ String
The volume ID.
12914 12915 12916 12917 12918 12919 12920 12921 12922 12923 12924 |
# File 'lib/aws-sdk-deadline/types.rb', line 12914 class VolumeSummary < Struct.new( :volume_id, :farm_id, :fleet_id, :state, :size_gi_b, :availability_zone_id, :attached_worker_id) SENSITIVE = [] include Aws::Structure end |