Class: Aws::Deadline::Types::WeightedBalancedSchedulingConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::WeightedBalancedSchedulingConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Configuration for weighted balanced scheduling. Workers are assigned to jobs based on a weighted formula:
‘weight = (priority * priorityWeight) + (errors * errorWeight) + ((currentTime - submissionTime) * submissionTimeWeight) + ((renderingTasks - renderingTaskBuffer) * renderingTaskWeight)`
The job with the highest calculated weight is scheduled first. Workers are distributed evenly amongst jobs with the same weight.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error_weight ⇒ Float
The weight applied to the number of errors on a job.
-
#max_priority_override ⇒ Types::SchedulingMaxPriorityOverride
Overrides the weighted scheduling formula for jobs at the maximum priority (100).
-
#min_priority_override ⇒ Types::SchedulingMinPriorityOverride
Overrides the weighted scheduling formula for jobs at the minimum priority (0).
-
#priority_weight ⇒ Float
The weight applied to job priority in the scheduling formula.
-
#rendering_task_buffer ⇒ Integer
The rendering task buffer is subtracted from the number of rendering tasks before applying the rendering task weight.
-
#rendering_task_weight ⇒ Float
The weight applied to the number of tasks currently rendering on a job.
-
#submission_time_weight ⇒ Float
The weight applied to job submission time.
Instance Attribute Details
#error_weight ⇒ Float
The weight applied to the number of errors on a job. A negative value means jobs without errors are scheduled first. A value of ‘0` means errors are ignored. The default value is `-10.0`.
12719 12720 12721 12722 12723 12724 12725 12726 12727 12728 12729 |
# File 'lib/aws-sdk-deadline/types.rb', line 12719 class WeightedBalancedSchedulingConfiguration < Struct.new( :priority_weight, :error_weight, :submission_time_weight, :rendering_task_weight, :rendering_task_buffer, :max_priority_override, :min_priority_override) SENSITIVE = [] include Aws::Structure end |
#max_priority_override ⇒ Types::SchedulingMaxPriorityOverride
Overrides the weighted scheduling formula for jobs at the maximum priority (100). When set, jobs with priority 100 are always scheduled first regardless of their calculated weight. When absent, maximum priority jobs use the standard weighted formula.
12719 12720 12721 12722 12723 12724 12725 12726 12727 12728 12729 |
# File 'lib/aws-sdk-deadline/types.rb', line 12719 class WeightedBalancedSchedulingConfiguration < Struct.new( :priority_weight, :error_weight, :submission_time_weight, :rendering_task_weight, :rendering_task_buffer, :max_priority_override, :min_priority_override) SENSITIVE = [] include Aws::Structure end |
#min_priority_override ⇒ Types::SchedulingMinPriorityOverride
Overrides the weighted scheduling formula for jobs at the minimum priority (0). When set, jobs with priority 0 are always scheduled last regardless of their calculated weight. When absent, minimum priority jobs use the standard weighted formula.
12719 12720 12721 12722 12723 12724 12725 12726 12727 12728 12729 |
# File 'lib/aws-sdk-deadline/types.rb', line 12719 class WeightedBalancedSchedulingConfiguration < Struct.new( :priority_weight, :error_weight, :submission_time_weight, :rendering_task_weight, :rendering_task_buffer, :max_priority_override, :min_priority_override) SENSITIVE = [] include Aws::Structure end |
#priority_weight ⇒ Float
The weight applied to job priority in the scheduling formula. Higher values give more influence to job priority. A value of ‘0` means priority is ignored. The default value is `100.0`.
12719 12720 12721 12722 12723 12724 12725 12726 12727 12728 12729 |
# File 'lib/aws-sdk-deadline/types.rb', line 12719 class WeightedBalancedSchedulingConfiguration < Struct.new( :priority_weight, :error_weight, :submission_time_weight, :rendering_task_weight, :rendering_task_buffer, :max_priority_override, :min_priority_override) SENSITIVE = [] include Aws::Structure end |
#rendering_task_buffer ⇒ Integer
The rendering task buffer is subtracted from the number of rendering tasks before applying the rendering task weight. This creates a stickiness effect where workers prefer to stay with their current job. Higher values make workers stickier. The default value is ‘1`. The buffer is only applied in the weight calculation for a job if the worker is currently assigned to that job.
12719 12720 12721 12722 12723 12724 12725 12726 12727 12728 12729 |
# File 'lib/aws-sdk-deadline/types.rb', line 12719 class WeightedBalancedSchedulingConfiguration < Struct.new( :priority_weight, :error_weight, :submission_time_weight, :rendering_task_weight, :rendering_task_buffer, :max_priority_override, :min_priority_override) SENSITIVE = [] include Aws::Structure end |
#rendering_task_weight ⇒ Float
The weight applied to the number of tasks currently rendering on a job. A negative value means jobs that are not already rendering are scheduled next. A value of ‘0` means the rendering state is ignored. The default value is `-100.0`.
12719 12720 12721 12722 12723 12724 12725 12726 12727 12728 12729 |
# File 'lib/aws-sdk-deadline/types.rb', line 12719 class WeightedBalancedSchedulingConfiguration < Struct.new( :priority_weight, :error_weight, :submission_time_weight, :rendering_task_weight, :rendering_task_buffer, :max_priority_override, :min_priority_override) SENSITIVE = [] include Aws::Structure end |
#submission_time_weight ⇒ Float
The weight applied to job submission time. A positive value means earlier jobs are scheduled first. A value of ‘0` means submission time is ignored. The default value is `3.0`.
12719 12720 12721 12722 12723 12724 12725 12726 12727 12728 12729 |
# File 'lib/aws-sdk-deadline/types.rb', line 12719 class WeightedBalancedSchedulingConfiguration < Struct.new( :priority_weight, :error_weight, :submission_time_weight, :rendering_task_weight, :rendering_task_buffer, :max_priority_override, :min_priority_override) SENSITIVE = [] include Aws::Structure end |