Class: Aws::Deadline::Waiters::FleetActive
- Inherits:
-
Object
- Object
- Aws::Deadline::Waiters::FleetActive
- Defined in:
- lib/aws-sdk-deadline/waiters.rb,
sig/waiters.rbs
Overview
Wait until a Fleet is activated. Use this after invoking CreateFleet or UpdateFleet.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ FleetActive
constructor
A new instance of FleetActive.
-
#wait(params = {}) ⇒ Types::GetFleetResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ FleetActive
Returns a new instance of FleetActive.
94 95 |
# File 'lib/aws-sdk-deadline/waiters.rb', line 94
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
132 133 134 |
# File 'lib/aws-sdk-deadline/waiters.rb', line 132 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetFleetResponse
Returns a response object which responds to the following methods:
- #fleet_id => String
- #farm_id => String
- #display_name => String
- #status => String
- #status_message => String
- #auto_scaling_status => String
- #target_worker_count => Integer
- #worker_count => Integer
- #min_worker_count => Integer
- #max_worker_count => Integer
- #configuration => Types::FleetConfiguration
- #created_at => Time
- #created_by => String
- #updated_at => Time
- #updated_by => String
- #description => String
- #host_configuration => Types::HostConfiguration
- #capabilities => Types::FleetCapabilities
- #role_arn => String
127 |
# File 'lib/aws-sdk-deadline/waiters.rb', line 127
def wait: (
|