Class: Aws::Deadline::Waiters::JobComplete
- Inherits:
-
Object
- Object
- Aws::Deadline::Waiters::JobComplete
- Defined in:
- lib/aws-sdk-deadline/waiters.rb,
sig/waiters.rbs
Overview
Wait until a job reaches any terminal status. Waits up to 1 hour by default.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ JobComplete
constructor
A new instance of JobComplete.
-
#wait(params = {}) ⇒ Types::GetJobResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ JobComplete
Returns a new instance of JobComplete.
145 146 |
# File 'lib/aws-sdk-deadline/waiters.rb', line 145
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
201 202 203 |
# File 'lib/aws-sdk-deadline/waiters.rb', line 201 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetJobResponse
Returns a response object which responds to the following methods:
- #job_id => String
- #name => String
- #lifecycle_status => String
- #lifecycle_status_message => String
- #priority => Integer
- #created_at => Time
- #created_by => String
- #updated_at => Time
- #updated_by => String
- #started_at => Time
- #ended_at => Time
- #task_run_status => String
- #target_task_run_status => String
- #task_run_status_counts => Hash<String,Integer>
- #task_failure_retry_count => Integer
- #storage_profile_id => String
- #max_failed_tasks_count => Integer
- #max_retries_per_task => Integer
- #parameters => Hash<String,Types::JobParameter>
- #attachments => Types::Attachments
- #description => String
- #max_worker_count => Integer
- #source_job_id => String
196 |
# File 'lib/aws-sdk-deadline/waiters.rb', line 196
def wait: (
|