Class: Aws::Deadline::Waiters::JobCreateComplete
- Inherits:
-
Object
- Object
- Aws::Deadline::Waiters::JobCreateComplete
- Defined in:
- lib/aws-sdk-deadline/waiters.rb
Overview
Wait until a job is created. Use this after invoking CreateJob.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ JobCreateComplete
constructor
A new instance of JobCreateComplete.
-
#wait(params = {}) ⇒ Types::GetJobResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ JobCreateComplete
Returns a new instance of JobCreateComplete.
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/aws-sdk-deadline/waiters.rb', line 214 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 120, delay: 1, poller: Aws::Waiters::Poller.new( operation_name: :get_job, acceptors: [ { "matcher" => "path", "argument" => "lifecycle_status", "state" => "success", "expected" => "CREATE_COMPLETE" }, { "matcher" => "path", "argument" => "lifecycle_status", "state" => "success", "expected" => "UPDATE_IN_PROGRESS" }, { "matcher" => "path", "argument" => "lifecycle_status", "state" => "success", "expected" => "UPDATE_FAILED" }, { "matcher" => "path", "argument" => "lifecycle_status", "state" => "success", "expected" => "UPDATE_SUCCEEDED" }, { "matcher" => "path", "argument" => "lifecycle_status", "state" => "failure", "expected" => "UPLOAD_FAILED" }, { "matcher" => "path", "argument" => "lifecycle_status", "state" => "failure", "expected" => "CREATE_FAILED" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
270 271 272 |
# File 'lib/aws-sdk-deadline/waiters.rb', line 270 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetJobResponse
Returns a response object which responds to the following methods:
-
#job_id => String
-
#name => String
-
#lifecycle_status => String
-
#lifecycle_status_message => String
-
#priority => Integer
-
#created_at => Time
-
#created_by => String
-
#updated_at => Time
-
#updated_by => String
-
#started_at => Time
-
#ended_at => Time
-
#task_run_status => String
-
#target_task_run_status => String
-
#task_run_status_counts => Hash<String,Integer>
-
#task_failure_retry_count => Integer
-
#storage_profile_id => String
-
#max_failed_tasks_count => Integer
-
#max_retries_per_task => Integer
-
#parameters => Hash<String,Types::JobParameter>
-
#attachments => Types::Attachments
-
#description => String
-
#max_worker_count => Integer
-
#source_job_id => String
265 266 267 |
# File 'lib/aws-sdk-deadline/waiters.rb', line 265 def wait(params = {}) @waiter.wait(client: @client, params: params) end |