Class: Aws::Deadline::Waiters::LicenseEndpointValid
- Inherits:
-
Object
- Object
- Aws::Deadline::Waiters::LicenseEndpointValid
- Defined in:
- lib/aws-sdk-deadline/waiters.rb,
sig/waiters.rbs
Overview
Wait until a LicenseEndpoint is Ready. Use this after invoking CreateLicenseEndpoint.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ LicenseEndpointValid
constructor
A new instance of LicenseEndpointValid.
-
#wait(params = {}) ⇒ Types::GetLicenseEndpointResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ LicenseEndpointValid
Returns a new instance of LicenseEndpointValid.
396 397 |
# File 'lib/aws-sdk-deadline/waiters.rb', line 396
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
428 429 430 |
# File 'lib/aws-sdk-deadline/waiters.rb', line 428 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetLicenseEndpointResponse
Returns a response object which responds to the following methods:
- #license_endpoint_id => String
- #status => String
- #status_message => String
- #vpc_id => String
- #dns_name => String
- #subnet_ids => Array<String>
- #security_group_ids => Array<String>
423 |
# File 'lib/aws-sdk-deadline/waiters.rb', line 423
def wait: (
|