Class: Aws::Deadline::Waiters::QueueFleetAssociationStopped
- Inherits:
-
Object
- Object
- Aws::Deadline::Waiters::QueueFleetAssociationStopped
- Defined in:
- lib/aws-sdk-deadline/waiters.rb,
sig/waiters.rbs
Overview
Wait until a QueueFleetAssociation is stopped. Use this after setting the status to STOP_SCHEDULING_AND_COMPLETE_TASKS or STOP_SCHEDULING_AND_CANCEL_TASKS to wait for a QueueFleetAssociation to reach STOPPED
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ QueueFleetAssociationStopped
constructor
A new instance of QueueFleetAssociationStopped.
-
#wait(params = {}) ⇒ Types::GetQueueFleetAssociationResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ QueueFleetAssociationStopped
Returns a new instance of QueueFleetAssociationStopped.
441 442 |
# File 'lib/aws-sdk-deadline/waiters.rb', line 441
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
465 466 467 |
# File 'lib/aws-sdk-deadline/waiters.rb', line 465 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetQueueFleetAssociationResponse
Returns a response object which responds to the following methods:
- #queue_id => String
- #fleet_id => String
- #status => String
- #created_at => Time
- #created_by => String
- #updated_at => Time
- #updated_by => String
460 |
# File 'lib/aws-sdk-deadline/waiters.rb', line 460
def wait: (
|