Class: Aws::Deadline::Waiters::QueueLimitAssociationStopped

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-deadline/waiters.rb,
sig/waiters.rbs

Overview

Wait until a QueueLimitAssociation is stopped. Use this after setting the status to STOP_LIMIT_USAGE_AND_COMPLETE_TASKS or STOP_LIMIT_USAGE_AND_CANCEL_TASKS to wait for a QueueLimitAssociation to reach STOPPED

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ QueueLimitAssociationStopped

Returns a new instance of QueueLimitAssociationStopped.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 60
  • :delay (Integer) — default: 10
  • :before_attempt (Proc)
  • :before_wait (Proc)


478
479
# File 'lib/aws-sdk-deadline/waiters.rb', line 478

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



502
503
504
# File 'lib/aws-sdk-deadline/waiters.rb', line 502

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::GetQueueLimitAssociationResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :farm_id (required, String)

    The unique identifier of the farm that contains the associated queue and limit.

  • :queue_id (required, String)

    The unique identifier of the queue associated with the limit.

  • :limit_id (required, String)

    The unique identifier of the limit associated with the queue.

Returns:



497
# File 'lib/aws-sdk-deadline/waiters.rb', line 497

def wait: (