Class: Aws::Deadline::Waiters::QueueScheduling
- Inherits:
-
Object
- Object
- Aws::Deadline::Waiters::QueueScheduling
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-deadline/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ QueueScheduling
constructor
A new instance of QueueScheduling.
-
#wait(params = {}) ⇒ Types::GetQueueResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ QueueScheduling
Returns a new instance of QueueScheduling.
514 515 |
# File 'lib/aws-sdk-deadline/waiters.rb', line 514
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
538 539 540 |
# File 'lib/aws-sdk-deadline/waiters.rb', line 538 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetQueueResponse
Returns a response object which responds to the following methods:
- #farm_id => String
- #queue_id => String
- #display_name => String
- #status => String
- #default_budget_action => String
- #blocked_reason => String
- #created_at => Time
- #created_by => String
- #updated_at => Time
- #updated_by => String
- #description => String
- #job_attachment_settings => Types::JobAttachmentSettings
- #role_arn => String
- #required_file_system_location_names => Array<String>
- #allowed_storage_profile_ids => Array<String>
- #job_run_as_user => Types::JobRunAsUser
- #scheduling_configuration => Types::SchedulingConfiguration
533 |
# File 'lib/aws-sdk-deadline/waiters.rb', line 533
def wait: (
|