Module: Aws::Deadline::Types
- Defined in:
- lib/aws-sdk-deadline/types.rb
Defined Under Namespace
Classes: AcceleratorCapabilities, AcceleratorCountRange, AcceleratorSelection, AcceleratorTotalMemoryMiBRange, AccessDeniedException, AcquiredLimit, AssignedEnvironmentEnterSessionActionDefinition, AssignedEnvironmentExitSessionActionDefinition, AssignedSession, AssignedSessionAction, AssignedSessionActionDefinition, AssignedSyncInputJobAttachmentsSessionActionDefinition, AssignedTaskRunSessionActionDefinition, AssociateMemberToFarmRequest, AssociateMemberToFarmResponse, AssociateMemberToFleetRequest, AssociateMemberToFleetResponse, AssociateMemberToJobRequest, AssociateMemberToJobResponse, AssociateMemberToQueueRequest, AssociateMemberToQueueResponse, AssumeFleetRoleForReadRequest, AssumeFleetRoleForReadResponse, AssumeFleetRoleForWorkerRequest, AssumeFleetRoleForWorkerResponse, AssumeQueueRoleForReadRequest, AssumeQueueRoleForReadResponse, AssumeQueueRoleForUserRequest, AssumeQueueRoleForUserResponse, AssumeQueueRoleForWorkerRequest, AssumeQueueRoleForWorkerResponse, Attachments, AwsCredentials, BatchGetJobEntityRequest, BatchGetJobEntityResponse, BatchGetJobError, BatchGetJobIdentifier, BatchGetJobItem, BatchGetJobRequest, BatchGetJobResponse, BatchGetSessionActionError, BatchGetSessionActionIdentifier, BatchGetSessionActionItem, BatchGetSessionActionRequest, BatchGetSessionActionResponse, BatchGetSessionError, BatchGetSessionIdentifier, BatchGetSessionItem, BatchGetSessionRequest, BatchGetSessionResponse, BatchGetStepError, BatchGetStepIdentifier, BatchGetStepItem, BatchGetStepRequest, BatchGetStepResponse, BatchGetTaskError, BatchGetTaskIdentifier, BatchGetTaskItem, BatchGetTaskRequest, BatchGetTaskResponse, BatchGetWorkerError, BatchGetWorkerIdentifier, BatchGetWorkerItem, BatchGetWorkerRequest, BatchGetWorkerResponse, BatchUpdateJobError, BatchUpdateJobItem, BatchUpdateJobRequest, BatchUpdateJobResponse, BatchUpdateTaskError, BatchUpdateTaskItem, BatchUpdateTaskRequest, BatchUpdateTaskResponse, BudgetActionToAdd, BudgetActionToRemove, BudgetSchedule, BudgetSummary, ConflictException, ConsumedUsages, CopyJobTemplateRequest, CopyJobTemplateResponse, CreateBudgetRequest, CreateBudgetResponse, CreateFarmRequest, CreateFarmResponse, CreateFleetRequest, CreateFleetResponse, CreateJobRequest, CreateJobResponse, CreateLicenseEndpointRequest, CreateLicenseEndpointResponse, CreateLimitRequest, CreateLimitResponse, CreateMonitorRequest, CreateMonitorResponse, CreateQueueEnvironmentRequest, CreateQueueEnvironmentResponse, CreateQueueFleetAssociationRequest, CreateQueueFleetAssociationResponse, CreateQueueLimitAssociationRequest, CreateQueueLimitAssociationResponse, CreateQueueRequest, CreateQueueResponse, CreateStorageProfileRequest, CreateStorageProfileResponse, CreateWorkerRequest, CreateWorkerResponse, CustomerManagedAutoScalingConfiguration, CustomerManagedFleetConfiguration, CustomerManagedWorkerCapabilities, DateTimeFilterExpression, DeleteBudgetRequest, DeleteBudgetResponse, DeleteFarmRequest, DeleteFarmResponse, DeleteFleetRequest, DeleteFleetResponse, DeleteLicenseEndpointRequest, DeleteLicenseEndpointResponse, DeleteLimitRequest, DeleteLimitResponse, DeleteMeteredProductRequest, DeleteMeteredProductResponse, DeleteMonitorRequest, DeleteMonitorResponse, DeleteQueueEnvironmentRequest, DeleteQueueEnvironmentResponse, DeleteQueueFleetAssociationRequest, DeleteQueueFleetAssociationResponse, DeleteQueueLimitAssociationRequest, DeleteQueueLimitAssociationResponse, DeleteQueueRequest, DeleteQueueResponse, DeleteStorageProfileRequest, DeleteStorageProfileResponse, DeleteVolumeRequest, DeleteVolumeResponse, DeleteWorkerRequest, DeleteWorkerResponse, DependencyCounts, DisassociateMemberFromFarmRequest, DisassociateMemberFromFarmResponse, DisassociateMemberFromFleetRequest, DisassociateMemberFromFleetResponse, DisassociateMemberFromJobRequest, DisassociateMemberFromJobResponse, DisassociateMemberFromQueueRequest, DisassociateMemberFromQueueResponse, Ec2EbsVolume, EnvironmentDetailsEntity, EnvironmentDetailsError, EnvironmentDetailsIdentifiers, EnvironmentEnterSessionActionDefinition, EnvironmentEnterSessionActionDefinitionSummary, EnvironmentExitSessionActionDefinition, EnvironmentExitSessionActionDefinitionSummary, FarmMember, FarmSummary, FieldSortExpression, FileSystemLocation, FixedBudgetSchedule, FleetAmountCapability, FleetAttributeCapability, FleetCapabilities, FleetConfiguration, FleetMember, FleetSummary, GetBudgetRequest, GetBudgetResponse, GetFarmRequest, GetFarmResponse, GetFleetRequest, GetFleetResponse, GetJobEntityError, GetJobRequest, GetJobResponse, GetLicenseEndpointRequest, GetLicenseEndpointResponse, GetLimitRequest, GetLimitResponse, GetMonitorRequest, GetMonitorResponse, GetMonitorSettingsRequest, GetMonitorSettingsResponse, GetQueueEnvironmentRequest, GetQueueEnvironmentResponse, GetQueueFleetAssociationRequest, GetQueueFleetAssociationResponse, GetQueueLimitAssociationRequest, GetQueueLimitAssociationResponse, GetQueueRequest, GetQueueResponse, GetSessionActionRequest, GetSessionActionResponse, GetSessionRequest, GetSessionResponse, GetSessionsStatisticsAggregationRequest, GetSessionsStatisticsAggregationResponse, GetStepRequest, GetStepResponse, GetStorageProfileForQueueRequest, GetStorageProfileForQueueResponse, GetStorageProfileRequest, GetStorageProfileResponse, GetTaskRequest, GetTaskResponse, GetVolumeRequest, GetVolumeResponse, GetWorkerRequest, GetWorkerResponse, HostConfiguration, HostPropertiesRequest, HostPropertiesResponse, InternalServerErrorException, IpAddresses, JobAttachmentDetailsEntity, JobAttachmentDetailsError, JobAttachmentDetailsIdentifiers, JobAttachmentSettings, JobDetailsEntity, JobDetailsError, JobDetailsIdentifiers, JobEntity, JobEntityIdentifiersUnion, JobMember, JobParameter, JobRunAsUser, JobSearchSummary, JobSummary, LicenseEndpointSummary, LimitSummary, ListAvailableMeteredProductsRequest, ListAvailableMeteredProductsResponse, ListBudgetsRequest, ListBudgetsResponse, ListFarmMembersRequest, ListFarmMembersResponse, ListFarmsRequest, ListFarmsResponse, ListFleetMembersRequest, ListFleetMembersResponse, ListFleetsRequest, ListFleetsResponse, ListJobMembersRequest, ListJobMembersResponse, ListJobParameterDefinitionsRequest, ListJobParameterDefinitionsResponse, ListJobsRequest, ListJobsResponse, ListLicenseEndpointsRequest, ListLicenseEndpointsResponse, ListLimitsRequest, ListLimitsResponse, ListMeteredProductsRequest, ListMeteredProductsResponse, ListMonitorsRequest, ListMonitorsResponse, ListQueueEnvironmentsRequest, ListQueueEnvironmentsResponse, ListQueueFleetAssociationsRequest, ListQueueFleetAssociationsResponse, ListQueueLimitAssociationsRequest, ListQueueLimitAssociationsResponse, ListQueueMembersRequest, ListQueueMembersResponse, ListQueuesRequest, ListQueuesResponse, ListSessionActionsRequest, ListSessionActionsResponse, ListSessionsForWorkerRequest, ListSessionsForWorkerResponse, ListSessionsRequest, ListSessionsResponse, ListStepConsumersRequest, ListStepConsumersResponse, ListStepDependenciesRequest, ListStepDependenciesResponse, ListStepsRequest, ListStepsResponse, ListStorageProfilesForQueueRequest, ListStorageProfilesForQueueResponse, ListStorageProfilesRequest, ListStorageProfilesResponse, ListTagsForResourceRequest, ListTagsForResourceResponse, ListTasksRequest, ListTasksResponse, ListVolumesRequest, ListVolumesResponse, ListWorkersRequest, ListWorkersResponse, LogConfiguration, ManifestProperties, MemoryMiBRange, MeteredProductSummary, MonitorSummary, ParameterFilterExpression, ParameterSortExpression, ParameterSpace, PathMappingRule, PersistentVolumeConfiguration, PosixUser, PriorityBalancedSchedulingConfiguration, PriorityFifoSchedulingConfiguration, PutMeteredProductRequest, PutMeteredProductResponse, QueueEnvironmentSummary, QueueFleetAssociationSummary, QueueLimitAssociationSummary, QueueMember, QueueSummary, ResourceNotFoundException, ResponseBudgetAction, S3Location, SchedulingConfiguration, SchedulingMaxPriorityOverride, SchedulingMaxPriorityOverrideAlwaysScheduleFirst, SchedulingMinPriorityOverride, SchedulingMinPriorityOverrideAlwaysScheduleLast, SearchFilterExpression, SearchGroupedFilterExpressions, SearchJobsRequest, SearchJobsResponse, SearchSortExpression, SearchStepsRequest, SearchStepsResponse, SearchTasksRequest, SearchTasksResponse, SearchTermFilterExpression, SearchWorkersRequest, SearchWorkersResponse, ServiceManagedEc2AutoScalingConfiguration, ServiceManagedEc2FleetConfiguration, ServiceManagedEc2InstanceCapabilities, ServiceManagedEc2InstanceMarketOptions, ServiceQuotaExceededException, SessionActionDefinition, SessionActionDefinitionSummary, SessionActionSummary, SessionSummary, SessionsStatisticsResources, StartSessionsStatisticsAggregationRequest, StartSessionsStatisticsAggregationResponse, Statistics, Stats, StepAmountCapability, StepAttributeCapability, StepConsumer, StepDependency, StepDetailsEntity, StepDetailsError, StepDetailsIdentifiers, StepParameter, StepParameterChunks, StepRequiredCapabilities, StepSearchSummary, StepSummary, StorageProfileSummary, StringFilterExpression, StringListFilterExpression, SyncInputJobAttachmentsSessionActionDefinition, SyncInputJobAttachmentsSessionActionDefinitionSummary, TagResourceRequest, TagResourceResponse, TaskParameterValue, TaskRunManifestPropertiesRequest, TaskRunManifestPropertiesResponse, TaskRunSessionActionDefinition, TaskRunSessionActionDefinitionSummary, TaskSearchSummary, TaskSummary, ThrottlingException, UntagResourceRequest, UntagResourceResponse, UpdateBudgetRequest, UpdateBudgetResponse, UpdateFarmRequest, UpdateFarmResponse, UpdateFleetRequest, UpdateFleetResponse, UpdateJobRequest, UpdateJobResponse, UpdateLimitRequest, UpdateLimitResponse, UpdateMonitorRequest, UpdateMonitorResponse, UpdateMonitorSettingsRequest, UpdateMonitorSettingsResponse, UpdateQueueEnvironmentRequest, UpdateQueueEnvironmentResponse, UpdateQueueFleetAssociationRequest, UpdateQueueFleetAssociationResponse, UpdateQueueLimitAssociationRequest, UpdateQueueLimitAssociationResponse, UpdateQueueRequest, UpdateQueueResponse, UpdateSessionRequest, UpdateSessionResponse, UpdateStepRequest, UpdateStepResponse, UpdateStorageProfileRequest, UpdateStorageProfileResponse, UpdateTaskRequest, UpdateTaskResponse, UpdateWorkerRequest, UpdateWorkerResponse, UpdateWorkerScheduleRequest, UpdateWorkerScheduleResponse, UpdatedSessionActionInfo, UsageTrackingResource, UserJobsFirst, VCpuCountRange, ValidationException, ValidationExceptionField, VolumeSummary, VpcConfiguration, WeightedBalancedSchedulingConfiguration, WindowsUser, WorkerAmountCapability, WorkerAttributeCapability, WorkerCapabilities, WorkerSearchSummary, WorkerSessionSummary, WorkerSummary
Instance Attribute Summary collapse
-
#always_schedule_first ⇒ Types::SchedulingMaxPriorityOverrideAlwaysScheduleFirst
Jobs at the maximum priority (100) are always scheduled before other jobs, regardless of the weighted scheduling formula.
-
#always_schedule_last ⇒ Types::SchedulingMinPriorityOverrideAlwaysScheduleLast
Jobs at the minimum priority (0) are always scheduled after all other jobs, regardless of the weighted scheduling formula.
-
#chunk_int ⇒ String
A range (for example 1-10) or selection of specific (for example 1,3,7,8,10) integers represented as a string.
-
#customer_managed ⇒ Types::CustomerManagedFleetConfiguration
The customer managed fleets within a fleet configuration.
-
#date_time_filter ⇒ Types::DateTimeFilterExpression
Filters based on date and time.
-
#env_enter ⇒ Types::EnvironmentEnterSessionActionDefinitionSummary
The environment to enter into.
-
#env_exit ⇒ Types::EnvironmentExitSessionActionDefinitionSummary
The environment to exit from.
-
#environment_details ⇒ Types::EnvironmentDetailsIdentifiers
The environment details.
-
#field_sort ⇒ Types::FieldSortExpression
Options for sorting by a field.
-
#fixed ⇒ Types::FixedBudgetSchedule
The fixed start and end time of the budget’s schedule.
-
#fleet_ids ⇒ Array<String>
One to 10 fleet IDs that specify the fleets to return statistics for.
-
#float ⇒ String
A double precision IEEE-754 floating point number represented as a string.
-
#group_filter ⇒ Types::SearchGroupedFilterExpressions
Filters by group.
-
#int ⇒ String
A signed integer represented as a string.
-
#job_attachment_details ⇒ Types::JobAttachmentDetailsIdentifiers
The job attachment details.
-
#job_details ⇒ Types::JobDetailsIdentifiers
The job details.
-
#parameter_filter ⇒ Types::ParameterFilterExpression
Filters by parameter.
-
#parameter_sort ⇒ Types::ParameterSortExpression
Options for sorting by a parameter.
-
#path ⇒ String
A file system path represented as a string.
-
#priority_balanced ⇒ Types::PriorityBalancedSchedulingConfiguration
Workers are distributed evenly across all jobs at the highest priority level.
-
#priority_fifo ⇒ Types::PriorityFifoSchedulingConfiguration
Workers are assigned to the highest-priority job first.
-
#queue_id ⇒ String
The queue ID.
-
#queue_ids ⇒ Array<String>
One to 10 queue IDs that specify the queues to return statistics for.
-
#search_term_filter ⇒ Types::SearchTermFilterExpression
Filters by a specified search term.
-
#service_managed_ec2 ⇒ Types::ServiceManagedEc2FleetConfiguration
The service managed Amazon EC2 instances for a fleet configuration.
-
#step_details ⇒ Types::StepDetailsIdentifiers
The step details.
-
#string ⇒ String
A UTF-8 string.
-
#string_filter ⇒ Types::StringFilterExpression
Filters by a string.
-
#string_list_filter ⇒ Types::StringListFilterExpression
Filters by a list of strings.
-
#sync_input_job_attachments ⇒ Types::SyncInputJobAttachmentsSessionActionDefinitionSummary
The session action definition summary for syncing input job attachments.
-
#task_run ⇒ Types::TaskRunSessionActionDefinitionSummary
The task run.
-
#user_jobs_first ⇒ Types::UserJobsFirst
Options for sorting a particular user’s jobs first.
-
#weighted_balanced ⇒ Types::WeightedBalancedSchedulingConfiguration
Workers are assigned to jobs based on a weighted formula that considers job priority, error count, submission time, and the number of tasks currently rendering.
Instance Attribute Details
#always_schedule_first ⇒ Types::SchedulingMaxPriorityOverrideAlwaysScheduleFirst
Jobs at the maximum priority (100) are always scheduled before other jobs, regardless of the weighted scheduling formula. If multiple jobs have priority 100, ties are broken using the standard weighted formula.
9842 9843 9844 9845 9846 9847 9848 9849 9850 9851 |
# File 'lib/aws-sdk-deadline/types.rb', line 9842 class SchedulingMaxPriorityOverride < Struct.new( :always_schedule_first, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AlwaysScheduleFirst < SchedulingMaxPriorityOverride; end class Unknown < SchedulingMaxPriorityOverride; end end |
#always_schedule_last ⇒ Types::SchedulingMinPriorityOverrideAlwaysScheduleLast
Jobs at the minimum priority (0) are always scheduled after all other jobs, regardless of the weighted scheduling formula. If multiple jobs have priority 0, ties are broken using the standard weighted formula.
9878 9879 9880 9881 9882 9883 9884 9885 9886 9887 |
# File 'lib/aws-sdk-deadline/types.rb', line 9878 class SchedulingMinPriorityOverride < Struct.new( :always_schedule_last, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AlwaysScheduleLast < SchedulingMinPriorityOverride; end class Unknown < SchedulingMinPriorityOverride; end end |
#chunk_int ⇒ String
A range (for example 1-10) or selection of specific (for example 1,3,7,8,10) integers represented as a string.
11490 11491 11492 11493 11494 11495 11496 11497 11498 11499 11500 11501 11502 11503 11504 11505 11506 11507 |
# File 'lib/aws-sdk-deadline/types.rb', line 11490 class TaskParameterValue < Struct.new( :int, :float, :string, :path, :chunk_int, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Int < TaskParameterValue; end class Float < TaskParameterValue; end class String < TaskParameterValue; end class Path < TaskParameterValue; end class ChunkInt < TaskParameterValue; end class Unknown < TaskParameterValue; end end |
#customer_managed ⇒ Types::CustomerManagedFleetConfiguration
The customer managed fleets within a fleet configuration.
4374 4375 4376 4377 4378 4379 4380 4381 4382 4383 4384 4385 |
# File 'lib/aws-sdk-deadline/types.rb', line 4374 class FleetConfiguration < Struct.new( :customer_managed, :service_managed_ec2, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CustomerManaged < FleetConfiguration; end class ServiceManagedEc2 < FleetConfiguration; end class Unknown < FleetConfiguration; end end |
#date_time_filter ⇒ Types::DateTimeFilterExpression
Filters based on date and time.
9928 9929 9930 9931 9932 9933 9934 9935 9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 |
# File 'lib/aws-sdk-deadline/types.rb', line 9928 class SearchFilterExpression < Struct.new( :date_time_filter, :parameter_filter, :search_term_filter, :string_filter, :string_list_filter, :group_filter, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DateTimeFilter < SearchFilterExpression; end class ParameterFilter < SearchFilterExpression; end class SearchTermFilter < SearchFilterExpression; end class StringFilter < SearchFilterExpression; end class StringListFilter < SearchFilterExpression; end class GroupFilter < SearchFilterExpression; end class Unknown < SearchFilterExpression; end end |
#env_enter ⇒ Types::EnvironmentEnterSessionActionDefinitionSummary
The environment to enter into.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/aws-sdk-deadline/types.rb', line 324 class AssignedSessionActionDefinition < Struct.new( :env_enter, :env_exit, :task_run, :sync_input_job_attachments, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EnvEnter < AssignedSessionActionDefinition; end class EnvExit < AssignedSessionActionDefinition; end class TaskRun < AssignedSessionActionDefinition; end class SyncInputJobAttachments < AssignedSessionActionDefinition; end class Unknown < AssignedSessionActionDefinition; end end |
#env_exit ⇒ Types::EnvironmentExitSessionActionDefinitionSummary
The environment to exit from.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/aws-sdk-deadline/types.rb', line 324 class AssignedSessionActionDefinition < Struct.new( :env_enter, :env_exit, :task_run, :sync_input_job_attachments, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EnvEnter < AssignedSessionActionDefinition; end class EnvExit < AssignedSessionActionDefinition; end class TaskRun < AssignedSessionActionDefinition; end class SyncInputJobAttachments < AssignedSessionActionDefinition; end class Unknown < AssignedSessionActionDefinition; end end |
#environment_details ⇒ Types::EnvironmentDetailsIdentifiers
The environment details.
4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 |
# File 'lib/aws-sdk-deadline/types.rb', line 4860 class GetJobEntityError < Struct.new( :job_details, :job_attachment_details, :step_details, :environment_details, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class JobDetails < GetJobEntityError; end class JobAttachmentDetails < GetJobEntityError; end class StepDetails < GetJobEntityError; end class EnvironmentDetails < GetJobEntityError; end class Unknown < GetJobEntityError; end end |
#field_sort ⇒ Types::FieldSortExpression
Options for sorting by a field.
10051 10052 10053 10054 10055 10056 10057 10058 10059 10060 10061 10062 10063 10064 |
# File 'lib/aws-sdk-deadline/types.rb', line 10051 class SearchSortExpression < Struct.new( :user_jobs_first, :field_sort, :parameter_sort, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class UserJobsFirst < SearchSortExpression; end class FieldSort < SearchSortExpression; end class ParameterSort < SearchSortExpression; end class Unknown < SearchSortExpression; end end |
#fixed ⇒ Types::FixedBudgetSchedule
The fixed start and end time of the budget’s schedule.
2303 2304 2305 2306 2307 2308 2309 2310 2311 2312 |
# File 'lib/aws-sdk-deadline/types.rb', line 2303 class BudgetSchedule < Struct.new( :fixed, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Fixed < BudgetSchedule; end class Unknown < BudgetSchedule; end end |
#fleet_ids ⇒ Array<String>
One to 10 fleet IDs that specify the fleets to return statistics for. If you specify the ‘fleetIds` field, you can’t specify the ‘queueIds` field.
10693 10694 10695 10696 10697 10698 10699 10700 10701 10702 10703 10704 |
# File 'lib/aws-sdk-deadline/types.rb', line 10693 class SessionsStatisticsResources < Struct.new( :queue_ids, :fleet_ids, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class QueueIds < SessionsStatisticsResources; end class FleetIds < SessionsStatisticsResources; end class Unknown < SessionsStatisticsResources; end end |
#float ⇒ String
A double precision IEEE-754 floating point number represented as a string.
6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 6935 6936 |
# File 'lib/aws-sdk-deadline/types.rb', line 6921 class JobParameter < Struct.new( :int, :float, :string, :path, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Int < JobParameter; end class Float < JobParameter; end class String < JobParameter; end class Path < JobParameter; end class Unknown < JobParameter; end end |
#group_filter ⇒ Types::SearchGroupedFilterExpressions
Filters by group.
9928 9929 9930 9931 9932 9933 9934 9935 9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 |
# File 'lib/aws-sdk-deadline/types.rb', line 9928 class SearchFilterExpression < Struct.new( :date_time_filter, :parameter_filter, :search_term_filter, :string_filter, :string_list_filter, :group_filter, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DateTimeFilter < SearchFilterExpression; end class ParameterFilter < SearchFilterExpression; end class SearchTermFilter < SearchFilterExpression; end class StringFilter < SearchFilterExpression; end class StringListFilter < SearchFilterExpression; end class GroupFilter < SearchFilterExpression; end class Unknown < SearchFilterExpression; end end |
#int ⇒ String
A signed integer represented as a string.
6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 6935 6936 |
# File 'lib/aws-sdk-deadline/types.rb', line 6921 class JobParameter < Struct.new( :int, :float, :string, :path, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Int < JobParameter; end class Float < JobParameter; end class String < JobParameter; end class Path < JobParameter; end class Unknown < JobParameter; end end |
#job_attachment_details ⇒ Types::JobAttachmentDetailsIdentifiers
The job attachment details.
4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 |
# File 'lib/aws-sdk-deadline/types.rb', line 4860 class GetJobEntityError < Struct.new( :job_details, :job_attachment_details, :step_details, :environment_details, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class JobDetails < GetJobEntityError; end class JobAttachmentDetails < GetJobEntityError; end class StepDetails < GetJobEntityError; end class EnvironmentDetails < GetJobEntityError; end class Unknown < GetJobEntityError; end end |
#job_details ⇒ Types::JobDetailsIdentifiers
The job details.
4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 |
# File 'lib/aws-sdk-deadline/types.rb', line 4860 class GetJobEntityError < Struct.new( :job_details, :job_attachment_details, :step_details, :environment_details, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class JobDetails < GetJobEntityError; end class JobAttachmentDetails < GetJobEntityError; end class StepDetails < GetJobEntityError; end class EnvironmentDetails < GetJobEntityError; end class Unknown < GetJobEntityError; end end |
#parameter_filter ⇒ Types::ParameterFilterExpression
Filters by parameter.
9928 9929 9930 9931 9932 9933 9934 9935 9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 |
# File 'lib/aws-sdk-deadline/types.rb', line 9928 class SearchFilterExpression < Struct.new( :date_time_filter, :parameter_filter, :search_term_filter, :string_filter, :string_list_filter, :group_filter, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DateTimeFilter < SearchFilterExpression; end class ParameterFilter < SearchFilterExpression; end class SearchTermFilter < SearchFilterExpression; end class StringFilter < SearchFilterExpression; end class StringListFilter < SearchFilterExpression; end class GroupFilter < SearchFilterExpression; end class Unknown < SearchFilterExpression; end end |
#parameter_sort ⇒ Types::ParameterSortExpression
Options for sorting by a parameter.
10051 10052 10053 10054 10055 10056 10057 10058 10059 10060 10061 10062 10063 10064 |
# File 'lib/aws-sdk-deadline/types.rb', line 10051 class SearchSortExpression < Struct.new( :user_jobs_first, :field_sort, :parameter_sort, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class UserJobsFirst < SearchSortExpression; end class FieldSort < SearchSortExpression; end class ParameterSort < SearchSortExpression; end class Unknown < SearchSortExpression; end end |
#path ⇒ String
A file system path represented as a string.
6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 6935 6936 |
# File 'lib/aws-sdk-deadline/types.rb', line 6921 class JobParameter < Struct.new( :int, :float, :string, :path, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Int < JobParameter; end class Float < JobParameter; end class String < JobParameter; end class Path < JobParameter; end class Unknown < JobParameter; end end |
#priority_balanced ⇒ Types::PriorityBalancedSchedulingConfiguration
Workers are distributed evenly across all jobs at the highest priority level. When workers cannot be evenly divided, the extra workers are assigned to the jobs submitted earliest. If a job has fewer remaining tasks than its share of workers, the surplus workers are redistributed to other jobs at the same priority level.
9811 9812 9813 9814 9815 9816 9817 9818 9819 9820 9821 9822 9823 9824 |
# File 'lib/aws-sdk-deadline/types.rb', line 9811 class SchedulingConfiguration < Struct.new( :priority_fifo, :priority_balanced, :weighted_balanced, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class PriorityFifo < SchedulingConfiguration; end class PriorityBalanced < SchedulingConfiguration; end class WeightedBalanced < SchedulingConfiguration; end class Unknown < SchedulingConfiguration; end end |
#priority_fifo ⇒ Types::PriorityFifoSchedulingConfiguration
Workers are assigned to the highest-priority job first. When multiple jobs share the same priority, the job submitted earliest receives workers first. This is the default scheduling configuration for new queues.
9811 9812 9813 9814 9815 9816 9817 9818 9819 9820 9821 9822 9823 9824 |
# File 'lib/aws-sdk-deadline/types.rb', line 9811 class SchedulingConfiguration < Struct.new( :priority_fifo, :priority_balanced, :weighted_balanced, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class PriorityFifo < SchedulingConfiguration; end class PriorityBalanced < SchedulingConfiguration; end class WeightedBalanced < SchedulingConfiguration; end class Unknown < SchedulingConfiguration; end end |
#queue_id ⇒ String
The queue ID.
12789 12790 12791 12792 12793 12794 12795 12796 12797 12798 |
# File 'lib/aws-sdk-deadline/types.rb', line 12789 class UsageTrackingResource < Struct.new( :queue_id, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class QueueId < UsageTrackingResource; end class Unknown < UsageTrackingResource; end end |
#queue_ids ⇒ Array<String>
One to 10 queue IDs that specify the queues to return statistics for. If you specify the ‘queueIds` field, you can’t specify the ‘fleetIds` field.
10693 10694 10695 10696 10697 10698 10699 10700 10701 10702 10703 10704 |
# File 'lib/aws-sdk-deadline/types.rb', line 10693 class SessionsStatisticsResources < Struct.new( :queue_ids, :fleet_ids, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class QueueIds < SessionsStatisticsResources; end class FleetIds < SessionsStatisticsResources; end class Unknown < SessionsStatisticsResources; end end |
#search_term_filter ⇒ Types::SearchTermFilterExpression
Filters by a specified search term.
9928 9929 9930 9931 9932 9933 9934 9935 9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 |
# File 'lib/aws-sdk-deadline/types.rb', line 9928 class SearchFilterExpression < Struct.new( :date_time_filter, :parameter_filter, :search_term_filter, :string_filter, :string_list_filter, :group_filter, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DateTimeFilter < SearchFilterExpression; end class ParameterFilter < SearchFilterExpression; end class SearchTermFilter < SearchFilterExpression; end class StringFilter < SearchFilterExpression; end class StringListFilter < SearchFilterExpression; end class GroupFilter < SearchFilterExpression; end class Unknown < SearchFilterExpression; end end |
#service_managed_ec2 ⇒ Types::ServiceManagedEc2FleetConfiguration
The service managed Amazon EC2 instances for a fleet configuration.
4374 4375 4376 4377 4378 4379 4380 4381 4382 4383 4384 4385 |
# File 'lib/aws-sdk-deadline/types.rb', line 4374 class FleetConfiguration < Struct.new( :customer_managed, :service_managed_ec2, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class CustomerManaged < FleetConfiguration; end class ServiceManagedEc2 < FleetConfiguration; end class Unknown < FleetConfiguration; end end |
#step_details ⇒ Types::StepDetailsIdentifiers
The step details.
4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 |
# File 'lib/aws-sdk-deadline/types.rb', line 4860 class GetJobEntityError < Struct.new( :job_details, :job_attachment_details, :step_details, :environment_details, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class JobDetails < GetJobEntityError; end class JobAttachmentDetails < GetJobEntityError; end class StepDetails < GetJobEntityError; end class EnvironmentDetails < GetJobEntityError; end class Unknown < GetJobEntityError; end end |
#string ⇒ String
A UTF-8 string.
6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 6935 6936 |
# File 'lib/aws-sdk-deadline/types.rb', line 6921 class JobParameter < Struct.new( :int, :float, :string, :path, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Int < JobParameter; end class Float < JobParameter; end class String < JobParameter; end class Path < JobParameter; end class Unknown < JobParameter; end end |
#string_filter ⇒ Types::StringFilterExpression
Filters by a string.
9928 9929 9930 9931 9932 9933 9934 9935 9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 |
# File 'lib/aws-sdk-deadline/types.rb', line 9928 class SearchFilterExpression < Struct.new( :date_time_filter, :parameter_filter, :search_term_filter, :string_filter, :string_list_filter, :group_filter, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DateTimeFilter < SearchFilterExpression; end class ParameterFilter < SearchFilterExpression; end class SearchTermFilter < SearchFilterExpression; end class StringFilter < SearchFilterExpression; end class StringListFilter < SearchFilterExpression; end class GroupFilter < SearchFilterExpression; end class Unknown < SearchFilterExpression; end end |
#string_list_filter ⇒ Types::StringListFilterExpression
Filters by a list of strings.
9928 9929 9930 9931 9932 9933 9934 9935 9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 |
# File 'lib/aws-sdk-deadline/types.rb', line 9928 class SearchFilterExpression < Struct.new( :date_time_filter, :parameter_filter, :search_term_filter, :string_filter, :string_list_filter, :group_filter, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class DateTimeFilter < SearchFilterExpression; end class ParameterFilter < SearchFilterExpression; end class SearchTermFilter < SearchFilterExpression; end class StringFilter < SearchFilterExpression; end class StringListFilter < SearchFilterExpression; end class GroupFilter < SearchFilterExpression; end class Unknown < SearchFilterExpression; end end |
#sync_input_job_attachments ⇒ Types::SyncInputJobAttachmentsSessionActionDefinitionSummary
The session action definition summary for syncing input job attachments.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/aws-sdk-deadline/types.rb', line 324 class AssignedSessionActionDefinition < Struct.new( :env_enter, :env_exit, :task_run, :sync_input_job_attachments, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EnvEnter < AssignedSessionActionDefinition; end class EnvExit < AssignedSessionActionDefinition; end class TaskRun < AssignedSessionActionDefinition; end class SyncInputJobAttachments < AssignedSessionActionDefinition; end class Unknown < AssignedSessionActionDefinition; end end |
#task_run ⇒ Types::TaskRunSessionActionDefinitionSummary
The task run.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/aws-sdk-deadline/types.rb', line 324 class AssignedSessionActionDefinition < Struct.new( :env_enter, :env_exit, :task_run, :sync_input_job_attachments, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EnvEnter < AssignedSessionActionDefinition; end class EnvExit < AssignedSessionActionDefinition; end class TaskRun < AssignedSessionActionDefinition; end class SyncInputJobAttachments < AssignedSessionActionDefinition; end class Unknown < AssignedSessionActionDefinition; end end |
#user_jobs_first ⇒ Types::UserJobsFirst
Options for sorting a particular user’s jobs first.
10051 10052 10053 10054 10055 10056 10057 10058 10059 10060 10061 10062 10063 10064 |
# File 'lib/aws-sdk-deadline/types.rb', line 10051 class SearchSortExpression < Struct.new( :user_jobs_first, :field_sort, :parameter_sort, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class UserJobsFirst < SearchSortExpression; end class FieldSort < SearchSortExpression; end class ParameterSort < SearchSortExpression; end class Unknown < SearchSortExpression; end end |
#weighted_balanced ⇒ Types::WeightedBalancedSchedulingConfiguration
Workers are assigned to jobs based on a weighted formula that considers job priority, error count, submission time, and the number of tasks currently rendering. Each factor has a configurable weight that determines its influence on scheduling decisions.
9811 9812 9813 9814 9815 9816 9817 9818 9819 9820 9821 9822 9823 9824 |
# File 'lib/aws-sdk-deadline/types.rb', line 9811 class SchedulingConfiguration < Struct.new( :priority_fifo, :priority_balanced, :weighted_balanced, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class PriorityFifo < SchedulingConfiguration; end class PriorityBalanced < SchedulingConfiguration; end class WeightedBalanced < SchedulingConfiguration; end class Unknown < SchedulingConfiguration; end end |