Class: Aws::Deadline::Types::AcceleratorSelection
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::AcceleratorSelection
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Describes a specific GPU accelerator required for an Amazon Elastic Compute Cloud worker host.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the chip used by the GPU accelerator.
-
#runtime ⇒ String
Specifies the runtime driver to use for the GPU accelerator.
Instance Attribute Details
#name ⇒ String
The name of the chip used by the GPU accelerator.
The available GPU accelerators are:
-
t4- NVIDIA T4 Tensor Core GPU (16 GiB memory) -
a10g- NVIDIA A10G Tensor Core GPU (24 GiB memory) -
l4- NVIDIA L4 Tensor Core GPU (24 GiB memory) -
l40s- NVIDIA L40S Tensor Core GPU (48 GiB memory) -
rtx-pro-server-6000- NVIDIA RTX PRO Server 6000 GPU (96 GiB memory)
157 158 159 160 161 162 |
# File 'lib/aws-sdk-deadline/types.rb', line 157 class AcceleratorSelection < Struct.new( :name, :runtime) SENSITIVE = [] include Aws::Structure end |
#runtime ⇒ String
Specifies the runtime driver to use for the GPU accelerator. You must use the same runtime for all GPUs in a fleet.
You can choose from the following runtimes:
-
latest- Use the latest runtime available for the chip. If you specifylatestand a new version of the runtime is released, the new version of the runtime is used. -
grid:r580- NVIDIA vGPU software 19 -
grid:r570- NVIDIA vGPU software 18 -
grid:r535- NVIDIA vGPU software 16
If you don't specify a runtime, Amazon Web Services Deadline Cloud
uses latest as the default. However, if you have multiple
accelerators and specify latest for some and leave others blank,
Amazon Web Services Deadline Cloud raises an exception.
Not all runtimes are compatible with all accelerator types:
-
t4anda10g: Support all runtimes (grid:r580,grid:r570,grid:r535) -
l4andl40s: Only supportgrid:r570and newer -
rtx-pro-server-6000: Only supportsgrid:r580
All accelerators in a fleet must use the same runtime version. You cannot mix different runtime versions within a single fleet.
latest, it resolves to grid:r580 for all
currently supported accelerators.
157 158 159 160 161 162 |
# File 'lib/aws-sdk-deadline/types.rb', line 157 class AcceleratorSelection < Struct.new( :name, :runtime) SENSITIVE = [] include Aws::Structure end |