Class: Aws::Deadline::Types::AcceleratorSelection

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Describes a specific GPU accelerator required for an Amazon Elastic Compute Cloud worker host.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The name of the chip used by the GPU accelerator.

The available GPU accelerators are:

  • ‘t4` - NVIDIA T4 Tensor Core GPU (16 GiB memory)

  • ‘a10g` - NVIDIA A10G Tensor Core GPU (24 GiB memory)

  • ‘l4` - NVIDIA L4 Tensor Core GPU (24 GiB memory)

  • ‘l40s` - NVIDIA L40S Tensor Core GPU (48 GiB memory)

Returns:

  • (String)


146
147
148
149
150
151
# File 'lib/aws-sdk-deadline/types.rb', line 146

class AcceleratorSelection < Struct.new(
  :name,
  :runtime)
  SENSITIVE = []
  include Aws::Structure
end

#runtimeString

Specifies the runtime driver to use for the GPU accelerator. You must use the same runtime for all GPUs in a fleet.

You can choose from the following runtimes:

  • ‘latest` - Use the latest runtime available for the chip. If you specify `latest` and a new version of the runtime is released, the new version of the runtime is used.

  • ‘grid:r570` - [NVIDIA vGPU software 18]

  • ‘grid:r535` - [NVIDIA vGPU software 16]

If you don’t specify a runtime, Amazon Web Services Deadline Cloud uses ‘latest` as the default. However, if you have multiple accelerators and specify `latest` for some and leave others blank, Amazon Web Services Deadline Cloud raises an exception.

Not all runtimes are compatible with all accelerator types:

* `t4` and `a10g`: Support all runtimes (`grid:r570`, `grid:r535`)
  • ‘l4` and `l40s`: Only support `grid:r570` and newer

All accelerators in a fleet must use the same runtime version. You

cannot mix different runtime versions within a single fleet.

<note markdown=“1”> When you specify ‘latest`, it resolves to `grid:r570` for all currently supported accelerators.

</note>

[1]: docs.nvidia.com/vgpu/18.0/index.html [2]: docs.nvidia.com/vgpu/16.0/index.html

Returns:

  • (String)


146
147
148
149
150
151
# File 'lib/aws-sdk-deadline/types.rb', line 146

class AcceleratorSelection < Struct.new(
  :name,
  :runtime)
  SENSITIVE = []
  include Aws::Structure
end