Class: Aws::Deadline::Types::AssociateMemberToFarmRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::AssociateMemberToFarmRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Shared member fields for Associate inputs and ResourceMember response structures. principalId is excluded because it has @httpLabel on inputs but not on responses.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#farm_id ⇒ String
The ID of the farm to associate with the member.
-
#identity_center_region ⇒ String
The Region of the IAM Identity Center instance.
-
#identity_store_id ⇒ String
The identity store ID of the member to associate with the farm.
-
#membership_level ⇒ String
The principal’s membership level for the associated farm.
-
#principal_id ⇒ String
The member’s principal ID to associate with the farm.
-
#principal_type ⇒ String
The principal type of the member to associate with the farm.
Instance Attribute Details
#farm_id ⇒ String
The ID of the farm to associate with the member.
412 413 414 415 416 417 418 419 420 421 |
# File 'lib/aws-sdk-deadline/types.rb', line 412 class AssociateMemberToFarmRequest < Struct.new( :farm_id, :principal_type, :identity_store_id, :membership_level, :principal_id, :identity_center_region) SENSITIVE = [] include Aws::Structure end |
#identity_center_region ⇒ String
The Region of the IAM Identity Center instance. If not provided, the service defaults to the Region of the farm.
412 413 414 415 416 417 418 419 420 421 |
# File 'lib/aws-sdk-deadline/types.rb', line 412 class AssociateMemberToFarmRequest < Struct.new( :farm_id, :principal_type, :identity_store_id, :membership_level, :principal_id, :identity_center_region) SENSITIVE = [] include Aws::Structure end |
#identity_store_id ⇒ String
The identity store ID of the member to associate with the farm.
412 413 414 415 416 417 418 419 420 421 |
# File 'lib/aws-sdk-deadline/types.rb', line 412 class AssociateMemberToFarmRequest < Struct.new( :farm_id, :principal_type, :identity_store_id, :membership_level, :principal_id, :identity_center_region) SENSITIVE = [] include Aws::Structure end |
#membership_level ⇒ String
The principal’s membership level for the associated farm.
412 413 414 415 416 417 418 419 420 421 |
# File 'lib/aws-sdk-deadline/types.rb', line 412 class AssociateMemberToFarmRequest < Struct.new( :farm_id, :principal_type, :identity_store_id, :membership_level, :principal_id, :identity_center_region) SENSITIVE = [] include Aws::Structure end |
#principal_id ⇒ String
The member’s principal ID to associate with the farm.
412 413 414 415 416 417 418 419 420 421 |
# File 'lib/aws-sdk-deadline/types.rb', line 412 class AssociateMemberToFarmRequest < Struct.new( :farm_id, :principal_type, :identity_store_id, :membership_level, :principal_id, :identity_center_region) SENSITIVE = [] include Aws::Structure end |
#principal_type ⇒ String
The principal type of the member to associate with the farm.
412 413 414 415 416 417 418 419 420 421 |
# File 'lib/aws-sdk-deadline/types.rb', line 412 class AssociateMemberToFarmRequest < Struct.new( :farm_id, :principal_type, :identity_store_id, :membership_level, :principal_id, :identity_center_region) SENSITIVE = [] include Aws::Structure end |