Class: Aws::Deadline::Types::BatchGetJobError
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::BatchGetJobError
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
The error details for a job that could not be retrieved in a batch get operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
The error code.
-
#farm_id ⇒ String
The farm ID of the job that could not be retrieved.
-
#job_id ⇒ String
The job ID of the job that could not be retrieved.
-
#message ⇒ String
The error message.
-
#queue_id ⇒ String
The queue ID of the job that could not be retrieved.
Instance Attribute Details
#code ⇒ String
The error code.
850 851 852 853 854 855 856 857 858 |
# File 'lib/aws-sdk-deadline/types.rb', line 850 class BatchGetJobError < Struct.new( :farm_id, :queue_id, :job_id, :code, :message) SENSITIVE = [] include Aws::Structure end |
#farm_id ⇒ String
The farm ID of the job that could not be retrieved.
850 851 852 853 854 855 856 857 858 |
# File 'lib/aws-sdk-deadline/types.rb', line 850 class BatchGetJobError < Struct.new( :farm_id, :queue_id, :job_id, :code, :message) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The job ID of the job that could not be retrieved.
850 851 852 853 854 855 856 857 858 |
# File 'lib/aws-sdk-deadline/types.rb', line 850 class BatchGetJobError < Struct.new( :farm_id, :queue_id, :job_id, :code, :message) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
The error message.
850 851 852 853 854 855 856 857 858 |
# File 'lib/aws-sdk-deadline/types.rb', line 850 class BatchGetJobError < Struct.new( :farm_id, :queue_id, :job_id, :code, :message) SENSITIVE = [] include Aws::Structure end |
#queue_id ⇒ String
The queue ID of the job that could not be retrieved.
850 851 852 853 854 855 856 857 858 |
# File 'lib/aws-sdk-deadline/types.rb', line 850 class BatchGetJobError < Struct.new( :farm_id, :queue_id, :job_id, :code, :message) SENSITIVE = [] include Aws::Structure end |