Class: Aws::Deadline::Types::BatchGetSessionActionError

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

The error details for a session action that could not be retrieved in a batch get operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeString

The error code.

Returns:

  • (String)


1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
# File 'lib/aws-sdk-deadline/types.rb', line 1080

class BatchGetSessionActionError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :session_action_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#farm_idString

The farm ID of the session action that could not be retrieved.

Returns:

  • (String)


1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
# File 'lib/aws-sdk-deadline/types.rb', line 1080

class BatchGetSessionActionError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :session_action_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The job ID of the session action that could not be retrieved.

Returns:

  • (String)


1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
# File 'lib/aws-sdk-deadline/types.rb', line 1080

class BatchGetSessionActionError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :session_action_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

The error message.

Returns:

  • (String)


1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
# File 'lib/aws-sdk-deadline/types.rb', line 1080

class BatchGetSessionActionError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :session_action_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#queue_idString

The queue ID of the session action that could not be retrieved.

Returns:

  • (String)


1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
# File 'lib/aws-sdk-deadline/types.rb', line 1080

class BatchGetSessionActionError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :session_action_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#session_action_idString

The session action ID of the session action that could not be retrieved.

Returns:

  • (String)


1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
# File 'lib/aws-sdk-deadline/types.rb', line 1080

class BatchGetSessionActionError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :session_action_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end