Class: Aws::Deadline::Types::BatchGetSessionActionError
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::BatchGetSessionActionError
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
The error details for a session action that could not be retrieved in a batch get operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
The error code.
-
#farm_id ⇒ String
The farm ID of the session action that could not be retrieved.
-
#job_id ⇒ String
The job ID of the session action that could not be retrieved.
-
#message ⇒ String
The error message.
-
#queue_id ⇒ String
The queue ID of the session action that could not be retrieved.
-
#session_action_id ⇒ String
The session action ID of the session action that could not be retrieved.
Instance Attribute Details
#code ⇒ String
The error code.
1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 |
# File 'lib/aws-sdk-deadline/types.rb', line 1080 class BatchGetSessionActionError < Struct.new( :farm_id, :queue_id, :job_id, :session_action_id, :code, :message) SENSITIVE = [] include Aws::Structure end |
#farm_id ⇒ String
The farm ID of the session action that could not be retrieved.
1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 |
# File 'lib/aws-sdk-deadline/types.rb', line 1080 class BatchGetSessionActionError < Struct.new( :farm_id, :queue_id, :job_id, :session_action_id, :code, :message) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The job ID of the session action that could not be retrieved.
1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 |
# File 'lib/aws-sdk-deadline/types.rb', line 1080 class BatchGetSessionActionError < Struct.new( :farm_id, :queue_id, :job_id, :session_action_id, :code, :message) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
The error message.
1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 |
# File 'lib/aws-sdk-deadline/types.rb', line 1080 class BatchGetSessionActionError < Struct.new( :farm_id, :queue_id, :job_id, :session_action_id, :code, :message) SENSITIVE = [] include Aws::Structure end |
#queue_id ⇒ String
The queue ID of the session action that could not be retrieved.
1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 |
# File 'lib/aws-sdk-deadline/types.rb', line 1080 class BatchGetSessionActionError < Struct.new( :farm_id, :queue_id, :job_id, :session_action_id, :code, :message) SENSITIVE = [] include Aws::Structure end |
#session_action_id ⇒ String
The session action ID of the session action that could not be retrieved.
1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 |
# File 'lib/aws-sdk-deadline/types.rb', line 1080 class BatchGetSessionActionError < Struct.new( :farm_id, :queue_id, :job_id, :session_action_id, :code, :message) SENSITIVE = [] include Aws::Structure end |