Class: Aws::Deadline::Types::BatchGetStepError
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::BatchGetStepError
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
The error details for a step that could not be retrieved in a batch get operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
The error code.
-
#farm_id ⇒ String
The farm ID of the step that could not be retrieved.
-
#job_id ⇒ String
The job ID of the step that could not be retrieved.
-
#message ⇒ String
The error message.
-
#queue_id ⇒ String
The queue ID of the step that could not be retrieved.
-
#step_id ⇒ String
The step ID of the step that could not be retrieved.
Instance Attribute Details
#code ⇒ String
The error code.
1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 |
# File 'lib/aws-sdk-deadline/types.rb', line 1446 class BatchGetStepError < Struct.new( :farm_id, :queue_id, :job_id, :step_id, :code, :message) SENSITIVE = [] include Aws::Structure end |
#farm_id ⇒ String
The farm ID of the step that could not be retrieved.
1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 |
# File 'lib/aws-sdk-deadline/types.rb', line 1446 class BatchGetStepError < Struct.new( :farm_id, :queue_id, :job_id, :step_id, :code, :message) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The job ID of the step that could not be retrieved.
1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 |
# File 'lib/aws-sdk-deadline/types.rb', line 1446 class BatchGetStepError < Struct.new( :farm_id, :queue_id, :job_id, :step_id, :code, :message) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
The error message.
1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 |
# File 'lib/aws-sdk-deadline/types.rb', line 1446 class BatchGetStepError < Struct.new( :farm_id, :queue_id, :job_id, :step_id, :code, :message) SENSITIVE = [] include Aws::Structure end |
#queue_id ⇒ String
The queue ID of the step that could not be retrieved.
1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 |
# File 'lib/aws-sdk-deadline/types.rb', line 1446 class BatchGetStepError < Struct.new( :farm_id, :queue_id, :job_id, :step_id, :code, :message) SENSITIVE = [] include Aws::Structure end |
#step_id ⇒ String
The step ID of the step that could not be retrieved.
1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 |
# File 'lib/aws-sdk-deadline/types.rb', line 1446 class BatchGetStepError < Struct.new( :farm_id, :queue_id, :job_id, :step_id, :code, :message) SENSITIVE = [] include Aws::Structure end |