Class: Aws::Deadline::Types::BatchGetTaskError

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

The error details for a task that could not be retrieved in a batch get operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeString

The error code.

Returns:

  • (String)


1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
# File 'lib/aws-sdk-deadline/types.rb', line 1663

class BatchGetTaskError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :task_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#farm_idString

The farm ID of the task that could not be retrieved.

Returns:

  • (String)


1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
# File 'lib/aws-sdk-deadline/types.rb', line 1663

class BatchGetTaskError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :task_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The job ID of the task that could not be retrieved.

Returns:

  • (String)


1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
# File 'lib/aws-sdk-deadline/types.rb', line 1663

class BatchGetTaskError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :task_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

The error message.

Returns:

  • (String)


1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
# File 'lib/aws-sdk-deadline/types.rb', line 1663

class BatchGetTaskError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :task_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#queue_idString

The queue ID of the task that could not be retrieved.

Returns:

  • (String)


1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
# File 'lib/aws-sdk-deadline/types.rb', line 1663

class BatchGetTaskError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :task_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#step_idString

The step ID of the task that could not be retrieved.

Returns:

  • (String)


1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
# File 'lib/aws-sdk-deadline/types.rb', line 1663

class BatchGetTaskError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :task_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#task_idString

The task ID of the task that could not be retrieved.

Returns:

  • (String)


1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
# File 'lib/aws-sdk-deadline/types.rb', line 1663

class BatchGetTaskError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :task_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end