Class: Aws::Deadline::Types::BatchGetTaskItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::BatchGetTaskItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
The details of a task returned in a batch get operation.
Constant Summary collapse
- SENSITIVE =
[:parameters]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The date and time the resource was created.
-
#created_by ⇒ String
The user or system that created this resource.
-
#ended_at ⇒ Time
The date and time the resource ended running.
-
#failure_retry_count ⇒ Integer
The number of times the task failed and was retried.
-
#farm_id ⇒ String
The farm ID of the task.
-
#job_id ⇒ String
The job ID of the task.
-
#latest_session_action_id ⇒ String
The latest session action for the task.
-
#parameters ⇒ Hash<String,Types::TaskParameterValue>
The parameters for the task.
-
#queue_id ⇒ String
The queue ID of the task.
-
#run_status ⇒ String
The run status of the task.
-
#started_at ⇒ Time
The date and time the resource started running.
-
#step_id ⇒ String
The step ID of the task.
-
#target_run_status ⇒ String
The run status with which to start the task.
-
#task_id ⇒ String
The task ID.
-
#updated_at ⇒ Time
The date and time the resource was updated.
-
#updated_by ⇒ String
The user or system that updated this resource.
Instance Attribute Details
#created_at ⇒ Time
The date and time the resource was created.
1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/aws-sdk-deadline/types.rb', line 1788 class BatchGetTaskItem < Struct.new( :farm_id, :queue_id, :job_id, :step_id, :task_id, :created_at, :created_by, :run_status, :target_run_status, :failure_retry_count, :started_at, :ended_at, :updated_at, :updated_by, :latest_session_action_id, :parameters) SENSITIVE = [:parameters] include Aws::Structure end |
#created_by ⇒ String
The user or system that created this resource.
1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/aws-sdk-deadline/types.rb', line 1788 class BatchGetTaskItem < Struct.new( :farm_id, :queue_id, :job_id, :step_id, :task_id, :created_at, :created_by, :run_status, :target_run_status, :failure_retry_count, :started_at, :ended_at, :updated_at, :updated_by, :latest_session_action_id, :parameters) SENSITIVE = [:parameters] include Aws::Structure end |
#ended_at ⇒ Time
The date and time the resource ended running.
1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/aws-sdk-deadline/types.rb', line 1788 class BatchGetTaskItem < Struct.new( :farm_id, :queue_id, :job_id, :step_id, :task_id, :created_at, :created_by, :run_status, :target_run_status, :failure_retry_count, :started_at, :ended_at, :updated_at, :updated_by, :latest_session_action_id, :parameters) SENSITIVE = [:parameters] include Aws::Structure end |
#failure_retry_count ⇒ Integer
The number of times the task failed and was retried.
1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/aws-sdk-deadline/types.rb', line 1788 class BatchGetTaskItem < Struct.new( :farm_id, :queue_id, :job_id, :step_id, :task_id, :created_at, :created_by, :run_status, :target_run_status, :failure_retry_count, :started_at, :ended_at, :updated_at, :updated_by, :latest_session_action_id, :parameters) SENSITIVE = [:parameters] include Aws::Structure end |
#farm_id ⇒ String
The farm ID of the task.
1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/aws-sdk-deadline/types.rb', line 1788 class BatchGetTaskItem < Struct.new( :farm_id, :queue_id, :job_id, :step_id, :task_id, :created_at, :created_by, :run_status, :target_run_status, :failure_retry_count, :started_at, :ended_at, :updated_at, :updated_by, :latest_session_action_id, :parameters) SENSITIVE = [:parameters] include Aws::Structure end |
#job_id ⇒ String
The job ID of the task.
1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/aws-sdk-deadline/types.rb', line 1788 class BatchGetTaskItem < Struct.new( :farm_id, :queue_id, :job_id, :step_id, :task_id, :created_at, :created_by, :run_status, :target_run_status, :failure_retry_count, :started_at, :ended_at, :updated_at, :updated_by, :latest_session_action_id, :parameters) SENSITIVE = [:parameters] include Aws::Structure end |
#latest_session_action_id ⇒ String
The latest session action for the task.
1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/aws-sdk-deadline/types.rb', line 1788 class BatchGetTaskItem < Struct.new( :farm_id, :queue_id, :job_id, :step_id, :task_id, :created_at, :created_by, :run_status, :target_run_status, :failure_retry_count, :started_at, :ended_at, :updated_at, :updated_by, :latest_session_action_id, :parameters) SENSITIVE = [:parameters] include Aws::Structure end |
#parameters ⇒ Hash<String,Types::TaskParameterValue>
The parameters for the task.
1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/aws-sdk-deadline/types.rb', line 1788 class BatchGetTaskItem < Struct.new( :farm_id, :queue_id, :job_id, :step_id, :task_id, :created_at, :created_by, :run_status, :target_run_status, :failure_retry_count, :started_at, :ended_at, :updated_at, :updated_by, :latest_session_action_id, :parameters) SENSITIVE = [:parameters] include Aws::Structure end |
#queue_id ⇒ String
The queue ID of the task.
1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/aws-sdk-deadline/types.rb', line 1788 class BatchGetTaskItem < Struct.new( :farm_id, :queue_id, :job_id, :step_id, :task_id, :created_at, :created_by, :run_status, :target_run_status, :failure_retry_count, :started_at, :ended_at, :updated_at, :updated_by, :latest_session_action_id, :parameters) SENSITIVE = [:parameters] include Aws::Structure end |
#run_status ⇒ String
The run status of the task.
1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/aws-sdk-deadline/types.rb', line 1788 class BatchGetTaskItem < Struct.new( :farm_id, :queue_id, :job_id, :step_id, :task_id, :created_at, :created_by, :run_status, :target_run_status, :failure_retry_count, :started_at, :ended_at, :updated_at, :updated_by, :latest_session_action_id, :parameters) SENSITIVE = [:parameters] include Aws::Structure end |
#started_at ⇒ Time
The date and time the resource started running.
1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/aws-sdk-deadline/types.rb', line 1788 class BatchGetTaskItem < Struct.new( :farm_id, :queue_id, :job_id, :step_id, :task_id, :created_at, :created_by, :run_status, :target_run_status, :failure_retry_count, :started_at, :ended_at, :updated_at, :updated_by, :latest_session_action_id, :parameters) SENSITIVE = [:parameters] include Aws::Structure end |
#step_id ⇒ String
The step ID of the task.
1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/aws-sdk-deadline/types.rb', line 1788 class BatchGetTaskItem < Struct.new( :farm_id, :queue_id, :job_id, :step_id, :task_id, :created_at, :created_by, :run_status, :target_run_status, :failure_retry_count, :started_at, :ended_at, :updated_at, :updated_by, :latest_session_action_id, :parameters) SENSITIVE = [:parameters] include Aws::Structure end |
#target_run_status ⇒ String
The run status with which to start the task.
1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/aws-sdk-deadline/types.rb', line 1788 class BatchGetTaskItem < Struct.new( :farm_id, :queue_id, :job_id, :step_id, :task_id, :created_at, :created_by, :run_status, :target_run_status, :failure_retry_count, :started_at, :ended_at, :updated_at, :updated_by, :latest_session_action_id, :parameters) SENSITIVE = [:parameters] include Aws::Structure end |
#task_id ⇒ String
The task ID.
1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/aws-sdk-deadline/types.rb', line 1788 class BatchGetTaskItem < Struct.new( :farm_id, :queue_id, :job_id, :step_id, :task_id, :created_at, :created_by, :run_status, :target_run_status, :failure_retry_count, :started_at, :ended_at, :updated_at, :updated_by, :latest_session_action_id, :parameters) SENSITIVE = [:parameters] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the resource was updated.
1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/aws-sdk-deadline/types.rb', line 1788 class BatchGetTaskItem < Struct.new( :farm_id, :queue_id, :job_id, :step_id, :task_id, :created_at, :created_by, :run_status, :target_run_status, :failure_retry_count, :started_at, :ended_at, :updated_at, :updated_by, :latest_session_action_id, :parameters) SENSITIVE = [:parameters] include Aws::Structure end |
#updated_by ⇒ String
The user or system that updated this resource.
1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/aws-sdk-deadline/types.rb', line 1788 class BatchGetTaskItem < Struct.new( :farm_id, :queue_id, :job_id, :step_id, :task_id, :created_at, :created_by, :run_status, :target_run_status, :failure_retry_count, :started_at, :ended_at, :updated_at, :updated_by, :latest_session_action_id, :parameters) SENSITIVE = [:parameters] include Aws::Structure end |