Class: Aws::Deadline::Types::BatchUpdateJobError
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::BatchUpdateJobError
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
The error details for a job that could not be updated in a batch update operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
The error code.
-
#farm_id ⇒ String
The farm ID of the job that could not be updated.
-
#job_id ⇒ String
The job ID of the job that could not be updated.
-
#message ⇒ String
The error message.
-
#queue_id ⇒ String
The queue ID of the job that could not be updated.
Instance Attribute Details
#code ⇒ String
The error code.
2001 2002 2003 2004 2005 2006 2007 2008 2009 |
# File 'lib/aws-sdk-deadline/types.rb', line 2001 class BatchUpdateJobError < Struct.new( :farm_id, :queue_id, :job_id, :code, :message) SENSITIVE = [] include Aws::Structure end |
#farm_id ⇒ String
The farm ID of the job that could not be updated.
2001 2002 2003 2004 2005 2006 2007 2008 2009 |
# File 'lib/aws-sdk-deadline/types.rb', line 2001 class BatchUpdateJobError < Struct.new( :farm_id, :queue_id, :job_id, :code, :message) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The job ID of the job that could not be updated.
2001 2002 2003 2004 2005 2006 2007 2008 2009 |
# File 'lib/aws-sdk-deadline/types.rb', line 2001 class BatchUpdateJobError < Struct.new( :farm_id, :queue_id, :job_id, :code, :message) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
The error message.
2001 2002 2003 2004 2005 2006 2007 2008 2009 |
# File 'lib/aws-sdk-deadline/types.rb', line 2001 class BatchUpdateJobError < Struct.new( :farm_id, :queue_id, :job_id, :code, :message) SENSITIVE = [] include Aws::Structure end |
#queue_id ⇒ String
The queue ID of the job that could not be updated.
2001 2002 2003 2004 2005 2006 2007 2008 2009 |
# File 'lib/aws-sdk-deadline/types.rb', line 2001 class BatchUpdateJobError < Struct.new( :farm_id, :queue_id, :job_id, :code, :message) SENSITIVE = [] include Aws::Structure end |