Class: Aws::Deadline::Types::BatchUpdateJobItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

The details of a job to update in a batch update operation.

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the job to update.

Returns:

  • (String)


2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
# File 'lib/aws-sdk-deadline/types.rb', line 2065

class BatchUpdateJobItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :target_task_run_status,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :lifecycle_status,
  :max_worker_count,
  :name,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#farm_idString

The farm ID of the job to update.

Returns:

  • (String)


2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
# File 'lib/aws-sdk-deadline/types.rb', line 2065

class BatchUpdateJobItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :target_task_run_status,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :lifecycle_status,
  :max_worker_count,
  :name,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#job_idString

The job ID of the job to update.

Returns:

  • (String)


2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
# File 'lib/aws-sdk-deadline/types.rb', line 2065

class BatchUpdateJobItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :target_task_run_status,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :lifecycle_status,
  :max_worker_count,
  :name,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#lifecycle_statusString

The status of a job in its lifecycle. When you change the status of the job to ‘ARCHIVED`, the job can’t be scheduled or archived.

An archived job and its steps and tasks are deleted after 120 days. The job can’t be recovered.

Returns:

  • (String)


2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
# File 'lib/aws-sdk-deadline/types.rb', line 2065

class BatchUpdateJobItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :target_task_run_status,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :lifecycle_status,
  :max_worker_count,
  :name,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#max_failed_tasks_countInteger

The number of task failures before the job stops running and is marked as ‘FAILED`.

Returns:

  • (Integer)


2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
# File 'lib/aws-sdk-deadline/types.rb', line 2065

class BatchUpdateJobItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :target_task_run_status,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :lifecycle_status,
  :max_worker_count,
  :name,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#max_retries_per_taskInteger

The maximum number of retries per failed tasks.

Returns:

  • (Integer)


2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
# File 'lib/aws-sdk-deadline/types.rb', line 2065

class BatchUpdateJobItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :target_task_run_status,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :lifecycle_status,
  :max_worker_count,
  :name,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#max_worker_countInteger

The maximum number of worker hosts that can concurrently process a job.

Returns:

  • (Integer)


2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
# File 'lib/aws-sdk-deadline/types.rb', line 2065

class BatchUpdateJobItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :target_task_run_status,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :lifecycle_status,
  :max_worker_count,
  :name,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#nameString

The name of the job to update.

Returns:

  • (String)


2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
# File 'lib/aws-sdk-deadline/types.rb', line 2065

class BatchUpdateJobItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :target_task_run_status,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :lifecycle_status,
  :max_worker_count,
  :name,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#priorityInteger

The job priority to update.

Returns:

  • (Integer)


2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
# File 'lib/aws-sdk-deadline/types.rb', line 2065

class BatchUpdateJobItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :target_task_run_status,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :lifecycle_status,
  :max_worker_count,
  :name,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#queue_idString

The queue ID of the job to update.

Returns:

  • (String)


2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
# File 'lib/aws-sdk-deadline/types.rb', line 2065

class BatchUpdateJobItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :target_task_run_status,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :lifecycle_status,
  :max_worker_count,
  :name,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#target_task_run_statusString

The task status to update the job’s tasks to.

Returns:

  • (String)


2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
# File 'lib/aws-sdk-deadline/types.rb', line 2065

class BatchUpdateJobItem < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :target_task_run_status,
  :priority,
  :max_failed_tasks_count,
  :max_retries_per_task,
  :lifecycle_status,
  :max_worker_count,
  :name,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end