Class: Aws::Deadline::Types::BatchUpdateTaskError

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

The error details for a task that could not be updated in a batch update operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeString

The error code.

Returns:

  • (String)


2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
# File 'lib/aws-sdk-deadline/types.rb', line 2148

class BatchUpdateTaskError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :task_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#farm_idString

The farm ID of the task that could not be updated.

Returns:

  • (String)


2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
# File 'lib/aws-sdk-deadline/types.rb', line 2148

class BatchUpdateTaskError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :task_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#job_idString

The job ID of the task that could not be updated.

Returns:

  • (String)


2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
# File 'lib/aws-sdk-deadline/types.rb', line 2148

class BatchUpdateTaskError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :task_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

The error message.

Returns:

  • (String)


2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
# File 'lib/aws-sdk-deadline/types.rb', line 2148

class BatchUpdateTaskError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :task_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#queue_idString

The queue ID of the task that could not be updated.

Returns:

  • (String)


2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
# File 'lib/aws-sdk-deadline/types.rb', line 2148

class BatchUpdateTaskError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :task_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#step_idString

The step ID of the task that could not be updated.

Returns:

  • (String)


2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
# File 'lib/aws-sdk-deadline/types.rb', line 2148

class BatchUpdateTaskError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :task_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#task_idString

The task ID of the task that could not be updated.

Returns:

  • (String)


2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
# File 'lib/aws-sdk-deadline/types.rb', line 2148

class BatchUpdateTaskError < Struct.new(
  :farm_id,
  :queue_id,
  :job_id,
  :step_id,
  :task_id,
  :code,
  :message)
  SENSITIVE = []
  include Aws::Structure
end