Class: Aws::Deadline::Types::BatchUpdateTaskError
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::BatchUpdateTaskError
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
The error details for a task that could not be updated in a batch update operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
The error code.
-
#farm_id ⇒ String
The farm ID of the task that could not be updated.
-
#job_id ⇒ String
The job ID of the task that could not be updated.
-
#message ⇒ String
The error message.
-
#queue_id ⇒ String
The queue ID of the task that could not be updated.
-
#step_id ⇒ String
The step ID of the task that could not be updated.
-
#task_id ⇒ String
The task ID of the task that could not be updated.
Instance Attribute Details
#code ⇒ String
The error code.
2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 |
# File 'lib/aws-sdk-deadline/types.rb', line 2148 class BatchUpdateTaskError < Struct.new( :farm_id, :queue_id, :job_id, :step_id, :task_id, :code, :message) SENSITIVE = [] include Aws::Structure end |
#farm_id ⇒ String
The farm ID of the task that could not be updated.
2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 |
# File 'lib/aws-sdk-deadline/types.rb', line 2148 class BatchUpdateTaskError < Struct.new( :farm_id, :queue_id, :job_id, :step_id, :task_id, :code, :message) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The job ID of the task that could not be updated.
2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 |
# File 'lib/aws-sdk-deadline/types.rb', line 2148 class BatchUpdateTaskError < Struct.new( :farm_id, :queue_id, :job_id, :step_id, :task_id, :code, :message) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
The error message.
2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 |
# File 'lib/aws-sdk-deadline/types.rb', line 2148 class BatchUpdateTaskError < Struct.new( :farm_id, :queue_id, :job_id, :step_id, :task_id, :code, :message) SENSITIVE = [] include Aws::Structure end |
#queue_id ⇒ String
The queue ID of the task that could not be updated.
2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 |
# File 'lib/aws-sdk-deadline/types.rb', line 2148 class BatchUpdateTaskError < Struct.new( :farm_id, :queue_id, :job_id, :step_id, :task_id, :code, :message) SENSITIVE = [] include Aws::Structure end |
#step_id ⇒ String
The step ID of the task that could not be updated.
2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 |
# File 'lib/aws-sdk-deadline/types.rb', line 2148 class BatchUpdateTaskError < Struct.new( :farm_id, :queue_id, :job_id, :step_id, :task_id, :code, :message) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
The task ID of the task that could not be updated.
2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 |
# File 'lib/aws-sdk-deadline/types.rb', line 2148 class BatchUpdateTaskError < Struct.new( :farm_id, :queue_id, :job_id, :step_id, :task_id, :code, :message) SENSITIVE = [] include Aws::Structure end |