Class: Aws::Deadline::Types::CreateLimitRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::CreateLimitRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#amount_requirement_name ⇒ String
The value that you specify as the ‘name` in the `amounts` field of the `hostRequirements` in a step of a job template to declare the limit requirement.
-
#client_token ⇒ String
The unique token which the server uses to recognize retries of the same request.
-
#description ⇒ String
A description of the limit.
-
#display_name ⇒ String
The display name of the limit.
-
#farm_id ⇒ String
The farm ID of the farm that contains the limit.
-
#max_count ⇒ Integer
The maximum number of resources constrained by this limit.
Instance Attribute Details
#amount_requirement_name ⇒ String
The value that you specify as the ‘name` in the `amounts` field of the `hostRequirements` in a step of a job template to declare the limit requirement.
2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 |
# File 'lib/aws-sdk-deadline/types.rb', line 2962 class CreateLimitRequest < Struct.new( :farm_id, :client_token, :display_name, :amount_requirement_name, :max_count, :description) SENSITIVE = [:description] include Aws::Structure end |
#client_token ⇒ String
The unique token which the server uses to recognize retries of the same request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 |
# File 'lib/aws-sdk-deadline/types.rb', line 2962 class CreateLimitRequest < Struct.new( :farm_id, :client_token, :display_name, :amount_requirement_name, :max_count, :description) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
A description of the limit. A description helps you identify the purpose of the limit.
This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.
2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 |
# File 'lib/aws-sdk-deadline/types.rb', line 2962 class CreateLimitRequest < Struct.new( :farm_id, :client_token, :display_name, :amount_requirement_name, :max_count, :description) SENSITIVE = [:description] include Aws::Structure end |
#display_name ⇒ String
The display name of the limit.
This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.
2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 |
# File 'lib/aws-sdk-deadline/types.rb', line 2962 class CreateLimitRequest < Struct.new( :farm_id, :client_token, :display_name, :amount_requirement_name, :max_count, :description) SENSITIVE = [:description] include Aws::Structure end |
#farm_id ⇒ String
The farm ID of the farm that contains the limit.
2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 |
# File 'lib/aws-sdk-deadline/types.rb', line 2962 class CreateLimitRequest < Struct.new( :farm_id, :client_token, :display_name, :amount_requirement_name, :max_count, :description) SENSITIVE = [:description] include Aws::Structure end |
#max_count ⇒ Integer
The maximum number of resources constrained by this limit. When all of the resources are in use, steps that require the limit won’t be scheduled until the resource is available.
The ‘maxCount` must not be 0. If the value is -1, there is no restriction on the number of resources that can be acquired for this limit.
2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 |
# File 'lib/aws-sdk-deadline/types.rb', line 2962 class CreateLimitRequest < Struct.new( :farm_id, :client_token, :display_name, :amount_requirement_name, :max_count, :description) SENSITIVE = [:description] include Aws::Structure end |