Class: Aws::Deadline::Types::CreateMonitorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::CreateMonitorRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
The unique token which the server uses to recognize retries of the same request.
-
#display_name ⇒ String
The name that you give the monitor that is displayed in the Deadline Cloud console.
-
#identity_center_instance_arn ⇒ String
The Amazon Resource Name of the IAM Identity Center instance that authenticates monitor users.
-
#identity_center_region ⇒ String
The AWS region where IAM Identity Center is enabled.
-
#role_arn ⇒ String
The Amazon Resource Name of the IAM role that the monitor uses to connect to Deadline Cloud.
-
#subdomain ⇒ String
The subdomain to use when creating the monitor URL.
-
#tags ⇒ Hash<String,String>
The tags to add to your monitor.
Instance Attribute Details
#client_token ⇒ String
The unique token which the server uses to recognize retries of the same request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 |
# File 'lib/aws-sdk-deadline/types.rb', line 3033 class CreateMonitorRequest < Struct.new( :client_token, :display_name, :identity_center_instance_arn, :identity_center_region, :subdomain, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The name that you give the monitor that is displayed in the Deadline Cloud console.
This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.
3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 |
# File 'lib/aws-sdk-deadline/types.rb', line 3033 class CreateMonitorRequest < Struct.new( :client_token, :display_name, :identity_center_instance_arn, :identity_center_region, :subdomain, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#identity_center_instance_arn ⇒ String
The Amazon Resource Name of the IAM Identity Center instance that authenticates monitor users.
3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 |
# File 'lib/aws-sdk-deadline/types.rb', line 3033 class CreateMonitorRequest < Struct.new( :client_token, :display_name, :identity_center_instance_arn, :identity_center_region, :subdomain, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#identity_center_region ⇒ String
The AWS region where IAM Identity Center is enabled. Required when Identity Center is in a different region than the monitor.
3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 |
# File 'lib/aws-sdk-deadline/types.rb', line 3033 class CreateMonitorRequest < Struct.new( :client_token, :display_name, :identity_center_instance_arn, :identity_center_region, :subdomain, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name of the IAM role that the monitor uses to connect to Deadline Cloud. Every user that signs in to the monitor using IAM Identity Center uses this role to access Deadline Cloud resources.
3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 |
# File 'lib/aws-sdk-deadline/types.rb', line 3033 class CreateMonitorRequest < Struct.new( :client_token, :display_name, :identity_center_instance_arn, :identity_center_region, :subdomain, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#subdomain ⇒ String
The subdomain to use when creating the monitor URL. The full URL of the monitor is subdomain.Region.deadlinecloud.amazonaws.com.
3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 |
# File 'lib/aws-sdk-deadline/types.rb', line 3033 class CreateMonitorRequest < Struct.new( :client_token, :display_name, :identity_center_instance_arn, :identity_center_region, :subdomain, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to add to your monitor. Each tag consists of a tag key and a tag value. Tag keys and values are both required, but tag values can be empty strings.
3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 |
# File 'lib/aws-sdk-deadline/types.rb', line 3033 class CreateMonitorRequest < Struct.new( :client_token, :display_name, :identity_center_instance_arn, :identity_center_region, :subdomain, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |