Class: Aws::Deadline::Types::CreateQueueEnvironmentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::CreateQueueEnvironmentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:template]
Instance Attribute Summary collapse
-
#client_token ⇒ String
The unique token which the server uses to recognize retries of the same request.
-
#farm_id ⇒ String
The farm ID of the farm to connect to the environment.
-
#priority ⇒ Integer
Sets the priority of the environments in the queue from 0 to 10,000, where 0 is the highest priority (activated first and deactivated last).
-
#queue_id ⇒ String
The queue ID to connect the queue and environment.
-
#template ⇒ String
The environment template to use in the queue.
-
#template_type ⇒ String
The template’s file type, ‘JSON` or `YAML`.
Instance Attribute Details
#client_token ⇒ String
The unique token which the server uses to recognize retries of the same request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
3135 3136 3137 3138 3139 3140 3141 3142 3143 3144 |
# File 'lib/aws-sdk-deadline/types.rb', line 3135 class CreateQueueEnvironmentRequest < Struct.new( :farm_id, :queue_id, :client_token, :priority, :template_type, :template) SENSITIVE = [:template] include Aws::Structure end |
#farm_id ⇒ String
The farm ID of the farm to connect to the environment.
3135 3136 3137 3138 3139 3140 3141 3142 3143 3144 |
# File 'lib/aws-sdk-deadline/types.rb', line 3135 class CreateQueueEnvironmentRequest < Struct.new( :farm_id, :queue_id, :client_token, :priority, :template_type, :template) SENSITIVE = [:template] include Aws::Structure end |
#priority ⇒ Integer
Sets the priority of the environments in the queue from 0 to 10,000, where 0 is the highest priority (activated first and deactivated last). If two environments share the same priority value, the environment created first takes higher priority.
3135 3136 3137 3138 3139 3140 3141 3142 3143 3144 |
# File 'lib/aws-sdk-deadline/types.rb', line 3135 class CreateQueueEnvironmentRequest < Struct.new( :farm_id, :queue_id, :client_token, :priority, :template_type, :template) SENSITIVE = [:template] include Aws::Structure end |
#queue_id ⇒ String
The queue ID to connect the queue and environment.
3135 3136 3137 3138 3139 3140 3141 3142 3143 3144 |
# File 'lib/aws-sdk-deadline/types.rb', line 3135 class CreateQueueEnvironmentRequest < Struct.new( :farm_id, :queue_id, :client_token, :priority, :template_type, :template) SENSITIVE = [:template] include Aws::Structure end |
#template ⇒ String
The environment template to use in the queue.
3135 3136 3137 3138 3139 3140 3141 3142 3143 3144 |
# File 'lib/aws-sdk-deadline/types.rb', line 3135 class CreateQueueEnvironmentRequest < Struct.new( :farm_id, :queue_id, :client_token, :priority, :template_type, :template) SENSITIVE = [:template] include Aws::Structure end |
#template_type ⇒ String
The template’s file type, ‘JSON` or `YAML`.
3135 3136 3137 3138 3139 3140 3141 3142 3143 3144 |
# File 'lib/aws-sdk-deadline/types.rb', line 3135 class CreateQueueEnvironmentRequest < Struct.new( :farm_id, :queue_id, :client_token, :priority, :template_type, :template) SENSITIVE = [:template] include Aws::Structure end |