Method: Aws::Deadline::Types::CreateWorkerRequest#client_token
- Defined in:
- lib/aws-sdk-deadline/types.rb
#client_token ⇒ String
The unique token which the server uses to recognize retries of the same request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
1850 1851 1852 1853 1854 1855 1856 1857 1858 |
# File 'lib/aws-sdk-deadline/types.rb', line 1850 class CreateWorkerRequest < Struct.new( :farm_id, :fleet_id, :host_properties, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |