Class: Aws::Deadline::Types::CustomerManagedFleetConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::CustomerManagedFleetConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
The configuration details for a customer managed fleet.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_scaling_configuration ⇒ Types::CustomerManagedAutoScalingConfiguration
The auto scaling configuration settings for the customer managed fleet.
-
#mode ⇒ String
The Auto Scaling mode for the customer managed fleet.
-
#storage_profile_id ⇒ String
The storage profile ID for the customer managed fleet.
-
#tag_propagation_mode ⇒ String
The tag propagation mode for the customer managed fleet.
-
#worker_capabilities ⇒ Types::CustomerManagedWorkerCapabilities
The worker capabilities for the customer managed fleet.
Instance Attribute Details
#auto_scaling_configuration ⇒ Types::CustomerManagedAutoScalingConfiguration
The auto scaling configuration settings for the customer managed fleet.
3440 3441 3442 3443 3444 3445 3446 3447 3448 |
# File 'lib/aws-sdk-deadline/types.rb', line 3440 class CustomerManagedFleetConfiguration < Struct.new( :mode, :auto_scaling_configuration, :worker_capabilities, :storage_profile_id, :tag_propagation_mode) SENSITIVE = [] include Aws::Structure end |
#mode ⇒ String
The Auto Scaling mode for the customer managed fleet.
3440 3441 3442 3443 3444 3445 3446 3447 3448 |
# File 'lib/aws-sdk-deadline/types.rb', line 3440 class CustomerManagedFleetConfiguration < Struct.new( :mode, :auto_scaling_configuration, :worker_capabilities, :storage_profile_id, :tag_propagation_mode) SENSITIVE = [] include Aws::Structure end |
#storage_profile_id ⇒ String
The storage profile ID for the customer managed fleet.
3440 3441 3442 3443 3444 3445 3446 3447 3448 |
# File 'lib/aws-sdk-deadline/types.rb', line 3440 class CustomerManagedFleetConfiguration < Struct.new( :mode, :auto_scaling_configuration, :worker_capabilities, :storage_profile_id, :tag_propagation_mode) SENSITIVE = [] include Aws::Structure end |
#tag_propagation_mode ⇒ String
The tag propagation mode for the customer managed fleet.
3440 3441 3442 3443 3444 3445 3446 3447 3448 |
# File 'lib/aws-sdk-deadline/types.rb', line 3440 class CustomerManagedFleetConfiguration < Struct.new( :mode, :auto_scaling_configuration, :worker_capabilities, :storage_profile_id, :tag_propagation_mode) SENSITIVE = [] include Aws::Structure end |
#worker_capabilities ⇒ Types::CustomerManagedWorkerCapabilities
The worker capabilities for the customer managed fleet.
3440 3441 3442 3443 3444 3445 3446 3447 3448 |
# File 'lib/aws-sdk-deadline/types.rb', line 3440 class CustomerManagedFleetConfiguration < Struct.new( :mode, :auto_scaling_configuration, :worker_capabilities, :storage_profile_id, :tag_propagation_mode) SENSITIVE = [] include Aws::Structure end |