Class: Aws::Deadline::Types::FleetSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::FleetSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
The details of a fleet.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_scaling_status ⇒ String
The Auto Scaling status of a fleet.
-
#configuration ⇒ Types::FleetConfiguration
The configuration details for the fleet.
-
#created_at ⇒ Time
The date and time the resource was created.
-
#created_by ⇒ String
The user or system that created this resource.
-
#display_name ⇒ String
The display name of the fleet summary to update.
-
#farm_id ⇒ String
The farm ID.
-
#fleet_id ⇒ String
The fleet ID.
-
#max_worker_count ⇒ Integer
The maximum number of workers specified in the fleet.
-
#min_worker_count ⇒ Integer
The minimum number of workers in the fleet.
-
#status ⇒ String
The status of the fleet.
-
#status_message ⇒ String
A message that communicates a suspended status of the fleet.
-
#target_worker_count ⇒ Integer
The target number of workers in a fleet.
-
#updated_at ⇒ Time
The date and time the resource was updated.
-
#updated_by ⇒ String
The user or system that updated this resource.
-
#worker_count ⇒ Integer
The number of workers in the fleet summary.
Instance Attribute Details
#auto_scaling_status ⇒ String
The Auto Scaling status of a fleet.
4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 |
# File 'lib/aws-sdk-deadline/types.rb', line 4468 class FleetSummary < Struct.new( :fleet_id, :farm_id, :display_name, :status, :status_message, :auto_scaling_status, :target_worker_count, :worker_count, :min_worker_count, :max_worker_count, :configuration, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#configuration ⇒ Types::FleetConfiguration
The configuration details for the fleet.
4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 |
# File 'lib/aws-sdk-deadline/types.rb', line 4468 class FleetSummary < Struct.new( :fleet_id, :farm_id, :display_name, :status, :status_message, :auto_scaling_status, :target_worker_count, :worker_count, :min_worker_count, :max_worker_count, :configuration, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the resource was created.
4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 |
# File 'lib/aws-sdk-deadline/types.rb', line 4468 class FleetSummary < Struct.new( :fleet_id, :farm_id, :display_name, :status, :status_message, :auto_scaling_status, :target_worker_count, :worker_count, :min_worker_count, :max_worker_count, :configuration, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The user or system that created this resource.
4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 |
# File 'lib/aws-sdk-deadline/types.rb', line 4468 class FleetSummary < Struct.new( :fleet_id, :farm_id, :display_name, :status, :status_message, :auto_scaling_status, :target_worker_count, :worker_count, :min_worker_count, :max_worker_count, :configuration, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The display name of the fleet summary to update.
This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.
4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 |
# File 'lib/aws-sdk-deadline/types.rb', line 4468 class FleetSummary < Struct.new( :fleet_id, :farm_id, :display_name, :status, :status_message, :auto_scaling_status, :target_worker_count, :worker_count, :min_worker_count, :max_worker_count, :configuration, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#farm_id ⇒ String
The farm ID.
4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 |
# File 'lib/aws-sdk-deadline/types.rb', line 4468 class FleetSummary < Struct.new( :fleet_id, :farm_id, :display_name, :status, :status_message, :auto_scaling_status, :target_worker_count, :worker_count, :min_worker_count, :max_worker_count, :configuration, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#fleet_id ⇒ String
The fleet ID.
4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 |
# File 'lib/aws-sdk-deadline/types.rb', line 4468 class FleetSummary < Struct.new( :fleet_id, :farm_id, :display_name, :status, :status_message, :auto_scaling_status, :target_worker_count, :worker_count, :min_worker_count, :max_worker_count, :configuration, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#max_worker_count ⇒ Integer
The maximum number of workers specified in the fleet.
4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 |
# File 'lib/aws-sdk-deadline/types.rb', line 4468 class FleetSummary < Struct.new( :fleet_id, :farm_id, :display_name, :status, :status_message, :auto_scaling_status, :target_worker_count, :worker_count, :min_worker_count, :max_worker_count, :configuration, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#min_worker_count ⇒ Integer
The minimum number of workers in the fleet.
4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 |
# File 'lib/aws-sdk-deadline/types.rb', line 4468 class FleetSummary < Struct.new( :fleet_id, :farm_id, :display_name, :status, :status_message, :auto_scaling_status, :target_worker_count, :worker_count, :min_worker_count, :max_worker_count, :configuration, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the fleet.
4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 |
# File 'lib/aws-sdk-deadline/types.rb', line 4468 class FleetSummary < Struct.new( :fleet_id, :farm_id, :display_name, :status, :status_message, :auto_scaling_status, :target_worker_count, :worker_count, :min_worker_count, :max_worker_count, :configuration, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
A message that communicates a suspended status of the fleet.
4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 |
# File 'lib/aws-sdk-deadline/types.rb', line 4468 class FleetSummary < Struct.new( :fleet_id, :farm_id, :display_name, :status, :status_message, :auto_scaling_status, :target_worker_count, :worker_count, :min_worker_count, :max_worker_count, :configuration, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#target_worker_count ⇒ Integer
The target number of workers in a fleet.
4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 |
# File 'lib/aws-sdk-deadline/types.rb', line 4468 class FleetSummary < Struct.new( :fleet_id, :farm_id, :display_name, :status, :status_message, :auto_scaling_status, :target_worker_count, :worker_count, :min_worker_count, :max_worker_count, :configuration, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the resource was updated.
4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 |
# File 'lib/aws-sdk-deadline/types.rb', line 4468 class FleetSummary < Struct.new( :fleet_id, :farm_id, :display_name, :status, :status_message, :auto_scaling_status, :target_worker_count, :worker_count, :min_worker_count, :max_worker_count, :configuration, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#updated_by ⇒ String
The user or system that updated this resource.
4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 |
# File 'lib/aws-sdk-deadline/types.rb', line 4468 class FleetSummary < Struct.new( :fleet_id, :farm_id, :display_name, :status, :status_message, :auto_scaling_status, :target_worker_count, :worker_count, :min_worker_count, :max_worker_count, :configuration, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#worker_count ⇒ Integer
The number of workers in the fleet summary.
4468 4469 4470 4471 4472 4473 4474 4475 4476 4477 4478 4479 4480 4481 4482 4483 4484 4485 4486 |
# File 'lib/aws-sdk-deadline/types.rb', line 4468 class FleetSummary < Struct.new( :fleet_id, :farm_id, :display_name, :status, :status_message, :auto_scaling_status, :target_worker_count, :worker_count, :min_worker_count, :max_worker_count, :configuration, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |