Class: Aws::Deadline::Types::GetFleetResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Mixin that adds an optional ARN field to response structures. Apply to SummaryMixins (flows into Get, Summary, and BatchGet) and Create outputs.

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_scaling_statusString

The Auto Scaling status of the fleet. Either ‘GROWING`, `STEADY`, or `SHRINKING`.

Returns:

  • (String)


4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
# File 'lib/aws-sdk-deadline/types.rb', line 4838

class GetFleetResponse < Struct.new(
  :fleet_id,
  :farm_id,
  :display_name,
  :status,
  :status_message,
  :auto_scaling_status,
  :target_worker_count,
  :worker_count,
  :min_worker_count,
  :max_worker_count,
  :configuration,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :host_configuration,
  :capabilities,
  :role_arn)
  SENSITIVE = [:description]
  include Aws::Structure
end

#capabilitiesTypes::FleetCapabilities

Outlines what the fleet is capable of for minimums, maximums, and naming, in addition to attribute names and values.



4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
# File 'lib/aws-sdk-deadline/types.rb', line 4838

class GetFleetResponse < Struct.new(
  :fleet_id,
  :farm_id,
  :display_name,
  :status,
  :status_message,
  :auto_scaling_status,
  :target_worker_count,
  :worker_count,
  :min_worker_count,
  :max_worker_count,
  :configuration,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :host_configuration,
  :capabilities,
  :role_arn)
  SENSITIVE = [:description]
  include Aws::Structure
end

#configurationTypes::FleetConfiguration

The configuration setting for the fleet.



4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
# File 'lib/aws-sdk-deadline/types.rb', line 4838

class GetFleetResponse < Struct.new(
  :fleet_id,
  :farm_id,
  :display_name,
  :status,
  :status_message,
  :auto_scaling_status,
  :target_worker_count,
  :worker_count,
  :min_worker_count,
  :max_worker_count,
  :configuration,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :host_configuration,
  :capabilities,
  :role_arn)
  SENSITIVE = [:description]
  include Aws::Structure
end

#created_atTime

The date and time the resource was created.

Returns:

  • (Time)


4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
# File 'lib/aws-sdk-deadline/types.rb', line 4838

class GetFleetResponse < Struct.new(
  :fleet_id,
  :farm_id,
  :display_name,
  :status,
  :status_message,
  :auto_scaling_status,
  :target_worker_count,
  :worker_count,
  :min_worker_count,
  :max_worker_count,
  :configuration,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :host_configuration,
  :capabilities,
  :role_arn)
  SENSITIVE = [:description]
  include Aws::Structure
end

#created_byString

The user or system that created this resource.

Returns:

  • (String)


4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
# File 'lib/aws-sdk-deadline/types.rb', line 4838

class GetFleetResponse < Struct.new(
  :fleet_id,
  :farm_id,
  :display_name,
  :status,
  :status_message,
  :auto_scaling_status,
  :target_worker_count,
  :worker_count,
  :min_worker_count,
  :max_worker_count,
  :configuration,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :host_configuration,
  :capabilities,
  :role_arn)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

The description of the fleet.

This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.

Returns:

  • (String)


4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
# File 'lib/aws-sdk-deadline/types.rb', line 4838

class GetFleetResponse < Struct.new(
  :fleet_id,
  :farm_id,
  :display_name,
  :status,
  :status_message,
  :auto_scaling_status,
  :target_worker_count,
  :worker_count,
  :min_worker_count,
  :max_worker_count,
  :configuration,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :host_configuration,
  :capabilities,
  :role_arn)
  SENSITIVE = [:description]
  include Aws::Structure
end

#display_nameString

The display name of the fleet.

This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.

Returns:

  • (String)


4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
# File 'lib/aws-sdk-deadline/types.rb', line 4838

class GetFleetResponse < Struct.new(
  :fleet_id,
  :farm_id,
  :display_name,
  :status,
  :status_message,
  :auto_scaling_status,
  :target_worker_count,
  :worker_count,
  :min_worker_count,
  :max_worker_count,
  :configuration,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :host_configuration,
  :capabilities,
  :role_arn)
  SENSITIVE = [:description]
  include Aws::Structure
end

#farm_idString

The farm ID of the farm in the fleet.

Returns:

  • (String)


4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
# File 'lib/aws-sdk-deadline/types.rb', line 4838

class GetFleetResponse < Struct.new(
  :fleet_id,
  :farm_id,
  :display_name,
  :status,
  :status_message,
  :auto_scaling_status,
  :target_worker_count,
  :worker_count,
  :min_worker_count,
  :max_worker_count,
  :configuration,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :host_configuration,
  :capabilities,
  :role_arn)
  SENSITIVE = [:description]
  include Aws::Structure
end

#fleet_idString

The fleet ID.

Returns:

  • (String)


4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
# File 'lib/aws-sdk-deadline/types.rb', line 4838

class GetFleetResponse < Struct.new(
  :fleet_id,
  :farm_id,
  :display_name,
  :status,
  :status_message,
  :auto_scaling_status,
  :target_worker_count,
  :worker_count,
  :min_worker_count,
  :max_worker_count,
  :configuration,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :host_configuration,
  :capabilities,
  :role_arn)
  SENSITIVE = [:description]
  include Aws::Structure
end

#host_configurationTypes::HostConfiguration

The script that runs as a worker is starting up that you can use to provide additional configuration for workers in your fleet.



4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
# File 'lib/aws-sdk-deadline/types.rb', line 4838

class GetFleetResponse < Struct.new(
  :fleet_id,
  :farm_id,
  :display_name,
  :status,
  :status_message,
  :auto_scaling_status,
  :target_worker_count,
  :worker_count,
  :min_worker_count,
  :max_worker_count,
  :configuration,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :host_configuration,
  :capabilities,
  :role_arn)
  SENSITIVE = [:description]
  include Aws::Structure
end

#max_worker_countInteger

The maximum number of workers specified in the fleet.

Returns:

  • (Integer)


4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
# File 'lib/aws-sdk-deadline/types.rb', line 4838

class GetFleetResponse < Struct.new(
  :fleet_id,
  :farm_id,
  :display_name,
  :status,
  :status_message,
  :auto_scaling_status,
  :target_worker_count,
  :worker_count,
  :min_worker_count,
  :max_worker_count,
  :configuration,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :host_configuration,
  :capabilities,
  :role_arn)
  SENSITIVE = [:description]
  include Aws::Structure
end

#min_worker_countInteger

The minimum number of workers specified in the fleet.

Returns:

  • (Integer)


4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
# File 'lib/aws-sdk-deadline/types.rb', line 4838

class GetFleetResponse < Struct.new(
  :fleet_id,
  :farm_id,
  :display_name,
  :status,
  :status_message,
  :auto_scaling_status,
  :target_worker_count,
  :worker_count,
  :min_worker_count,
  :max_worker_count,
  :configuration,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :host_configuration,
  :capabilities,
  :role_arn)
  SENSITIVE = [:description]
  include Aws::Structure
end

#role_arnString

The IAM role ARN.

Returns:

  • (String)


4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
# File 'lib/aws-sdk-deadline/types.rb', line 4838

class GetFleetResponse < Struct.new(
  :fleet_id,
  :farm_id,
  :display_name,
  :status,
  :status_message,
  :auto_scaling_status,
  :target_worker_count,
  :worker_count,
  :min_worker_count,
  :max_worker_count,
  :configuration,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :host_configuration,
  :capabilities,
  :role_arn)
  SENSITIVE = [:description]
  include Aws::Structure
end

#statusString

The status of the fleet.

Returns:

  • (String)


4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
# File 'lib/aws-sdk-deadline/types.rb', line 4838

class GetFleetResponse < Struct.new(
  :fleet_id,
  :farm_id,
  :display_name,
  :status,
  :status_message,
  :auto_scaling_status,
  :target_worker_count,
  :worker_count,
  :min_worker_count,
  :max_worker_count,
  :configuration,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :host_configuration,
  :capabilities,
  :role_arn)
  SENSITIVE = [:description]
  include Aws::Structure
end

#status_messageString

A message that communicates a suspended status of the fleet.

Returns:

  • (String)


4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
# File 'lib/aws-sdk-deadline/types.rb', line 4838

class GetFleetResponse < Struct.new(
  :fleet_id,
  :farm_id,
  :display_name,
  :status,
  :status_message,
  :auto_scaling_status,
  :target_worker_count,
  :worker_count,
  :min_worker_count,
  :max_worker_count,
  :configuration,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :host_configuration,
  :capabilities,
  :role_arn)
  SENSITIVE = [:description]
  include Aws::Structure
end

#target_worker_countInteger

The number of target workers in the fleet.

Returns:

  • (Integer)


4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
# File 'lib/aws-sdk-deadline/types.rb', line 4838

class GetFleetResponse < Struct.new(
  :fleet_id,
  :farm_id,
  :display_name,
  :status,
  :status_message,
  :auto_scaling_status,
  :target_worker_count,
  :worker_count,
  :min_worker_count,
  :max_worker_count,
  :configuration,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :host_configuration,
  :capabilities,
  :role_arn)
  SENSITIVE = [:description]
  include Aws::Structure
end

#updated_atTime

The date and time the resource was updated.

Returns:

  • (Time)


4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
# File 'lib/aws-sdk-deadline/types.rb', line 4838

class GetFleetResponse < Struct.new(
  :fleet_id,
  :farm_id,
  :display_name,
  :status,
  :status_message,
  :auto_scaling_status,
  :target_worker_count,
  :worker_count,
  :min_worker_count,
  :max_worker_count,
  :configuration,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :host_configuration,
  :capabilities,
  :role_arn)
  SENSITIVE = [:description]
  include Aws::Structure
end

#updated_byString

The user or system that updated this resource.

Returns:

  • (String)


4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
# File 'lib/aws-sdk-deadline/types.rb', line 4838

class GetFleetResponse < Struct.new(
  :fleet_id,
  :farm_id,
  :display_name,
  :status,
  :status_message,
  :auto_scaling_status,
  :target_worker_count,
  :worker_count,
  :min_worker_count,
  :max_worker_count,
  :configuration,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :host_configuration,
  :capabilities,
  :role_arn)
  SENSITIVE = [:description]
  include Aws::Structure
end

#worker_countInteger

The number of workers in the fleet.

Returns:

  • (Integer)


4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
4852
4853
4854
4855
4856
4857
4858
4859
4860
# File 'lib/aws-sdk-deadline/types.rb', line 4838

class GetFleetResponse < Struct.new(
  :fleet_id,
  :farm_id,
  :display_name,
  :status,
  :status_message,
  :auto_scaling_status,
  :target_worker_count,
  :worker_count,
  :min_worker_count,
  :max_worker_count,
  :configuration,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :host_configuration,
  :capabilities,
  :role_arn)
  SENSITIVE = [:description]
  include Aws::Structure
end