Class: Aws::Deadline::Types::GetQueueLimitAssociationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::GetQueueLimitAssociationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#farm_id ⇒ String
The unique identifier of the farm that contains the associated queue and limit.
-
#limit_id ⇒ String
The unique identifier of the limit associated with the queue.
-
#queue_id ⇒ String
The unique identifier of the queue associated with the limit.
Instance Attribute Details
#farm_id ⇒ String
The unique identifier of the farm that contains the associated queue and limit.
3829 3830 3831 3832 3833 3834 3835 |
# File 'lib/aws-sdk-deadline/types.rb', line 3829 class GetQueueLimitAssociationRequest < Struct.new( :farm_id, :queue_id, :limit_id) SENSITIVE = [] include Aws::Structure end |
#limit_id ⇒ String
The unique identifier of the limit associated with the queue.
3829 3830 3831 3832 3833 3834 3835 |
# File 'lib/aws-sdk-deadline/types.rb', line 3829 class GetQueueLimitAssociationRequest < Struct.new( :farm_id, :queue_id, :limit_id) SENSITIVE = [] include Aws::Structure end |
#queue_id ⇒ String
The unique identifier of the queue associated with the limit.
3829 3830 3831 3832 3833 3834 3835 |
# File 'lib/aws-sdk-deadline/types.rb', line 3829 class GetQueueLimitAssociationRequest < Struct.new( :farm_id, :queue_id, :limit_id) SENSITIVE = [] include Aws::Structure end |