Class: Aws::Deadline::Types::GetQueueResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Mixin that adds an optional ARN field to response structures. Apply to SummaryMixins (flows into Get, Summary, and BatchGet) and Create outputs.

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_storage_profile_idsArray<String>

The storage profile IDs for the queue.

Returns:

  • (Array<String>)


5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
5634
5635
# File 'lib/aws-sdk-deadline/types.rb', line 5615

class GetQueueResponse < Struct.new(
  :farm_id,
  :queue_id,
  :display_name,
  :status,
  :default_budget_action,
  :blocked_reason,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :job_attachment_settings,
  :role_arn,
  :required_file_system_location_names,
  :allowed_storage_profile_ids,
  :job_run_as_user,
  :scheduling_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#blocked_reasonString

The reason the queue was blocked.

Returns:

  • (String)


5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
5634
5635
# File 'lib/aws-sdk-deadline/types.rb', line 5615

class GetQueueResponse < Struct.new(
  :farm_id,
  :queue_id,
  :display_name,
  :status,
  :default_budget_action,
  :blocked_reason,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :job_attachment_settings,
  :role_arn,
  :required_file_system_location_names,
  :allowed_storage_profile_ids,
  :job_run_as_user,
  :scheduling_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#created_atTime

The date and time the resource was created.

Returns:

  • (Time)


5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
5634
5635
# File 'lib/aws-sdk-deadline/types.rb', line 5615

class GetQueueResponse < Struct.new(
  :farm_id,
  :queue_id,
  :display_name,
  :status,
  :default_budget_action,
  :blocked_reason,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :job_attachment_settings,
  :role_arn,
  :required_file_system_location_names,
  :allowed_storage_profile_ids,
  :job_run_as_user,
  :scheduling_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#created_byString

The user or system that created this resource.

Returns:

  • (String)


5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
5634
5635
# File 'lib/aws-sdk-deadline/types.rb', line 5615

class GetQueueResponse < Struct.new(
  :farm_id,
  :queue_id,
  :display_name,
  :status,
  :default_budget_action,
  :blocked_reason,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :job_attachment_settings,
  :role_arn,
  :required_file_system_location_names,
  :allowed_storage_profile_ids,
  :job_run_as_user,
  :scheduling_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#default_budget_actionString

The default action taken on a queue if a budget wasn’t configured.

Returns:

  • (String)


5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
5634
5635
# File 'lib/aws-sdk-deadline/types.rb', line 5615

class GetQueueResponse < Struct.new(
  :farm_id,
  :queue_id,
  :display_name,
  :status,
  :default_budget_action,
  :blocked_reason,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :job_attachment_settings,
  :role_arn,
  :required_file_system_location_names,
  :allowed_storage_profile_ids,
  :job_run_as_user,
  :scheduling_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

The description of the queue.

This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.

Returns:

  • (String)


5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
5634
5635
# File 'lib/aws-sdk-deadline/types.rb', line 5615

class GetQueueResponse < Struct.new(
  :farm_id,
  :queue_id,
  :display_name,
  :status,
  :default_budget_action,
  :blocked_reason,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :job_attachment_settings,
  :role_arn,
  :required_file_system_location_names,
  :allowed_storage_profile_ids,
  :job_run_as_user,
  :scheduling_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#display_nameString

The display name of the queue.

This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.

Returns:

  • (String)


5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
5634
5635
# File 'lib/aws-sdk-deadline/types.rb', line 5615

class GetQueueResponse < Struct.new(
  :farm_id,
  :queue_id,
  :display_name,
  :status,
  :default_budget_action,
  :blocked_reason,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :job_attachment_settings,
  :role_arn,
  :required_file_system_location_names,
  :allowed_storage_profile_ids,
  :job_run_as_user,
  :scheduling_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#farm_idString

The farm ID for the queue.

Returns:

  • (String)


5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
5634
5635
# File 'lib/aws-sdk-deadline/types.rb', line 5615

class GetQueueResponse < Struct.new(
  :farm_id,
  :queue_id,
  :display_name,
  :status,
  :default_budget_action,
  :blocked_reason,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :job_attachment_settings,
  :role_arn,
  :required_file_system_location_names,
  :allowed_storage_profile_ids,
  :job_run_as_user,
  :scheduling_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#job_attachment_settingsTypes::JobAttachmentSettings

The job attachment settings for the queue.



5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
5634
5635
# File 'lib/aws-sdk-deadline/types.rb', line 5615

class GetQueueResponse < Struct.new(
  :farm_id,
  :queue_id,
  :display_name,
  :status,
  :default_budget_action,
  :blocked_reason,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :job_attachment_settings,
  :role_arn,
  :required_file_system_location_names,
  :allowed_storage_profile_ids,
  :job_run_as_user,
  :scheduling_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#job_run_as_userTypes::JobRunAsUser

The jobs in the queue ran as this specified POSIX user.

Returns:



5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
5634
5635
# File 'lib/aws-sdk-deadline/types.rb', line 5615

class GetQueueResponse < Struct.new(
  :farm_id,
  :queue_id,
  :display_name,
  :status,
  :default_budget_action,
  :blocked_reason,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :job_attachment_settings,
  :role_arn,
  :required_file_system_location_names,
  :allowed_storage_profile_ids,
  :job_run_as_user,
  :scheduling_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#queue_idString

The queue ID.

Returns:

  • (String)


5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
5634
5635
# File 'lib/aws-sdk-deadline/types.rb', line 5615

class GetQueueResponse < Struct.new(
  :farm_id,
  :queue_id,
  :display_name,
  :status,
  :default_budget_action,
  :blocked_reason,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :job_attachment_settings,
  :role_arn,
  :required_file_system_location_names,
  :allowed_storage_profile_ids,
  :job_run_as_user,
  :scheduling_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#required_file_system_location_namesArray<String>

A list of the required file system location names in the queue.

Returns:

  • (Array<String>)


5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
5634
5635
# File 'lib/aws-sdk-deadline/types.rb', line 5615

class GetQueueResponse < Struct.new(
  :farm_id,
  :queue_id,
  :display_name,
  :status,
  :default_budget_action,
  :blocked_reason,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :job_attachment_settings,
  :role_arn,
  :required_file_system_location_names,
  :allowed_storage_profile_ids,
  :job_run_as_user,
  :scheduling_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#role_arnString

The IAM role ARN.

Returns:

  • (String)


5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
5634
5635
# File 'lib/aws-sdk-deadline/types.rb', line 5615

class GetQueueResponse < Struct.new(
  :farm_id,
  :queue_id,
  :display_name,
  :status,
  :default_budget_action,
  :blocked_reason,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :job_attachment_settings,
  :role_arn,
  :required_file_system_location_names,
  :allowed_storage_profile_ids,
  :job_run_as_user,
  :scheduling_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#scheduling_configurationTypes::SchedulingConfiguration

The scheduling configuration for the queue. This configuration determines how workers are assigned to jobs in the queue.



5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
5634
5635
# File 'lib/aws-sdk-deadline/types.rb', line 5615

class GetQueueResponse < Struct.new(
  :farm_id,
  :queue_id,
  :display_name,
  :status,
  :default_budget_action,
  :blocked_reason,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :job_attachment_settings,
  :role_arn,
  :required_file_system_location_names,
  :allowed_storage_profile_ids,
  :job_run_as_user,
  :scheduling_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#statusString

The status of the queue.

  • ‘ACTIVE`–The queue is active.

  • ‘SCHEDULING`–The queue is scheduling.

  • ‘SCHEDULING_BLOCKED`–The queue scheduling is blocked. See the provided reason.

Returns:

  • (String)


5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
5634
5635
# File 'lib/aws-sdk-deadline/types.rb', line 5615

class GetQueueResponse < Struct.new(
  :farm_id,
  :queue_id,
  :display_name,
  :status,
  :default_budget_action,
  :blocked_reason,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :job_attachment_settings,
  :role_arn,
  :required_file_system_location_names,
  :allowed_storage_profile_ids,
  :job_run_as_user,
  :scheduling_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#updated_atTime

The date and time the resource was updated.

Returns:

  • (Time)


5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
5634
5635
# File 'lib/aws-sdk-deadline/types.rb', line 5615

class GetQueueResponse < Struct.new(
  :farm_id,
  :queue_id,
  :display_name,
  :status,
  :default_budget_action,
  :blocked_reason,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :job_attachment_settings,
  :role_arn,
  :required_file_system_location_names,
  :allowed_storage_profile_ids,
  :job_run_as_user,
  :scheduling_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end

#updated_byString

The user or system that updated this resource.

Returns:

  • (String)


5615
5616
5617
5618
5619
5620
5621
5622
5623
5624
5625
5626
5627
5628
5629
5630
5631
5632
5633
5634
5635
# File 'lib/aws-sdk-deadline/types.rb', line 5615

class GetQueueResponse < Struct.new(
  :farm_id,
  :queue_id,
  :display_name,
  :status,
  :default_budget_action,
  :blocked_reason,
  :created_at,
  :created_by,
  :updated_at,
  :updated_by,
  :description,
  :job_attachment_settings,
  :role_arn,
  :required_file_system_location_names,
  :allowed_storage_profile_ids,
  :job_run_as_user,
  :scheduling_configuration)
  SENSITIVE = [:description]
  include Aws::Structure
end