Class: Aws::Deadline::Types::GetQueueResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::GetQueueResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Mixin that adds an optional ARN field to response structures. Apply to SummaryMixins (flows into Get, Summary, and BatchGet) and Create outputs.
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#allowed_storage_profile_ids ⇒ Array<String>
The storage profile IDs for the queue.
-
#blocked_reason ⇒ String
The reason the queue was blocked.
-
#created_at ⇒ Time
The date and time the resource was created.
-
#created_by ⇒ String
The user or system that created this resource.
-
#default_budget_action ⇒ String
The default action taken on a queue if a budget wasn’t configured.
-
#description ⇒ String
The description of the queue.
-
#display_name ⇒ String
The display name of the queue.
-
#farm_id ⇒ String
The farm ID for the queue.
-
#job_attachment_settings ⇒ Types::JobAttachmentSettings
The job attachment settings for the queue.
-
#job_run_as_user ⇒ Types::JobRunAsUser
The jobs in the queue ran as this specified POSIX user.
-
#queue_id ⇒ String
The queue ID.
-
#required_file_system_location_names ⇒ Array<String>
A list of the required file system location names in the queue.
-
#role_arn ⇒ String
The IAM role ARN.
-
#scheduling_configuration ⇒ Types::SchedulingConfiguration
The scheduling configuration for the queue.
-
#status ⇒ String
The status of the queue.
-
#updated_at ⇒ Time
The date and time the resource was updated.
-
#updated_by ⇒ String
The user or system that updated this resource.
Instance Attribute Details
#allowed_storage_profile_ids ⇒ Array<String>
The storage profile IDs for the queue.
5605 5606 5607 5608 5609 5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 5624 5625 |
# File 'lib/aws-sdk-deadline/types.rb', line 5605 class GetQueueResponse < Struct.new( :farm_id, :queue_id, :display_name, :status, :default_budget_action, :blocked_reason, :created_at, :created_by, :updated_at, :updated_by, :description, :job_attachment_settings, :role_arn, :required_file_system_location_names, :allowed_storage_profile_ids, :job_run_as_user, :scheduling_configuration) SENSITIVE = [:description] include Aws::Structure end |
#blocked_reason ⇒ String
The reason the queue was blocked.
5605 5606 5607 5608 5609 5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 5624 5625 |
# File 'lib/aws-sdk-deadline/types.rb', line 5605 class GetQueueResponse < Struct.new( :farm_id, :queue_id, :display_name, :status, :default_budget_action, :blocked_reason, :created_at, :created_by, :updated_at, :updated_by, :description, :job_attachment_settings, :role_arn, :required_file_system_location_names, :allowed_storage_profile_ids, :job_run_as_user, :scheduling_configuration) SENSITIVE = [:description] include Aws::Structure end |
#created_at ⇒ Time
The date and time the resource was created.
5605 5606 5607 5608 5609 5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 5624 5625 |
# File 'lib/aws-sdk-deadline/types.rb', line 5605 class GetQueueResponse < Struct.new( :farm_id, :queue_id, :display_name, :status, :default_budget_action, :blocked_reason, :created_at, :created_by, :updated_at, :updated_by, :description, :job_attachment_settings, :role_arn, :required_file_system_location_names, :allowed_storage_profile_ids, :job_run_as_user, :scheduling_configuration) SENSITIVE = [:description] include Aws::Structure end |
#created_by ⇒ String
The user or system that created this resource.
5605 5606 5607 5608 5609 5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 5624 5625 |
# File 'lib/aws-sdk-deadline/types.rb', line 5605 class GetQueueResponse < Struct.new( :farm_id, :queue_id, :display_name, :status, :default_budget_action, :blocked_reason, :created_at, :created_by, :updated_at, :updated_by, :description, :job_attachment_settings, :role_arn, :required_file_system_location_names, :allowed_storage_profile_ids, :job_run_as_user, :scheduling_configuration) SENSITIVE = [:description] include Aws::Structure end |
#default_budget_action ⇒ String
The default action taken on a queue if a budget wasn’t configured.
5605 5606 5607 5608 5609 5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 5624 5625 |
# File 'lib/aws-sdk-deadline/types.rb', line 5605 class GetQueueResponse < Struct.new( :farm_id, :queue_id, :display_name, :status, :default_budget_action, :blocked_reason, :created_at, :created_by, :updated_at, :updated_by, :description, :job_attachment_settings, :role_arn, :required_file_system_location_names, :allowed_storage_profile_ids, :job_run_as_user, :scheduling_configuration) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
The description of the queue.
This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.
5605 5606 5607 5608 5609 5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 5624 5625 |
# File 'lib/aws-sdk-deadline/types.rb', line 5605 class GetQueueResponse < Struct.new( :farm_id, :queue_id, :display_name, :status, :default_budget_action, :blocked_reason, :created_at, :created_by, :updated_at, :updated_by, :description, :job_attachment_settings, :role_arn, :required_file_system_location_names, :allowed_storage_profile_ids, :job_run_as_user, :scheduling_configuration) SENSITIVE = [:description] include Aws::Structure end |
#display_name ⇒ String
The display name of the queue.
This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.
5605 5606 5607 5608 5609 5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 5624 5625 |
# File 'lib/aws-sdk-deadline/types.rb', line 5605 class GetQueueResponse < Struct.new( :farm_id, :queue_id, :display_name, :status, :default_budget_action, :blocked_reason, :created_at, :created_by, :updated_at, :updated_by, :description, :job_attachment_settings, :role_arn, :required_file_system_location_names, :allowed_storage_profile_ids, :job_run_as_user, :scheduling_configuration) SENSITIVE = [:description] include Aws::Structure end |
#farm_id ⇒ String
The farm ID for the queue.
5605 5606 5607 5608 5609 5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 5624 5625 |
# File 'lib/aws-sdk-deadline/types.rb', line 5605 class GetQueueResponse < Struct.new( :farm_id, :queue_id, :display_name, :status, :default_budget_action, :blocked_reason, :created_at, :created_by, :updated_at, :updated_by, :description, :job_attachment_settings, :role_arn, :required_file_system_location_names, :allowed_storage_profile_ids, :job_run_as_user, :scheduling_configuration) SENSITIVE = [:description] include Aws::Structure end |
#job_attachment_settings ⇒ Types::JobAttachmentSettings
The job attachment settings for the queue.
5605 5606 5607 5608 5609 5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 5624 5625 |
# File 'lib/aws-sdk-deadline/types.rb', line 5605 class GetQueueResponse < Struct.new( :farm_id, :queue_id, :display_name, :status, :default_budget_action, :blocked_reason, :created_at, :created_by, :updated_at, :updated_by, :description, :job_attachment_settings, :role_arn, :required_file_system_location_names, :allowed_storage_profile_ids, :job_run_as_user, :scheduling_configuration) SENSITIVE = [:description] include Aws::Structure end |
#job_run_as_user ⇒ Types::JobRunAsUser
The jobs in the queue ran as this specified POSIX user.
5605 5606 5607 5608 5609 5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 5624 5625 |
# File 'lib/aws-sdk-deadline/types.rb', line 5605 class GetQueueResponse < Struct.new( :farm_id, :queue_id, :display_name, :status, :default_budget_action, :blocked_reason, :created_at, :created_by, :updated_at, :updated_by, :description, :job_attachment_settings, :role_arn, :required_file_system_location_names, :allowed_storage_profile_ids, :job_run_as_user, :scheduling_configuration) SENSITIVE = [:description] include Aws::Structure end |
#queue_id ⇒ String
The queue ID.
5605 5606 5607 5608 5609 5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 5624 5625 |
# File 'lib/aws-sdk-deadline/types.rb', line 5605 class GetQueueResponse < Struct.new( :farm_id, :queue_id, :display_name, :status, :default_budget_action, :blocked_reason, :created_at, :created_by, :updated_at, :updated_by, :description, :job_attachment_settings, :role_arn, :required_file_system_location_names, :allowed_storage_profile_ids, :job_run_as_user, :scheduling_configuration) SENSITIVE = [:description] include Aws::Structure end |
#required_file_system_location_names ⇒ Array<String>
A list of the required file system location names in the queue.
5605 5606 5607 5608 5609 5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 5624 5625 |
# File 'lib/aws-sdk-deadline/types.rb', line 5605 class GetQueueResponse < Struct.new( :farm_id, :queue_id, :display_name, :status, :default_budget_action, :blocked_reason, :created_at, :created_by, :updated_at, :updated_by, :description, :job_attachment_settings, :role_arn, :required_file_system_location_names, :allowed_storage_profile_ids, :job_run_as_user, :scheduling_configuration) SENSITIVE = [:description] include Aws::Structure end |
#role_arn ⇒ String
The IAM role ARN.
5605 5606 5607 5608 5609 5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 5624 5625 |
# File 'lib/aws-sdk-deadline/types.rb', line 5605 class GetQueueResponse < Struct.new( :farm_id, :queue_id, :display_name, :status, :default_budget_action, :blocked_reason, :created_at, :created_by, :updated_at, :updated_by, :description, :job_attachment_settings, :role_arn, :required_file_system_location_names, :allowed_storage_profile_ids, :job_run_as_user, :scheduling_configuration) SENSITIVE = [:description] include Aws::Structure end |
#scheduling_configuration ⇒ Types::SchedulingConfiguration
The scheduling configuration for the queue. This configuration determines how workers are assigned to jobs in the queue.
5605 5606 5607 5608 5609 5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 5624 5625 |
# File 'lib/aws-sdk-deadline/types.rb', line 5605 class GetQueueResponse < Struct.new( :farm_id, :queue_id, :display_name, :status, :default_budget_action, :blocked_reason, :created_at, :created_by, :updated_at, :updated_by, :description, :job_attachment_settings, :role_arn, :required_file_system_location_names, :allowed_storage_profile_ids, :job_run_as_user, :scheduling_configuration) SENSITIVE = [:description] include Aws::Structure end |
#status ⇒ String
The status of the queue.
-
‘ACTIVE`–The queue is active.
-
‘SCHEDULING`–The queue is scheduling.
-
‘SCHEDULING_BLOCKED`–The queue scheduling is blocked. See the provided reason.
5605 5606 5607 5608 5609 5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 5624 5625 |
# File 'lib/aws-sdk-deadline/types.rb', line 5605 class GetQueueResponse < Struct.new( :farm_id, :queue_id, :display_name, :status, :default_budget_action, :blocked_reason, :created_at, :created_by, :updated_at, :updated_by, :description, :job_attachment_settings, :role_arn, :required_file_system_location_names, :allowed_storage_profile_ids, :job_run_as_user, :scheduling_configuration) SENSITIVE = [:description] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the resource was updated.
5605 5606 5607 5608 5609 5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 5624 5625 |
# File 'lib/aws-sdk-deadline/types.rb', line 5605 class GetQueueResponse < Struct.new( :farm_id, :queue_id, :display_name, :status, :default_budget_action, :blocked_reason, :created_at, :created_by, :updated_at, :updated_by, :description, :job_attachment_settings, :role_arn, :required_file_system_location_names, :allowed_storage_profile_ids, :job_run_as_user, :scheduling_configuration) SENSITIVE = [:description] include Aws::Structure end |
#updated_by ⇒ String
The user or system that updated this resource.
5605 5606 5607 5608 5609 5610 5611 5612 5613 5614 5615 5616 5617 5618 5619 5620 5621 5622 5623 5624 5625 |
# File 'lib/aws-sdk-deadline/types.rb', line 5605 class GetQueueResponse < Struct.new( :farm_id, :queue_id, :display_name, :status, :default_budget_action, :blocked_reason, :created_at, :created_by, :updated_at, :updated_by, :description, :job_attachment_settings, :role_arn, :required_file_system_location_names, :allowed_storage_profile_ids, :job_run_as_user, :scheduling_configuration) SENSITIVE = [:description] include Aws::Structure end |