Class: Aws::Deadline::Types::GetStepResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::GetStepResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The date and time the resource was created.
-
#created_by ⇒ String
The user or system that created this resource.
-
#dependency_counts ⇒ Types::DependencyCounts
The number of dependencies in the step.
-
#description ⇒ String
The description of the step.
-
#ended_at ⇒ Time
The date and time the resource ended running.
-
#lifecycle_status ⇒ String
The life cycle status of the step.
-
#lifecycle_status_message ⇒ String
A message that describes the lifecycle status of the step.
-
#name ⇒ String
The name of the step.
-
#parameter_space ⇒ Types::ParameterSpace
A list of step parameters and the combination expression for the step.
-
#required_capabilities ⇒ Types::StepRequiredCapabilities
The required capabilities of the step.
-
#started_at ⇒ Time
The date and time the resource started running.
-
#step_id ⇒ String
The step ID.
-
#target_task_run_status ⇒ String
The task status with which the job started.
-
#task_failure_retry_count ⇒ Integer
The total number of times tasks from the step failed and were retried.
-
#task_run_status ⇒ String
The task run status for the job.
-
#task_run_status_counts ⇒ Hash<String,Integer>
The number of tasks running on the job.
-
#updated_at ⇒ Time
The date and time the resource was updated.
-
#updated_by ⇒ String
The user or system that updated this resource.
Instance Attribute Details
#created_at ⇒ Time
The date and time the resource was created.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 6027 |
# File 'lib/aws-sdk-deadline/types.rb', line 6006 class GetStepResponse < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts, :required_capabilities, :parameter_space, :description) SENSITIVE = [:description] include Aws::Structure end |
#created_by ⇒ String
The user or system that created this resource.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 6027 |
# File 'lib/aws-sdk-deadline/types.rb', line 6006 class GetStepResponse < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts, :required_capabilities, :parameter_space, :description) SENSITIVE = [:description] include Aws::Structure end |
#dependency_counts ⇒ Types::DependencyCounts
The number of dependencies in the step.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 6027 |
# File 'lib/aws-sdk-deadline/types.rb', line 6006 class GetStepResponse < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts, :required_capabilities, :parameter_space, :description) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
The description of the step.
This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 6027 |
# File 'lib/aws-sdk-deadline/types.rb', line 6006 class GetStepResponse < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts, :required_capabilities, :parameter_space, :description) SENSITIVE = [:description] include Aws::Structure end |
#ended_at ⇒ Time
The date and time the resource ended running.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 6027 |
# File 'lib/aws-sdk-deadline/types.rb', line 6006 class GetStepResponse < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts, :required_capabilities, :parameter_space, :description) SENSITIVE = [:description] include Aws::Structure end |
#lifecycle_status ⇒ String
The life cycle status of the step.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 6027 |
# File 'lib/aws-sdk-deadline/types.rb', line 6006 class GetStepResponse < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts, :required_capabilities, :parameter_space, :description) SENSITIVE = [:description] include Aws::Structure end |
#lifecycle_status_message ⇒ String
A message that describes the lifecycle status of the step.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 6027 |
# File 'lib/aws-sdk-deadline/types.rb', line 6006 class GetStepResponse < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts, :required_capabilities, :parameter_space, :description) SENSITIVE = [:description] include Aws::Structure end |
#name ⇒ String
The name of the step.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 6027 |
# File 'lib/aws-sdk-deadline/types.rb', line 6006 class GetStepResponse < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts, :required_capabilities, :parameter_space, :description) SENSITIVE = [:description] include Aws::Structure end |
#parameter_space ⇒ Types::ParameterSpace
A list of step parameters and the combination expression for the step.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 6027 |
# File 'lib/aws-sdk-deadline/types.rb', line 6006 class GetStepResponse < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts, :required_capabilities, :parameter_space, :description) SENSITIVE = [:description] include Aws::Structure end |
#required_capabilities ⇒ Types::StepRequiredCapabilities
The required capabilities of the step.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 6027 |
# File 'lib/aws-sdk-deadline/types.rb', line 6006 class GetStepResponse < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts, :required_capabilities, :parameter_space, :description) SENSITIVE = [:description] include Aws::Structure end |
#started_at ⇒ Time
The date and time the resource started running.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 6027 |
# File 'lib/aws-sdk-deadline/types.rb', line 6006 class GetStepResponse < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts, :required_capabilities, :parameter_space, :description) SENSITIVE = [:description] include Aws::Structure end |
#step_id ⇒ String
The step ID.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 6027 |
# File 'lib/aws-sdk-deadline/types.rb', line 6006 class GetStepResponse < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts, :required_capabilities, :parameter_space, :description) SENSITIVE = [:description] include Aws::Structure end |
#target_task_run_status ⇒ String
The task status with which the job started.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 6027 |
# File 'lib/aws-sdk-deadline/types.rb', line 6006 class GetStepResponse < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts, :required_capabilities, :parameter_space, :description) SENSITIVE = [:description] include Aws::Structure end |
#task_failure_retry_count ⇒ Integer
The total number of times tasks from the step failed and were retried.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 6027 |
# File 'lib/aws-sdk-deadline/types.rb', line 6006 class GetStepResponse < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts, :required_capabilities, :parameter_space, :description) SENSITIVE = [:description] include Aws::Structure end |
#task_run_status ⇒ String
The task run status for the job.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 6027 |
# File 'lib/aws-sdk-deadline/types.rb', line 6006 class GetStepResponse < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts, :required_capabilities, :parameter_space, :description) SENSITIVE = [:description] include Aws::Structure end |
#task_run_status_counts ⇒ Hash<String,Integer>
The number of tasks running on the job.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 6027 |
# File 'lib/aws-sdk-deadline/types.rb', line 6006 class GetStepResponse < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts, :required_capabilities, :parameter_space, :description) SENSITIVE = [:description] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the resource was updated.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 6027 |
# File 'lib/aws-sdk-deadline/types.rb', line 6006 class GetStepResponse < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts, :required_capabilities, :parameter_space, :description) SENSITIVE = [:description] include Aws::Structure end |
#updated_by ⇒ String
The user or system that updated this resource.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 6027 |
# File 'lib/aws-sdk-deadline/types.rb', line 6006 class GetStepResponse < Struct.new( :step_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :task_run_status_counts, :task_failure_retry_count, :target_task_run_status, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :dependency_counts, :required_capabilities, :parameter_space, :description) SENSITIVE = [:description] include Aws::Structure end |