Class: Aws::Deadline::Types::JobEntity
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::JobEntity
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Note:
JobEntity is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of JobEntity corresponding to the set member.
The details of a job entity.
Direct Known Subclasses
EnvironmentDetails, JobAttachmentDetails, JobDetails, StepDetails, Unknown
Defined Under Namespace
Classes: EnvironmentDetails, JobAttachmentDetails, JobDetails, StepDetails, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#environment_details ⇒ Types::EnvironmentDetailsEntity
The environment details for the job entity.
-
#job_attachment_details ⇒ Types::JobAttachmentDetailsEntity
The job attachment details.
-
#job_details ⇒ Types::JobDetailsEntity
The job details.
-
#step_details ⇒ Types::StepDetailsEntity
The step details.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#environment_details ⇒ Types::EnvironmentDetailsEntity
The environment details for the job entity.
6657 6658 6659 6660 6661 6662 6663 6664 6665 6666 6667 6668 6669 6670 6671 6672 |
# File 'lib/aws-sdk-deadline/types.rb', line 6657 class JobEntity < Struct.new( :job_details, :job_attachment_details, :step_details, :environment_details, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class JobDetails < JobEntity; end class JobAttachmentDetails < JobEntity; end class StepDetails < JobEntity; end class EnvironmentDetails < JobEntity; end class Unknown < JobEntity; end end |
#job_attachment_details ⇒ Types::JobAttachmentDetailsEntity
The job attachment details.
6657 6658 6659 6660 6661 6662 6663 6664 6665 6666 6667 6668 6669 6670 6671 6672 |
# File 'lib/aws-sdk-deadline/types.rb', line 6657 class JobEntity < Struct.new( :job_details, :job_attachment_details, :step_details, :environment_details, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class JobDetails < JobEntity; end class JobAttachmentDetails < JobEntity; end class StepDetails < JobEntity; end class EnvironmentDetails < JobEntity; end class Unknown < JobEntity; end end |
#job_details ⇒ Types::JobDetailsEntity
The job details.
6657 6658 6659 6660 6661 6662 6663 6664 6665 6666 6667 6668 6669 6670 6671 6672 |
# File 'lib/aws-sdk-deadline/types.rb', line 6657 class JobEntity < Struct.new( :job_details, :job_attachment_details, :step_details, :environment_details, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class JobDetails < JobEntity; end class JobAttachmentDetails < JobEntity; end class StepDetails < JobEntity; end class EnvironmentDetails < JobEntity; end class Unknown < JobEntity; end end |
#step_details ⇒ Types::StepDetailsEntity
The step details.
6657 6658 6659 6660 6661 6662 6663 6664 6665 6666 6667 6668 6669 6670 6671 6672 |
# File 'lib/aws-sdk-deadline/types.rb', line 6657 class JobEntity < Struct.new( :job_details, :job_attachment_details, :step_details, :environment_details, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class JobDetails < JobEntity; end class JobAttachmentDetails < JobEntity; end class StepDetails < JobEntity; end class EnvironmentDetails < JobEntity; end class Unknown < JobEntity; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
6657 6658 6659 |
# File 'lib/aws-sdk-deadline/types.rb', line 6657 def unknown @unknown end |