Class: Aws::Deadline::Types::JobRunAsUser
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::JobRunAsUser
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Identifies the user for a job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#posix ⇒ Types::PosixUser
The user and group that the jobs in the queue run as.
-
#run_as ⇒ String
Specifies whether the job should run using the queue’s system user or if the job should run using the worker agent system user.
-
#windows ⇒ Types::WindowsUser
Identifies a Microsoft Windows user.
Instance Attribute Details
#posix ⇒ Types::PosixUser
The user and group that the jobs in the queue run as.
6979 6980 6981 6982 6983 6984 6985 |
# File 'lib/aws-sdk-deadline/types.rb', line 6979 class JobRunAsUser < Struct.new( :posix, :windows, :run_as) SENSITIVE = [] include Aws::Structure end |
#run_as ⇒ String
Specifies whether the job should run using the queue’s system user or if the job should run using the worker agent system user.
6979 6980 6981 6982 6983 6984 6985 |
# File 'lib/aws-sdk-deadline/types.rb', line 6979 class JobRunAsUser < Struct.new( :posix, :windows, :run_as) SENSITIVE = [] include Aws::Structure end |
#windows ⇒ Types::WindowsUser
Identifies a Microsoft Windows user.
6979 6980 6981 6982 6983 6984 6985 |
# File 'lib/aws-sdk-deadline/types.rb', line 6979 class JobRunAsUser < Struct.new( :posix, :windows, :run_as) SENSITIVE = [] include Aws::Structure end |