Method: Aws::Deadline::Types::JobRunAsUser#run_as
- Defined in:
- lib/aws-sdk-deadline/types.rb
#run_as ⇒ String
Specifies whether the job should run using the queue’s system user or if the job should run using the worker agent system user.
5178 5179 5180 5181 5182 5183 5184 |
# File 'lib/aws-sdk-deadline/types.rb', line 5178 class JobRunAsUser < Struct.new( :posix, :windows, :run_as) SENSITIVE = [] include Aws::Structure end |