Class: Aws::Deadline::Types::JobSearchSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::JobSearchSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
The details of a job search.
Constant Summary collapse
- SENSITIVE =
[:job_parameters]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The date and time the resource was created.
-
#created_by ⇒ String
The user or system that created this resource.
-
#ended_at ⇒ Time
The date and time the resource ended running.
-
#job_id ⇒ String
The job ID.
-
#job_parameters ⇒ Hash<String,Types::JobParameter>
The job parameters.
-
#lifecycle_status ⇒ String
The life cycle status.
-
#lifecycle_status_message ⇒ String
The life cycle status message.
-
#max_failed_tasks_count ⇒ Integer
The number of task failures before the job stops running and is marked as
FAILED. -
#max_retries_per_task ⇒ Integer
The maximum number of retries for a job.
-
#max_worker_count ⇒ Integer
The maximum number of worker hosts that can concurrently process a job.
-
#name ⇒ String
The job name.
-
#priority ⇒ Integer
The job priority.
-
#queue_id ⇒ String
The queue ID.
-
#source_job_id ⇒ String
The job ID for the source job.
-
#started_at ⇒ Time
The date and time the resource started running.
-
#target_task_run_status ⇒ String
The task status to update the job's tasks to.
-
#task_failure_retry_count ⇒ Integer
The total number of times tasks from the job failed and were retried.
-
#task_run_status ⇒ String
The task run status for the job.
-
#task_run_status_counts ⇒ Hash<String,Integer>
The number of tasks running on the job.
-
#updated_at ⇒ Time
The date and time the resource was updated.
-
#updated_by ⇒ String
The user or system that updated this resource.
Instance Attribute Details
#created_at ⇒ Time
The date and time the resource was created.
7125 7126 7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 7138 7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 |
# File 'lib/aws-sdk-deadline/types.rb', line 7125 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#created_by ⇒ String
The user or system that created this resource.
7125 7126 7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 7138 7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 |
# File 'lib/aws-sdk-deadline/types.rb', line 7125 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#ended_at ⇒ Time
The date and time the resource ended running.
7125 7126 7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 7138 7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 |
# File 'lib/aws-sdk-deadline/types.rb', line 7125 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#job_id ⇒ String
The job ID.
7125 7126 7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 7138 7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 |
# File 'lib/aws-sdk-deadline/types.rb', line 7125 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#job_parameters ⇒ Hash<String,Types::JobParameter>
The job parameters.
7125 7126 7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 7138 7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 |
# File 'lib/aws-sdk-deadline/types.rb', line 7125 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#lifecycle_status ⇒ String
The life cycle status.
7125 7126 7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 7138 7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 |
# File 'lib/aws-sdk-deadline/types.rb', line 7125 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#lifecycle_status_message ⇒ String
The life cycle status message.
7125 7126 7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 7138 7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 |
# File 'lib/aws-sdk-deadline/types.rb', line 7125 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#max_failed_tasks_count ⇒ Integer
The number of task failures before the job stops running and is
marked as FAILED.
7125 7126 7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 7138 7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 |
# File 'lib/aws-sdk-deadline/types.rb', line 7125 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#max_retries_per_task ⇒ Integer
The maximum number of retries for a job.
7125 7126 7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 7138 7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 |
# File 'lib/aws-sdk-deadline/types.rb', line 7125 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#max_worker_count ⇒ Integer
The maximum number of worker hosts that can concurrently process a
job. When the maxWorkerCount is reached, no more workers will be
assigned to process the job, even if the fleets assigned to the
job's queue has available workers.
You can't set the maxWorkerCount to 0. If you set it to -1, there
is no maximum number of workers.
If you don't specify the maxWorkerCount, the default is -1.
7125 7126 7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 7138 7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 |
# File 'lib/aws-sdk-deadline/types.rb', line 7125 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#name ⇒ String
The job name.
7125 7126 7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 7138 7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 |
# File 'lib/aws-sdk-deadline/types.rb', line 7125 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#priority ⇒ Integer
The job priority.
7125 7126 7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 7138 7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 |
# File 'lib/aws-sdk-deadline/types.rb', line 7125 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#queue_id ⇒ String
The queue ID.
7125 7126 7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 7138 7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 |
# File 'lib/aws-sdk-deadline/types.rb', line 7125 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#source_job_id ⇒ String
The job ID for the source job.
7125 7126 7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 7138 7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 |
# File 'lib/aws-sdk-deadline/types.rb', line 7125 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#started_at ⇒ Time
The date and time the resource started running.
7125 7126 7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 7138 7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 |
# File 'lib/aws-sdk-deadline/types.rb', line 7125 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#target_task_run_status ⇒ String
The task status to update the job's tasks to.
7125 7126 7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 7138 7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 |
# File 'lib/aws-sdk-deadline/types.rb', line 7125 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#task_failure_retry_count ⇒ Integer
The total number of times tasks from the job failed and were retried.
7125 7126 7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 7138 7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 |
# File 'lib/aws-sdk-deadline/types.rb', line 7125 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#task_run_status ⇒ String
The task run status for the job.
-
PENDING–pending and waiting for resources. -
READY–ready to be processed. -
ASSIGNED–assigned and will run next on a worker. -
SCHEDULED–scheduled to be run on a worker. -
INTERRUPTING–being interrupted. -
RUNNING–running on a worker. -
SUSPENDED–the task is suspended. -
CANCELED–the task has been canceled. -
FAILED–the task has failed. -
SUCCEEDED–the task has succeeded.
7125 7126 7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 7138 7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 |
# File 'lib/aws-sdk-deadline/types.rb', line 7125 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#task_run_status_counts ⇒ Hash<String,Integer>
The number of tasks running on the job.
7125 7126 7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 7138 7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 |
# File 'lib/aws-sdk-deadline/types.rb', line 7125 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the resource was updated.
7125 7126 7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 7138 7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 |
# File 'lib/aws-sdk-deadline/types.rb', line 7125 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#updated_by ⇒ String
The user or system that updated this resource.
7125 7126 7127 7128 7129 7130 7131 7132 7133 7134 7135 7136 7137 7138 7139 7140 7141 7142 7143 7144 7145 7146 7147 7148 7149 |
# File 'lib/aws-sdk-deadline/types.rb', line 7125 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |