Class: Aws::Deadline::Types::JobSearchSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::JobSearchSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
The details of a job search.
Constant Summary collapse
- SENSITIVE =
[:job_parameters]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The date and time the resource was created.
-
#created_by ⇒ String
The user or system that created this resource.
-
#ended_at ⇒ Time
The date and time the resource ended running.
-
#job_id ⇒ String
The job ID.
-
#job_parameters ⇒ Hash<String,Types::JobParameter>
The job parameters.
-
#lifecycle_status ⇒ String
The life cycle status.
-
#lifecycle_status_message ⇒ String
The life cycle status message.
-
#max_failed_tasks_count ⇒ Integer
The number of task failures before the job stops running and is marked as ‘FAILED`.
-
#max_retries_per_task ⇒ Integer
The maximum number of retries for a job.
-
#max_worker_count ⇒ Integer
The maximum number of worker hosts that can concurrently process a job.
-
#name ⇒ String
The job name.
-
#priority ⇒ Integer
The job priority.
-
#queue_id ⇒ String
The queue ID.
-
#source_job_id ⇒ String
The job ID for the source job.
-
#started_at ⇒ Time
The date and time the resource started running.
-
#target_task_run_status ⇒ String
The task status to update the job’s tasks to.
-
#task_failure_retry_count ⇒ Integer
The total number of times tasks from the job failed and were retried.
-
#task_run_status ⇒ String
The task run status for the job.
-
#task_run_status_counts ⇒ Hash<String,Integer>
The number of tasks running on the job.
-
#updated_at ⇒ Time
The date and time the resource was updated.
-
#updated_by ⇒ String
The user or system that updated this resource.
Instance Attribute Details
#created_at ⇒ Time
The date and time the resource was created.
6942 6943 6944 6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 |
# File 'lib/aws-sdk-deadline/types.rb', line 6942 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#created_by ⇒ String
The user or system that created this resource.
6942 6943 6944 6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 |
# File 'lib/aws-sdk-deadline/types.rb', line 6942 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#ended_at ⇒ Time
The date and time the resource ended running.
6942 6943 6944 6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 |
# File 'lib/aws-sdk-deadline/types.rb', line 6942 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#job_id ⇒ String
The job ID.
6942 6943 6944 6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 |
# File 'lib/aws-sdk-deadline/types.rb', line 6942 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#job_parameters ⇒ Hash<String,Types::JobParameter>
The job parameters.
6942 6943 6944 6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 |
# File 'lib/aws-sdk-deadline/types.rb', line 6942 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#lifecycle_status ⇒ String
The life cycle status.
6942 6943 6944 6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 |
# File 'lib/aws-sdk-deadline/types.rb', line 6942 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#lifecycle_status_message ⇒ String
The life cycle status message.
6942 6943 6944 6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 |
# File 'lib/aws-sdk-deadline/types.rb', line 6942 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#max_failed_tasks_count ⇒ Integer
The number of task failures before the job stops running and is marked as ‘FAILED`.
6942 6943 6944 6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 |
# File 'lib/aws-sdk-deadline/types.rb', line 6942 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#max_retries_per_task ⇒ Integer
The maximum number of retries for a job.
6942 6943 6944 6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 |
# File 'lib/aws-sdk-deadline/types.rb', line 6942 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#max_worker_count ⇒ Integer
The maximum number of worker hosts that can concurrently process a job. When the ‘maxWorkerCount` is reached, no more workers will be assigned to process the job, even if the fleets assigned to the job’s queue has available workers.
You can’t set the ‘maxWorkerCount` to 0. If you set it to -1, there is no maximum number of workers.
If you don’t specify the ‘maxWorkerCount`, the default is -1.
6942 6943 6944 6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 |
# File 'lib/aws-sdk-deadline/types.rb', line 6942 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#name ⇒ String
The job name.
6942 6943 6944 6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 |
# File 'lib/aws-sdk-deadline/types.rb', line 6942 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#priority ⇒ Integer
The job priority.
6942 6943 6944 6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 |
# File 'lib/aws-sdk-deadline/types.rb', line 6942 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#queue_id ⇒ String
The queue ID.
6942 6943 6944 6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 |
# File 'lib/aws-sdk-deadline/types.rb', line 6942 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#source_job_id ⇒ String
The job ID for the source job.
6942 6943 6944 6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 |
# File 'lib/aws-sdk-deadline/types.rb', line 6942 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#started_at ⇒ Time
The date and time the resource started running.
6942 6943 6944 6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 |
# File 'lib/aws-sdk-deadline/types.rb', line 6942 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#target_task_run_status ⇒ String
The task status to update the job’s tasks to.
6942 6943 6944 6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 |
# File 'lib/aws-sdk-deadline/types.rb', line 6942 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#task_failure_retry_count ⇒ Integer
The total number of times tasks from the job failed and were retried.
6942 6943 6944 6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 |
# File 'lib/aws-sdk-deadline/types.rb', line 6942 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#task_run_status ⇒ String
The task run status for the job.
-
‘PENDING`–pending and waiting for resources.
-
‘READY`–ready to be processed.
-
‘ASSIGNED`–assigned and will run next on a worker.
-
‘SCHEDULED`–scheduled to be run on a worker.
-
‘INTERRUPTING`–being interrupted.
-
‘RUNNING`–running on a worker.
-
‘SUSPENDED`–the task is suspended.
-
‘CANCELED`–the task has been canceled.
-
‘FAILED`–the task has failed.
-
‘SUCCEEDED`–the task has succeeded.
6942 6943 6944 6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 |
# File 'lib/aws-sdk-deadline/types.rb', line 6942 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#task_run_status_counts ⇒ Hash<String,Integer>
The number of tasks running on the job.
6942 6943 6944 6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 |
# File 'lib/aws-sdk-deadline/types.rb', line 6942 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the resource was updated.
6942 6943 6944 6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 |
# File 'lib/aws-sdk-deadline/types.rb', line 6942 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |
#updated_by ⇒ String
The user or system that updated this resource.
6942 6943 6944 6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 6965 6966 |
# File 'lib/aws-sdk-deadline/types.rb', line 6942 class JobSearchSummary < Struct.new( :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :priority, :max_failed_tasks_count, :max_retries_per_task, :created_by, :created_at, :ended_at, :started_at, :updated_at, :updated_by, :job_parameters, :max_worker_count, :source_job_id) SENSITIVE = [:job_parameters] include Aws::Structure end |