Class: Aws::Deadline::Types::JobSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::JobSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
A summary of job details.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The date and time the resource was created.
-
#created_by ⇒ String
The user or system that created this resource.
-
#ended_at ⇒ Time
The date and time the resource ended running.
-
#job_id ⇒ String
The job ID.
-
#lifecycle_status ⇒ String
The life cycle status.
-
#lifecycle_status_message ⇒ String
The life cycle status message.
-
#max_failed_tasks_count ⇒ Integer
The number of task failures before the job stops running and is marked as ‘FAILED`.
-
#max_retries_per_task ⇒ Integer
The maximum number of retries for a job.
-
#max_worker_count ⇒ Integer
The maximum number of worker hosts that can concurrently process a job.
-
#name ⇒ String
The job name.
-
#priority ⇒ Integer
The job priority.
-
#source_job_id ⇒ String
The job ID for the source job.
-
#started_at ⇒ Time
The date and time the resource started running.
-
#target_task_run_status ⇒ String
The task status to update the job’s tasks to.
-
#task_failure_retry_count ⇒ Integer
The total number of times tasks from the job failed and were retried.
-
#task_run_status ⇒ String
The task run status for the job.
-
#task_run_status_counts ⇒ Hash<String,Integer>
The number of tasks running on the job.
-
#updated_at ⇒ Time
The date and time the resource was updated.
-
#updated_by ⇒ String
The user or system that updated this resource.
Instance Attribute Details
#created_at ⇒ Time
The date and time the resource was created.
7078 7079 7080 7081 7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 7100 |
# File 'lib/aws-sdk-deadline/types.rb', line 7078 class JobSummary < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The user or system that created this resource.
7078 7079 7080 7081 7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 7100 |
# File 'lib/aws-sdk-deadline/types.rb', line 7078 class JobSummary < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id) SENSITIVE = [] include Aws::Structure end |
#ended_at ⇒ Time
The date and time the resource ended running.
7078 7079 7080 7081 7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 7100 |
# File 'lib/aws-sdk-deadline/types.rb', line 7078 class JobSummary < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The job ID.
7078 7079 7080 7081 7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 7100 |
# File 'lib/aws-sdk-deadline/types.rb', line 7078 class JobSummary < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id) SENSITIVE = [] include Aws::Structure end |
#lifecycle_status ⇒ String
The life cycle status.
7078 7079 7080 7081 7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 7100 |
# File 'lib/aws-sdk-deadline/types.rb', line 7078 class JobSummary < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id) SENSITIVE = [] include Aws::Structure end |
#lifecycle_status_message ⇒ String
The life cycle status message.
7078 7079 7080 7081 7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 7100 |
# File 'lib/aws-sdk-deadline/types.rb', line 7078 class JobSummary < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id) SENSITIVE = [] include Aws::Structure end |
#max_failed_tasks_count ⇒ Integer
The number of task failures before the job stops running and is marked as ‘FAILED`.
7078 7079 7080 7081 7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 7100 |
# File 'lib/aws-sdk-deadline/types.rb', line 7078 class JobSummary < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id) SENSITIVE = [] include Aws::Structure end |
#max_retries_per_task ⇒ Integer
The maximum number of retries for a job.
7078 7079 7080 7081 7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 7100 |
# File 'lib/aws-sdk-deadline/types.rb', line 7078 class JobSummary < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id) SENSITIVE = [] include Aws::Structure end |
#max_worker_count ⇒ Integer
The maximum number of worker hosts that can concurrently process a job. When the ‘maxWorkerCount` is reached, no more workers will be assigned to process the job, even if the fleets assigned to the job’s queue has available workers.
You can’t set the ‘maxWorkerCount` to 0. If you set it to -1, there is no maximum number of workers.
If you don’t specify the ‘maxWorkerCount`, the default is -1.
7078 7079 7080 7081 7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 7100 |
# File 'lib/aws-sdk-deadline/types.rb', line 7078 class JobSummary < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The job name.
7078 7079 7080 7081 7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 7100 |
# File 'lib/aws-sdk-deadline/types.rb', line 7078 class JobSummary < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ Integer
The job priority.
7078 7079 7080 7081 7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 7100 |
# File 'lib/aws-sdk-deadline/types.rb', line 7078 class JobSummary < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id) SENSITIVE = [] include Aws::Structure end |
#source_job_id ⇒ String
The job ID for the source job.
7078 7079 7080 7081 7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 7100 |
# File 'lib/aws-sdk-deadline/types.rb', line 7078 class JobSummary < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The date and time the resource started running.
7078 7079 7080 7081 7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 7100 |
# File 'lib/aws-sdk-deadline/types.rb', line 7078 class JobSummary < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id) SENSITIVE = [] include Aws::Structure end |
#target_task_run_status ⇒ String
The task status to update the job’s tasks to.
7078 7079 7080 7081 7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 7100 |
# File 'lib/aws-sdk-deadline/types.rb', line 7078 class JobSummary < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id) SENSITIVE = [] include Aws::Structure end |
#task_failure_retry_count ⇒ Integer
The total number of times tasks from the job failed and were retried.
7078 7079 7080 7081 7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 7100 |
# File 'lib/aws-sdk-deadline/types.rb', line 7078 class JobSummary < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id) SENSITIVE = [] include Aws::Structure end |
#task_run_status ⇒ String
The task run status for the job.
-
‘PENDING`–pending and waiting for resources.
-
‘READY`–ready to be processed.
-
‘ASSIGNED`–assigned and will run next on a worker.
-
‘SCHEDULED`–scheduled to be run on a worker.
-
‘INTERRUPTING`–being interrupted.
-
‘RUNNING`–running on a worker.
-
‘SUSPENDED`–the task is suspended.
-
‘CANCELED`–the task has been canceled.
-
‘FAILED`–the task has failed.
-
‘SUCCEEDED`–the task has succeeded.
7078 7079 7080 7081 7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 7100 |
# File 'lib/aws-sdk-deadline/types.rb', line 7078 class JobSummary < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id) SENSITIVE = [] include Aws::Structure end |
#task_run_status_counts ⇒ Hash<String,Integer>
The number of tasks running on the job.
7078 7079 7080 7081 7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 7100 |
# File 'lib/aws-sdk-deadline/types.rb', line 7078 class JobSummary < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the resource was updated.
7078 7079 7080 7081 7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 7100 |
# File 'lib/aws-sdk-deadline/types.rb', line 7078 class JobSummary < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id) SENSITIVE = [] include Aws::Structure end |
#updated_by ⇒ String
The user or system that updated this resource.
7078 7079 7080 7081 7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 7094 7095 7096 7097 7098 7099 7100 |
# File 'lib/aws-sdk-deadline/types.rb', line 7078 class JobSummary < Struct.new( :job_id, :name, :lifecycle_status, :lifecycle_status_message, :priority, :created_at, :created_by, :updated_at, :updated_by, :started_at, :ended_at, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :max_failed_tasks_count, :max_retries_per_task, :max_worker_count, :source_job_id) SENSITIVE = [] include Aws::Structure end |