Class: Aws::Deadline::Types::LimitSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::LimitSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Provides information about a specific limit.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#amount_requirement_name ⇒ String
The value that you specify as the ‘name` in the `amounts` field of the `hostRequirements` in a step of a job template to declare the limit requirement.
-
#created_at ⇒ Time
The Unix timestamp of the date and time that the limit was created.
-
#created_by ⇒ String
The user identifier of the person that created the limit.
-
#current_count ⇒ Integer
The number of resources from the limit that are being used by jobs.
-
#display_name ⇒ String
The name of the limit used in lists to identify the limit.
-
#farm_id ⇒ String
The unique identifier of the farm that contains the limit.
-
#limit_id ⇒ String
The unique identifier of the limit.
-
#max_count ⇒ Integer
The maximum number of resources constrained by this limit.
-
#updated_at ⇒ Time
The Unix timestamp of the date and time that the limit was last updated.
-
#updated_by ⇒ String
The user identifier of the person that last updated the limit.
Instance Attribute Details
#amount_requirement_name ⇒ String
The value that you specify as the ‘name` in the `amounts` field of the `hostRequirements` in a step of a job template to declare the limit requirement.
7191 7192 7193 7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 |
# File 'lib/aws-sdk-deadline/types.rb', line 7191 class LimitSummary < Struct.new( :farm_id, :limit_id, :current_count, :created_at, :created_by, :updated_at, :updated_by, :display_name, :amount_requirement_name, :max_count) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The Unix timestamp of the date and time that the limit was created.
7191 7192 7193 7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 |
# File 'lib/aws-sdk-deadline/types.rb', line 7191 class LimitSummary < Struct.new( :farm_id, :limit_id, :current_count, :created_at, :created_by, :updated_at, :updated_by, :display_name, :amount_requirement_name, :max_count) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The user identifier of the person that created the limit.
7191 7192 7193 7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 |
# File 'lib/aws-sdk-deadline/types.rb', line 7191 class LimitSummary < Struct.new( :farm_id, :limit_id, :current_count, :created_at, :created_by, :updated_at, :updated_by, :display_name, :amount_requirement_name, :max_count) SENSITIVE = [] include Aws::Structure end |
#current_count ⇒ Integer
The number of resources from the limit that are being used by jobs. The result is delayed and may not be the count at the time that you called the operation.
7191 7192 7193 7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 |
# File 'lib/aws-sdk-deadline/types.rb', line 7191 class LimitSummary < Struct.new( :farm_id, :limit_id, :current_count, :created_at, :created_by, :updated_at, :updated_by, :display_name, :amount_requirement_name, :max_count) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The name of the limit used in lists to identify the limit.
This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.
7191 7192 7193 7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 |
# File 'lib/aws-sdk-deadline/types.rb', line 7191 class LimitSummary < Struct.new( :farm_id, :limit_id, :current_count, :created_at, :created_by, :updated_at, :updated_by, :display_name, :amount_requirement_name, :max_count) SENSITIVE = [] include Aws::Structure end |
#farm_id ⇒ String
The unique identifier of the farm that contains the limit.
7191 7192 7193 7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 |
# File 'lib/aws-sdk-deadline/types.rb', line 7191 class LimitSummary < Struct.new( :farm_id, :limit_id, :current_count, :created_at, :created_by, :updated_at, :updated_by, :display_name, :amount_requirement_name, :max_count) SENSITIVE = [] include Aws::Structure end |
#limit_id ⇒ String
The unique identifier of the limit.
7191 7192 7193 7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 |
# File 'lib/aws-sdk-deadline/types.rb', line 7191 class LimitSummary < Struct.new( :farm_id, :limit_id, :current_count, :created_at, :created_by, :updated_at, :updated_by, :display_name, :amount_requirement_name, :max_count) SENSITIVE = [] include Aws::Structure end |
#max_count ⇒ Integer
The maximum number of resources constrained by this limit. When all of the resources are in use, steps that require the limit won’t be scheduled until the resource is available.
The ‘maxValue` must not be 0. If the value is -1, there is no restriction on the number of resources that can be acquired for this limit.
7191 7192 7193 7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 |
# File 'lib/aws-sdk-deadline/types.rb', line 7191 class LimitSummary < Struct.new( :farm_id, :limit_id, :current_count, :created_at, :created_by, :updated_at, :updated_by, :display_name, :amount_requirement_name, :max_count) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The Unix timestamp of the date and time that the limit was last updated.
7191 7192 7193 7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 |
# File 'lib/aws-sdk-deadline/types.rb', line 7191 class LimitSummary < Struct.new( :farm_id, :limit_id, :current_count, :created_at, :created_by, :updated_at, :updated_by, :display_name, :amount_requirement_name, :max_count) SENSITIVE = [] include Aws::Structure end |
#updated_by ⇒ String
The user identifier of the person that last updated the limit.
7191 7192 7193 7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 7204 |
# File 'lib/aws-sdk-deadline/types.rb', line 7191 class LimitSummary < Struct.new( :farm_id, :limit_id, :current_count, :created_at, :created_by, :updated_at, :updated_by, :display_name, :amount_requirement_name, :max_count) SENSITIVE = [] include Aws::Structure end |