Class: Aws::Deadline::Types::ListFarmsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::ListFarmsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Shared pagination fields for List operation inputs (nextToken + maxResults).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return.
-
#next_token ⇒ String
The token for the next set of results, or
nullto start from the beginning. -
#principal_id ⇒ String
The principal ID of the member to list on the farm.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return. Use this parameter with
NextToken to get results as a set of sequential pages.
7564 7565 7566 7567 7568 7569 7570 |
# File 'lib/aws-sdk-deadline/types.rb', line 7564 class ListFarmsRequest < Struct.new( :next_token, :max_results, :principal_id) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results, or null to start from the
beginning.
7564 7565 7566 7567 7568 7569 7570 |
# File 'lib/aws-sdk-deadline/types.rb', line 7564 class ListFarmsRequest < Struct.new( :next_token, :max_results, :principal_id) SENSITIVE = [] include Aws::Structure end |
#principal_id ⇒ String
The principal ID of the member to list on the farm.
7564 7565 7566 7567 7568 7569 7570 |
# File 'lib/aws-sdk-deadline/types.rb', line 7564 class ListFarmsRequest < Struct.new( :next_token, :max_results, :principal_id) SENSITIVE = [] include Aws::Structure end |