Class: Aws::Deadline::Types::ListLicenseEndpointsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages.

Returns:

  • (Integer)


6047
6048
6049
6050
6051
6052
# File 'lib/aws-sdk-deadline/types.rb', line 6047

class ListLicenseEndpointsRequest < Struct.new(
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results, or null to start from the beginning.

Returns:

  • (String)


6047
6048
6049
6050
6051
6052
# File 'lib/aws-sdk-deadline/types.rb', line 6047

class ListLicenseEndpointsRequest < Struct.new(
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end