Class: Aws::Deadline::Types::ListLimitsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#farm_idString

The unique identifier of the farm that contains the limits.

Returns:

  • (String)


6102
6103
6104
6105
6106
6107
6108
# File 'lib/aws-sdk-deadline/types.rb', line 6102

class ListLimitsRequest < Struct.new(
  :farm_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of limits to return in each page of results.

Returns:

  • (Integer)


6102
6103
6104
6105
6106
6107
6108
# File 'lib/aws-sdk-deadline/types.rb', line 6102

class ListLimitsRequest < Struct.new(
  :farm_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results, or null to start from the beginning.

Returns:

  • (String)


6102
6103
6104
6105
6106
6107
6108
# File 'lib/aws-sdk-deadline/types.rb', line 6102

class ListLimitsRequest < Struct.new(
  :farm_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end