Class: Aws::Deadline::Types::ListLimitsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::ListLimitsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#farm_id ⇒ String
The unique identifier of the farm that contains the limits.
-
#max_results ⇒ Integer
The maximum number of limits to return in each page of results.
-
#next_token ⇒ String
The token for the next set of results, or
nullto start from the beginning.
Instance Attribute Details
#farm_id ⇒ String
The unique identifier of the farm that contains the limits.
6102 6103 6104 6105 6106 6107 6108 |
# File 'lib/aws-sdk-deadline/types.rb', line 6102 class ListLimitsRequest < Struct.new( :farm_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of limits to return in each page of results.
6102 6103 6104 6105 6106 6107 6108 |
# File 'lib/aws-sdk-deadline/types.rb', line 6102 class ListLimitsRequest < Struct.new( :farm_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results, or null to start from the beginning.
6102 6103 6104 6105 6106 6107 6108 |
# File 'lib/aws-sdk-deadline/types.rb', line 6102 class ListLimitsRequest < Struct.new( :farm_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |