Class: Aws::Deadline::Types::ListQueueEnvironmentsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#environmentsArray<Types::QueueEnvironmentSummary>

The environments to include in the queue environments list.

Returns:



6268
6269
6270
6271
6272
6273
# File 'lib/aws-sdk-deadline/types.rb', line 6268

class ListQueueEnvironmentsResponse < Struct.new(
  :environments,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If Deadline Cloud returns nextToken, then there are more results available. The value of nextToken is a unique pagination token for each page. To retrieve the next page, call the operation again using the returned token. Keep all other arguments unchanged. If no results remain, then nextToken is set to null. Each pagination token expires after 24 hours. If you provide a token that isn’t valid, then you receive an HTTP 400 ValidationException error.

Returns:



6268
6269
6270
6271
6272
6273
# File 'lib/aws-sdk-deadline/types.rb', line 6268

class ListQueueEnvironmentsResponse < Struct.new(
  :environments,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end