Class: Aws::Deadline::Types::ListQueueEnvironmentsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::ListQueueEnvironmentsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#environments ⇒ Array<Types::QueueEnvironmentSummary>
The environments to include in the queue environments list.
-
#next_token ⇒ String
If Deadline Cloud returns
nextToken, then there are more results available.
Instance Attribute Details
#environments ⇒ Array<Types::QueueEnvironmentSummary>
The environments to include in the queue environments list.
6258 6259 6260 6261 6262 6263 |
# File 'lib/aws-sdk-deadline/types.rb', line 6258 class ListQueueEnvironmentsResponse < Struct.new( :environments, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If Deadline Cloud returns nextToken, then there are more results available. The value of nextToken is a unique pagination token for each page. To retrieve the next page, call the operation again using the returned token. Keep all other arguments unchanged. If no results remain, then nextToken is set to null. Each pagination token expires after 24 hours. If you provide a token that isn’t valid, then you receive an HTTP 400 ValidationException error.
6258 6259 6260 6261 6262 6263 |
# File 'lib/aws-sdk-deadline/types.rb', line 6258 class ListQueueEnvironmentsResponse < Struct.new( :environments, :next_token) SENSITIVE = [] include Aws::Structure end |