Class: Aws::Deadline::Types::ListQueueLimitAssociationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#farm_idString

The unique identifier of the farm that contains the limits and associations.

Returns:

  • (String)


6353
6354
6355
6356
6357
6358
6359
6360
6361
# File 'lib/aws-sdk-deadline/types.rb', line 6353

class ListQueueLimitAssociationsRequest < Struct.new(
  :farm_id,
  :queue_id,
  :limit_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#limit_idString

Specifies that the operation should return only the queue limit associations for the specified limit. If you specify both the queueId and the limitId, only the specified limit is returned if it exists.

Returns:

  • (String)


6353
6354
6355
6356
6357
6358
6359
6360
6361
# File 'lib/aws-sdk-deadline/types.rb', line 6353

class ListQueueLimitAssociationsRequest < Struct.new(
  :farm_id,
  :queue_id,
  :limit_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of associations to return in each page of results.

Returns:

  • (Integer)


6353
6354
6355
6356
6357
6358
6359
6360
6361
# File 'lib/aws-sdk-deadline/types.rb', line 6353

class ListQueueLimitAssociationsRequest < Struct.new(
  :farm_id,
  :queue_id,
  :limit_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results, or null to start from the beginning.

Returns:

  • (String)


6353
6354
6355
6356
6357
6358
6359
6360
6361
# File 'lib/aws-sdk-deadline/types.rb', line 6353

class ListQueueLimitAssociationsRequest < Struct.new(
  :farm_id,
  :queue_id,
  :limit_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#queue_idString

Specifies that the operation should return only the queue limit associations for the specified queue. If you specify both the queueId and the limitId, only the specified limit is returned if it exists.

Returns:

  • (String)


6353
6354
6355
6356
6357
6358
6359
6360
6361
# File 'lib/aws-sdk-deadline/types.rb', line 6353

class ListQueueLimitAssociationsRequest < Struct.new(
  :farm_id,
  :queue_id,
  :limit_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end