Class: Aws::Deadline::Types::ListQueueLimitAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::ListQueueLimitAssociationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#farm_id ⇒ String
The unique identifier of the farm that contains the limits and associations.
-
#limit_id ⇒ String
Specifies that the operation should return only the queue limit associations for the specified limit.
-
#max_results ⇒ Integer
The maximum number of associations to return in each page of results.
-
#next_token ⇒ String
The token for the next set of results, or
nullto start from the beginning. -
#queue_id ⇒ String
Specifies that the operation should return only the queue limit associations for the specified queue.
Instance Attribute Details
#farm_id ⇒ String
The unique identifier of the farm that contains the limits and associations.
6353 6354 6355 6356 6357 6358 6359 6360 6361 |
# File 'lib/aws-sdk-deadline/types.rb', line 6353 class ListQueueLimitAssociationsRequest < Struct.new( :farm_id, :queue_id, :limit_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#limit_id ⇒ String
Specifies that the operation should return only the queue limit associations for the specified limit. If you specify both the queueId and the limitId, only the specified limit is returned if it exists.
6353 6354 6355 6356 6357 6358 6359 6360 6361 |
# File 'lib/aws-sdk-deadline/types.rb', line 6353 class ListQueueLimitAssociationsRequest < Struct.new( :farm_id, :queue_id, :limit_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of associations to return in each page of results.
6353 6354 6355 6356 6357 6358 6359 6360 6361 |
# File 'lib/aws-sdk-deadline/types.rb', line 6353 class ListQueueLimitAssociationsRequest < Struct.new( :farm_id, :queue_id, :limit_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results, or null to start from the beginning.
6353 6354 6355 6356 6357 6358 6359 6360 6361 |
# File 'lib/aws-sdk-deadline/types.rb', line 6353 class ListQueueLimitAssociationsRequest < Struct.new( :farm_id, :queue_id, :limit_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#queue_id ⇒ String
Specifies that the operation should return only the queue limit associations for the specified queue. If you specify both the queueId and the limitId, only the specified limit is returned if it exists.
6353 6354 6355 6356 6357 6358 6359 6360 6361 |
# File 'lib/aws-sdk-deadline/types.rb', line 6353 class ListQueueLimitAssociationsRequest < Struct.new( :farm_id, :queue_id, :limit_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |