Class: Aws::Deadline::Types::ListQueueLimitAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::ListQueueLimitAssociationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Shared pagination fields for List operation inputs (nextToken + maxResults).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#farm_id ⇒ String
The unique identifier of the farm that contains the limits and associations.
-
#limit_id ⇒ String
Specifies that the operation should return only the queue limit associations for the specified limit.
-
#max_results ⇒ Integer
The maximum number of associations to return in each page of results.
-
#next_token ⇒ String
The token for the next set of results, or
nullto start from the beginning. -
#queue_id ⇒ String
Specifies that the operation should return only the queue limit associations for the specified queue.
Instance Attribute Details
#farm_id ⇒ String
The unique identifier of the farm that contains the limits and associations.
8262 8263 8264 8265 8266 8267 8268 8269 8270 |
# File 'lib/aws-sdk-deadline/types.rb', line 8262 class ListQueueLimitAssociationsRequest < Struct.new( :farm_id, :next_token, :max_results, :queue_id, :limit_id) SENSITIVE = [] include Aws::Structure end |
#limit_id ⇒ String
Specifies that the operation should return only the queue limit
associations for the specified limit. If you specify both the
queueId and the limitId, only the specified limit is returned if
it exists.
8262 8263 8264 8265 8266 8267 8268 8269 8270 |
# File 'lib/aws-sdk-deadline/types.rb', line 8262 class ListQueueLimitAssociationsRequest < Struct.new( :farm_id, :next_token, :max_results, :queue_id, :limit_id) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of associations to return in each page of results.
8262 8263 8264 8265 8266 8267 8268 8269 8270 |
# File 'lib/aws-sdk-deadline/types.rb', line 8262 class ListQueueLimitAssociationsRequest < Struct.new( :farm_id, :next_token, :max_results, :queue_id, :limit_id) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results, or null to start from the
beginning.
8262 8263 8264 8265 8266 8267 8268 8269 8270 |
# File 'lib/aws-sdk-deadline/types.rb', line 8262 class ListQueueLimitAssociationsRequest < Struct.new( :farm_id, :next_token, :max_results, :queue_id, :limit_id) SENSITIVE = [] include Aws::Structure end |
#queue_id ⇒ String
Specifies that the operation should return only the queue limit
associations for the specified queue. If you specify both the
queueId and the limitId, only the specified limit is returned if
it exists.
8262 8263 8264 8265 8266 8267 8268 8269 8270 |
# File 'lib/aws-sdk-deadline/types.rb', line 8262 class ListQueueLimitAssociationsRequest < Struct.new( :farm_id, :next_token, :max_results, :queue_id, :limit_id) SENSITIVE = [] include Aws::Structure end |