Class: Aws::Deadline::Types::ListQueueLimitAssociationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::ListQueueLimitAssociationsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Shared pagination field for List operation outputs (nextToken).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If Deadline Cloud returns
nextToken, then there are more results available. -
#queue_limit_associations ⇒ Array<Types::QueueLimitAssociationSummary>
A list of associations between limits and queues in the farm specified in the request.
Instance Attribute Details
#next_token ⇒ String
If Deadline Cloud returns nextToken, then there are more results
available. The value of nextToken is a unique pagination token for
each page. To retrieve the next page, call the operation again using
the returned token. Keep all other arguments unchanged. If no
results remain, then nextToken is set to null. Each pagination
token expires after 24 hours. If you provide a token that isn't
valid, then you receive an HTTP 400 ValidationException error.
8291 8292 8293 8294 8295 8296 |
# File 'lib/aws-sdk-deadline/types.rb', line 8291 class ListQueueLimitAssociationsResponse < Struct.new( :queue_limit_associations, :next_token) SENSITIVE = [] include Aws::Structure end |
#queue_limit_associations ⇒ Array<Types::QueueLimitAssociationSummary>
A list of associations between limits and queues in the farm specified in the request.
8291 8292 8293 8294 8295 8296 |
# File 'lib/aws-sdk-deadline/types.rb', line 8291 class ListQueueLimitAssociationsResponse < Struct.new( :queue_limit_associations, :next_token) SENSITIVE = [] include Aws::Structure end |