Class: Aws::Deadline::Types::ListQueuesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#farm_idString

The farm ID of the queue.



6480
6481
6482
6483
6484
6485
6486
6487
6488
# File 'lib/aws-sdk-deadline/types.rb', line 6480

class ListQueuesRequest < Struct.new(
  :farm_id,
  :principal_id,
  :status,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages.



6480
6481
6482
6483
6484
6485
6486
6487
6488
# File 'lib/aws-sdk-deadline/types.rb', line 6480

class ListQueuesRequest < Struct.new(
  :farm_id,
  :principal_id,
  :status,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of results, or null to start from the beginning.



6480
6481
6482
6483
6484
6485
6486
6487
6488
# File 'lib/aws-sdk-deadline/types.rb', line 6480

class ListQueuesRequest < Struct.new(
  :farm_id,
  :principal_id,
  :status,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#principal_idString

The principal IDs to include in the list of queues.



6480
6481
6482
6483
6484
6485
6486
6487
6488
# File 'lib/aws-sdk-deadline/types.rb', line 6480

class ListQueuesRequest < Struct.new(
  :farm_id,
  :principal_id,
  :status,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the queues listed.

  • ACTIVE–The queues are active.

  • SCHEDULING–The queues are scheduling.

  • SCHEDULING_BLOCKED–The queue scheduling is blocked for these queues.



6480
6481
6482
6483
6484
6485
6486
6487
6488
# File 'lib/aws-sdk-deadline/types.rb', line 6480

class ListQueuesRequest < Struct.new(
  :farm_id,
  :principal_id,
  :status,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end