Class: Aws::Deadline::Types::ListQueuesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::ListQueuesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Shared pagination fields for List operation inputs (nextToken + maxResults).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#farm_id ⇒ String
The farm ID of the queue.
-
#max_results ⇒ Integer
The maximum number of results to return.
-
#next_token ⇒ String
The token for the next set of results, or
nullto start from the beginning. -
#principal_id ⇒ String
The principal IDs to include in the list of queues.
-
#status ⇒ String
The status of the queues listed.
Instance Attribute Details
#farm_id ⇒ String
The farm ID of the queue.
8389 8390 8391 8392 8393 8394 8395 8396 8397 |
# File 'lib/aws-sdk-deadline/types.rb', line 8389 class ListQueuesRequest < Struct.new( :farm_id, :next_token, :max_results, :principal_id, :status) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return. Use this parameter with
NextToken to get results as a set of sequential pages.
8389 8390 8391 8392 8393 8394 8395 8396 8397 |
# File 'lib/aws-sdk-deadline/types.rb', line 8389 class ListQueuesRequest < Struct.new( :farm_id, :next_token, :max_results, :principal_id, :status) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results, or null to start from the
beginning.
8389 8390 8391 8392 8393 8394 8395 8396 8397 |
# File 'lib/aws-sdk-deadline/types.rb', line 8389 class ListQueuesRequest < Struct.new( :farm_id, :next_token, :max_results, :principal_id, :status) SENSITIVE = [] include Aws::Structure end |
#principal_id ⇒ String
The principal IDs to include in the list of queues.
8389 8390 8391 8392 8393 8394 8395 8396 8397 |
# File 'lib/aws-sdk-deadline/types.rb', line 8389 class ListQueuesRequest < Struct.new( :farm_id, :next_token, :max_results, :principal_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the queues listed.
-
ACTIVE–The queues are active. -
SCHEDULING–The queues are scheduling. -
SCHEDULING_BLOCKED–The queue scheduling is blocked for these queues.
8389 8390 8391 8392 8393 8394 8395 8396 8397 |
# File 'lib/aws-sdk-deadline/types.rb', line 8389 class ListQueuesRequest < Struct.new( :farm_id, :next_token, :max_results, :principal_id, :status) SENSITIVE = [] include Aws::Structure end |