Class: Aws::Deadline::Types::ListTasksResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::ListTasksResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If Deadline Cloud returns
nextToken, then there are more results available. -
#tasks ⇒ Array<Types::TaskSummary>
Tasks for the job.
Instance Attribute Details
#next_token ⇒ String
If Deadline Cloud returns nextToken, then there are more results available. The value of nextToken is a unique pagination token for each page. To retrieve the next page, call the operation again using the returned token. Keep all other arguments unchanged. If no results remain, then nextToken is set to null. Each pagination token expires after 24 hours. If you provide a token that isn’t valid, then you receive an HTTP 400 ValidationException error.
7049 7050 7051 7052 7053 7054 |
# File 'lib/aws-sdk-deadline/types.rb', line 7049 class ListTasksResponse < Struct.new( :tasks, :next_token) SENSITIVE = [] include Aws::Structure end |
#tasks ⇒ Array<Types::TaskSummary>
Tasks for the job.
7049 7050 7051 7052 7053 7054 |
# File 'lib/aws-sdk-deadline/types.rb', line 7049 class ListTasksResponse < Struct.new( :tasks, :next_token) SENSITIVE = [] include Aws::Structure end |