Class: Aws::Deadline::Types::MonitorSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::MonitorSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Provides information about a monitor in Deadline Cloud.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The UNIX timestamp of the date and time that the monitor was created.
-
#created_by ⇒ String
The user name of the person that created the monitor.
-
#display_name ⇒ String
The name of the monitor that displays on the Deadline Cloud console.
-
#identity_center_application_arn ⇒ String
The Amazon Resource Name that the IAM Identity Center assigned to the monitor when it was created.
-
#identity_center_instance_arn ⇒ String
The Amazon Resource Name of the IAM Identity Center instance responsible for authenticating monitor users.
-
#identity_center_region ⇒ String
The Region where IAM Identity Center is enabled.
-
#monitor_id ⇒ String
The unique identifier for the monitor.
-
#role_arn ⇒ String
The Amazon Resource Name of the IAM role for the monitor.
-
#subdomain ⇒ String
The subdomain used for the monitor URL.
-
#updated_at ⇒ Time
The UNIX timestamp of the date and time that the monitor was last updated.
-
#updated_by ⇒ String
The user name of the person that last updated the monitor.
-
#url ⇒ String
The complete URL of the monitor.
Instance Attribute Details
#created_at ⇒ Time
The UNIX timestamp of the date and time that the monitor was created.
9299 9300 9301 9302 9303 9304 9305 9306 9307 9308 9309 9310 9311 9312 9313 9314 |
# File 'lib/aws-sdk-deadline/types.rb', line 9299 class MonitorSummary < Struct.new( :monitor_id, :display_name, :subdomain, :url, :role_arn, :identity_center_instance_arn, :identity_center_region, :identity_center_application_arn, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The user name of the person that created the monitor.
9299 9300 9301 9302 9303 9304 9305 9306 9307 9308 9309 9310 9311 9312 9313 9314 |
# File 'lib/aws-sdk-deadline/types.rb', line 9299 class MonitorSummary < Struct.new( :monitor_id, :display_name, :subdomain, :url, :role_arn, :identity_center_instance_arn, :identity_center_region, :identity_center_application_arn, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The name of the monitor that displays on the Deadline Cloud console.
This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.
9299 9300 9301 9302 9303 9304 9305 9306 9307 9308 9309 9310 9311 9312 9313 9314 |
# File 'lib/aws-sdk-deadline/types.rb', line 9299 class MonitorSummary < Struct.new( :monitor_id, :display_name, :subdomain, :url, :role_arn, :identity_center_instance_arn, :identity_center_region, :identity_center_application_arn, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#identity_center_application_arn ⇒ String
The Amazon Resource Name that the IAM Identity Center assigned to the monitor when it was created.
9299 9300 9301 9302 9303 9304 9305 9306 9307 9308 9309 9310 9311 9312 9313 9314 |
# File 'lib/aws-sdk-deadline/types.rb', line 9299 class MonitorSummary < Struct.new( :monitor_id, :display_name, :subdomain, :url, :role_arn, :identity_center_instance_arn, :identity_center_region, :identity_center_application_arn, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#identity_center_instance_arn ⇒ String
The Amazon Resource Name of the IAM Identity Center instance responsible for authenticating monitor users.
9299 9300 9301 9302 9303 9304 9305 9306 9307 9308 9309 9310 9311 9312 9313 9314 |
# File 'lib/aws-sdk-deadline/types.rb', line 9299 class MonitorSummary < Struct.new( :monitor_id, :display_name, :subdomain, :url, :role_arn, :identity_center_instance_arn, :identity_center_region, :identity_center_application_arn, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#identity_center_region ⇒ String
The Region where IAM Identity Center is enabled.
9299 9300 9301 9302 9303 9304 9305 9306 9307 9308 9309 9310 9311 9312 9313 9314 |
# File 'lib/aws-sdk-deadline/types.rb', line 9299 class MonitorSummary < Struct.new( :monitor_id, :display_name, :subdomain, :url, :role_arn, :identity_center_instance_arn, :identity_center_region, :identity_center_application_arn, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#monitor_id ⇒ String
The unique identifier for the monitor.
9299 9300 9301 9302 9303 9304 9305 9306 9307 9308 9309 9310 9311 9312 9313 9314 |
# File 'lib/aws-sdk-deadline/types.rb', line 9299 class MonitorSummary < Struct.new( :monitor_id, :display_name, :subdomain, :url, :role_arn, :identity_center_instance_arn, :identity_center_region, :identity_center_application_arn, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name of the IAM role for the monitor. Users of the monitor use this role to access Deadline Cloud resources.
9299 9300 9301 9302 9303 9304 9305 9306 9307 9308 9309 9310 9311 9312 9313 9314 |
# File 'lib/aws-sdk-deadline/types.rb', line 9299 class MonitorSummary < Struct.new( :monitor_id, :display_name, :subdomain, :url, :role_arn, :identity_center_instance_arn, :identity_center_region, :identity_center_application_arn, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#subdomain ⇒ String
The subdomain used for the monitor URL. The full URL of the monitor is subdomain.Region.deadlinecloud.amazonaws.com.
9299 9300 9301 9302 9303 9304 9305 9306 9307 9308 9309 9310 9311 9312 9313 9314 |
# File 'lib/aws-sdk-deadline/types.rb', line 9299 class MonitorSummary < Struct.new( :monitor_id, :display_name, :subdomain, :url, :role_arn, :identity_center_instance_arn, :identity_center_region, :identity_center_application_arn, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The UNIX timestamp of the date and time that the monitor was last updated.
9299 9300 9301 9302 9303 9304 9305 9306 9307 9308 9309 9310 9311 9312 9313 9314 |
# File 'lib/aws-sdk-deadline/types.rb', line 9299 class MonitorSummary < Struct.new( :monitor_id, :display_name, :subdomain, :url, :role_arn, :identity_center_instance_arn, :identity_center_region, :identity_center_application_arn, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#updated_by ⇒ String
The user name of the person that last updated the monitor.
9299 9300 9301 9302 9303 9304 9305 9306 9307 9308 9309 9310 9311 9312 9313 9314 |
# File 'lib/aws-sdk-deadline/types.rb', line 9299 class MonitorSummary < Struct.new( :monitor_id, :display_name, :subdomain, :url, :role_arn, :identity_center_instance_arn, :identity_center_region, :identity_center_application_arn, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#url ⇒ String
The complete URL of the monitor. The full URL of the monitor is subdomain.Region.deadlinecloud.amazonaws.com.
9299 9300 9301 9302 9303 9304 9305 9306 9307 9308 9309 9310 9311 9312 9313 9314 |
# File 'lib/aws-sdk-deadline/types.rb', line 9299 class MonitorSummary < Struct.new( :monitor_id, :display_name, :subdomain, :url, :role_arn, :identity_center_instance_arn, :identity_center_region, :identity_center_application_arn, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |