Class: Aws::Deadline::Types::MonitorSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::MonitorSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Provides information about a monitor in Deadline Cloud.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The UNIX timestamp of the date and time that the monitor was created.
-
#created_by ⇒ String
The user name of the person that created the monitor.
-
#display_name ⇒ String
The name of the monitor that displays on the Deadline Cloud console.
-
#identity_center_application_arn ⇒ String
The Amazon Resource Name that the IAM Identity Center assigned to the monitor when it was created.
-
#identity_center_instance_arn ⇒ String
The Amazon Resource Name of the IAM Identity Center instance responsible for authenticating monitor users.
-
#identity_center_region ⇒ String
The Region where IAM Identity Center is enabled.
-
#monitor_id ⇒ String
The unique identifier for the monitor.
-
#role_arn ⇒ String
The Amazon Resource Name of the IAM role for the monitor.
-
#subdomain ⇒ String
The subdomain used for the monitor URL.
-
#updated_at ⇒ Time
The UNIX timestamp of the date and time that the monitor was last updated.
-
#updated_by ⇒ String
The user name of the person that last updated the monitor.
-
#url ⇒ String
The complete URL of the monitor.
Instance Attribute Details
#created_at ⇒ Time
The UNIX timestamp of the date and time that the monitor was created.
9279 9280 9281 9282 9283 9284 9285 9286 9287 9288 9289 9290 9291 9292 9293 9294 |
# File 'lib/aws-sdk-deadline/types.rb', line 9279 class MonitorSummary < Struct.new( :monitor_id, :display_name, :subdomain, :url, :role_arn, :identity_center_instance_arn, :identity_center_region, :identity_center_application_arn, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The user name of the person that created the monitor.
9279 9280 9281 9282 9283 9284 9285 9286 9287 9288 9289 9290 9291 9292 9293 9294 |
# File 'lib/aws-sdk-deadline/types.rb', line 9279 class MonitorSummary < Struct.new( :monitor_id, :display_name, :subdomain, :url, :role_arn, :identity_center_instance_arn, :identity_center_region, :identity_center_application_arn, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The name of the monitor that displays on the Deadline Cloud console.
This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.
9279 9280 9281 9282 9283 9284 9285 9286 9287 9288 9289 9290 9291 9292 9293 9294 |
# File 'lib/aws-sdk-deadline/types.rb', line 9279 class MonitorSummary < Struct.new( :monitor_id, :display_name, :subdomain, :url, :role_arn, :identity_center_instance_arn, :identity_center_region, :identity_center_application_arn, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#identity_center_application_arn ⇒ String
The Amazon Resource Name that the IAM Identity Center assigned to the monitor when it was created.
9279 9280 9281 9282 9283 9284 9285 9286 9287 9288 9289 9290 9291 9292 9293 9294 |
# File 'lib/aws-sdk-deadline/types.rb', line 9279 class MonitorSummary < Struct.new( :monitor_id, :display_name, :subdomain, :url, :role_arn, :identity_center_instance_arn, :identity_center_region, :identity_center_application_arn, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#identity_center_instance_arn ⇒ String
The Amazon Resource Name of the IAM Identity Center instance responsible for authenticating monitor users.
9279 9280 9281 9282 9283 9284 9285 9286 9287 9288 9289 9290 9291 9292 9293 9294 |
# File 'lib/aws-sdk-deadline/types.rb', line 9279 class MonitorSummary < Struct.new( :monitor_id, :display_name, :subdomain, :url, :role_arn, :identity_center_instance_arn, :identity_center_region, :identity_center_application_arn, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#identity_center_region ⇒ String
The Region where IAM Identity Center is enabled.
9279 9280 9281 9282 9283 9284 9285 9286 9287 9288 9289 9290 9291 9292 9293 9294 |
# File 'lib/aws-sdk-deadline/types.rb', line 9279 class MonitorSummary < Struct.new( :monitor_id, :display_name, :subdomain, :url, :role_arn, :identity_center_instance_arn, :identity_center_region, :identity_center_application_arn, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#monitor_id ⇒ String
The unique identifier for the monitor.
9279 9280 9281 9282 9283 9284 9285 9286 9287 9288 9289 9290 9291 9292 9293 9294 |
# File 'lib/aws-sdk-deadline/types.rb', line 9279 class MonitorSummary < Struct.new( :monitor_id, :display_name, :subdomain, :url, :role_arn, :identity_center_instance_arn, :identity_center_region, :identity_center_application_arn, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name of the IAM role for the monitor. Users of the monitor use this role to access Deadline Cloud resources.
9279 9280 9281 9282 9283 9284 9285 9286 9287 9288 9289 9290 9291 9292 9293 9294 |
# File 'lib/aws-sdk-deadline/types.rb', line 9279 class MonitorSummary < Struct.new( :monitor_id, :display_name, :subdomain, :url, :role_arn, :identity_center_instance_arn, :identity_center_region, :identity_center_application_arn, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#subdomain ⇒ String
The subdomain used for the monitor URL. The full URL of the monitor is subdomain.Region.deadlinecloud.amazonaws.com.
9279 9280 9281 9282 9283 9284 9285 9286 9287 9288 9289 9290 9291 9292 9293 9294 |
# File 'lib/aws-sdk-deadline/types.rb', line 9279 class MonitorSummary < Struct.new( :monitor_id, :display_name, :subdomain, :url, :role_arn, :identity_center_instance_arn, :identity_center_region, :identity_center_application_arn, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The UNIX timestamp of the date and time that the monitor was last updated.
9279 9280 9281 9282 9283 9284 9285 9286 9287 9288 9289 9290 9291 9292 9293 9294 |
# File 'lib/aws-sdk-deadline/types.rb', line 9279 class MonitorSummary < Struct.new( :monitor_id, :display_name, :subdomain, :url, :role_arn, :identity_center_instance_arn, :identity_center_region, :identity_center_application_arn, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#updated_by ⇒ String
The user name of the person that last updated the monitor.
9279 9280 9281 9282 9283 9284 9285 9286 9287 9288 9289 9290 9291 9292 9293 9294 |
# File 'lib/aws-sdk-deadline/types.rb', line 9279 class MonitorSummary < Struct.new( :monitor_id, :display_name, :subdomain, :url, :role_arn, :identity_center_instance_arn, :identity_center_region, :identity_center_application_arn, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |
#url ⇒ String
The complete URL of the monitor. The full URL of the monitor is subdomain.Region.deadlinecloud.amazonaws.com.
9279 9280 9281 9282 9283 9284 9285 9286 9287 9288 9289 9290 9291 9292 9293 9294 |
# File 'lib/aws-sdk-deadline/types.rb', line 9279 class MonitorSummary < Struct.new( :monitor_id, :display_name, :subdomain, :url, :role_arn, :identity_center_instance_arn, :identity_center_region, :identity_center_application_arn, :created_at, :created_by, :updated_at, :updated_by) SENSITIVE = [] include Aws::Structure end |