Class: Aws::Deadline::Types::PersistentVolumeConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Specifies the persistent EBS volume configuration for workers in a service managed fleet.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#iopsInteger

The IOPS per persistent volume. The default is 3000.

Returns:

  • (Integer)


9385
9386
9387
9388
9389
9390
9391
9392
9393
# File 'lib/aws-sdk-deadline/types.rb', line 9385

class PersistentVolumeConfiguration < Struct.new(
  :size_gi_b,
  :iops,
  :throughput_mi_b,
  :mount_path,
  :last_used_ttl_hours)
  SENSITIVE = []
  include Aws::Structure
end

#last_used_ttl_hoursInteger

The number of hours a persistent volume can remain unused before it is deleted. The default is 168 (7 days).

Returns:

  • (Integer)


9385
9386
9387
9388
9389
9390
9391
9392
9393
# File 'lib/aws-sdk-deadline/types.rb', line 9385

class PersistentVolumeConfiguration < Struct.new(
  :size_gi_b,
  :iops,
  :throughput_mi_b,
  :mount_path,
  :last_used_ttl_hours)
  SENSITIVE = []
  include Aws::Structure
end

#mount_pathString

The file system path where the persistent volume is mounted on the worker instance.

Returns:

  • (String)


9385
9386
9387
9388
9389
9390
9391
9392
9393
# File 'lib/aws-sdk-deadline/types.rb', line 9385

class PersistentVolumeConfiguration < Struct.new(
  :size_gi_b,
  :iops,
  :throughput_mi_b,
  :mount_path,
  :last_used_ttl_hours)
  SENSITIVE = []
  include Aws::Structure
end

#size_gi_bInteger

The persistent volume size in GiB. The default is 250.

Returns:

  • (Integer)


9385
9386
9387
9388
9389
9390
9391
9392
9393
# File 'lib/aws-sdk-deadline/types.rb', line 9385

class PersistentVolumeConfiguration < Struct.new(
  :size_gi_b,
  :iops,
  :throughput_mi_b,
  :mount_path,
  :last_used_ttl_hours)
  SENSITIVE = []
  include Aws::Structure
end

#throughput_mi_bInteger

The throughput per persistent volume in MiB. The default is 125.

Returns:

  • (Integer)


9385
9386
9387
9388
9389
9390
9391
9392
9393
# File 'lib/aws-sdk-deadline/types.rb', line 9385

class PersistentVolumeConfiguration < Struct.new(
  :size_gi_b,
  :iops,
  :throughput_mi_b,
  :mount_path,
  :last_used_ttl_hours)
  SENSITIVE = []
  include Aws::Structure
end