Class: Aws::Deadline::Types::PersistentVolumeConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::PersistentVolumeConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Specifies the persistent EBS volume configuration for workers in a service managed fleet.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#iops ⇒ Integer
The IOPS per persistent volume.
-
#last_used_ttl_hours ⇒ Integer
The number of hours a persistent volume can remain unused before it is deleted.
-
#mount_path ⇒ String
The file system path where the persistent volume is mounted on the worker instance.
-
#size_gi_b ⇒ Integer
The persistent volume size in GiB.
-
#throughput_mi_b ⇒ Integer
The throughput per persistent volume in MiB.
Instance Attribute Details
#iops ⇒ Integer
The IOPS per persistent volume. The default is 3000.
9385 9386 9387 9388 9389 9390 9391 9392 9393 |
# File 'lib/aws-sdk-deadline/types.rb', line 9385 class PersistentVolumeConfiguration < Struct.new( :size_gi_b, :iops, :throughput_mi_b, :mount_path, :last_used_ttl_hours) SENSITIVE = [] include Aws::Structure end |
#last_used_ttl_hours ⇒ Integer
The number of hours a persistent volume can remain unused before it is deleted. The default is 168 (7 days).
9385 9386 9387 9388 9389 9390 9391 9392 9393 |
# File 'lib/aws-sdk-deadline/types.rb', line 9385 class PersistentVolumeConfiguration < Struct.new( :size_gi_b, :iops, :throughput_mi_b, :mount_path, :last_used_ttl_hours) SENSITIVE = [] include Aws::Structure end |
#mount_path ⇒ String
The file system path where the persistent volume is mounted on the worker instance.
9385 9386 9387 9388 9389 9390 9391 9392 9393 |
# File 'lib/aws-sdk-deadline/types.rb', line 9385 class PersistentVolumeConfiguration < Struct.new( :size_gi_b, :iops, :throughput_mi_b, :mount_path, :last_used_ttl_hours) SENSITIVE = [] include Aws::Structure end |
#size_gi_b ⇒ Integer
The persistent volume size in GiB. The default is 250.
9385 9386 9387 9388 9389 9390 9391 9392 9393 |
# File 'lib/aws-sdk-deadline/types.rb', line 9385 class PersistentVolumeConfiguration < Struct.new( :size_gi_b, :iops, :throughput_mi_b, :mount_path, :last_used_ttl_hours) SENSITIVE = [] include Aws::Structure end |
#throughput_mi_b ⇒ Integer
The throughput per persistent volume in MiB. The default is 125.
9385 9386 9387 9388 9389 9390 9391 9392 9393 |
# File 'lib/aws-sdk-deadline/types.rb', line 9385 class PersistentVolumeConfiguration < Struct.new( :size_gi_b, :iops, :throughput_mi_b, :mount_path, :last_used_ttl_hours) SENSITIVE = [] include Aws::Structure end |