Class: Aws::Deadline::Types::PriorityBalancedSchedulingConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::PriorityBalancedSchedulingConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Configuration for priority balanced scheduling. Workers are distributed evenly across all jobs at the highest priority level.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#rendering_task_buffer ⇒ Integer
The rendering task buffer controls worker stickiness.
Instance Attribute Details
#rendering_task_buffer ⇒ Integer
The rendering task buffer controls worker stickiness. A worker only switches from its current job to another job at the same priority if the other job has fewer rendering tasks by more than this buffer value. Higher values make workers stickier to their current jobs. The default value is ‘1`.
9194 9195 9196 9197 9198 |
# File 'lib/aws-sdk-deadline/types.rb', line 9194 class PriorityBalancedSchedulingConfiguration < Struct.new( :rendering_task_buffer) SENSITIVE = [] include Aws::Structure end |