Class: Aws::Deadline::Types::SchedulingMaxPriorityOverride

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Note:

SchedulingMaxPriorityOverride is a union - when making an API calls you must set exactly one of the members.

Note:

SchedulingMaxPriorityOverride is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of SchedulingMaxPriorityOverride corresponding to the set member.

Defines the override behavior for jobs at the maximum priority (100) in weighted balanced scheduling.

Direct Known Subclasses

AlwaysScheduleFirst, Unknown

Defined Under Namespace

Classes: AlwaysScheduleFirst, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#always_schedule_firstTypes::SchedulingMaxPriorityOverrideAlwaysScheduleFirst

Jobs at the maximum priority (100) are always scheduled before other jobs, regardless of the weighted scheduling formula. If multiple jobs have priority 100, ties are broken using the standard weighted formula.



9619
9620
9621
9622
9623
9624
9625
9626
9627
9628
# File 'lib/aws-sdk-deadline/types.rb', line 9619

class SchedulingMaxPriorityOverride < Struct.new(
  :always_schedule_first,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AlwaysScheduleFirst < SchedulingMaxPriorityOverride; end
  class Unknown < SchedulingMaxPriorityOverride; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



9619
9620
9621
# File 'lib/aws-sdk-deadline/types.rb', line 9619

def unknown
  @unknown
end