Class: Aws::Deadline::Types::SchedulingMaxPriorityOverride
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::SchedulingMaxPriorityOverride
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
SchedulingMaxPriorityOverride is a union - when making an API calls you must set exactly one of the members.
SchedulingMaxPriorityOverride is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of SchedulingMaxPriorityOverride corresponding to the set member.
Defines the override behavior for jobs at the maximum priority (100) in weighted balanced scheduling.
Direct Known Subclasses
Defined Under Namespace
Classes: AlwaysScheduleFirst, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#always_schedule_first ⇒ Types::SchedulingMaxPriorityOverrideAlwaysScheduleFirst
Jobs at the maximum priority (100) are always scheduled before other jobs, regardless of the weighted scheduling formula.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#always_schedule_first ⇒ Types::SchedulingMaxPriorityOverrideAlwaysScheduleFirst
Jobs at the maximum priority (100) are always scheduled before other jobs, regardless of the weighted scheduling formula. If multiple jobs have priority 100, ties are broken using the standard weighted formula.
9609 9610 9611 9612 9613 9614 9615 9616 9617 9618 |
# File 'lib/aws-sdk-deadline/types.rb', line 9609 class SchedulingMaxPriorityOverride < Struct.new( :always_schedule_first, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AlwaysScheduleFirst < SchedulingMaxPriorityOverride; end class Unknown < SchedulingMaxPriorityOverride; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
9609 9610 9611 |
# File 'lib/aws-sdk-deadline/types.rb', line 9609 def unknown @unknown end |