Class: Aws::Deadline::Types::SchedulingMinPriorityOverride
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::SchedulingMinPriorityOverride
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
SchedulingMinPriorityOverride is a union - when making an API calls you must set exactly one of the members.
SchedulingMinPriorityOverride is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of SchedulingMinPriorityOverride corresponding to the set member.
Defines the override behavior for jobs at the minimum priority (0) in weighted balanced scheduling.
Direct Known Subclasses
Defined Under Namespace
Classes: AlwaysScheduleLast, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#always_schedule_last ⇒ Types::SchedulingMinPriorityOverrideAlwaysScheduleLast
Jobs at the minimum priority (0) are always scheduled after all other jobs, regardless of the weighted scheduling formula.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#always_schedule_last ⇒ Types::SchedulingMinPriorityOverrideAlwaysScheduleLast
Jobs at the minimum priority (0) are always scheduled after all other jobs, regardless of the weighted scheduling formula. If multiple jobs have priority 0, ties are broken using the standard weighted formula.
9878 9879 9880 9881 9882 9883 9884 9885 9886 9887 |
# File 'lib/aws-sdk-deadline/types.rb', line 9878 class SchedulingMinPriorityOverride < Struct.new( :always_schedule_last, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AlwaysScheduleLast < SchedulingMinPriorityOverride; end class Unknown < SchedulingMinPriorityOverride; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
9878 9879 9880 |
# File 'lib/aws-sdk-deadline/types.rb', line 9878 def unknown @unknown end |