Class: Aws::Deadline::Types::SchedulingMinPriorityOverride

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Note:

SchedulingMinPriorityOverride is a union - when making an API calls you must set exactly one of the members.

Note:

SchedulingMinPriorityOverride is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of SchedulingMinPriorityOverride corresponding to the set member.

Defines the override behavior for jobs at the minimum priority (0) in weighted balanced scheduling.

Direct Known Subclasses

AlwaysScheduleLast, Unknown

Defined Under Namespace

Classes: AlwaysScheduleLast, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#always_schedule_lastTypes::SchedulingMinPriorityOverrideAlwaysScheduleLast

Jobs at the minimum priority (0) are always scheduled after all other jobs, regardless of the weighted scheduling formula. If multiple jobs have priority 0, ties are broken using the standard weighted formula.



9655
9656
9657
9658
9659
9660
9661
9662
9663
9664
# File 'lib/aws-sdk-deadline/types.rb', line 9655

class SchedulingMinPriorityOverride < Struct.new(
  :always_schedule_last,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AlwaysScheduleLast < SchedulingMinPriorityOverride; end
  class Unknown < SchedulingMinPriorityOverride; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



9655
9656
9657
# File 'lib/aws-sdk-deadline/types.rb', line 9655

def unknown
  @unknown
end