Class: Aws::Deadline::Types::ServiceQuotaExceededException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

You exceeded your service quota. Service quotas, also referred to as limits, are the maximum number of service resources or operations for your Amazon Web Services account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contextHash<String,String>

Information about the resources in use when the exception was thrown.

Returns:

  • (Hash<String,String>)


10249
10250
10251
10252
10253
10254
10255
10256
10257
10258
10259
# File 'lib/aws-sdk-deadline/types.rb', line 10249

class ServiceQuotaExceededException < Struct.new(
  :message,
  :reason,
  :resource_type,
  :service_code,
  :quota_code,
  :resource_id,
  :context)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

Returns:

  • (String)


10249
10250
10251
10252
10253
10254
10255
10256
10257
10258
10259
# File 'lib/aws-sdk-deadline/types.rb', line 10249

class ServiceQuotaExceededException < Struct.new(
  :message,
  :reason,
  :resource_type,
  :service_code,
  :quota_code,
  :resource_id,
  :context)
  SENSITIVE = []
  include Aws::Structure
end

#quota_codeString

Identifies the quota that has been exceeded.

Returns:

  • (String)


10249
10250
10251
10252
10253
10254
10255
10256
10257
10258
10259
# File 'lib/aws-sdk-deadline/types.rb', line 10249

class ServiceQuotaExceededException < Struct.new(
  :message,
  :reason,
  :resource_type,
  :service_code,
  :quota_code,
  :resource_id,
  :context)
  SENSITIVE = []
  include Aws::Structure
end

#reasonString

A string that describes the reason the quota was exceeded.

Returns:

  • (String)


10249
10250
10251
10252
10253
10254
10255
10256
10257
10258
10259
# File 'lib/aws-sdk-deadline/types.rb', line 10249

class ServiceQuotaExceededException < Struct.new(
  :message,
  :reason,
  :resource_type,
  :service_code,
  :quota_code,
  :resource_id,
  :context)
  SENSITIVE = []
  include Aws::Structure
end

#resource_idString

The identifier of the affected resource.

Returns:

  • (String)


10249
10250
10251
10252
10253
10254
10255
10256
10257
10258
10259
# File 'lib/aws-sdk-deadline/types.rb', line 10249

class ServiceQuotaExceededException < Struct.new(
  :message,
  :reason,
  :resource_type,
  :service_code,
  :quota_code,
  :resource_id,
  :context)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The type of the affected resource

Returns:

  • (String)


10249
10250
10251
10252
10253
10254
10255
10256
10257
10258
10259
# File 'lib/aws-sdk-deadline/types.rb', line 10249

class ServiceQuotaExceededException < Struct.new(
  :message,
  :reason,
  :resource_type,
  :service_code,
  :quota_code,
  :resource_id,
  :context)
  SENSITIVE = []
  include Aws::Structure
end

#service_codeString

Identifies the service that exceeded the quota.

Returns:

  • (String)


10249
10250
10251
10252
10253
10254
10255
10256
10257
10258
10259
# File 'lib/aws-sdk-deadline/types.rb', line 10249

class ServiceQuotaExceededException < Struct.new(
  :message,
  :reason,
  :resource_type,
  :service_code,
  :quota_code,
  :resource_id,
  :context)
  SENSITIVE = []
  include Aws::Structure
end