Class: Aws::Deadline::Types::ServiceQuotaExceededException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::ServiceQuotaExceededException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
You exceeded your service quota. Service quotas, also referred to as limits, are the maximum number of service resources or operations for your Amazon Web Services account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#context ⇒ Hash<String,String>
Information about the resources in use when the exception was thrown.
- #message ⇒ String
-
#quota_code ⇒ String
Identifies the quota that has been exceeded.
-
#reason ⇒ String
A string that describes the reason the quota was exceeded.
-
#resource_id ⇒ String
The identifier of the affected resource.
-
#resource_type ⇒ String
The type of the affected resource.
-
#service_code ⇒ String
Identifies the service that exceeded the quota.
Instance Attribute Details
#context ⇒ Hash<String,String>
Information about the resources in use when the exception was thrown.
10249 10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 |
# File 'lib/aws-sdk-deadline/types.rb', line 10249 class ServiceQuotaExceededException < Struct.new( :message, :reason, :resource_type, :service_code, :quota_code, :resource_id, :context) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
10249 10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 |
# File 'lib/aws-sdk-deadline/types.rb', line 10249 class ServiceQuotaExceededException < Struct.new( :message, :reason, :resource_type, :service_code, :quota_code, :resource_id, :context) SENSITIVE = [] include Aws::Structure end |
#quota_code ⇒ String
Identifies the quota that has been exceeded.
10249 10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 |
# File 'lib/aws-sdk-deadline/types.rb', line 10249 class ServiceQuotaExceededException < Struct.new( :message, :reason, :resource_type, :service_code, :quota_code, :resource_id, :context) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
A string that describes the reason the quota was exceeded.
10249 10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 |
# File 'lib/aws-sdk-deadline/types.rb', line 10249 class ServiceQuotaExceededException < Struct.new( :message, :reason, :resource_type, :service_code, :quota_code, :resource_id, :context) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The identifier of the affected resource.
10249 10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 |
# File 'lib/aws-sdk-deadline/types.rb', line 10249 class ServiceQuotaExceededException < Struct.new( :message, :reason, :resource_type, :service_code, :quota_code, :resource_id, :context) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of the affected resource
10249 10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 |
# File 'lib/aws-sdk-deadline/types.rb', line 10249 class ServiceQuotaExceededException < Struct.new( :message, :reason, :resource_type, :service_code, :quota_code, :resource_id, :context) SENSITIVE = [] include Aws::Structure end |
#service_code ⇒ String
Identifies the service that exceeded the quota.
10249 10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 |
# File 'lib/aws-sdk-deadline/types.rb', line 10249 class ServiceQuotaExceededException < Struct.new( :message, :reason, :resource_type, :service_code, :quota_code, :resource_id, :context) SENSITIVE = [] include Aws::Structure end |