Class: Aws::Deadline::Types::ServiceQuotaExceededException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::ServiceQuotaExceededException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
You exceeded your service quota. Service quotas, also referred to as limits, are the maximum number of service resources or operations for your Amazon Web Services account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#context ⇒ Hash<String,String>
Information about the resources in use when the exception was thrown.
- #message ⇒ String
-
#quota_code ⇒ String
Identifies the quota that has been exceeded.
-
#reason ⇒ String
A string that describes the reason the quota was exceeded.
-
#resource_id ⇒ String
The identifier of the affected resource.
-
#resource_type ⇒ String
The type of the affected resource.
-
#service_code ⇒ String
Identifies the service that exceeded the quota.
Instance Attribute Details
#context ⇒ Hash<String,String>
Information about the resources in use when the exception was thrown.
8256 8257 8258 8259 8260 8261 8262 8263 8264 8265 8266 |
# File 'lib/aws-sdk-deadline/types.rb', line 8256 class ServiceQuotaExceededException < Struct.new( :message, :reason, :resource_type, :service_code, :quota_code, :resource_id, :context) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
8256 8257 8258 8259 8260 8261 8262 8263 8264 8265 8266 |
# File 'lib/aws-sdk-deadline/types.rb', line 8256 class ServiceQuotaExceededException < Struct.new( :message, :reason, :resource_type, :service_code, :quota_code, :resource_id, :context) SENSITIVE = [] include Aws::Structure end |
#quota_code ⇒ String
Identifies the quota that has been exceeded.
8256 8257 8258 8259 8260 8261 8262 8263 8264 8265 8266 |
# File 'lib/aws-sdk-deadline/types.rb', line 8256 class ServiceQuotaExceededException < Struct.new( :message, :reason, :resource_type, :service_code, :quota_code, :resource_id, :context) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
A string that describes the reason the quota was exceeded.
8256 8257 8258 8259 8260 8261 8262 8263 8264 8265 8266 |
# File 'lib/aws-sdk-deadline/types.rb', line 8256 class ServiceQuotaExceededException < Struct.new( :message, :reason, :resource_type, :service_code, :quota_code, :resource_id, :context) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The identifier of the affected resource.
8256 8257 8258 8259 8260 8261 8262 8263 8264 8265 8266 |
# File 'lib/aws-sdk-deadline/types.rb', line 8256 class ServiceQuotaExceededException < Struct.new( :message, :reason, :resource_type, :service_code, :quota_code, :resource_id, :context) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of the affected resource
8256 8257 8258 8259 8260 8261 8262 8263 8264 8265 8266 |
# File 'lib/aws-sdk-deadline/types.rb', line 8256 class ServiceQuotaExceededException < Struct.new( :message, :reason, :resource_type, :service_code, :quota_code, :resource_id, :context) SENSITIVE = [] include Aws::Structure end |
#service_code ⇒ String
Identifies the service that exceeded the quota.
8256 8257 8258 8259 8260 8261 8262 8263 8264 8265 8266 |
# File 'lib/aws-sdk-deadline/types.rb', line 8256 class ServiceQuotaExceededException < Struct.new( :message, :reason, :resource_type, :service_code, :quota_code, :resource_id, :context) SENSITIVE = [] include Aws::Structure end |