Class: Aws::Deadline::Types::SessionsStatisticsResources
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::SessionsStatisticsResources
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
SessionsStatisticsResources is a union - when making an API calls you must set exactly one of the members.
Specifies the fleet IDs or queue IDs to return statistics. You can specify only fleet IDs or queue IDS, not both.
Defined Under Namespace
Classes: FleetIds, QueueIds, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#fleet_ids ⇒ Array<String>
One to 10 fleet IDs that specify the fleets to return statistics for.
-
#queue_ids ⇒ Array<String>
One to 10 queue IDs that specify the queues to return statistics for.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#fleet_ids ⇒ Array<String>
One to 10 fleet IDs that specify the fleets to return statistics
for. If you specify the fleetIds field, you can't specify the
queueIds field.
10737 10738 10739 10740 10741 10742 10743 10744 10745 10746 10747 10748 |
# File 'lib/aws-sdk-deadline/types.rb', line 10737 class SessionsStatisticsResources < Struct.new( :queue_ids, :fleet_ids, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class QueueIds < SessionsStatisticsResources; end class FleetIds < SessionsStatisticsResources; end class Unknown < SessionsStatisticsResources; end end |
#queue_ids ⇒ Array<String>
One to 10 queue IDs that specify the queues to return statistics
for. If you specify the queueIds field, you can't specify the
fleetIds field.
10737 10738 10739 10740 10741 10742 10743 10744 10745 10746 10747 10748 |
# File 'lib/aws-sdk-deadline/types.rb', line 10737 class SessionsStatisticsResources < Struct.new( :queue_ids, :fleet_ids, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class QueueIds < SessionsStatisticsResources; end class FleetIds < SessionsStatisticsResources; end class Unknown < SessionsStatisticsResources; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
10737 10738 10739 |
# File 'lib/aws-sdk-deadline/types.rb', line 10737 def unknown @unknown end |