Class: Aws::Deadline::Types::SessionsStatisticsResources
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::SessionsStatisticsResources
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
SessionsStatisticsResources is a union - when making an API calls you must set exactly one of the members.
Specifies the fleet IDs or queue IDs to return statistics. You can specify only fleet IDs or queue IDS, not both.
Defined Under Namespace
Classes: FleetIds, QueueIds, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#fleet_ids ⇒ Array<String>
One to 10 fleet IDs that specify the fleets to return statistics for.
-
#queue_ids ⇒ Array<String>
One to 10 queue IDs that specify the queues to return statistics for.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#fleet_ids ⇒ Array<String>
One to 10 fleet IDs that specify the fleets to return statistics for. If you specify the ‘fleetIds` field, you can’t specify the ‘queueIds` field.
10464 10465 10466 10467 10468 10469 10470 10471 10472 10473 10474 10475 |
# File 'lib/aws-sdk-deadline/types.rb', line 10464 class SessionsStatisticsResources < Struct.new( :queue_ids, :fleet_ids, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class QueueIds < SessionsStatisticsResources; end class FleetIds < SessionsStatisticsResources; end class Unknown < SessionsStatisticsResources; end end |
#queue_ids ⇒ Array<String>
One to 10 queue IDs that specify the queues to return statistics for. If you specify the ‘queueIds` field, you can’t specify the ‘fleetIds` field.
10464 10465 10466 10467 10468 10469 10470 10471 10472 10473 10474 10475 |
# File 'lib/aws-sdk-deadline/types.rb', line 10464 class SessionsStatisticsResources < Struct.new( :queue_ids, :fleet_ids, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class QueueIds < SessionsStatisticsResources; end class FleetIds < SessionsStatisticsResources; end class Unknown < SessionsStatisticsResources; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
10464 10465 10466 |
# File 'lib/aws-sdk-deadline/types.rb', line 10464 def unknown @unknown end |