Class: Aws::Deadline::Types::StepParameterChunks

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Defines how a step parameter range should be divided into chunks.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#default_task_countInteger

The number of tasks to combine into a single chunk by default.

Returns:

  • (Integer)


10849
10850
10851
10852
10853
10854
10855
# File 'lib/aws-sdk-deadline/types.rb', line 10849

class StepParameterChunks < Struct.new(
  :default_task_count,
  :target_runtime_seconds,
  :range_constraint)
  SENSITIVE = []
  include Aws::Structure
end

#range_constraintString

Specifies whether the chunked ranges must be contiguous or can have gaps between them.

Returns:

  • (String)


10849
10850
10851
10852
10853
10854
10855
# File 'lib/aws-sdk-deadline/types.rb', line 10849

class StepParameterChunks < Struct.new(
  :default_task_count,
  :target_runtime_seconds,
  :range_constraint)
  SENSITIVE = []
  include Aws::Structure
end

#target_runtime_secondsInteger

The number of seconds to aim for when forming chunks.

Returns:

  • (Integer)


10849
10850
10851
10852
10853
10854
10855
# File 'lib/aws-sdk-deadline/types.rb', line 10849

class StepParameterChunks < Struct.new(
  :default_task_count,
  :target_runtime_seconds,
  :range_constraint)
  SENSITIVE = []
  include Aws::Structure
end