Class: Aws::Deadline::Types::StepSearchSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::StepSearchSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
The details of a step search.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The date and time the resource was created.
-
#created_by ⇒ String
The user or system that created this resource.
-
#ended_at ⇒ Time
The date and time the resource ended running.
-
#job_id ⇒ String
The job ID.
-
#lifecycle_status ⇒ String
The life cycle status.
-
#lifecycle_status_message ⇒ String
The life cycle status message.
-
#name ⇒ String
The step name.
-
#parameter_space ⇒ Types::ParameterSpace
The parameters and combination expressions for the search.
-
#queue_id ⇒ String
The queue ID.
-
#started_at ⇒ Time
The date and time the resource started running.
-
#step_id ⇒ String
The step ID.
-
#target_task_run_status ⇒ String
The task status to update the job’s tasks to.
-
#task_failure_retry_count ⇒ Integer
The total number of times tasks from the step failed and were retried.
-
#task_run_status ⇒ String
The task run status for the job.
-
#task_run_status_counts ⇒ Hash<String,Integer>
The number of tasks running on the job.
-
#updated_at ⇒ Time
The date and time the resource was updated.
-
#updated_by ⇒ String
The user or system that updated this resource.
Instance Attribute Details
#created_at ⇒ Time
The date and time the resource was created.
10978 10979 10980 10981 10982 10983 10984 10985 10986 10987 10988 10989 10990 10991 10992 10993 10994 10995 10996 10997 10998 |
# File 'lib/aws-sdk-deadline/types.rb', line 10978 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ String
The user or system that created this resource.
10978 10979 10980 10981 10982 10983 10984 10985 10986 10987 10988 10989 10990 10991 10992 10993 10994 10995 10996 10997 10998 |
# File 'lib/aws-sdk-deadline/types.rb', line 10978 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#ended_at ⇒ Time
The date and time the resource ended running.
10978 10979 10980 10981 10982 10983 10984 10985 10986 10987 10988 10989 10990 10991 10992 10993 10994 10995 10996 10997 10998 |
# File 'lib/aws-sdk-deadline/types.rb', line 10978 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The job ID.
10978 10979 10980 10981 10982 10983 10984 10985 10986 10987 10988 10989 10990 10991 10992 10993 10994 10995 10996 10997 10998 |
# File 'lib/aws-sdk-deadline/types.rb', line 10978 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#lifecycle_status ⇒ String
The life cycle status.
10978 10979 10980 10981 10982 10983 10984 10985 10986 10987 10988 10989 10990 10991 10992 10993 10994 10995 10996 10997 10998 |
# File 'lib/aws-sdk-deadline/types.rb', line 10978 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#lifecycle_status_message ⇒ String
The life cycle status message.
10978 10979 10980 10981 10982 10983 10984 10985 10986 10987 10988 10989 10990 10991 10992 10993 10994 10995 10996 10997 10998 |
# File 'lib/aws-sdk-deadline/types.rb', line 10978 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The step name.
10978 10979 10980 10981 10982 10983 10984 10985 10986 10987 10988 10989 10990 10991 10992 10993 10994 10995 10996 10997 10998 |
# File 'lib/aws-sdk-deadline/types.rb', line 10978 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#parameter_space ⇒ Types::ParameterSpace
The parameters and combination expressions for the search.
10978 10979 10980 10981 10982 10983 10984 10985 10986 10987 10988 10989 10990 10991 10992 10993 10994 10995 10996 10997 10998 |
# File 'lib/aws-sdk-deadline/types.rb', line 10978 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#queue_id ⇒ String
The queue ID.
10978 10979 10980 10981 10982 10983 10984 10985 10986 10987 10988 10989 10990 10991 10992 10993 10994 10995 10996 10997 10998 |
# File 'lib/aws-sdk-deadline/types.rb', line 10978 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The date and time the resource started running.
10978 10979 10980 10981 10982 10983 10984 10985 10986 10987 10988 10989 10990 10991 10992 10993 10994 10995 10996 10997 10998 |
# File 'lib/aws-sdk-deadline/types.rb', line 10978 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#step_id ⇒ String
The step ID.
10978 10979 10980 10981 10982 10983 10984 10985 10986 10987 10988 10989 10990 10991 10992 10993 10994 10995 10996 10997 10998 |
# File 'lib/aws-sdk-deadline/types.rb', line 10978 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#target_task_run_status ⇒ String
The task status to update the job’s tasks to.
10978 10979 10980 10981 10982 10983 10984 10985 10986 10987 10988 10989 10990 10991 10992 10993 10994 10995 10996 10997 10998 |
# File 'lib/aws-sdk-deadline/types.rb', line 10978 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#task_failure_retry_count ⇒ Integer
The total number of times tasks from the step failed and were retried.
10978 10979 10980 10981 10982 10983 10984 10985 10986 10987 10988 10989 10990 10991 10992 10993 10994 10995 10996 10997 10998 |
# File 'lib/aws-sdk-deadline/types.rb', line 10978 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#task_run_status ⇒ String
The task run status for the job.
-
‘PENDING`–pending and waiting for resources.
-
‘READY`–ready to be processed.
-
‘ASSIGNED`–assigned and will run next on a worker.
-
‘SCHEDULED`–scheduled to be run on a worker.
-
‘INTERRUPTING`–being interrupted.
-
‘RUNNING`–running on a worker.
-
‘SUSPENDED`–the task is suspended.
-
‘CANCELED`–the task has been canceled.
-
‘FAILED`–the task has failed.
-
‘SUCCEEDED`–the task has succeeded.
10978 10979 10980 10981 10982 10983 10984 10985 10986 10987 10988 10989 10990 10991 10992 10993 10994 10995 10996 10997 10998 |
# File 'lib/aws-sdk-deadline/types.rb', line 10978 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#task_run_status_counts ⇒ Hash<String,Integer>
The number of tasks running on the job.
10978 10979 10980 10981 10982 10983 10984 10985 10986 10987 10988 10989 10990 10991 10992 10993 10994 10995 10996 10997 10998 |
# File 'lib/aws-sdk-deadline/types.rb', line 10978 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time the resource was updated.
10978 10979 10980 10981 10982 10983 10984 10985 10986 10987 10988 10989 10990 10991 10992 10993 10994 10995 10996 10997 10998 |
# File 'lib/aws-sdk-deadline/types.rb', line 10978 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |
#updated_by ⇒ String
The user or system that updated this resource.
10978 10979 10980 10981 10982 10983 10984 10985 10986 10987 10988 10989 10990 10991 10992 10993 10994 10995 10996 10997 10998 |
# File 'lib/aws-sdk-deadline/types.rb', line 10978 class StepSearchSummary < Struct.new( :step_id, :job_id, :queue_id, :name, :lifecycle_status, :lifecycle_status_message, :task_run_status, :target_task_run_status, :task_run_status_counts, :task_failure_retry_count, :created_at, :created_by, :started_at, :ended_at, :updated_at, :updated_by, :parameter_space) SENSITIVE = [] include Aws::Structure end |