Class: Aws::Deadline::Types::SyncInputJobAttachmentsSessionActionDefinition

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

The session action definition for syncing input job attachments.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#step_idString

The step ID for the sync input job attachments session action.

Returns:

  • (String)


11189
11190
11191
11192
11193
# File 'lib/aws-sdk-deadline/types.rb', line 11189

class SyncInputJobAttachmentsSessionActionDefinition < Struct.new(
  :step_id)
  SENSITIVE = []
  include Aws::Structure
end