Class: Aws::Deadline::Types::UpdateFarmRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::UpdateFarmRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#cost_scale_factor ⇒ Float
A multiplier applied to the farm’s calculated costs for usage data and budget tracking.
-
#description ⇒ String
The description of the farm to update.
-
#display_name ⇒ String
The display name of the farm to update.
-
#farm_id ⇒ String
The farm ID to update.
Instance Attribute Details
#cost_scale_factor ⇒ Float
A multiplier applied to the farm’s calculated costs for usage data and budget tracking. A value less than 1 represents a discount, a value greater than 1 represents a premium, and a value of 1 represents no adjustment.
11666 11667 11668 11669 11670 11671 11672 11673 |
# File 'lib/aws-sdk-deadline/types.rb', line 11666 class UpdateFarmRequest < Struct.new( :farm_id, :display_name, :description, :cost_scale_factor) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
The description of the farm to update.
This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.
11666 11667 11668 11669 11670 11671 11672 11673 |
# File 'lib/aws-sdk-deadline/types.rb', line 11666 class UpdateFarmRequest < Struct.new( :farm_id, :display_name, :description, :cost_scale_factor) SENSITIVE = [:description] include Aws::Structure end |
#display_name ⇒ String
The display name of the farm to update.
This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.
11666 11667 11668 11669 11670 11671 11672 11673 |
# File 'lib/aws-sdk-deadline/types.rb', line 11666 class UpdateFarmRequest < Struct.new( :farm_id, :display_name, :description, :cost_scale_factor) SENSITIVE = [:description] include Aws::Structure end |
#farm_id ⇒ String
The farm ID to update.
11666 11667 11668 11669 11670 11671 11672 11673 |
# File 'lib/aws-sdk-deadline/types.rb', line 11666 class UpdateFarmRequest < Struct.new( :farm_id, :display_name, :description, :cost_scale_factor) SENSITIVE = [:description] include Aws::Structure end |