Class: Aws::Deadline::Types::UpdateJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::UpdateJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#client_token ⇒ String
The unique token which the server uses to recognize retries of the same request.
-
#description ⇒ String
The updated job description.
-
#farm_id ⇒ String
The farm ID of the job to update.
-
#job_id ⇒ String
The job ID to update.
-
#lifecycle_status ⇒ String
The status of a job in its lifecycle.
-
#max_failed_tasks_count ⇒ Integer
The number of task failures before the job stops running and is marked as ‘FAILED`.
-
#max_retries_per_task ⇒ Integer
The maximum number of retries for a job.
-
#max_worker_count ⇒ Integer
The maximum number of worker hosts that can concurrently process a job.
-
#name ⇒ String
The updated job name.
-
#priority ⇒ Integer
The updated job priority.
-
#queue_id ⇒ String
The queue ID of the job to update.
-
#target_task_run_status ⇒ String
The task status to update the job’s tasks to.
Instance Attribute Details
#client_token ⇒ String
The unique token which the server uses to recognize retries of the same request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
12070 12071 12072 12073 12074 12075 12076 12077 12078 12079 12080 12081 12082 12083 12084 12085 |
# File 'lib/aws-sdk-deadline/types.rb', line 12070 class UpdateJobRequest < Struct.new( :farm_id, :queue_id, :job_id, :client_token, :target_task_run_status, :priority, :max_failed_tasks_count, :max_retries_per_task, :lifecycle_status, :max_worker_count, :name, :description) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
The updated job description.
12070 12071 12072 12073 12074 12075 12076 12077 12078 12079 12080 12081 12082 12083 12084 12085 |
# File 'lib/aws-sdk-deadline/types.rb', line 12070 class UpdateJobRequest < Struct.new( :farm_id, :queue_id, :job_id, :client_token, :target_task_run_status, :priority, :max_failed_tasks_count, :max_retries_per_task, :lifecycle_status, :max_worker_count, :name, :description) SENSITIVE = [:description] include Aws::Structure end |
#farm_id ⇒ String
The farm ID of the job to update.
12070 12071 12072 12073 12074 12075 12076 12077 12078 12079 12080 12081 12082 12083 12084 12085 |
# File 'lib/aws-sdk-deadline/types.rb', line 12070 class UpdateJobRequest < Struct.new( :farm_id, :queue_id, :job_id, :client_token, :target_task_run_status, :priority, :max_failed_tasks_count, :max_retries_per_task, :lifecycle_status, :max_worker_count, :name, :description) SENSITIVE = [:description] include Aws::Structure end |
#job_id ⇒ String
The job ID to update.
12070 12071 12072 12073 12074 12075 12076 12077 12078 12079 12080 12081 12082 12083 12084 12085 |
# File 'lib/aws-sdk-deadline/types.rb', line 12070 class UpdateJobRequest < Struct.new( :farm_id, :queue_id, :job_id, :client_token, :target_task_run_status, :priority, :max_failed_tasks_count, :max_retries_per_task, :lifecycle_status, :max_worker_count, :name, :description) SENSITIVE = [:description] include Aws::Structure end |
#lifecycle_status ⇒ String
The status of a job in its lifecycle. When you change the status of the job to ‘ARCHIVED`, the job can’t be scheduled or archived.
An archived jobs and its steps and tasks are deleted after 120 days. The job can’t be recovered.
12070 12071 12072 12073 12074 12075 12076 12077 12078 12079 12080 12081 12082 12083 12084 12085 |
# File 'lib/aws-sdk-deadline/types.rb', line 12070 class UpdateJobRequest < Struct.new( :farm_id, :queue_id, :job_id, :client_token, :target_task_run_status, :priority, :max_failed_tasks_count, :max_retries_per_task, :lifecycle_status, :max_worker_count, :name, :description) SENSITIVE = [:description] include Aws::Structure end |
#max_failed_tasks_count ⇒ Integer
The number of task failures before the job stops running and is marked as ‘FAILED`.
12070 12071 12072 12073 12074 12075 12076 12077 12078 12079 12080 12081 12082 12083 12084 12085 |
# File 'lib/aws-sdk-deadline/types.rb', line 12070 class UpdateJobRequest < Struct.new( :farm_id, :queue_id, :job_id, :client_token, :target_task_run_status, :priority, :max_failed_tasks_count, :max_retries_per_task, :lifecycle_status, :max_worker_count, :name, :description) SENSITIVE = [:description] include Aws::Structure end |
#max_retries_per_task ⇒ Integer
The maximum number of retries for a job.
12070 12071 12072 12073 12074 12075 12076 12077 12078 12079 12080 12081 12082 12083 12084 12085 |
# File 'lib/aws-sdk-deadline/types.rb', line 12070 class UpdateJobRequest < Struct.new( :farm_id, :queue_id, :job_id, :client_token, :target_task_run_status, :priority, :max_failed_tasks_count, :max_retries_per_task, :lifecycle_status, :max_worker_count, :name, :description) SENSITIVE = [:description] include Aws::Structure end |
#max_worker_count ⇒ Integer
The maximum number of worker hosts that can concurrently process a job. When the ‘maxWorkerCount` is reached, no more workers will be assigned to process the job, even if the fleets assigned to the job’s queue has available workers.
You can’t set the ‘maxWorkerCount` to 0. If you set it to -1, there is no maximum number of workers.
If you don’t specify the ‘maxWorkerCount`, the default is -1.
The maximum number of workers that can process tasks in the job.
12070 12071 12072 12073 12074 12075 12076 12077 12078 12079 12080 12081 12082 12083 12084 12085 |
# File 'lib/aws-sdk-deadline/types.rb', line 12070 class UpdateJobRequest < Struct.new( :farm_id, :queue_id, :job_id, :client_token, :target_task_run_status, :priority, :max_failed_tasks_count, :max_retries_per_task, :lifecycle_status, :max_worker_count, :name, :description) SENSITIVE = [:description] include Aws::Structure end |
#name ⇒ String
The updated job name.
12070 12071 12072 12073 12074 12075 12076 12077 12078 12079 12080 12081 12082 12083 12084 12085 |
# File 'lib/aws-sdk-deadline/types.rb', line 12070 class UpdateJobRequest < Struct.new( :farm_id, :queue_id, :job_id, :client_token, :target_task_run_status, :priority, :max_failed_tasks_count, :max_retries_per_task, :lifecycle_status, :max_worker_count, :name, :description) SENSITIVE = [:description] include Aws::Structure end |
#priority ⇒ Integer
The updated job priority.
12070 12071 12072 12073 12074 12075 12076 12077 12078 12079 12080 12081 12082 12083 12084 12085 |
# File 'lib/aws-sdk-deadline/types.rb', line 12070 class UpdateJobRequest < Struct.new( :farm_id, :queue_id, :job_id, :client_token, :target_task_run_status, :priority, :max_failed_tasks_count, :max_retries_per_task, :lifecycle_status, :max_worker_count, :name, :description) SENSITIVE = [:description] include Aws::Structure end |
#queue_id ⇒ String
The queue ID of the job to update.
12070 12071 12072 12073 12074 12075 12076 12077 12078 12079 12080 12081 12082 12083 12084 12085 |
# File 'lib/aws-sdk-deadline/types.rb', line 12070 class UpdateJobRequest < Struct.new( :farm_id, :queue_id, :job_id, :client_token, :target_task_run_status, :priority, :max_failed_tasks_count, :max_retries_per_task, :lifecycle_status, :max_worker_count, :name, :description) SENSITIVE = [:description] include Aws::Structure end |
#target_task_run_status ⇒ String
The task status to update the job’s tasks to.
12070 12071 12072 12073 12074 12075 12076 12077 12078 12079 12080 12081 12082 12083 12084 12085 |
# File 'lib/aws-sdk-deadline/types.rb', line 12070 class UpdateJobRequest < Struct.new( :farm_id, :queue_id, :job_id, :client_token, :target_task_run_status, :priority, :max_failed_tasks_count, :max_retries_per_task, :lifecycle_status, :max_worker_count, :name, :description) SENSITIVE = [:description] include Aws::Structure end |