Method: Aws::Deadline::Types::UpdateMonitorRequest#display_name
- Defined in:
- lib/aws-sdk-deadline/types.rb
#display_name ⇒ String
The new value to use for the monitor’s display name.
This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.
9928 9929 9930 9931 9932 9933 9934 9935 |
# File 'lib/aws-sdk-deadline/types.rb', line 9928 class UpdateMonitorRequest < Struct.new( :monitor_id, :subdomain, :display_name, :role_arn) SENSITIVE = [] include Aws::Structure end |