Class: Aws::Deadline::Types::UpdateQueueLimitAssociationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-deadline/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#farm_idString

The unique identifier of the farm that contains the associated queues and limits.

Returns:

  • (String)


12080
12081
12082
12083
12084
12085
12086
12087
# File 'lib/aws-sdk-deadline/types.rb', line 12080

class UpdateQueueLimitAssociationRequest < Struct.new(
  :farm_id,
  :queue_id,
  :limit_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#limit_idString

The unique identifier of the limit associated to the queue.

Returns:

  • (String)


12080
12081
12082
12083
12084
12085
12086
12087
# File 'lib/aws-sdk-deadline/types.rb', line 12080

class UpdateQueueLimitAssociationRequest < Struct.new(
  :farm_id,
  :queue_id,
  :limit_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#queue_idString

The unique identifier of the queue associated to the limit.

Returns:

  • (String)


12080
12081
12082
12083
12084
12085
12086
12087
# File 'lib/aws-sdk-deadline/types.rb', line 12080

class UpdateQueueLimitAssociationRequest < Struct.new(
  :farm_id,
  :queue_id,
  :limit_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Sets the status of the limit. You can mark the limit active, or you can stop usage of the limit and either complete existing tasks or cancel any existing tasks immediately.

Returns:

  • (String)


12080
12081
12082
12083
12084
12085
12086
12087
# File 'lib/aws-sdk-deadline/types.rb', line 12080

class UpdateQueueLimitAssociationRequest < Struct.new(
  :farm_id,
  :queue_id,
  :limit_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end