Class: Aws::Deadline::Types::UpdateQueueLimitAssociationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Deadline::Types::UpdateQueueLimitAssociationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-deadline/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#farm_id ⇒ String
The unique identifier of the farm that contains the associated queues and limits.
-
#limit_id ⇒ String
The unique identifier of the limit associated to the queue.
-
#queue_id ⇒ String
The unique identifier of the queue associated to the limit.
-
#status ⇒ String
Sets the status of the limit.
Instance Attribute Details
#farm_id ⇒ String
The unique identifier of the farm that contains the associated queues and limits.
10058 10059 10060 10061 10062 10063 10064 10065 |
# File 'lib/aws-sdk-deadline/types.rb', line 10058 class UpdateQueueLimitAssociationRequest < Struct.new( :farm_id, :queue_id, :limit_id, :status) SENSITIVE = [] include Aws::Structure end |
#limit_id ⇒ String
The unique identifier of the limit associated to the queue.
10058 10059 10060 10061 10062 10063 10064 10065 |
# File 'lib/aws-sdk-deadline/types.rb', line 10058 class UpdateQueueLimitAssociationRequest < Struct.new( :farm_id, :queue_id, :limit_id, :status) SENSITIVE = [] include Aws::Structure end |
#queue_id ⇒ String
The unique identifier of the queue associated to the limit.
10058 10059 10060 10061 10062 10063 10064 10065 |
# File 'lib/aws-sdk-deadline/types.rb', line 10058 class UpdateQueueLimitAssociationRequest < Struct.new( :farm_id, :queue_id, :limit_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Sets the status of the limit. You can mark the limit active, or you can stop usage of the limit and either complete existing tasks or cancel any existing tasks immediately.
10058 10059 10060 10061 10062 10063 10064 10065 |
# File 'lib/aws-sdk-deadline/types.rb', line 10058 class UpdateQueueLimitAssociationRequest < Struct.new( :farm_id, :queue_id, :limit_id, :status) SENSITIVE = [] include Aws::Structure end |