Class: Aws::Deadline::Waiters::JobComplete
- Inherits:
-
Object
- Object
- Aws::Deadline::Waiters::JobComplete
- Defined in:
- lib/aws-sdk-deadline/waiters.rb
Overview
Wait until a job reaches any terminal status. Waits up to 1 hour by default.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ JobComplete
constructor
A new instance of JobComplete.
-
#wait(params = {}) ⇒ Types::GetJobResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ JobComplete
Returns a new instance of JobComplete.
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/aws-sdk-deadline/waiters.rb', line 145 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 240, delay: 15, poller: Aws::Waiters::Poller.new( operation_name: :get_job, acceptors: [ { "matcher" => "path", "argument" => "task_run_status", "state" => "success", "expected" => "SUCCEEDED" }, { "matcher" => "path", "argument" => "task_run_status", "state" => "success", "expected" => "FAILED" }, { "matcher" => "path", "argument" => "task_run_status", "state" => "success", "expected" => "CANCELED" }, { "matcher" => "path", "argument" => "task_run_status", "state" => "success", "expected" => "SUSPENDED" }, { "matcher" => "path", "argument" => "task_run_status", "state" => "success", "expected" => "NOT_COMPATIBLE" }, { "matcher" => "path", "argument" => "lifecycle_status", "state" => "success", "expected" => "ARCHIVED" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
201 202 203 |
# File 'lib/aws-sdk-deadline/waiters.rb', line 201 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetJobResponse
Returns a response object which responds to the following methods:
-
#job_id => String
-
#name => String
-
#lifecycle_status => String
-
#lifecycle_status_message => String
-
#priority => Integer
-
#created_at => Time
-
#created_by => String
-
#updated_at => Time
-
#updated_by => String
-
#started_at => Time
-
#ended_at => Time
-
#task_run_status => String
-
#target_task_run_status => String
-
#task_run_status_counts => Hash<String,Integer>
-
#task_failure_retry_count => Integer
-
#storage_profile_id => String
-
#max_failed_tasks_count => Integer
-
#max_retries_per_task => Integer
-
#parameters => Hash<String,Types::JobParameter>
-
#attachments => Types::Attachments
-
#description => String
-
#max_worker_count => Integer
-
#source_job_id => String
196 197 198 |
# File 'lib/aws-sdk-deadline/waiters.rb', line 196 def wait(params = {}) @waiter.wait(client: @client, params: params) end |