Class: Aws::Deadline::Waiters::QueueLimitAssociationStopped
- Inherits:
-
Object
- Object
- Aws::Deadline::Waiters::QueueLimitAssociationStopped
- Defined in:
- lib/aws-sdk-deadline/waiters.rb,
sig/waiters.rbs
Overview
Wait until a QueueLimitAssociation is stopped. Use this after setting the status to STOP_LIMIT_USAGE_AND_COMPLETE_TASKS or STOP_LIMIT_USAGE_AND_CANCEL_TASKS to wait for a QueueLimitAssociation to reach STOPPED
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ QueueLimitAssociationStopped
constructor
A new instance of QueueLimitAssociationStopped.
-
#wait(params = {}) ⇒ Types::GetQueueLimitAssociationResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ QueueLimitAssociationStopped
Returns a new instance of QueueLimitAssociationStopped.
478 479 |
# File 'lib/aws-sdk-deadline/waiters.rb', line 478
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
502 503 504 |
# File 'lib/aws-sdk-deadline/waiters.rb', line 502 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetQueueLimitAssociationResponse
Returns a response object which responds to the following methods:
- #queue_id => String
- #limit_id => String
- #status => String
- #created_at => Time
- #created_by => String
- #updated_at => Time
- #updated_by => String
497 |
# File 'lib/aws-sdk-deadline/waiters.rb', line 497
def wait: (
|